@@ -850,7 +850,8 @@ namespace Starter_ns {
                 process->line.replace(pos, 1, " ");
             return true;
         } else {
-            std::cerr << fname.str() << ":	" << strerror(errno) << std::endl;
+            //removed because it polluted std error
+            //std::cerr << fname.str() << ":	" << strerror(errno) << std::endl;
             return false;
         }
 #else	//	solaris
