@@ -59,7 +59,7 @@
 #		include <fcntl.h>
 #		include <sys/stat.h>
 #		include <pwd.h>
-#	if (!defined __GLIBC__) && (!defined __darwin__) && (!defined __freebsd__)
+#	if (!defined __linux__) && (!defined __darwin__) && (!defined __freebsd__)
      /* solaris */
 #		include <procfs.h>
 #		include <fcntl.h>
