@@ -216,12 +216,13 @@ namespace Starter_ns {
  */
 //+------------------------------------------------------------------
     char *StarterUtil::strtime(time_t t) {
-        static char str[100];
+        const std::size_t sizeof_str{100};
+        static char str[sizeof_str];
         struct tm *st = localtime(&t);
 
         if (st->tm_year >= 100)
             st->tm_year -= 100;
-        sprintf(str, "%02d/%02d/%02d   %02d:%02d:%02d",
+        snprintf(str, sizeof_str, "%02d/%02d/%02d   %02d:%02d:%02d",
                 st->tm_mday, st->tm_mon + 1, st->tm_year,
                 st->tm_hour, st->tm_min, st->tm_sec);
         return str;
@@ -366,8 +367,9 @@ namespace Starter_ns {
         struct tm *st = localtime(&info.st_mtime);
         if (st->tm_year >= 100)
             st->tm_year -= 100;
-        char strdate[32];
-        sprintf(strdate, "_[20%02d-%02d-%02d_%02d-%02d-%02d]",
+        const std::size_t sizeof_strdate{32};
+        char strdate[sizeof_strdate];
+        snprintf(strdate, sizeof_strdate, "_[20%02d-%02d-%02d_%02d-%02d-%02d]",
                 st->tm_year, st->tm_mon + 1, st->tm_mday,
                 st->tm_hour, st->tm_min, st->tm_sec);
 
