@@ -39,7 +39,7 @@
   #include <net/if.h>
   #include <sys/ioctl.h>
   #include <netdb.h>
-  #include <signal.h>
+  #include <csignal>
   #include <ifaddrs.h>
   #include <netinet/in.h> // FreeBSD
 #else
@@ -50,7 +50,7 @@
 namespace Tango
 {
 
-ApiUtil *ApiUtil::_instance = NULL;
+ApiUtil *ApiUtil::_instance = nullptr;
 
 omni_mutex ApiUtil::inst_mutex;
 
@@ -97,14 +97,11 @@ void ApiUtil::cleanup()
 //------------------------------------------------------------------------------------------------------------------
 
 ApiUtil::ApiUtil() :
-    exit_lock_installed(false),
-    reset_already_executed_flag(false),
+
     ext(new ApiUtilExt),
-    notifd_event_consumer(NULL),
-    cl_pid(0),
-    user_connect_timeout(-1),
-    zmq_event_consumer(NULL),
-    user_sub_hwm(-1)
+
+    cl_pid(0)
+
 {
     _orb = CORBA::ORB::_nil();
 
@@ -112,14 +109,7 @@ ApiUtil::ApiUtil() :
     // Check if it is created from a device server
     //
 
-    if(Util::_constructed == true)
-    {
-        in_serv = true;
-    }
-    else
-    {
-        in_serv = false;
-    }
+    in_serv = Util::_constructed;
 
     //
     // Create the Asynchronous polling request Id generator
@@ -138,7 +128,7 @@ ApiUtil::ApiUtil() :
     //
 
     auto_cb = PULL_CALLBACK;
-    cb_thread_ptr = NULL;
+    cb_thread_ptr = nullptr;
 
     //
     // Get the process PID
@@ -201,10 +191,10 @@ ApiUtil::~ApiUtil()
 
     delete asyn_p_table;
 
-    if(cb_thread_ptr != NULL)
+    if(cb_thread_ptr != nullptr)
     {
         cb_thread_cmd.stop_thread();
-        cb_thread_ptr->join(0);
+        cb_thread_ptr->join(nullptr);
     }
 
     //
@@ -219,9 +209,9 @@ ApiUtil::~ApiUtil()
 
     bool event_was_used = false;
 
-    if(ext.get() != NULL)
+    if(ext != nullptr)
     {
-        if((notifd_event_consumer != NULL) || (zmq_event_consumer != NULL))
+        if((notifd_event_consumer != nullptr) || (zmq_event_consumer != nullptr))
         {
             event_was_used = true;
             leavefunc();
@@ -243,9 +233,9 @@ ApiUtil::~ApiUtil()
     // Properly shutdown the ORB
     //
 
-    if((in_serv == false) && (CORBA::is_nil(_orb) == false))
+    if((!in_serv) && (!CORBA::is_nil(_orb)))
     {
-        if(event_was_used == false)
+        if(!event_was_used)
         {
             try
             {
@@ -271,7 +261,7 @@ ApiUtil::~ApiUtil()
 void ApiUtil::set_sig_handler()
 {
 #ifndef _TG_WINDOWS_
-    if(in_serv == false)
+    if(!in_serv)
     {
         struct sigaction sa, old_action;
 
@@ -279,19 +269,19 @@ void ApiUtil::set_sig_handler()
         sigemptyset(&sa.sa_mask);
         sa.sa_flags = SA_RESTART;
 
-        if(sigaction(SIGTERM, NULL, &old_action) != -1)
+        if(sigaction(SIGTERM, nullptr, &old_action) != -1)
         {
-            if(old_action.sa_handler == NULL)
+            if(old_action.sa_handler == nullptr)
             {
-                sigaction(SIGTERM, &sa, NULL);
+                sigaction(SIGTERM, &sa, nullptr);
             }
         }
 
-        if(sigaction(SIGINT, NULL, &old_action) != -1)
+        if(sigaction(SIGINT, nullptr, &old_action) != -1)
         {
-            if(old_action.sa_handler == NULL)
+            if(old_action.sa_handler == nullptr)
             {
-                sigaction(SIGINT, &sa, NULL);
+                sigaction(SIGINT, &sa, nullptr);
             }
         }
     }
@@ -328,11 +318,11 @@ void ApiUtil::create_orb()
 
 #ifndef _TG_WINDOWS_
     struct sigaction sa;
-    sa.sa_handler = NULL;
+    sa.sa_handler = nullptr;
 
-    if(sigaction(SIGPIPE, NULL, &sa) == -1)
+    if(sigaction(SIGPIPE, nullptr, &sa) == -1)
     {
-        sa.sa_handler = NULL;
+        sa.sa_handler = nullptr;
     }
 #endif
 
@@ -344,7 +334,7 @@ void ApiUtil::create_orb()
                                 {"giopMaxMsgSize", MAX_TRANSFER_SIZE},
                                 {"throwTransientOnTimeOut", "1"},
                                 {"exceptionIdInAny", "0"},
-                                {0, 0}};
+                                {nullptr, nullptr}};
 
     _orb = CORBA::ORB_init(_argc, _argv, "omniORB4", options);
 
@@ -355,13 +345,13 @@ void ApiUtil::create_orb()
     //
 
 #ifndef _TG_WINDOWS_
-    if(sa.sa_handler != NULL)
+    if(sa.sa_handler != nullptr)
     {
         struct sigaction sb;
 
         sb = sa;
 
-        if(sigaction(SIGPIPE, &sb, NULL) == -1)
+        if(sigaction(SIGPIPE, &sb, nullptr) == -1)
         {
             std::cerr << "Can re-install user signal handler for SIGPIPE!" << std::endl;
         }
@@ -385,7 +375,7 @@ int ApiUtil::get_db_ind()
 
     for(unsigned int i = 0; i < db_vect.size(); i++)
     {
-        if(db_vect[i]->get_from_env_var() == true)
+        if(db_vect[i]->get_from_env_var())
         {
             return i;
         }
@@ -443,7 +433,7 @@ void ApiUtil::get_asynch_replies()
 
     try
     {
-        while(_orb->poll_next_response() == true)
+        while(_orb->poll_next_response())
         {
             CORBA::Request_ptr req;
             _orb->get_next_response(req);
@@ -481,7 +471,7 @@ void ApiUtil::get_asynch_replies()
 
     for(pos = req_table.begin(); pos != req_table.end(); ++pos)
     {
-        if(pos->second.arrived == true)
+        if(pos->second.arrived)
         {
             process_request(pos->first, pos->second, pos->second.request);
         }
@@ -535,7 +525,7 @@ void ApiUtil::get_asynch_replies(long call_timeout)
 
     for(pos = req_table.begin(); pos != req_table.end(); ++pos)
     {
-        if(pos->second.arrived == true)
+        if(pos->second.arrived)
         {
             switch(pos->second.req_type)
             {
@@ -581,7 +571,7 @@ void ApiUtil::get_asynch_replies(long call_timeout)
 
                 try
                 {
-                    if(_orb->poll_next_response() == true)
+                    if(_orb->poll_next_response())
                     {
                         _orb->get_next_response(req);
 
@@ -635,7 +625,7 @@ void ApiUtil::get_asynch_replies(long call_timeout)
             {
                 TangoSys_OMemStream desc;
                 desc << "Still some reply(ies) for asynchronous callback call(s) to be received" << std::ends;
-                TANGO_THROW_API_EXCEPTION(ApiAsynNotThereExcept, API_AsynReplyNotArrived, desc.str());
+                TANGO_THROW_DETAILED_EXCEPTION(ApiAsynNotThereExcept, API_AsynReplyNotArrived, desc.str());
             }
         }
         else
@@ -719,7 +709,7 @@ void ApiUtil::set_asynch_cb_sub_model(cb_sub_model mode)
             //
 
             delete cb_thread_ptr;
-            cb_thread_ptr = NULL;
+            cb_thread_ptr = nullptr;
 
             cb_thread_cmd.start_thread();
 
@@ -792,12 +782,12 @@ void ApiUtil::clean_locking_threads(bool clean)
 {
     omni_mutex_lock oml(lock_th_map);
 
-    if(lock_threads.empty() == false)
+    if(!lock_threads.empty())
     {
         std::map<std::string, LockingThread>::iterator pos;
         for(pos = lock_threads.begin(); pos != lock_threads.end(); ++pos)
         {
-            if(pos->second.shared->suicide == true)
+            if(pos->second.shared->suicide)
             {
                 delete pos->second.shared;
                 delete pos->second.mon;
@@ -808,7 +798,7 @@ void ApiUtil::clean_locking_threads(bool clean)
                     omni_mutex_lock sync(*(pos->second.mon));
 
                     pos->second.shared->cmd_pending = true;
-                    if(clean == true)
+                    if(clean)
                     {
                         pos->second.shared->cmd_code = LOCK_UNLOCK_ALL_EXIT;
                     }
@@ -821,7 +811,7 @@ void ApiUtil::clean_locking_threads(bool clean)
 
                     TANGO_LOG_DEBUG << "Cmd sent to locking thread" << std::endl;
 
-                    if(pos->second.shared->cmd_pending == true)
+                    if(pos->second.shared->cmd_pending)
                     {
                         pos->second.mon->wait(DEFAULT_TIMEOUT);
                     }
@@ -831,7 +821,7 @@ void ApiUtil::clean_locking_threads(bool clean)
             }
         }
 
-        if(clean == false)
+        if(!clean)
         {
             lock_threads.clear();
         }
@@ -936,7 +926,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_lo->maximum();
             len = tmp_seq_lo->length();
-            if(tmp_seq_lo->release() == true)
+            if(tmp_seq_lo->release())
             {
                 tmp_lo = (const_cast<DevVarLongArray *>(tmp_seq_lo))->get_buffer((CORBA::Boolean) true);
                 dev_attr->LongSeq = new DevVarLongArray(max, len, tmp_lo, true);
@@ -960,7 +950,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_64->maximum();
             len = tmp_seq_64->length();
-            if(tmp_seq_64->release() == true)
+            if(tmp_seq_64->release())
             {
                 tmp_lolo = (const_cast<DevVarLong64Array *>(tmp_seq_64))->get_buffer((CORBA::Boolean) true);
                 dev_attr->Long64Seq = new DevVarLong64Array(max, len, tmp_lolo, true);
@@ -984,7 +974,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_sh->maximum();
             len = tmp_seq_sh->length();
-            if(tmp_seq_sh->release() == true)
+            if(tmp_seq_sh->release())
             {
                 tmp_sh = (const_cast<DevVarShortArray *>(tmp_seq_sh))->get_buffer((CORBA::Boolean) true);
                 dev_attr->ShortSeq = new DevVarShortArray(max, len, tmp_sh, true);
@@ -1008,7 +998,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_db->maximum();
             len = tmp_seq_db->length();
-            if(tmp_seq_db->release() == true)
+            if(tmp_seq_db->release())
             {
                 tmp_db = (const_cast<DevVarDoubleArray *>(tmp_seq_db))->get_buffer((CORBA::Boolean) true);
                 dev_attr->DoubleSeq = new DevVarDoubleArray(max, len, tmp_db, true);
@@ -1032,7 +1022,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_str->maximum();
             len = tmp_seq_str->length();
-            if(tmp_seq_str->release() == true)
+            if(tmp_seq_str->release())
             {
                 tmp_str = (const_cast<DevVarStringArray *>(tmp_seq_str))->get_buffer((CORBA::Boolean) true);
                 dev_attr->StringSeq = new DevVarStringArray(max, len, tmp_str, true);
@@ -1056,7 +1046,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_fl->maximum();
             len = tmp_seq_fl->length();
-            if(tmp_seq_fl->release() == true)
+            if(tmp_seq_fl->release())
             {
                 tmp_fl = (const_cast<DevVarFloatArray *>(tmp_seq_fl))->get_buffer((CORBA::Boolean) true);
                 dev_attr->FloatSeq = new DevVarFloatArray(max, len, tmp_fl, true);
@@ -1080,7 +1070,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_boo->maximum();
             len = tmp_seq_boo->length();
-            if(tmp_seq_boo->release() == true)
+            if(tmp_seq_boo->release())
             {
                 tmp_boo = (const_cast<DevVarBooleanArray *>(tmp_seq_boo))->get_buffer((CORBA::Boolean) true);
                 dev_attr->BooleanSeq = new DevVarBooleanArray(max, len, tmp_boo, true);
@@ -1104,7 +1094,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_ush->maximum();
             len = tmp_seq_ush->length();
-            if(tmp_seq_ush->release() == true)
+            if(tmp_seq_ush->release())
             {
                 tmp_ush = (const_cast<DevVarUShortArray *>(tmp_seq_ush))->get_buffer((CORBA::Boolean) true);
                 dev_attr->UShortSeq = new DevVarUShortArray(max, len, tmp_ush, true);
@@ -1128,7 +1118,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_uch->maximum();
             len = tmp_seq_uch->length();
-            if(tmp_seq_uch->release() == true)
+            if(tmp_seq_uch->release())
             {
                 tmp_uch = (const_cast<DevVarCharArray *>(tmp_seq_uch))->get_buffer((CORBA::Boolean) true);
                 dev_attr->UCharSeq = new DevVarCharArray(max, len, tmp_uch, true);
@@ -1152,7 +1142,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_ulo->maximum();
             len = tmp_seq_ulo->length();
-            if(tmp_seq_ulo->release() == true)
+            if(tmp_seq_ulo->release())
             {
                 tmp_ulo = (const_cast<DevVarULongArray *>(tmp_seq_ulo))->get_buffer((CORBA::Boolean) true);
                 dev_attr->ULongSeq = new DevVarULongArray(max, len, tmp_ulo, true);
@@ -1176,7 +1166,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_u64->maximum();
             len = tmp_seq_u64->length();
-            if(tmp_seq_u64->release() == true)
+            if(tmp_seq_u64->release())
             {
                 tmp_ulolo = (const_cast<DevVarULong64Array *>(tmp_seq_u64))->get_buffer((CORBA::Boolean) true);
                 dev_attr->ULong64Seq = new DevVarULong64Array(max, len, tmp_ulolo, true);
@@ -1200,7 +1190,7 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
             }
             max = tmp_seq_state->maximum();
             len = tmp_seq_state->length();
-            if(tmp_seq_state->release() == true)
+            if(tmp_seq_state->release())
             {
                 tmp_state = (const_cast<DevVarStateArray *>(tmp_seq_state))->get_buffer((CORBA::Boolean) true);
                 dev_attr->StateSeq = new DevVarStateArray(max, len, tmp_state, true);
@@ -1214,7 +1204,10 @@ void ApiUtil::attr_to_device(const AttributeValue *attr_value,
 
         default:
             dev_attr->data_type = Tango::DATA_TYPE_UNKNOWN;
-            TANGO_THROW_ON_DEFAULT(ty_seq->kind());
+            TangoSys_OMemStream desc;
+            desc << (vers == 3 ? "'attr_value_3" : "'attr_value") << "->value' with unexpected sequence kind '"
+                 << ty_seq->kind() << "'.";
+            TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
         }
     }
 }
@@ -1255,55 +1248,55 @@ void ApiUtil::device_to_attr(const DeviceAttribute &dev_attr, AttributeValue_4 &
     att.w_dim.dim_y = dev_attr.dim_y;
     att.data_format = Tango::FMT_UNKNOWN;
 
-    if(dev_attr.LongSeq.operator->() != NULL)
+    if(dev_attr.LongSeq.operator->() != nullptr)
     {
         att.value.long_att_value(dev_attr.LongSeq.in());
     }
-    else if(dev_attr.ShortSeq.operator->() != NULL)
+    else if(dev_attr.ShortSeq.operator->() != nullptr)
     {
         att.value.short_att_value(dev_attr.ShortSeq.in());
     }
-    else if(dev_attr.DoubleSeq.operator->() != NULL)
+    else if(dev_attr.DoubleSeq.operator->() != nullptr)
     {
         att.value.double_att_value(dev_attr.DoubleSeq.in());
     }
-    else if(dev_attr.StringSeq.operator->() != NULL)
+    else if(dev_attr.StringSeq.operator->() != nullptr)
     {
         att.value.string_att_value(dev_attr.StringSeq.in());
     }
-    else if(dev_attr.FloatSeq.operator->() != NULL)
+    else if(dev_attr.FloatSeq.operator->() != nullptr)
     {
         att.value.float_att_value(dev_attr.FloatSeq.in());
     }
-    else if(dev_attr.BooleanSeq.operator->() != NULL)
+    else if(dev_attr.BooleanSeq.operator->() != nullptr)
     {
         att.value.bool_att_value(dev_attr.BooleanSeq.in());
     }
-    else if(dev_attr.UShortSeq.operator->() != NULL)
+    else if(dev_attr.UShortSeq.operator->() != nullptr)
     {
         att.value.ushort_att_value(dev_attr.UShortSeq.in());
     }
-    else if(dev_attr.UCharSeq.operator->() != NULL)
+    else if(dev_attr.UCharSeq.operator->() != nullptr)
     {
         att.value.uchar_att_value(dev_attr.UCharSeq.in());
     }
-    else if(dev_attr.Long64Seq.operator->() != NULL)
+    else if(dev_attr.Long64Seq.operator->() != nullptr)
     {
         att.value.long64_att_value(dev_attr.Long64Seq.in());
     }
-    else if(dev_attr.ULongSeq.operator->() != NULL)
+    else if(dev_attr.ULongSeq.operator->() != nullptr)
     {
         att.value.ulong_att_value(dev_attr.ULongSeq.in());
     }
-    else if(dev_attr.ULong64Seq.operator->() != NULL)
+    else if(dev_attr.ULong64Seq.operator->() != nullptr)
     {
         att.value.ulong64_att_value(dev_attr.ULong64Seq.in());
     }
-    else if(dev_attr.StateSeq.operator->() != NULL)
+    else if(dev_attr.StateSeq.operator->() != nullptr)
     {
         att.value.state_att_value(dev_attr.StateSeq.in());
     }
-    else if(dev_attr.EncodedSeq.operator->() != NULL)
+    else if(dev_attr.EncodedSeq.operator->() != nullptr)
     {
         att.value.encoded_att_value(dev_attr.EncodedSeq.in());
     }
@@ -1317,60 +1310,60 @@ void ApiUtil::device_to_attr(const DeviceAttribute &dev_attr, AttributeValue &at
     att.dim_x = dev_attr.dim_x;
     att.dim_y = dev_attr.dim_y;
 
-    if(dev_attr.LongSeq.operator->() != NULL)
+    if(dev_attr.LongSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.LongSeq.in();
     }
-    else if(dev_attr.ShortSeq.operator->() != NULL)
+    else if(dev_attr.ShortSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.ShortSeq.in();
     }
-    else if(dev_attr.DoubleSeq.operator->() != NULL)
+    else if(dev_attr.DoubleSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.DoubleSeq.in();
     }
-    else if(dev_attr.StringSeq.operator->() != NULL)
+    else if(dev_attr.StringSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.StringSeq.in();
     }
-    else if(dev_attr.FloatSeq.operator->() != NULL)
+    else if(dev_attr.FloatSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.FloatSeq.in();
     }
-    else if(dev_attr.BooleanSeq.operator->() != NULL)
+    else if(dev_attr.BooleanSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.BooleanSeq.in();
     }
-    else if(dev_attr.UShortSeq.operator->() != NULL)
+    else if(dev_attr.UShortSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.UShortSeq.in();
     }
-    else if(dev_attr.UCharSeq.operator->() != NULL)
+    else if(dev_attr.UCharSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.UCharSeq.in();
     }
-    else if(dev_attr.Long64Seq.operator->() != NULL)
+    else if(dev_attr.Long64Seq.operator->() != nullptr)
     {
         att.value <<= dev_attr.Long64Seq.in();
     }
-    else if(dev_attr.ULongSeq.operator->() != NULL)
+    else if(dev_attr.ULongSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.ULongSeq.in();
     }
-    else if(dev_attr.ULong64Seq.operator->() != NULL)
+    else if(dev_attr.ULong64Seq.operator->() != nullptr)
     {
         att.value <<= dev_attr.ULong64Seq.in();
     }
-    else if(dev_attr.StateSeq.operator->() != NULL)
+    else if(dev_attr.StateSeq.operator->() != nullptr)
     {
         att.value <<= dev_attr.StateSeq.in();
     }
-    else if(dev_attr.EncodedSeq.operator->() != NULL)
+    else if(dev_attr.EncodedSeq.operator->() != nullptr)
     {
         TangoSys_OMemStream desc;
         desc << "Device " << d_name;
         desc << " does not support DevEncoded data type" << std::ends;
-        TANGO_THROW_API_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, desc.str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, desc.str());
     }
 }
 
@@ -1428,7 +1421,7 @@ void ApiUtil::AttributeInfoEx_to_AttributeConfig(const AttributeInfoEx *aie, Att
         break;
 
     default:
-        TANGO_THROW_ON_DEFAULT(aie->memorized);
+        TANGO_ASSERT_ON_DEFAULT(aie->memorized);
     }
     att_conf_5->enum_labels.length(aie->enum_labels.size());
     for(size_t j = 0; j < aie->enum_labels.size(); j++)
@@ -1521,7 +1514,7 @@ void ApiUtil::get_ip_from_if(std::vector<std::string> &ip_adr_list)
 {
     omni_mutex_lock oml(lock_th_map);
 
-    if(host_ip_adrs.empty() == true)
+    if(host_ip_adrs.empty())
     {
 #ifndef _TG_WINDOWS_
         struct ifaddrs *ifaddr, *ifa;
@@ -1541,9 +1534,9 @@ void ApiUtil::get_ip_from_if(std::vector<std::string> &ip_adr_list)
         // format of the address structure.)
         //
 
-        for(ifa = ifaddr; ifa != NULL; ifa = ifa->ifa_next)
+        for(ifa = ifaddr; ifa != nullptr; ifa = ifa->ifa_next)
         {
-            if(ifa->ifa_addr != NULL)
+            if(ifa->ifa_addr != nullptr)
             {
                 family = ifa->ifa_addr->sa_family;
 
@@ -1559,7 +1552,7 @@ void ApiUtil::get_ip_from_if(std::vector<std::string> &ip_adr_list)
                 if(family == AF_INET)
                 {
                     s = getnameinfo(
-                        ifa->ifa_addr, sizeof(struct sockaddr_in), host, NI_MAXHOST, NULL, 0, NI_NUMERICHOST);
+                        ifa->ifa_addr, sizeof(struct sockaddr_in), host, NI_MAXHOST, nullptr, 0, NI_NUMERICHOST);
 
                     if(s != 0)
                     {
@@ -1572,7 +1565,7 @@ void ApiUtil::get_ip_from_if(std::vector<std::string> &ip_adr_list)
                     }
                     else
                     {
-                        host_ip_adrs.push_back(std::string(host));
+                        host_ip_adrs.emplace_back(host);
                     }
                 }
             }
@@ -1587,6 +1580,14 @@ void ApiUtil::get_ip_from_if(std::vector<std::string> &ip_adr_list)
 
         int sock = socket(AF_INET, SOCK_STREAM, 0);
 
+        if(sock == INVALID_SOCKET)
+        {
+            int err = WSAGetLastError();
+            TangoSys_OMemStream desc;
+            desc << "Unable to create socket! Error = " << err;
+            TANGO_THROW_EXCEPTION(API_SystemCallFailed, desc.str().c_str());
+        }
+
         INTERFACE_INFO info[64]; // Assume max 64 interfaces
         DWORD retlen;
 
@@ -1666,7 +1667,7 @@ void ApiUtil::get_ip_from_if(std::vector<std::string> &ip_adr_list)
 
 void ApiUtil::print_error_message(const char *mess)
 {
-    std::tm tm = Tango_localtime(time(NULL));
+    const std::tm tm = Tango_localtime(Tango::get_current_system_datetime());
     std::cerr << std::put_time(&tm, "%c") << ": " << mess << std::endl;
 }
 
@@ -1881,13 +1882,13 @@ AttributeInfoEx &AttributeInfoEx::operator=(const AttributeConfig_5 *att_5)
     }
     disp_level = att_5->level;
     root_attr_name = att_5->root_attr_name;
-    if(att_5->memorized == false)
+    if(!att_5->memorized)
     {
         memorized = NONE;
     }
     else
     {
-        if(att_5->mem_init == false)
+        if(!att_5->mem_init)
         {
             memorized = MEMORIZED;
         }
@@ -1899,7 +1900,7 @@ AttributeInfoEx &AttributeInfoEx::operator=(const AttributeConfig_5 *att_5)
     enum_labels.clear();
     for(unsigned int j = 0; j < att_5->enum_labels.length(); j++)
     {
-        enum_labels.push_back(att_5->enum_labels[j].in());
+        enum_labels.emplace_back(att_5->enum_labels[j].in());
     }
 
     alarms.min_alarm = att_5->att_alarm.min_alarm;
@@ -1982,7 +1983,7 @@ std::ostream &operator<<(std::ostream &o_str, const AttributeInfoEx &p)
         // do nothing
         break;
     default:
-        TANGO_THROW_ON_DEFAULT(p.data_format);
+        TANGO_ASSERT_ON_DEFAULT(p.data_format);
     }
 
     o_str << "Attribute writable type = " << p.writable << std::endl;
@@ -2008,14 +2009,14 @@ std::ostream &operator<<(std::ostream &o_str, const AttributeInfoEx &p)
             break;
 
         default:
-            TANGO_THROW_ON_DEFAULT(p.data_format);
+            TANGO_ASSERT_ON_DEFAULT(p.data_format);
         }
     }
 
     o_str << "Attribute display level = " << p.disp_level << std::endl;
 
     o_str << "Attribute writable_attr_name = " << p.writable_attr_name << std::endl;
-    if(p.root_attr_name.empty() == false)
+    if(!p.root_attr_name.empty())
     {
         o_str << "Root attribute name = " << p.root_attr_name << std::endl;
     }
@@ -2035,27 +2036,27 @@ std::ostream &operator<<(std::ostream &o_str, const AttributeInfoEx &p)
     }
 
     o_str << "Attribute alarm : min alarm = ";
-    p.alarms.min_alarm.empty() == true ? o_str << "Not specified" : o_str << p.alarms.min_alarm;
+    p.alarms.min_alarm.empty() ? o_str << "Not specified" : o_str << p.alarms.min_alarm;
     o_str << std::endl;
 
     o_str << "Attribute alarm : max alarm = ";
-    p.alarms.max_alarm.empty() == true ? o_str << "Not specified" : o_str << p.alarms.max_alarm;
+    p.alarms.max_alarm.empty() ? o_str << "Not specified" : o_str << p.alarms.max_alarm;
     o_str << std::endl;
 
     o_str << "Attribute warning alarm : min warning = ";
-    p.alarms.min_warning.empty() == true ? o_str << "Not specified" : o_str << p.alarms.min_warning;
+    p.alarms.min_warning.empty() ? o_str << "Not specified" : o_str << p.alarms.min_warning;
     o_str << std::endl;
 
     o_str << "Attribute warning alarm : max warning = ";
-    p.alarms.max_warning.empty() == true ? o_str << "Not specified" : o_str << p.alarms.max_warning;
+    p.alarms.max_warning.empty() ? o_str << "Not specified" : o_str << p.alarms.max_warning;
     o_str << std::endl;
 
     o_str << "Attribute rds alarm : delta time = ";
-    p.alarms.delta_t.empty() == true ? o_str << "Not specified" : o_str << p.alarms.delta_t;
+    p.alarms.delta_t.empty() ? o_str << "Not specified" : o_str << p.alarms.delta_t;
     o_str << std::endl;
 
     o_str << "Attribute rds alarm : delta value = ";
-    p.alarms.delta_val.empty() == true ? o_str << "Not specified" : o_str << p.alarms.delta_val;
+    p.alarms.delta_val.empty() ? o_str << "Not specified" : o_str << p.alarms.delta_val;
     o_str << std::endl;
 
     for(i = 0; i < p.alarms.extensions.size(); i++)
@@ -2064,11 +2065,11 @@ std::ostream &operator<<(std::ostream &o_str, const AttributeInfoEx &p)
     }
 
     o_str << "Attribute event : change event absolute change = ";
-    p.events.ch_event.abs_change.empty() == true ? o_str << "Not specified" : o_str << p.events.ch_event.abs_change;
+    p.events.ch_event.abs_change.empty() ? o_str << "Not specified" : o_str << p.events.ch_event.abs_change;
     o_str << std::endl;
 
     o_str << "Attribute event : change event relative change = ";
-    p.events.ch_event.rel_change.empty() == true ? o_str << "Not specified" : o_str << p.events.ch_event.rel_change;
+    p.events.ch_event.rel_change.empty() ? o_str << "Not specified" : o_str << p.events.ch_event.rel_change;
     o_str << std::endl;
 
     for(i = 0; i < p.events.ch_event.extensions.size(); i++)
@@ -2078,7 +2079,7 @@ std::ostream &operator<<(std::ostream &o_str, const AttributeInfoEx &p)
     }
 
     o_str << "Attribute event : periodic event period = ";
-    p.events.per_event.period.empty() == true ? o_str << "Not specified" : o_str << p.events.per_event.period;
+    p.events.per_event.period.empty() ? o_str << "Not specified" : o_str << p.events.per_event.period;
     o_str << std::endl;
 
     for(i = 0; i < p.events.per_event.extensions.size(); i++)
@@ -2088,18 +2089,17 @@ std::ostream &operator<<(std::ostream &o_str, const AttributeInfoEx &p)
     }
 
     o_str << "Attribute event : archive event absolute change = ";
-    p.events.arch_event.archive_abs_change.empty() == true ? o_str << "Not specified"
-                                                           : o_str << p.events.arch_event.archive_abs_change;
+    p.events.arch_event.archive_abs_change.empty() ? o_str << "Not specified"
+                                                   : o_str << p.events.arch_event.archive_abs_change;
     o_str << std::endl;
 
     o_str << "Attribute event : archive event relative change = ";
-    p.events.arch_event.archive_rel_change.empty() == true ? o_str << "Not specified"
-                                                           : o_str << p.events.arch_event.archive_rel_change;
+    p.events.arch_event.archive_rel_change.empty() ? o_str << "Not specified"
+                                                   : o_str << p.events.arch_event.archive_rel_change;
     o_str << std::endl;
 
     o_str << "Attribute event : archive event period = ";
-    p.events.arch_event.archive_period.empty() == true ? o_str << "Not specified"
-                                                       : o_str << p.events.arch_event.archive_period;
+    p.events.arch_event.archive_period.empty() ? o_str << "Not specified" : o_str << p.events.arch_event.archive_period;
     o_str << std::endl;
 
     for(i = 0; i < p.events.arch_event.extensions.size(); i++)
