@@ -210,7 +210,7 @@ DbServerCache::DbServerCache(Database *db, const std::string &ds_name, const std
         }
         else
         {
-            classes_idx[cl_loop].class_pipe_prop.atts_idx = NULL;
+            classes_idx[cl_loop].class_pipe_prop.atts_idx = nullptr;
         }
 
         //
@@ -250,7 +250,7 @@ DbServerCache::DbServerCache(Database *db, const std::string &ds_name, const std
             }
             else
             {
-                classes_idx[cl_loop].devs_idx[loop].dev_pipe_prop.atts_idx = NULL;
+                classes_idx[cl_loop].devs_idx[loop].dev_pipe_prop.atts_idx = nullptr;
             }
         }
     }
@@ -507,7 +507,7 @@ void DbServerCache::get_obj_prop(DevVarStringArray *in_param, PropEltIdx &obj, b
         {
             int old_length = ret_length;
             ret_length = ret_length + 2;
-            if(dev_prop == true)
+            if(dev_prop)
             {
                 ret_length++;
             }
@@ -515,7 +515,7 @@ void DbServerCache::get_obj_prop(DevVarStringArray *in_param, PropEltIdx &obj, b
             ret_obj_prop.length(ret_length);
             ret_obj_prop[old_length] = Tango::string_dup((*in_param)[loop + 1]);
             ret_obj_prop[old_length + 1] = Tango::string_dup("0");
-            if(dev_prop == true)
+            if(dev_prop)
             {
                 ret_obj_prop[old_length + 2] = Tango::string_dup(" ");
             }
@@ -939,30 +939,30 @@ DbServerCache::~DbServerCache()
 
     for(int cl_loop = 0; cl_loop < class_nb; cl_loop++)
     {
-        if(classes_idx[cl_loop].class_prop.props_idx != NULL)
+        if(classes_idx[cl_loop].class_prop.props_idx != nullptr)
         {
             delete[] classes_idx[cl_loop].class_prop.props_idx;
         }
-        if(classes_idx[cl_loop].class_att_prop.atts_idx != NULL)
+        if(classes_idx[cl_loop].class_att_prop.atts_idx != nullptr)
         {
             delete[] classes_idx[cl_loop].class_att_prop.atts_idx;
         }
-        if(classes_idx[cl_loop].class_pipe_prop.atts_idx != NULL)
+        if(classes_idx[cl_loop].class_pipe_prop.atts_idx != nullptr)
         {
             delete[] classes_idx[cl_loop].class_pipe_prop.atts_idx;
         }
 
         for(int dev_loop = 0; dev_loop < classes_idx[cl_loop].dev_nb; dev_loop++)
         {
-            if(classes_idx[cl_loop].devs_idx[dev_loop].dev_prop.props_idx != NULL)
+            if(classes_idx[cl_loop].devs_idx[dev_loop].dev_prop.props_idx != nullptr)
             {
                 delete[] classes_idx[cl_loop].devs_idx[dev_loop].dev_prop.props_idx;
             }
-            if(classes_idx[cl_loop].devs_idx[dev_loop].dev_att_prop.atts_idx != NULL)
+            if(classes_idx[cl_loop].devs_idx[dev_loop].dev_att_prop.atts_idx != nullptr)
             {
                 delete[] classes_idx[cl_loop].devs_idx[dev_loop].dev_att_prop.atts_idx;
             }
-            if(classes_idx[cl_loop].devs_idx[dev_loop].dev_pipe_prop.atts_idx != NULL)
+            if(classes_idx[cl_loop].devs_idx[dev_loop].dev_pipe_prop.atts_idx != nullptr)
             {
                 delete[] classes_idx[cl_loop].devs_idx[dev_loop].dev_pipe_prop.atts_idx;
             }
@@ -998,7 +998,7 @@ void DbServerCache::prop_indexes(int &start, int &stop, PropEltIdx &obj, const D
         obj.last_idx = stop;
         obj.first_idx = start;
         obj.prop_nb = 0;
-        obj.props_idx = NULL;
+        obj.props_idx = nullptr;
         return;
     }
     stop = stop + 2;
@@ -1048,7 +1048,7 @@ void DbServerCache::prop_att_indexes(int &start, int &stop, AttPropEltIdx &obj,
         obj.last_idx = stop;
         obj.first_idx = start;
         obj.att_nb = 0;
-        obj.atts_idx = NULL;
+        obj.atts_idx = nullptr;
         return;
     }
 
@@ -1107,7 +1107,7 @@ void DbServerCache::prop_pipe_indexes(int &start, int &stop, AttPropEltIdx &obj,
         obj.last_idx = stop;
         obj.first_idx = start;
         obj.att_nb = 0;
-        obj.atts_idx = NULL;
+        obj.atts_idx = nullptr;
         return;
     }
 
@@ -1316,11 +1316,11 @@ void DbServerCache::get_obj_prop_list(DevVarStringArray *in_param, PropEltIdx &o
         //
 
         bool store = false;
-        if(wildcard_used == true)
+        if(wildcard_used)
         {
-            if(before == false)
+            if(!before)
             {
-                if(after == false)
+                if(!after)
                 {
                     store = true;
                 }
@@ -1341,7 +1341,7 @@ void DbServerCache::get_obj_prop_list(DevVarStringArray *in_param, PropEltIdx &o
                 std::string tmp_name((*data_list)[obj.props_idx[lo]]);
                 std::transform(tmp_name.begin(), tmp_name.end(), tmp_name.begin(), ::tolower);
 
-                if(after == false)
+                if(!after)
                 {
                     pos_before = tmp_name.find(before_str);
                     if((pos_before != std::string::npos) && (pos_before == 0))
@@ -1376,7 +1376,7 @@ void DbServerCache::get_obj_prop_list(DevVarStringArray *in_param, PropEltIdx &o
         // Store the property name if decided
         //
 
-        if(store == true)
+        if(store)
         {
             ret_prop_list.length(ret_length);
             ret_prop_list[ret_length - 1] = Tango::string_dup((*data_list)[obj.props_idx[lo]]);
