@@ -31,6 +31,7 @@
 
 #include <tango/tango.h>
 #include <iomanip>
+#include <memory>
 
 using namespace CORBA;
 
@@ -44,13 +45,13 @@ namespace Tango
 //-----------------------------------------------------------------------------
 
 DeviceDataHistory::DeviceDataHistory() :
-    DeviceData(),
+
     ext_hist(nullptr)
 {
     fail = false;
     err = new DevErrorList();
-    seq_ptr = NULL;
-    ref_ctr_ptr = NULL;
+    seq_ptr = nullptr;
+    ref_ctr_ptr = nullptr;
 }
 
 DeviceDataHistory::DeviceDataHistory(int n, int *ref, DevCmdHistoryList *ptr) :
@@ -77,15 +78,15 @@ DeviceDataHistory::DeviceDataHistory(const DeviceDataHistory &source) :
 
     seq_ptr = source.seq_ptr;
     ref_ctr_ptr = source.ref_ctr_ptr;
-    if(ref_ctr_ptr != NULL)
+    if(ref_ctr_ptr != nullptr)
     {
         (*ref_ctr_ptr)++;
     }
 
-    if(source.ext_hist.get() != NULL)
+    if(source.ext_hist != nullptr)
     {
-        ext_hist.reset(new DeviceDataHistoryExt);
-        *(ext_hist.get()) = *(source.ext_hist.get());
+        ext_hist = std::make_unique<DeviceDataHistoryExt>();
+        *(ext_hist) = *(source.ext_hist);
     }
 }
 
@@ -100,7 +101,7 @@ DeviceDataHistory::DeviceDataHistory(DeviceDataHistory &&source) :
     seq_ptr = source.seq_ptr;
     ref_ctr_ptr = source.ref_ctr_ptr;
 
-    if(source.ext_hist.get() != NULL)
+    if(source.ext_hist != nullptr)
     {
         ext_hist = std::move(source.ext_hist);
     }
@@ -118,7 +119,7 @@ DeviceDataHistory::DeviceDataHistory(DeviceDataHistory &&source) :
 
 DeviceDataHistory::~DeviceDataHistory()
 {
-    if(seq_ptr != NULL)
+    if(seq_ptr != nullptr)
     {
         any._retn();
         err._retn();
@@ -156,7 +157,7 @@ DeviceDataHistory &DeviceDataHistory::operator=(const DeviceDataHistory &rval)
         time = rval.time;
         err = rval.err;
 
-        if(ref_ctr_ptr != NULL)
+        if(ref_ctr_ptr != nullptr)
         {
             (*ref_ctr_ptr)--;
             if(*ref_ctr_ptr == 0)
@@ -170,10 +171,10 @@ DeviceDataHistory &DeviceDataHistory::operator=(const DeviceDataHistory &rval)
         ref_ctr_ptr = rval.ref_ctr_ptr;
         (*ref_ctr_ptr)++;
 
-        if(rval.ext_hist.get() != NULL)
+        if(rval.ext_hist != nullptr)
         {
-            ext_hist.reset(new DeviceDataHistoryExt);
-            *(ext_hist.get()) = *(rval.ext_hist.get());
+            ext_hist = std::make_unique<DeviceDataHistoryExt>();
+            *(ext_hist) = *(rval.ext_hist);
         }
         else
         {
@@ -209,7 +210,7 @@ DeviceDataHistory &DeviceDataHistory::operator=(DeviceDataHistory &&rval)
     //
     // Decrement old ctr
     //
-    if(ref_ctr_ptr != NULL)
+    if(ref_ctr_ptr != nullptr)
     {
         (*ref_ctr_ptr)--;
         if(*ref_ctr_ptr == 0)
@@ -230,7 +231,7 @@ DeviceDataHistory &DeviceDataHistory::operator=(DeviceDataHistory &&rval)
     // Extension class
     //
 
-    if(rval.ext_hist.get() != NULL)
+    if(rval.ext_hist != nullptr)
     {
         ext_hist = std::move(rval.ext_hist);
     }
@@ -265,7 +266,7 @@ std::ostream &operator<<(std::ostream &o_str, const DeviceDataHistory &dh)
     // Print data or error stack
     //
 
-    if(dh.fail == true)
+    if(dh.fail)
     {
         unsigned int nb_err = dh.err.in().length();
         for(unsigned long i = 0; i < nb_err; i++)
@@ -315,7 +316,7 @@ std::ostream &operator<<(std::ostream &o_str, const DeviceDataHistory &dh)
 //-----------------------------------------------------------------------------
 
 DeviceAttributeHistory::DeviceAttributeHistory() :
-    DeviceAttribute(),
+
     ext_hist(nullptr)
 {
     fail = false;
@@ -361,7 +362,7 @@ DeviceAttributeHistory::DeviceAttributeHistory(int n, DevAttrHistoryList_var &se
 
     CORBA::ULong max, len;
 
-    if((fail == false) && (quality != Tango::ATTR_INVALID))
+    if((!fail) && (quality != Tango::ATTR_INVALID))
     {
         CORBA::TypeCode_var ty = seq[n].value.value.type();
         CORBA::TypeCode_var ty_alias = ty->content_type();
@@ -465,7 +466,9 @@ DeviceAttributeHistory::DeviceAttributeHistory(int n, DevAttrHistoryList_var &se
             break;
 
         default:
-            TANGO_THROW_ON_DEFAULT(ty_seq->kind());
+            TangoSys_OMemStream desc;
+            desc << "'seq[" << n << "].value.value' with unexpected sequence kind '" << ty_seq->kind() << "'.";
+            TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
         }
     }
 }
@@ -511,7 +514,7 @@ DeviceAttributeHistory::DeviceAttributeHistory(int n, DevAttrHistoryList_3_var &
 
     CORBA::ULong max, len;
 
-    if((fail == false) && (quality != Tango::ATTR_INVALID))
+    if((!fail) && (quality != Tango::ATTR_INVALID))
     {
         CORBA::TypeCode_var ty = seq[n].value.value.type();
         CORBA::TypeCode_var ty_alias = ty->content_type();
@@ -615,7 +618,9 @@ DeviceAttributeHistory::DeviceAttributeHistory(int n, DevAttrHistoryList_3_var &
             break;
 
         default:
-            TANGO_THROW_ON_DEFAULT(ty_seq->kind());
+            TangoSys_OMemStream desc;
+            desc << "'seq[" << n << "].value.value' with unexpected sequence kind '" << ty_seq->kind() << "'.";
+            TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
         }
     }
 }
@@ -626,10 +631,10 @@ DeviceAttributeHistory::DeviceAttributeHistory(const DeviceAttributeHistory &sou
 {
     fail = source.fail;
 
-    if(source.ext_hist.get() != NULL)
+    if(source.ext_hist != nullptr)
     {
-        ext_hist.reset(new DeviceAttributeHistoryExt);
-        *(ext_hist.get()) = *(source.ext_hist.get());
+        ext_hist = std::make_unique<DeviceAttributeHistoryExt>();
+        *(ext_hist) = *(source.ext_hist);
     }
 }
 
@@ -639,7 +644,7 @@ DeviceAttributeHistory::DeviceAttributeHistory(DeviceAttributeHistory &&source)
 {
     fail = source.fail;
 
-    if(source.ext_hist.get() != NULL)
+    if(source.ext_hist != nullptr)
     {
         ext_hist = std::move(source.ext_hist);
     }
@@ -675,10 +680,10 @@ DeviceAttributeHistory &DeviceAttributeHistory::operator=(const DeviceAttributeH
 
         fail = rval.fail;
 
-        if(rval.ext_hist.get() != NULL)
+        if(rval.ext_hist != nullptr)
         {
-            ext_hist.reset(new DeviceAttributeHistoryExt);
-            *(ext_hist.get()) = *(rval.ext_hist.get());
+            ext_hist = std::make_unique<DeviceAttributeHistoryExt>();
+            *(ext_hist) = *(rval.ext_hist);
         }
         else
         {
@@ -703,7 +708,7 @@ DeviceAttributeHistory &DeviceAttributeHistory::operator=(DeviceAttributeHistory
 
     fail = rval.fail;
 
-    if(rval.ext_hist.get() != NULL)
+    if(rval.ext_hist != nullptr)
     {
         ext_hist = std::move(rval.ext_hist);
     }
@@ -787,7 +792,7 @@ std::ostream &operator<<(std::ostream &o_str, const DeviceAttributeHistory &dah)
     // Print data (if valid) or error stack
     //
 
-    if(dah.fail == true)
+    if(dah.fail)
     {
         unsigned int nb_err = dah.err_list.in().length();
         for(unsigned long i = 0; i < nb_err; i++)
@@ -826,57 +831,57 @@ std::ostream &operator<<(std::ostream &o_str, const DeviceAttributeHistory &dah)
     {
         if(dah.quality != Tango::ATTR_INVALID)
         {
-            if(dah.is_empty_noexcept() == true)
+            if(dah.is_empty_noexcept())
             {
                 o_str << "No data in DeviceData object";
             }
             else
             {
-                if(dah.LongSeq.operator->() != NULL)
+                if(dah.LongSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.LongSeq.operator->());
                 }
-                else if(dah.ShortSeq.operator->() != NULL)
+                else if(dah.ShortSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.ShortSeq.operator->());
                 }
-                else if(dah.DoubleSeq.operator->() != NULL)
+                else if(dah.DoubleSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.DoubleSeq.operator->());
                 }
-                else if(dah.FloatSeq.operator->() != NULL)
+                else if(dah.FloatSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.FloatSeq.operator->());
                 }
-                else if(dah.BooleanSeq.operator->() != NULL)
+                else if(dah.BooleanSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.BooleanSeq.operator->());
                 }
-                else if(dah.UShortSeq.operator->() != NULL)
+                else if(dah.UShortSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.UShortSeq.operator->());
                 }
-                else if(dah.UCharSeq.operator->() != NULL)
+                else if(dah.UCharSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.UCharSeq.operator->());
                 }
-                else if(dah.Long64Seq.operator->() != NULL)
+                else if(dah.Long64Seq.operator->() != nullptr)
                 {
                     o_str << *(dah.Long64Seq.operator->());
                 }
-                else if(dah.ULongSeq.operator->() != NULL)
+                else if(dah.ULongSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.ULongSeq.operator->());
                 }
-                else if(dah.ULong64Seq.operator->() != NULL)
+                else if(dah.ULong64Seq.operator->() != nullptr)
                 {
                     o_str << *(dah.ULong64Seq.operator->());
                 }
-                else if(dah.StateSeq.operator->() != NULL)
+                else if(dah.StateSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.StateSeq.operator->());
                 }
-                else if(dah.EncodedSeq.operator->() != NULL)
+                else if(dah.EncodedSeq.operator->() != nullptr)
                 {
                     o_str << *(dah.EncodedSeq.operator->());
                 }
