@@ -29,6 +29,7 @@
 
 #include <tango/tango.h>
 #include <iomanip>
+#include <memory>
 
 using namespace CORBA;
 
@@ -76,10 +77,10 @@ DevicePipe::DevicePipe(const DevicePipe &source) :
     time = source.time;
     the_root_blob = source.the_root_blob;
 
-    if(source.ext.get() != NULL)
+    if(source.ext != nullptr)
     {
-        ext.reset(new DevicePipeExt);
-        *(ext.get()) = *(source.ext.get());
+        ext = std::make_unique<DevicePipeExt>();
+        *(ext) = *(source.ext);
     }
 }
 
@@ -97,10 +98,10 @@ DevicePipe &DevicePipe::operator=(const DevicePipe &rhs)
         time = rhs.time;
         the_root_blob = rhs.the_root_blob;
 
-        if(rhs.ext.get() != NULL)
+        if(rhs.ext != nullptr)
         {
-            ext.reset(new DevicePipeExt);
-            *(ext.get()) = *(rhs.ext.get());
+            ext = std::make_unique<DevicePipeExt>();
+            *(ext) = *(rhs.ext);
         }
     }
     return *this;
@@ -119,7 +120,7 @@ DevicePipe::DevicePipe(DevicePipe &&source) :
     time = source.time;
     the_root_blob = std::move(source.the_root_blob);
 
-    if(source.ext.get() != NULL)
+    if(source.ext != nullptr)
     {
         ext = std::move(source.ext);
     }
@@ -137,7 +138,7 @@ DevicePipe &DevicePipe::operator=(DevicePipe &&rhs)
     time = rhs.time;
     the_root_blob = std::move(rhs.the_root_blob);
 
-    if(rhs.ext.get() != NULL)
+    if(rhs.ext != nullptr)
     {
         ext = std::move(rhs.ext);
     }
@@ -218,7 +219,7 @@ DevicePipeBlob::DevicePipeBlob(const std::string &blob_name) :
 
 DevicePipeBlob::~DevicePipeBlob()
 {
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
     }
@@ -253,7 +254,7 @@ DevicePipeBlob::DevicePipeBlob(const DevicePipeBlob &source) :
 
     if(source.extract_elt_array != nullptr)
     {
-        DevVarPipeDataEltArray *tmp = new DevVarPipeDataEltArray();
+        auto *tmp = new DevVarPipeDataEltArray();
         *tmp = (*source.extract_elt_array);
         set_extract_data(tmp);
         extract_delete = true;
@@ -264,10 +265,10 @@ DevicePipeBlob::DevicePipeBlob(const DevicePipeBlob &source) :
     }
     extract_ctr = source.extract_ctr;
 
-    if(source.ext.get() != NULL)
+    if(source.ext != nullptr)
     {
-        ext.reset(new DevicePipeBlobExt);
-        *(ext.get()) = *(source.ext.get());
+        ext = std::make_unique<DevicePipeBlobExt>();
+        *(ext) = *(source.ext);
     }
 }
 
@@ -301,7 +302,7 @@ DevicePipeBlob &DevicePipeBlob::operator=(const DevicePipeBlob &rhs)
 
         if(rhs.extract_elt_array != nullptr)
         {
-            DevVarPipeDataEltArray *tmp = new DevVarPipeDataEltArray();
+            auto *tmp = new DevVarPipeDataEltArray();
             *tmp = (*rhs.extract_elt_array);
             set_extract_data(tmp);
             extract_delete = true;
@@ -312,10 +313,10 @@ DevicePipeBlob &DevicePipeBlob::operator=(const DevicePipeBlob &rhs)
         }
         extract_ctr = rhs.extract_ctr;
 
-        if(rhs.ext.get() != NULL)
+        if(rhs.ext != nullptr)
         {
-            ext.reset(new DevicePipeBlobExt);
-            *(ext.get()) = *(rhs.ext.get());
+            ext = std::make_unique<DevicePipeBlobExt>();
+            *(ext) = *(rhs.ext);
         }
         else
         {
@@ -354,7 +355,7 @@ DevicePipeBlob::DevicePipeBlob(DevicePipeBlob &&source) :
 
     if(source.extract_elt_array != nullptr)
     {
-        DevVarPipeDataEltArray *tmp = new DevVarPipeDataEltArray();
+        auto *tmp = new DevVarPipeDataEltArray();
         *tmp = (*source.extract_elt_array);
         set_extract_data(tmp);
         extract_delete = true;
@@ -365,7 +366,7 @@ DevicePipeBlob::DevicePipeBlob(DevicePipeBlob &&source) :
     }
     extract_ctr = source.extract_ctr;
 
-    if(source.ext.get() != NULL)
+    if(source.ext != nullptr)
     {
         ext = std::move(source.ext);
     }
@@ -393,7 +394,7 @@ DevicePipeBlob &DevicePipeBlob::operator=(DevicePipeBlob &&rhs)
     rhs.insert_elt_array = nullptr;
     insert_ctr = rhs.insert_ctr;
 
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
     }
@@ -406,7 +407,7 @@ DevicePipeBlob &DevicePipeBlob::operator=(DevicePipeBlob &&rhs)
     extract_delete = rhs.extract_delete;
     extract_ctr = rhs.extract_ctr;
 
-    if(rhs.ext.get() != NULL)
+    if(rhs.ext != nullptr)
     {
         ext = std::move(rhs.ext);
     }
@@ -446,7 +447,7 @@ std::vector<std::string> DevicePipeBlob::get_data_elt_names()
 
     for(size_t loop = 0; loop < nb_elt; loop++)
     {
-        v_str.push_back(std::string((*extract_elt_array)[loop].name.in()));
+        v_str.emplace_back((*extract_elt_array)[loop].name.in());
     }
 
     return v_str;
@@ -704,10 +705,15 @@ int DevicePipeBlob::get_data_elt_type(size_t _ind)
         }
         break;
 
-        default:
+        case DEVICE_STATE:
+            [[fallthrough]];
+        case ATT_NO_DATA:
             TANGO_THROW_EXCEPTION(API_PipeWrongArg,
                                   "Unsupported data type in data element! (ATT_NO_DATA, DEVICE_STATE)");
             break;
+
+        default:
+            TANGO_ASSERT_ON_DEFAULT((*extract_elt_array)[_ind].value._d());
         }
     }
 
@@ -762,7 +768,7 @@ size_t DevicePipeBlob::get_extract_ind_from_name(const std::string &_na)
         }
     }
 
-    if(found == false)
+    if(!found)
     {
         std::stringstream ss;
 
@@ -805,7 +811,7 @@ size_t DevicePipeBlob::get_insert_ind_from_name(const std::string &_na)
         }
     }
 
-    if(found == false)
+    if(!found)
     {
         std::stringstream ss;
 
@@ -902,7 +908,7 @@ void DevicePipeBlob::set_data_elt_names(const std::vector<std::string> &elt_name
         sort(same_de.begin(), same_de.end());
         std::vector<std::string> same_de_lower = same_de;
 
-        std::vector<std::string>::iterator pos = unique(same_de.begin(), same_de.end());
+        auto pos = unique(same_de.begin(), same_de.end());
 
         int duplicate_de;
         duplicate_de = distance(elt_names.begin(), elt_names.end()) - distance(same_de.begin(), pos);
@@ -924,7 +930,7 @@ void DevicePipeBlob::set_data_elt_names(const std::vector<std::string> &elt_name
                     }
                 }
             }
-            TANGO_THROW_API_EXCEPTION(ApiConnExcept, API_PipeDuplicateDEName, desc.str());
+            TANGO_THROW_DETAILED_EXCEPTION(ApiConnExcept, API_PipeDuplicateDEName, desc.str());
         }
     }
 
@@ -1174,22 +1180,22 @@ DevicePipeBlob &DevicePipeBlob::operator<<(const DevString &datum)
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(blobdenamenotset_flag) == true && exceptions_flags.test(blobdenamenotset_flag) == true)
+    if(ext_state.test(blobdenamenotset_flag) && exceptions_flags.test(blobdenamenotset_flag))
     {
         throw_name_not_set("operator<<");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator<<", false);
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
@@ -1252,22 +1258,22 @@ DevicePipeBlob &DevicePipeBlob::operator<<(const std::string &datum)
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(blobdenamenotset_flag) == true && exceptions_flags.test(blobdenamenotset_flag) == true)
+    if(ext_state.test(blobdenamenotset_flag) && exceptions_flags.test(blobdenamenotset_flag))
     {
         throw_name_not_set("operator<<");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator<<", false);
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
@@ -1324,22 +1330,22 @@ DevicePipeBlob &DevicePipeBlob::operator<<(const DevicePipeBlob &datum)
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(blobdenamenotset_flag) == true && exceptions_flags.test(blobdenamenotset_flag) == true)
+    if(ext_state.test(blobdenamenotset_flag) && exceptions_flags.test(blobdenamenotset_flag))
     {
         throw_name_not_set("operator<<");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator<<", false);
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
@@ -1389,22 +1395,22 @@ DevicePipeBlob &DevicePipeBlob::operator<<(const std::vector<DevBoolean> &datum)
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(blobdenamenotset_flag) == true && exceptions_flags.test(blobdenamenotset_flag) == true)
+    if(ext_state.test(blobdenamenotset_flag) && exceptions_flags.test(blobdenamenotset_flag))
     {
         throw_name_not_set("operator<<");
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator<<", false);
     }
@@ -1543,22 +1549,22 @@ DevicePipeBlob &DevicePipeBlob::operator<<(const std::vector<std::string> &datum
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(blobdenamenotset_flag) == true && exceptions_flags.test(blobdenamenotset_flag) == true)
+    if(ext_state.test(blobdenamenotset_flag) && exceptions_flags.test(blobdenamenotset_flag))
     {
         throw_name_not_set("operator<<");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator<<", false);
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
@@ -1882,27 +1888,27 @@ DevicePipeBlob &DevicePipeBlob::operator>>(DevString &datum)
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(isempty_flag) == true && exceptions_flags.test(isempty_flag) == true)
+    if(ext_state.test(isempty_flag) && exceptions_flags.test(isempty_flag))
     {
         throw_is_empty("operator>>");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator>>", true);
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
 
-    if(ext_state.test(wrongtype_flag) == true && exceptions_flags.test(wrongtype_flag) == true)
+    if(ext_state.test(wrongtype_flag) && exceptions_flags.test(wrongtype_flag))
     {
         throw_type_except("DevString", "operator>>");
     }
@@ -1989,27 +1995,27 @@ DevicePipeBlob &DevicePipeBlob::operator>>(DevicePipeBlob &datum)
         }
     }
 
-    if(ext_state.any() == true)
+    if(ext_state.any())
     {
         failed = true;
     }
 
-    if(ext_state.test(isempty_flag) == true && exceptions_flags.test(isempty_flag) == true)
+    if(ext_state.test(isempty_flag) && exceptions_flags.test(isempty_flag))
     {
         throw_is_empty("operator>>");
     }
 
-    if(ext_state.test(notenoughde_flag) == true && exceptions_flags.test(notenoughde_flag) == true)
+    if(ext_state.test(notenoughde_flag) && exceptions_flags.test(notenoughde_flag))
     {
         throw_too_many("operator>>", true);
     }
 
-    if(ext_state.test(mixing_flag) == true && exceptions_flags.test(mixing_flag) == true)
+    if(ext_state.test(mixing_flag) && exceptions_flags.test(mixing_flag))
     {
         throw_mixing("operator>>");
     }
 
-    if(ext_state.test(wrongtype_flag) == true && exceptions_flags.test(wrongtype_flag) == true)
+    if(ext_state.test(wrongtype_flag) && exceptions_flags.test(wrongtype_flag))
     {
         throw_type_except("DevicePipeBlob", "operator>>");
     }
@@ -2218,10 +2224,10 @@ DevicePipeBlob &DevicePipeBlob::operator>>(DevVarEncodedArray *datum)
 
 bool DevicePipeBlob::has_failed()
 {
-    if(failed == true)
+    if(failed)
     {
         delete insert_elt_array;
-        if(extract_delete == true)
+        if(extract_delete)
         {
             delete extract_elt_array;
             extract_delete = false;
@@ -2248,7 +2254,7 @@ bool DevicePipeBlob::has_failed()
 void DevicePipeBlob::throw_type_except(const std::string &_ty, const std::string &_meth)
 {
     delete insert_elt_array;
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
         extract_delete = false;
@@ -2259,7 +2265,7 @@ void DevicePipeBlob::throw_type_except(const std::string &_ty, const std::string
     ss << "Can't get data element " << extract_ctr << " (numbering starting from 0) into a " << _ty << " data type";
     std::string m_name("DevicePipeBlob::");
     m_name = m_name + _meth;
-    TANGO_THROW_API_EXCEPTION(ApiDataExcept, API_IncompatibleArgumentType, ss.str());
+    TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept, API_IncompatibleArgumentType, ss.str());
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -2281,7 +2287,7 @@ void DevicePipeBlob::throw_too_many(const std::string &_meth, bool _extract)
 {
     std::stringstream ss;
     ss << "Not enough data element in blob (";
-    if(_extract == true)
+    if(_extract)
     {
         ss << get_data_elt_nb();
     }
@@ -2295,13 +2301,13 @@ void DevicePipeBlob::throw_too_many(const std::string &_meth, bool _extract)
 
     delete insert_elt_array;
     insert_elt_array = nullptr;
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
         extract_delete = false;
     }
 
-    TANGO_THROW_API_EXCEPTION(ApiDataExcept, API_PipeWrongArg, ss.str());
+    TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept, API_PipeWrongArg, ss.str());
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -2321,7 +2327,7 @@ void DevicePipeBlob::throw_too_many(const std::string &_meth, bool _extract)
 void DevicePipeBlob::throw_is_empty(const std::string &_meth)
 {
     delete insert_elt_array;
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
         extract_delete = false;
@@ -2329,7 +2335,7 @@ void DevicePipeBlob::throw_is_empty(const std::string &_meth)
 
     std::string m_name("DevicePipeBlob::");
     m_name = m_name + _meth;
-    TANGO_THROW_API_EXCEPTION(ApiDataExcept, API_EmptyDataElement, "The data element is empty");
+    TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept, API_EmptyDataElement, "The data element is empty");
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -2349,7 +2355,7 @@ void DevicePipeBlob::throw_is_empty(const std::string &_meth)
 void DevicePipeBlob::throw_name_not_set(const std::string &_meth)
 {
     delete insert_elt_array;
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
         extract_delete = false;
@@ -2357,7 +2363,8 @@ void DevicePipeBlob::throw_name_not_set(const std::string &_meth)
 
     std::string m_name("DevicePipeBlob::");
     m_name = m_name + _meth;
-    TANGO_THROW_API_EXCEPTION(ApiDataExcept, API_PipeNoDataElement, "The blob data element number (or name) not set");
+    TANGO_THROW_DETAILED_EXCEPTION(
+        ApiDataExcept, API_PipeNoDataElement, "The blob data element number (or name) not set");
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -2377,7 +2384,7 @@ void DevicePipeBlob::throw_name_not_set(const std::string &_meth)
 void DevicePipeBlob::throw_mixing(const std::string &_meth)
 {
     delete insert_elt_array;
-    if(extract_delete == true)
+    if(extract_delete)
     {
         delete extract_elt_array;
         extract_delete = false;
@@ -2412,7 +2419,7 @@ void DevicePipeBlob::print(std::ostream &o_str, int indent, bool insert_extract)
     // Print blob name (if any)
     //
 
-    if(name.size() != 0 && insert_extract == true)
+    if(name.size() != 0 && insert_extract)
     {
         int max = indent;
         if(indent > 1)
@@ -2431,7 +2438,7 @@ void DevicePipeBlob::print(std::ostream &o_str, int indent, bool insert_extract)
     //
 
     const DevVarPipeDataEltArray *dvpdea;
-    if(insert_extract == false)
+    if(!insert_extract)
     {
         dvpdea = get_extract_data();
     }
@@ -2566,7 +2573,7 @@ void DevicePipeBlob::print(std::ostream &o_str, int indent, bool insert_extract)
                 break;
 
             default:
-                TANGO_THROW_ON_DEFAULT((*dvpdea)[ctr].value._d());
+                TANGO_ASSERT_ON_DEFAULT((*dvpdea)[ctr].value._d());
             }
 
             //
