@@ -37,7 +37,7 @@
 #include <tango/client/eventconsumer.h>
 #include <tango/server/auto_tango_monitor.h>
 
-#include <stdio.h>
+#include <cstdio>
 
 #ifdef _TG_WINDOWS_
   #include <process.h>
@@ -90,14 +90,14 @@ bool EventConsumerKeepAliveThread::reconnect_to_channel(const EvChanIte &ipos, E
             std::vector<EventSubscribeStruct>::iterator esspos;
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
-                if(esspos->callback != NULL || esspos->ev_queue != NULL)
+                if(esspos->callback != nullptr || esspos->ev_queue != nullptr)
                 {
                     need_reconnect = true;
                     break;
                 }
             }
 
-            if(need_reconnect == true)
+            if(need_reconnect)
             {
                 try
                 {
@@ -106,7 +106,7 @@ bool EventConsumerKeepAliveThread::reconnect_to_channel(const EvChanIte &ipos, E
                     event_consumer->connect_event_channel(
                         adm_name, epos->second.get_device_proxy().get_device_db(), true, dummy);
 
-                    if(ipos->second.adm_device_proxy != NULL)
+                    if(ipos->second.adm_device_proxy != nullptr)
                     {
                         delete ipos->second.adm_device_proxy;
                     }
@@ -160,14 +160,14 @@ bool EventConsumerKeepAliveThread::reconnect_to_zmq_channel(const EvChanIte &ipo
             std::vector<EventSubscribeStruct>::iterator esspos;
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
-                if(esspos->callback != NULL || esspos->ev_queue != NULL)
+                if(esspos->callback != nullptr || esspos->ev_queue != nullptr)
                 {
                     need_reconnect = true;
                     break;
                 }
             }
 
-            if(need_reconnect == true)
+            if(need_reconnect)
             {
                 try
                 {
@@ -186,9 +186,9 @@ bool EventConsumerKeepAliveThread::reconnect_to_zmq_channel(const EvChanIte &ipo
                     }
 
                     // only delete the existing admin device if we could create a new one
-                    auto new_adm_proxy{new DeviceProxy(new_adm_name)};
+                    auto *new_adm_proxy{new DeviceProxy(new_adm_name)};
 
-                    auto old_adm_proxy{ipos->second.adm_device_proxy};
+                    auto *old_adm_proxy{ipos->second.adm_device_proxy};
 
                     ipos->second.adm_device_proxy = new_adm_proxy;
 
@@ -198,9 +198,10 @@ bool EventConsumerKeepAliveThread::reconnect_to_zmq_channel(const EvChanIte &ipo
                     std::vector<std::string> subscriber_info;
                     subscriber_info.push_back(epos->second.get_device_proxy().dev_name());
                     subscriber_info.push_back(epos->second.obj_name);
-                    subscriber_info.push_back("subscribe");
+                    subscriber_info.emplace_back("subscribe");
                     subscriber_info.push_back(epos->second.event_name);
-                    subscriber_info.push_back("0");
+                    subscriber_info.emplace_back("0");
+
                     subscriber_in << subscriber_info;
 
                     subscriber_out =
@@ -211,7 +212,7 @@ bool EventConsumerKeepAliveThread::reconnect_to_zmq_channel(const EvChanIte &ipo
                     // function in order to support older (< 9.3) Tango versions.
                     const DevVarLongStringArray *event_sub_change_result;
                     subscriber_out >> event_sub_change_result;
-                    std::string local_callback_key = ""; // We are not interested in event name, pass dummy value.
+                    std::string local_callback_key; // We are not interested in event name, pass dummy value.
                     auto event_and_channel_name = event_consumer->initialize_received_from_admin(
                         event_sub_change_result,
                         local_callback_key,
@@ -285,14 +286,14 @@ void EventConsumerKeepAliveThread::reconnect_to_event(const EvChanIte &ipos, Eve
             std::vector<EventSubscribeStruct>::iterator esspos;
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
-                if(esspos->callback != NULL || esspos->ev_queue != NULL)
+                if(esspos->callback != nullptr || esspos->ev_queue != nullptr)
                 {
                     need_reconnect = true;
                     break;
                 }
             }
 
-            if(need_reconnect == true)
+            if(need_reconnect)
             {
                 try
                 {
@@ -350,8 +351,6 @@ void EventConsumerKeepAliveThread::re_subscribe_event(const EvCbIte &epos, const
     CosNotifyFilter::Filter_var filter = CosNotifyFilter::Filter::_nil();
     CosNotifyFilter::FilterID filter_id;
 
-    std::string channel_name = epos->second.channel_name;
-
     try
     {
         ffp = ipos->second.eventChannel->default_filter_factory();
@@ -359,15 +358,16 @@ void EventConsumerKeepAliveThread::re_subscribe_event(const EvCbIte &epos, const
     }
     catch(CORBA::COMM_FAILURE &)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught CORBA::COMM_FAILURE exception while creating event filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(
+            EventSystemExcept,
+            API_NotificationServiceFailed,
+            "Caught CORBA::COMM_FAILURE exception while creating event filter (check filter)");
     }
     catch(...)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught exception while creating event filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Caught exception while creating event filter (check filter)");
     }
 
     //
@@ -381,7 +381,7 @@ void EventConsumerKeepAliveThread::re_subscribe_event(const EvCbIte &epos, const
     exp.length(1);
     exp[0].event_types = evs;
     exp[0].constraint_expr = Tango::string_dup(constraint_expr.c_str());
-    CORBA::Boolean res = 0; // OK
+    bool error_occurred = false;
     try
     {
         CosNotifyFilter::ConstraintInfoSeq_var dummy = filter->add_constraints(exp);
@@ -394,20 +394,20 @@ void EventConsumerKeepAliveThread::re_subscribe_event(const EvCbIte &epos, const
     {
         // cerr << "Exception thrown : Invalid constraint given "
         //      << (const char *)constraint_expr << std::endl;
-        res = 1;
+        error_occurred = true;
     }
     catch(...)
     {
         // cerr << "Exception thrown while adding constraint "
         //      << (const char *)constraint_expr << std::endl;
-        res = 1;
+        error_occurred = true;
     }
 
     //
     // If error, destroy filter
     //
 
-    if(res == 1)
+    if(error_occurred)
     {
         try
         {
@@ -418,9 +418,9 @@ void EventConsumerKeepAliveThread::re_subscribe_event(const EvCbIte &epos, const
         }
 
         filter = CosNotifyFilter::Filter::_nil();
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught exception while creating event filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Caught exception while creating event filter (check filter)");
     }
 }
 
@@ -462,14 +462,14 @@ void EventConsumerKeepAliveThread::reconnect_to_zmq_event(const EvChanIte &ipos,
             std::vector<EventSubscribeStruct>::iterator esspos;
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
-                if(esspos->callback != NULL || esspos->ev_queue != NULL)
+                if(esspos->callback != nullptr || esspos->ev_queue != nullptr)
                 {
                     need_reconnect = true;
                     break;
                 }
             }
 
-            if(need_reconnect == true)
+            if(need_reconnect)
             {
                 try
                 {
@@ -480,7 +480,7 @@ void EventConsumerKeepAliveThread::reconnect_to_zmq_event(const EvChanIte &ipos,
                         EventCallBackStruct ecbs;
                         std::vector<std::string> vs;
 
-                        vs.push_back(std::string("reconnect"));
+                        vs.emplace_back("reconnect");
 
                         std::string d_name = epos->second.get_device_proxy().dev_name();
                         std::string &fqen = epos->second.fully_qualified_event_name;
@@ -490,7 +490,7 @@ void EventConsumerKeepAliveThread::reconnect_to_zmq_event(const EvChanIte &ipos,
                         std::string prefix = fqen.substr(0, pos + 1);
                         d_name.insert(0, prefix);
 
-                        if(disconnect_called == false)
+                        if(!disconnect_called)
                         {
                             event_consumer->disconnect_event(epos->second.fully_qualified_event_name,
                                                              epos->second.endpoint);
@@ -560,7 +560,7 @@ void *EventConsumerKeepAliveThread::run_undetached(TANGO_UNUSED(void *arg))
     event_consumer = ApiUtil::instance()->get_zmq_event_consumer();
     notifd_event_consumer = ApiUtil::instance()->get_notifd_event_consumer();
 
-    while(exit_th == false)
+    while(!exit_th)
     {
         time_to_sleep = EVENT_HEARTBEAT_PERIOD;
 
@@ -572,7 +572,7 @@ void *EventConsumerKeepAliveThread::run_undetached(TANGO_UNUSED(void *arg))
 
         {
             omni_mutex_lock sync(shared_cmd);
-            if(shared_cmd.cmd_pending == false)
+            if(!shared_cmd.cmd_pending)
             {
                 unsigned long s, n;
 
@@ -583,10 +583,10 @@ void *EventConsumerKeepAliveThread::run_undetached(TANGO_UNUSED(void *arg))
                 omni_thread::get_time(&s, &n, nb_sec, nb_nanos);
                 shared_cmd.cond.timedwait(s, n);
             }
-            if(shared_cmd.cmd_pending == true)
+            if(shared_cmd.cmd_pending)
             {
                 exit_th = true;
-                return (void *) NULL;
+                return (void *) nullptr;
             }
         }
 
@@ -601,17 +601,17 @@ void *EventConsumerKeepAliveThread::run_undetached(TANGO_UNUSED(void *arg))
         // at the end of the process startup. Verified with some ESRF HdbEventHandler process)
         //
 
-        if(event_consumer)
+        if(event_consumer != nullptr)
         {
             event_consumer = ApiUtil::instance()->get_zmq_event_consumer();
         }
-        if(notifd_event_consumer == NULL)
+        if(notifd_event_consumer == nullptr)
         {
             notifd_event_consumer = ApiUtil::instance()->get_notifd_event_consumer();
         }
 
-        now = time(NULL);
-        if(event_consumer->event_not_connected.empty() == false)
+        now = Tango::get_current_system_datetime();
+        if(!event_consumer->event_not_connected.empty())
         {
             DelayEvent de(event_consumer);
             event_consumer->map_modification_lock.writerIn();
@@ -669,7 +669,7 @@ void *EventConsumerKeepAliveThread::run_undetached(TANGO_UNUSED(void *arg))
                     bool heartbeat_skipped;
                     heartbeat_skipped = ((now - ipos->second.last_heartbeat) >= EVENT_HEARTBEAT_PERIOD);
 
-                    if(heartbeat_skipped || ipos->second.heartbeat_skipped || ipos->second.event_system_failed == true)
+                    if(heartbeat_skipped || ipos->second.heartbeat_skipped || ipos->second.event_system_failed)
                     {
                         ipos->second.heartbeat_skipped = true;
                         main_reconnect(event_consumer, notifd_event_consumer, epos, ipos);
@@ -730,7 +730,7 @@ void *EventConsumerKeepAliveThread::run_undetached(TANGO_UNUSED(void *arg))
     // If we arrive here, this means that we have received the exit thread command.
     //
 
-    return (void *) NULL;
+    return (void *) nullptr;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -795,7 +795,7 @@ void EventConsumerKeepAliveThread::not_conected_event(ZmqEventConsumer *event_co
                     {
                         try
                         {
-                            if(notifd_event_consumer == NULL)
+                            if(notifd_event_consumer == nullptr)
                             {
                                 ApiUtil::instance()->create_notifd_event_consumer();
                                 notifd_event_consumer = ApiUtil::instance()->get_notifd_event_consumer();
@@ -872,7 +872,7 @@ void EventConsumerKeepAliveThread::fwd_not_conected_event(ZmqEventConsumer *even
 
     if(!event_consumer->event_not_connected.empty())
     {
-        time_t now = time(NULL);
+        const time_t now = Tango::get_current_system_datetime();
         std::vector<EventNotConnected>::iterator vpos;
         for(vpos = event_consumer->event_not_connected.begin(); vpos != event_consumer->event_not_connected.end();
             /*vpos++*/)
@@ -978,13 +978,13 @@ void EventConsumerKeepAliveThread::confirm_subscription(ZmqEventConsumer *event_
                     std::vector<std::string> subscriber_info;
                     subscriber_info.push_back(epos->second.get_device_proxy().dev_name());
                     subscriber_info.push_back(epos->second.obj_name);
-                    subscriber_info.push_back("subscribe");
+                    subscriber_info.emplace_back("subscribe");
                     subscriber_info.push_back(epos->second.event_name);
                     subscriber_in << subscriber_info;
 
                     ipos->second.adm_device_proxy->command_inout("EventSubscriptionChange", subscriber_in);
 
-                    time_t ti = time(NULL);
+                    const time_t ti = Tango::get_current_system_datetime();
                     ipos->second.last_subscribed = ti;
                     epos->second.last_subscribed = ti;
                 }
@@ -997,7 +997,7 @@ void EventConsumerKeepAliveThread::confirm_subscription(ZmqEventConsumer *event_
         }
     }
 
-    if(ipos->second.channel_type == ZMQ && cmd_params.empty() == false)
+    if(ipos->second.channel_type == ZMQ && !cmd_params.empty())
     {
         try
         {
@@ -1006,7 +1006,7 @@ void EventConsumerKeepAliveThread::confirm_subscription(ZmqEventConsumer *event_
 
             ipos->second.adm_device_proxy->command_inout("EventConfirmSubscription", sub_cmd_in);
 
-            time_t ti = time(NULL);
+            const time_t ti = Tango::get_current_system_datetime();
             ipos->second.last_subscribed = ti;
             for(unsigned int loop = 0; loop < vd.size(); ++loop)
             {
@@ -1028,7 +1028,7 @@ void EventConsumerKeepAliveThread::confirm_subscription(ZmqEventConsumer *event_
                 // Send confirmation the old way
                 //
 
-                time_t ti = time(NULL);
+                const time_t ti = Tango::get_current_system_datetime();
                 ipos->second.last_subscribed = ti;
 
                 for(unsigned int loop = 0; loop < vd.size(); ++loop)
@@ -1037,9 +1037,9 @@ void EventConsumerKeepAliveThread::confirm_subscription(ZmqEventConsumer *event_
                     std::vector<std::string> subscriber_info;
                     subscriber_info.push_back(cmd_params[(loop * 3)]);
                     subscriber_info.push_back(cmd_params[(loop * 3) + 1]);
-                    subscriber_info.push_back("subscribe");
+                    subscriber_info.emplace_back("subscribe");
                     subscriber_info.push_back(cmd_params[(loop * 3) + 2]);
-                    subscriber_info.push_back("0");
+                    subscriber_info.emplace_back("0");
                     subscriber_in << subscriber_info;
 
                     try
@@ -1141,7 +1141,7 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
         // The notify deamon might have closed the connection, try to reconnect!
         //
 
-        if(ipos->second.event_system_failed == false && ipos->second.has_notifd_closed_the_connection >= 3)
+        if(!ipos->second.event_system_failed && ipos->second.has_notifd_closed_the_connection >= 3)
         {
             ipos->second.event_system_failed = true;
         }
@@ -1151,19 +1151,12 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
         // channel, then reconnect callbacks to this new event channel
         //
 
-        if(ipos->second.event_system_failed == true)
+        if(ipos->second.event_system_failed)
         {
             bool notifd_reco = reconnect_to_channel(ipos, notifd_event_consumer);
-            if(notifd_reco)
-            {
-                ipos->second.event_system_failed = false;
-            }
-            else
-            {
-                ipos->second.event_system_failed = true;
-            }
+            ipos->second.event_system_failed = !notifd_reco;
 
-            if(ipos->second.event_system_failed == false)
+            if(!ipos->second.event_system_failed)
             {
                 reconnect_to_event(ipos, notifd_event_consumer);
             }
@@ -1173,16 +1166,9 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
     {
         DeviceData dd;
         bool zmq_reco = reconnect_to_zmq_channel(ipos, event_consumer, dd);
-        if(zmq_reco)
-        {
-            ipos->second.event_system_failed = false;
-        }
-        else
-        {
-            ipos->second.event_system_failed = true;
-        }
+        ipos->second.event_system_failed = !zmq_reco;
 
-        if(ipos->second.event_system_failed == false)
+        if(!ipos->second.event_system_failed)
         {
             reconnect_to_zmq_event(ipos, event_consumer, dd);
         }
@@ -1196,9 +1182,9 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
     errors[0].reason = Tango::string_dup(API_EventTimeout);
     errors[0].desc =
         Tango::string_dup("Event channel is not responding anymore, maybe the server or event system is down");
-    DeviceAttribute *dev_attr = NULL;
-    AttributeInfoEx *dev_attr_conf = NULL;
-    DevicePipe *dev_pipe = NULL;
+    DeviceAttribute *dev_attr = nullptr;
+    AttributeInfoEx *dev_attr_conf = nullptr;
+    DevicePipe *dev_pipe = nullptr;
 
     for(epos = event_consumer->event_callback_map.begin(); epos != event_consumer->event_callback_map.end(); ++epos)
     {
@@ -1211,7 +1197,7 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
             std::vector<EventSubscribeStruct>::iterator esspos;
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
-                if(esspos->callback != NULL || esspos->ev_queue != NULL)
+                if(esspos->callback != nullptr || esspos->ev_queue != nullptr)
                 {
                     need_reconnect = true;
                     break;
@@ -1222,9 +1208,9 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
             {
                 epos->second.callback_monitor->get_monitor();
 
-                if(need_reconnect == true)
+                if(need_reconnect)
                 {
-                    if((ipos->second.channel_type == NOTIFD) && (epos->second.filter_ok == false))
+                    if((ipos->second.channel_type == NOTIFD) && (!epos->second.filter_ok))
                     {
                         try
                         {
@@ -1269,10 +1255,10 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
 
                     if(event_name == CONF_TYPE_EVENT)
                     {
-                        FwdAttrConfEventData *event_data =
+                        auto *event_data =
                             new FwdAttrConfEventData(esspos->device, domain_name, event_name, dev_attr_conf, errors);
                         // if a callback method was specified, call it!
-                        if(callback != NULL)
+                        if(callback != nullptr)
                         {
                             try
                             {
@@ -1301,9 +1287,9 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
                     else if(event_name == DATA_READY_TYPE_EVENT)
                     {
                         DataReadyEventData *event_data =
-                            new DataReadyEventData(esspos->device, NULL, event_name, errors);
+                            new DataReadyEventData(esspos->device, nullptr, event_name, errors);
                         // if a callback method was specified, call it!
-                        if(callback != NULL)
+                        if(callback != nullptr)
                         {
                             try
                             {
@@ -1331,15 +1317,15 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
                     }
                     else if(event_name == EventName[INTERFACE_CHANGE_EVENT])
                     {
-                        DevIntrChangeEventData *event_data = new DevIntrChangeEventData(esspos->device,
-                                                                                        event_name,
-                                                                                        domain_name,
-                                                                                        (CommandInfoList *) NULL,
-                                                                                        (AttributeInfoListEx *) NULL,
-                                                                                        false,
-                                                                                        errors);
+                        auto *event_data = new DevIntrChangeEventData(esspos->device,
+                                                                      event_name,
+                                                                      domain_name,
+                                                                      (CommandInfoList *) nullptr,
+                                                                      (AttributeInfoListEx *) nullptr,
+                                                                      false,
+                                                                      errors);
                         // if a callback method was specified, call it!
-                        if(callback != NULL)
+                        if(callback != nullptr)
                         {
                             try
                             {
@@ -1371,7 +1357,7 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
                             new PipeEventData(esspos->device, domain_name, event_name, dev_pipe, errors);
 
                         // if a callback method was specified, call it!
-                        if(callback != NULL)
+                        if(callback != nullptr)
                         {
                             try
                             {
@@ -1403,7 +1389,7 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
                             new FwdEventData(esspos->device, domain_name, event_name, dev_attr, errors);
 
                         // if a callback method was specified, call it!
-                        if(callback != NULL)
+                        if(callback != nullptr)
                         {
                             try
                             {
@@ -1431,7 +1417,7 @@ void EventConsumerKeepAliveThread::main_reconnect(ZmqEventConsumer *event_consum
                     }
                 }
 
-                if(ipos->second.event_system_failed == false)
+                if(!ipos->second.event_system_failed)
                 {
                     re_subscribe_after_reconnect(event_consumer, notifd_event_consumer, epos, ipos, domain_name);
                 }
@@ -1480,11 +1466,11 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
     auto &device = epos->second.get_device_proxy();
     subscriber_info.push_back(device.dev_name());
     subscriber_info.push_back(epos->second.obj_name);
-    subscriber_info.push_back("subscribe");
+    subscriber_info.emplace_back("subscribe");
     subscriber_info.push_back(epos->second.event_name);
     if(ipos->second.channel_type == ZMQ)
     {
-        subscriber_info.push_back("0");
+        subscriber_info.emplace_back("0");
     }
     subscriber_in << subscriber_info;
 
@@ -1502,14 +1488,14 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
         }
 
         ipos->second.heartbeat_skipped = false;
-        ipos->second.last_subscribed = time(NULL);
+        ipos->second.last_subscribed = Tango::get_current_system_datetime();
     }
     catch(...)
     {
         ds_failed = true;
     }
 
-    if(ds_failed == false)
+    if(!ds_failed)
     {
         //
         // Push an event with the value just read from the re-connected server
@@ -1525,13 +1511,13 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
             ev_name.erase(0, EVENT_COMPAT_IDL5_SIZE);
         }
 
-        if((ev_name == "change") || (ev_name == "quality") || (ev_name == "archive") || (ev_name == "user_event"))
+        if((ev_name == "change") || (ev_name == "alarm") || (ev_name == "archive") || (ev_name == "user_event"))
         {
             //
             // For attribute data event
             //
 
-            DeviceAttribute *da = NULL;
+            DeviceAttribute *da = nullptr;
             DevErrorList err;
             err.length(0);
 
@@ -1543,7 +1529,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
                 da = new DeviceAttribute();
                 *da = device.read_attribute(epos->second.obj_name.c_str());
 
-                if(da->has_failed() == true)
+                if(da->has_failed())
                 {
                     err = da->get_err_stack();
                 }
@@ -1566,7 +1552,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
             // if callback methods were specified, call them!
             unsigned int cb_nb = epos->second.callback_list.size();
             unsigned int cb_ctr = 0;
-            DeviceAttribute *da_copy = NULL;
+            DeviceAttribute *da_copy = nullptr;
 
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
@@ -1588,7 +1574,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
                 CallBack *callback = esspos->callback;
                 EventQueue *ev_queue = esspos->ev_queue;
 
-                if(callback != NULL)
+                if(callback != nullptr)
                 {
                     try
                     {
@@ -1623,7 +1609,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
             // For attribute configuration event
             //
 
-            AttributeInfoEx *aie = NULL;
+            AttributeInfoEx *aie = nullptr;
             DevErrorList err;
             err.length(0);
             std::string prefix;
@@ -1633,10 +1619,10 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
             }
             else
             {
-                if(device.get_from_env_var() == false)
+                if(!device.get_from_env_var())
                 {
                     prefix = "tango://";
-                    if(device.is_dbase_used() == false)
+                    if(!device.is_dbase_used())
                     {
                         prefix = prefix + device.get_dev_host() + ':' + device.get_dev_port() + '/';
                     }
@@ -1652,7 +1638,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
             }
 
             std::string dom_name = prefix + device.dev_name();
-            if(device.is_dbase_used() == false)
+            if(!device.is_dbase_used())
             {
                 dom_name = dom_name + MODIFIER_DBASE_NO;
             }
@@ -1684,7 +1670,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
 
             unsigned int cb_nb = epos->second.callback_list.size();
             unsigned int cb_ctr = 0;
-            AttributeInfoEx *aie_copy = NULL;
+            AttributeInfoEx *aie_copy = nullptr;
 
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
@@ -1712,7 +1698,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
                 EventQueue *ev_queue = esspos->ev_queue;
 
                 // if a callback method was specified, call it!
-                if(callback != NULL)
+                if(callback != nullptr)
                 {
                     try
                     {
@@ -1800,7 +1786,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
                 EventQueue *ev_queue = esspos->ev_queue;
 
                 // if a callback method was specified, call it!
-                if(callback != NULL)
+                if(callback != nullptr)
                 {
                     try
                     {
@@ -1864,7 +1850,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
             unsigned int cb_nb = epos->second.callback_list.size();
             unsigned int cb_ctr = 0;
 
-            DevicePipe *dp_copy = NULL;
+            DevicePipe *dp_copy = nullptr;
 
             for(esspos = epos->second.callback_list.begin(); esspos != epos->second.callback_list.end(); ++esspos)
             {
@@ -1886,7 +1872,7 @@ void EventConsumerKeepAliveThread::re_subscribe_after_reconnect(
                 CallBack *callback = esspos->callback;
                 EventQueue *ev_queue = esspos->ev_queue;
 
-                if(callback != NULL)
+                if(callback != nullptr)
                 {
                     try
                     {
@@ -1959,15 +1945,15 @@ void EventConsumerKeepAliveThread::stateless_subscription_failed(const std::vect
     // For attribute data event
     //
 
-    if((vpos->event_name == "change") || (vpos->event_name == "quality") || (vpos->event_name == "archive") ||
+    if((vpos->event_name == "change") || (vpos->event_name == "alarm") || (vpos->event_name == "archive") ||
        (vpos->event_name == "periodic") || (vpos->event_name == "user_event"))
     {
-        DeviceAttribute *da = NULL;
+        DeviceAttribute *da = nullptr;
         FwdEventData *event_data = new FwdEventData(vpos->device, domain_name, vpos->event_name, da, err);
 
         // if a callback method was specified, call it!
 
-        if(vpos->callback != NULL)
+        if(vpos->callback != nullptr)
         {
             try
             {
@@ -2001,14 +1987,14 @@ void EventConsumerKeepAliveThread::stateless_subscription_failed(const std::vect
 
     else if(vpos->event_name == CONF_TYPE_EVENT)
     {
-        AttributeInfoEx *aie = NULL;
+        AttributeInfoEx *aie = nullptr;
         AttrConfEventData *event_data = new AttrConfEventData(vpos->device, domain_name, vpos->event_name, aie, err);
 
         //
         // If a callback method was specified, call it!
         //
 
-        if(vpos->callback != NULL)
+        if(vpos->callback != nullptr)
         {
             try
             {
@@ -2039,13 +2025,13 @@ void EventConsumerKeepAliveThread::stateless_subscription_failed(const std::vect
     }
     else if(vpos->event_name == DATA_READY_TYPE_EVENT)
     {
-        DataReadyEventData *event_data = new DataReadyEventData(vpos->device, NULL, vpos->event_name, err);
+        DataReadyEventData *event_data = new DataReadyEventData(vpos->device, nullptr, vpos->event_name, err);
 
         //
         // If a callback method was specified, call it!
         //
 
-        if(vpos->callback != NULL)
+        if(vpos->callback != nullptr)
         {
             try
             {
@@ -2073,19 +2059,19 @@ void EventConsumerKeepAliveThread::stateless_subscription_failed(const std::vect
     }
     else if(vpos->event_name == EventName[INTERFACE_CHANGE_EVENT])
     {
-        DevIntrChangeEventData *event_data = new DevIntrChangeEventData(vpos->device,
-                                                                        vpos->event_name,
-                                                                        domain_name,
-                                                                        (CommandInfoList *) NULL,
-                                                                        (AttributeInfoListEx *) NULL,
-                                                                        false,
-                                                                        err);
+        auto *event_data = new DevIntrChangeEventData(vpos->device,
+                                                      vpos->event_name,
+                                                      domain_name,
+                                                      (CommandInfoList *) nullptr,
+                                                      (AttributeInfoListEx *) nullptr,
+                                                      false,
+                                                      err);
 
         //
         // If a callback method was specified, call it!
         //
 
-        if(vpos->callback != NULL)
+        if(vpos->callback != nullptr)
         {
             try
             {
@@ -2114,13 +2100,13 @@ void EventConsumerKeepAliveThread::stateless_subscription_failed(const std::vect
     else if(vpos->event_name == EventName[PIPE_EVENT])
     {
         PipeEventData *event_data =
-            new PipeEventData(vpos->device, domain_name, vpos->event_name, (DevicePipe *) NULL, err);
+            new PipeEventData(vpos->device, domain_name, vpos->event_name, (DevicePipe *) nullptr, err);
 
         //
         // If a callback method was specified, call it!
         //
 
-        if(vpos->callback != NULL)
+        if(vpos->callback != nullptr)
         {
             try
             {
