@@ -174,13 +174,13 @@ void EventQueue::insert_event(EventData *new_event)
     else
     {
         // allocate ring buffer when not yet done
-        if(event_buffer.empty() == true)
+        if(event_buffer.empty())
         {
-            event_buffer.resize(max_elt, NULL);
+            event_buffer.resize(max_elt, nullptr);
         }
 
         // free data when necessary
-        if(event_buffer[insert_elt] != NULL)
+        if(event_buffer[insert_elt] != nullptr)
         {
             delete event_buffer[insert_elt];
         }
@@ -228,13 +228,13 @@ void EventQueue::insert_event(AttrConfEventData *new_event)
     else
     {
         // allocate ring buffer when not yet done
-        if(conf_event_buffer.empty() == true)
+        if(conf_event_buffer.empty())
         {
-            conf_event_buffer.resize(max_elt, NULL);
+            conf_event_buffer.resize(max_elt, nullptr);
         }
 
         // free data when necessary
-        if(conf_event_buffer[insert_elt] != NULL)
+        if(conf_event_buffer[insert_elt] != nullptr)
         {
             delete conf_event_buffer[insert_elt];
         }
@@ -282,13 +282,13 @@ void EventQueue::insert_event(DataReadyEventData *new_event)
     else
     {
         // allocate ring buffer when not yet done
-        if(ready_event_buffer.empty() == true)
+        if(ready_event_buffer.empty())
         {
-            ready_event_buffer.resize(max_elt, NULL);
+            ready_event_buffer.resize(max_elt, nullptr);
         }
 
         // free data when necessary
-        if(ready_event_buffer[insert_elt] != NULL)
+        if(ready_event_buffer[insert_elt] != nullptr)
         {
             delete ready_event_buffer[insert_elt];
         }
@@ -348,16 +348,16 @@ void EventQueue::insert_event(DevIntrChangeEventData *new_event)
         // allocate ring buffer when not yet done
         //
 
-        if(dev_inter_event_buffer.empty() == true)
+        if(dev_inter_event_buffer.empty())
         {
-            dev_inter_event_buffer.resize(max_elt, NULL);
+            dev_inter_event_buffer.resize(max_elt, nullptr);
         }
 
         //
         // free data when necessary
         //
 
-        if(dev_inter_event_buffer[insert_elt] != NULL)
+        if(dev_inter_event_buffer[insert_elt] != nullptr)
         {
             delete dev_inter_event_buffer[insert_elt];
         }
@@ -411,13 +411,13 @@ void EventQueue::insert_event(PipeEventData *new_event)
     else
     {
         // allocate ring buffer when not yet done
-        if(pipe_event_buffer.empty() == true)
+        if(pipe_event_buffer.empty())
         {
-            pipe_event_buffer.resize(max_elt, NULL);
+            pipe_event_buffer.resize(max_elt, nullptr);
         }
 
         // free data when necessary
-        if(pipe_event_buffer[insert_elt] != NULL)
+        if(pipe_event_buffer[insert_elt] != nullptr)
         {
             delete pipe_event_buffer[insert_elt];
         }
@@ -500,7 +500,7 @@ TimeVal EventQueue::get_last_event_date()
     // lock the event queue
     omni_mutex_lock l(modification_mutex);
 
-    if(event_buffer.empty() == false)
+    if(!event_buffer.empty())
     {
         if(insert_elt == 0)
         {
@@ -513,7 +513,7 @@ TimeVal EventQueue::get_last_event_date()
     }
     else
     {
-        if(conf_event_buffer.empty() == false)
+        if(!conf_event_buffer.empty())
         {
             if(insert_elt == 0)
             {
@@ -526,7 +526,7 @@ TimeVal EventQueue::get_last_event_date()
         }
         else
         {
-            if(ready_event_buffer.empty() == false)
+            if(!ready_event_buffer.empty())
             {
                 if(insert_elt == 0)
                 {
@@ -542,7 +542,7 @@ TimeVal EventQueue::get_last_event_date()
                 TangoSys_OMemStream o;
                 o << "No new events available!\n";
                 o << "Cannot return any event date" << std::ends;
-                TANGO_THROW_API_EXCEPTION(EventSystemExcept, API_EventQueues, o.str());
+                TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_EventQueues, o.str());
             }
         }
     }
@@ -605,7 +605,7 @@ void EventQueue::get_events(EventDataList &event_list)
 
         // we do not want to free the event data when cleaning-up
         // the vector
-        event_buffer[index] = NULL;
+        event_buffer[index] = nullptr;
 
         if(index == 0)
         {
@@ -621,7 +621,6 @@ void EventQueue::get_events(EventDataList &event_list)
     nb_elt = 0;
 
     TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
-    return;
 }
 
 //--------------------------------------------------------------------------------------------------------------------
@@ -675,7 +674,7 @@ void EventQueue::get_events(AttrConfEventDataList &event_list)
 
         // we do not want to free the event data when cleaning-up
         // the vector
-        conf_event_buffer[index] = NULL;
+        conf_event_buffer[index] = nullptr;
 
         if(index == 0)
         {
@@ -691,8 +690,6 @@ void EventQueue::get_events(AttrConfEventDataList &event_list)
     nb_elt = 0;
 
     TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
-
-    return;
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -746,7 +743,7 @@ void EventQueue::get_events(DataReadyEventDataList &event_list)
 
         // we do not want to free the event data when cleaning-up
         // the vector
-        ready_event_buffer[index] = NULL;
+        ready_event_buffer[index] = nullptr;
 
         if(index == 0)
         {
@@ -762,8 +759,6 @@ void EventQueue::get_events(DataReadyEventDataList &event_list)
     nb_elt = 0;
 
     TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
-
-    return;
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -826,7 +821,7 @@ void EventQueue::get_events(DevIntrChangeEventDataList &event_list)
         // the vector
         //
 
-        dev_inter_event_buffer[index] = NULL;
+        dev_inter_event_buffer[index] = nullptr;
 
         if(index == 0)
         {
@@ -845,8 +840,6 @@ void EventQueue::get_events(DevIntrChangeEventDataList &event_list)
     nb_elt = 0;
 
     TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
-
-    return;
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -909,7 +902,7 @@ void EventQueue::get_events(PipeEventDataList &event_list)
         // the vector
         //
 
-        pipe_event_buffer[index] = NULL;
+        pipe_event_buffer[index] = nullptr;
 
         if(index == 0)
         {
@@ -928,8 +921,6 @@ void EventQueue::get_events(PipeEventDataList &event_list)
     nb_elt = 0;
 
     TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
-
-    return;
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -951,19 +942,19 @@ void EventQueue::get_events(CallBack *cb)
 {
     TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
 
-    if(cb == NULL)
+    if(cb == nullptr)
     {
         TangoSys_OMemStream o;
         o << "No callback object given!\n";
         o << "Cannot return any event data" << std::ends;
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept, API_EventQueues, o.str());
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_EventQueues, o.str());
     }
 
     //
     // Check the event type
     //
 
-    if(event_buffer.empty() == false)
+    if(!event_buffer.empty())
     {
         //
         // Get event data for a local data copy. The event reception should not be blocked in case of a problem in the
@@ -995,7 +986,7 @@ void EventQueue::get_events(CallBack *cb)
             }
         }
     }
-    else if(conf_event_buffer.empty() == false)
+    else if(!conf_event_buffer.empty())
     {
         //
         // Get event data for a local data copy. The event reception should not be blocked in case of a problem in the
@@ -1026,7 +1017,7 @@ void EventQueue::get_events(CallBack *cb)
             }
         }
     }
-    else if(dev_inter_event_buffer.empty() == false)
+    else if(!dev_inter_event_buffer.empty())
     {
         //
         // Get event data for a local data copy. The event reception should not be blocked in case of a problem in the
