@@ -36,7 +36,7 @@
 #include <tango/tango.h>
 #include <tango/client/eventconsumer.h>
 
-#include <stdio.h>
+#include <cstdio>
 
 #ifdef _TG_WINDOWS_
   #include <process.h>
@@ -49,7 +49,7 @@ using namespace CORBA;
 namespace Tango
 {
 
-NotifdEventConsumer *NotifdEventConsumer::_instance = NULL;
+NotifdEventConsumer *NotifdEventConsumer::_instance = nullptr;
 omni_mutex EventConsumer::ev_consumer_inst_mutex;
 
 void NotifdEventConsumer::disconnect_structured_push_consumer()
@@ -90,7 +90,7 @@ NotifdEventConsumer *NotifdEventConsumer::create()
     // check if the NotifdEventConsumer singleton exists, if so return it
     //
 
-    if(_instance != NULL)
+    if(_instance != nullptr)
     {
         return _instance;
     }
@@ -121,7 +121,7 @@ void *NotifdEventConsumer::run_undetached(void *arg)
     //
 
     ApiUtil *api_util_ptr = (ApiUtil *) arg;
-    if(api_util_ptr->in_server() == false)
+    if(!api_util_ptr->in_server())
     {
         CORBA::Object_var obj = orb_->resolve_initial_references("RootPOA");
         PortableServer::POA_var poa = PortableServer::POA::_narrow(obj);
@@ -133,7 +133,7 @@ void *NotifdEventConsumer::run_undetached(void *arg)
         orb_->destroy();
     }
 
-    return (void *) NULL;
+    return (void *) nullptr;
 }
 
 //+----------------------------------------------------------------------------
@@ -174,7 +174,7 @@ void NotifdEventConsumer::cleanup_EventChannel_map()
     for(evt_it = channel_map.begin(); evt_it != channel_map.end(); ++evt_it)
     {
         EventChannelStruct &evt_ch = evt_it->second;
-        if(evt_ch.adm_device_proxy != NULL)
+        if(evt_ch.adm_device_proxy != nullptr)
         {
             AutoTangoMonitor _mon(evt_ch.channel_monitor);
 
@@ -205,7 +205,7 @@ void NotifdEventConsumer::cleanup_EventChannel_map()
                 // Release the connection to the device server administration device
 
                 delete evt_ch.adm_device_proxy;
-                evt_ch.adm_device_proxy = NULL;
+                evt_ch.adm_device_proxy = nullptr;
             }
         }
     }
@@ -261,15 +261,16 @@ void NotifdEventConsumer::connect_event_system(const std::string &device_name,
     }
     catch(CORBA::COMM_FAILURE &)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught CORBA::COMM_FAILURE exception while creating event filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(
+            EventSystemExcept,
+            API_NotificationServiceFailed,
+            "Caught CORBA::COMM_FAILURE exception while creating event filter (check filter)");
     }
     catch(...)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught exception while creating event filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Caught exception while creating event filter (check filter)");
     }
 
     //
@@ -279,7 +280,7 @@ void NotifdEventConsumer::connect_event_system(const std::string &device_name,
     // protocol prefix
     //
 
-    std::string tmp_dev_name(device_name);
+    const std::string &tmp_dev_name(device_name);
     std::string::size_type pos;
     pos = tmp_dev_name.find("://");
     pos = pos + 3;
@@ -291,7 +292,7 @@ void NotifdEventConsumer::connect_event_system(const std::string &device_name,
 
     std::snprintf(constraint_expr,
                   sizeof(constraint_expr),
-                  "$domain_name == \'%s/%s\' and $event_name == \'%s\'",
+                  R"($domain_name == '%s/%s' and $event_name == '%s')",
                   d_name.c_str(),
                   att_name.c_str(),
                   event_name.c_str());
@@ -316,7 +317,7 @@ void NotifdEventConsumer::connect_event_system(const std::string &device_name,
     exp.length(1);
     exp[0].event_types = evs;
     exp[0].constraint_expr = Tango::string_dup(constraint_expr);
-    CORBA::Boolean res = 0; // OK
+    bool error_occurred = false;
 
     try
     {
@@ -330,20 +331,20 @@ void NotifdEventConsumer::connect_event_system(const std::string &device_name,
     {
         // cerr << "Exception thrown : Invalid constraint given "
         //      << (const char *)constraint_expr << std::endl;
-        res = 1;
+        error_occurred = true;
     }
     catch(...)
     {
         // cerr << "Exception thrown while adding constraint "
         //      << (const char *)constraint_expr << std::endl;
-        res = 1;
+        error_occurred = true;
     }
 
     //
     // If error, destroy filter. Else, set the filter_ok flag to true
     //
 
-    if(res == 1)
+    if(error_occurred)
     {
         try
         {
@@ -354,9 +355,9 @@ void NotifdEventConsumer::connect_event_system(const std::string &device_name,
         }
 
         filter = CosNotifyFilter::Filter::_nil();
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught exception while creating event filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Caught exception while creating event filter (check filter)");
     }
     else
     {
@@ -394,11 +395,11 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
     // started with the -file option)
     //
 
-    int channel_exported;
+    bool channel_exported;
     std::string channel_ior;
     std::string hostname;
 
-    if(db != NULL)
+    if(db != nullptr)
     {
         //
         // Remove extra info from channel name (protocol,  dbase=xxx)
@@ -439,7 +440,7 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
 
         received.inout() >>= dev_import_list;
         channel_ior = std::string((dev_import_list->svalue)[1]);
-        channel_exported = dev_import_list->lvalue[0];
+        channel_exported = static_cast<bool>(dev_import_list->lvalue[0]);
 
         // get the hostname where the notifyd should be running
         hostname = std::string(dev_import_list->svalue[3]);
@@ -487,20 +488,21 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
 
             if(CORBA::is_nil(eventChannel))
             {
-                channel_exported = 0;
+                channel_exported = false;
             }
         }
         catch(...)
         {
-            TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                      API_NotificationServiceFailed,
-                                      "Failed to narrow EventChannel from notification daemon (hint: make sure the "
-                                      "notifd process is running on this host)");
+            TANGO_THROW_DETAILED_EXCEPTION(
+                EventSystemExcept,
+                API_NotificationServiceFailed,
+                "Failed to narrow EventChannel from notification daemon (hint: make sure the "
+                "notifd process is running on this host)");
         }
     }
     else
     {
-        TANGO_THROW_API_EXCEPTION(
+        TANGO_THROW_DETAILED_EXCEPTION(
             EventSystemExcept,
             API_EventChannelNotExported,
             "Failed to narrow EventChannel (hint: make sure a notifd process is running on the server host)");
@@ -521,18 +523,20 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
         if(CORBA::is_nil(consumerAdmin))
         {
             // cerr << "Could not get CosNotifyChannelAdmin::ConsumerAdmin" << std::endl;
-            TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                      API_NotificationServiceFailed,
-                                      "Failed to get default Consumer admin from notification daemon (hint: make sure "
-                                      "the notifd process is running on this host)");
+            TANGO_THROW_DETAILED_EXCEPTION(
+                EventSystemExcept,
+                API_NotificationServiceFailed,
+                "Failed to get default Consumer admin from notification daemon (hint: make sure "
+                "the notifd process is running on this host)");
         }
     }
     catch(...)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Failed to get default Consumer admin from notification daemon (hint: make sure the "
-                                  "notifd process is running on this host)");
+        TANGO_THROW_DETAILED_EXCEPTION(
+            EventSystemExcept,
+            API_NotificationServiceFailed,
+            "Failed to get default Consumer admin from notification daemon (hint: make sure the "
+            "notifd process is running on this host)");
     }
 
     //
@@ -550,10 +554,11 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
         if(CORBA::is_nil(proxySupplier))
         {
             // cerr << "Could not get CosNotifyChannelAdmin::ProxySupplier" << std::endl;
-            TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                      API_NotificationServiceFailed,
-                                      "Failed to obtain a push supplier from notification daemon (hint: make sure the "
-                                      "notifd process is running on this host)");
+            TANGO_THROW_DETAILED_EXCEPTION(
+                EventSystemExcept,
+                API_NotificationServiceFailed,
+                "Failed to obtain a push supplier from notification daemon (hint: make sure the "
+                "notifd process is running on this host)");
         }
 
         structuredProxyPushSupplier = CosNotifyChannelAdmin::StructuredProxyPushSupplier::_narrow(proxySupplier);
@@ -561,10 +566,11 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
         {
             // cerr << "Tango::NotifdEventConsumer::NotifdEventConsumer() could not get
             // CosNotifyChannelAdmin::StructuredProxyPushSupplier" << std::endl;
-            TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                      API_NotificationServiceFailed,
-                                      "Failed to narrow the push supplier from notification daemon (hint: make sure "
-                                      "the notifd process is running on this host)");
+            TANGO_THROW_DETAILED_EXCEPTION(
+                EventSystemExcept,
+                API_NotificationServiceFailed,
+                "Failed to narrow the push supplier from notification daemon (hint: make sure "
+                "the notifd process is running on this host)");
         }
 
         //
@@ -576,10 +582,10 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
     }
     catch(const CosNotifyChannelAdmin::AdminLimitExceeded &)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Failed to get PushSupplier from notification daemon due to AdminLimitExceeded "
-                                  "(hint: make sure the notifd process is running on this host)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Failed to get PushSupplier from notification daemon due to AdminLimitExceeded "
+                                       "(hint: make sure the notifd process is running on this host)");
     }
 
     //
@@ -595,14 +601,14 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
         std::cerr << "Tango::NotifdEventConsumer::NotifdEventConsumer() caught AlreadyConnected exception" << std::endl;
     }
 
-    EvChanIte evt_it = channel_map.end();
-    if(reconnect == true)
+    auto evt_it = channel_map.end();
+    if(reconnect)
     {
         evt_it = channel_map.find(channel_name);
         EventChannelStruct &evt_ch = evt_it->second;
         evt_ch.eventChannel = eventChannel;
         evt_ch.structuredProxyPushSupplier = structuredProxyPushSupplier;
-        evt_ch.last_heartbeat = time(NULL);
+        evt_ch.last_heartbeat = Tango::get_current_system_datetime();
         evt_ch.heartbeat_skipped = false;
         evt_ch.notifyd_host = hostname;
         evt_ch.event_system_failed = false;
@@ -613,9 +619,9 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
         EventChannelStruct new_event_channel_struct;
         new_event_channel_struct.eventChannel = eventChannel;
         new_event_channel_struct.structuredProxyPushSupplier = structuredProxyPushSupplier;
-        new_event_channel_struct.last_heartbeat = time(NULL);
+        new_event_channel_struct.last_heartbeat = Tango::get_current_system_datetime();
         new_event_channel_struct.heartbeat_skipped = false;
-        new_event_channel_struct.adm_device_proxy = NULL;
+        new_event_channel_struct.adm_device_proxy = nullptr;
         // create a channel monitor
         new_event_channel_struct.channel_monitor = new TangoMonitor(channel_name.c_str());
         // set the timeout for the channel monitor to 1000ms not to block the event consumer for to long.
@@ -646,9 +652,9 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
     catch(...)
     {
         // cerr << "Caught exception obtaining filter object" << std::endl;
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught exception while creating heartbeat filter (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Caught exception while creating heartbeat filter (check filter)");
     }
 
     //
@@ -660,7 +666,7 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
     exp.length(1);
     exp[0].event_types = evs;
     exp[0].constraint_expr = Tango::string_dup(constraint_expr);
-    CORBA::Boolean res = 0; // OK
+    bool error_occurred = false;
     try
     {
         CosNotifyFilter::ConstraintInfoSeq_var dummy = filter->add_constraints(exp);
@@ -668,14 +674,14 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
     }
     catch(...)
     {
-        res = 1; // error
+        error_occurred = true;
     }
 
     //
     // If error, destroy filter
     //
 
-    if(res == 1)
+    if(error_occurred)
     {
         try
         {
@@ -687,9 +693,9 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
 
         filter = CosNotifyFilter::Filter::_nil();
 
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept,
-                                  API_NotificationServiceFailed,
-                                  "Caught exception while adding constraint for heartbeat (check filter)");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept,
+                                       API_NotificationServiceFailed,
+                                       "Caught exception while adding constraint for heartbeat (check filter)");
     }
 }
 
@@ -719,7 +725,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
         std::string fq_dev_name = domain_name;
         if(event_type.find("tango://") != std::string::npos)
         {
-            if(event_type.find("#") == std::string::npos)
+            if(event_type.find('#') == std::string::npos)
             {
                 fq_dev_name.insert(0, event_type);
             }
@@ -780,7 +786,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
         // list. The first db server is the one used to create the entry in the map
         //
 
-        if(ipos == channel_map.end() && svr_send_tg_host == true)
+        if(ipos == channel_map.end() && svr_send_tg_host)
         {
             std::string svc_tango_host = event_type.substr(8, event_type.size() - 9);
             unsigned int i = 0;
@@ -805,7 +811,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
             try
             {
                 AutoTangoMonitor _mon(evt_ch.channel_monitor);
-                evt_ch.last_heartbeat = time(NULL);
+                evt_ch.last_heartbeat = Tango::get_current_system_datetime();
             }
             catch(...)
             {
@@ -821,7 +827,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
         std::string fq_dev_name = domain_name;
         if(event_type.find("tango://") != std::string::npos)
         {
-            if(event_type.find("#") == std::string::npos)
+            if(event_type.find('#') == std::string::npos)
             {
                 fq_dev_name.insert(0, event_type);
             }
@@ -863,7 +869,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
 
                 ipos = event_callback_map.find(attr_event_name);
 
-                if(ipos == event_callback_map.end() && svr_send_tg_host == true)
+                if(ipos == event_callback_map.end() && svr_send_tg_host)
                 {
                     std::string svc_tango_host = event_type.substr(8, event_type.size() - 9);
                     unsigned int i = 0;
@@ -893,23 +899,23 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
             {
                 AutoTangoMonitor _mon(evt_cb.callback_monitor);
 
-                AttributeValue *attr_value = NULL;
-                AttributeValue_3 *attr_value_3 = NULL;
-                AttributeValue_4 *attr_value_4 = NULL;
-                AttributeConfig_2 *attr_conf_2 = NULL;
-                AttributeConfig_3 *attr_conf_3 = NULL;
-                AttributeInfoEx *attr_info_ex = NULL;
-                AttDataReady *att_ready = NULL;
+                AttributeValue *attr_value = nullptr;
+                AttributeValue_3 *attr_value_3 = nullptr;
+                AttributeValue_4 *attr_value_4 = nullptr;
+                AttributeConfig_2 *attr_conf_2 = nullptr;
+                AttributeConfig_3 *attr_conf_3 = nullptr;
+                AttributeInfoEx *attr_info_ex = nullptr;
+                AttDataReady *att_ready = nullptr;
                 DevErrorList errors;
                 bool ev_attr_conf = false;
                 bool ev_attr_ready = false;
-                const DevErrorList *err_ptr = NULL;
+                const DevErrorList *err_ptr = nullptr;
 
                 //
                 // Check if the event transmit error
                 //
 
-                DeviceAttribute *dev_attr = NULL;
+                DeviceAttribute *dev_attr = nullptr;
                 CORBA::TypeCode_var ty = event.remainder_of_body.type();
                 if(ty->kind() == tk_struct)
                 {
@@ -969,7 +975,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                         errors[0].reason = Tango::string_dup(API_IncompatibleAttrDataType);
                         errors[0].desc =
                             Tango::string_dup("Unknown structure used to pass attribute value (Need compilation ?)");
-                        dev_attr = NULL;
+                        dev_attr = nullptr;
                     }
                 }
                 else
@@ -1018,13 +1024,13 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                             map_modification_lock.readerOut();
                         }
 
-                        if((ev_attr_conf == false) && (ev_attr_ready == false))
+                        if((!ev_attr_conf) && (!ev_attr_ready))
                         {
                             EventData *event_data;
                             if(cb_ctr != cb_nb)
                             {
-                                DeviceAttribute *dev_attr_copy = NULL;
-                                if(dev_attr != NULL)
+                                DeviceAttribute *dev_attr_copy = nullptr;
+                                if(dev_attr != nullptr)
                                 {
                                     dev_attr_copy = new DeviceAttribute();
                                     dev_attr_copy->deep_copy(*dev_attr);
@@ -1039,7 +1045,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                             }
 
                             // if a callback method was specified, call it!
-                            if(callback != NULL)
+                            if(callback != nullptr)
                             {
                                 try
                                 {
@@ -1062,7 +1068,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                                 ev_queue->insert_event(event_data);
                             }
                         }
-                        else if(ev_attr_ready == false)
+                        else if(!ev_attr_ready)
                         {
                             AttrConfEventData *event_data;
 
@@ -1080,7 +1086,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                             }
 
                             // if callback methods were specified, call them!
-                            if(callback != NULL)
+                            if(callback != nullptr)
                             {
                                 try
                                 {
@@ -1108,7 +1114,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                             DataReadyEventData *event_data =
                                 new DataReadyEventData(esspos->device, att_ready, event_name, errors);
                             // if a callback method was specified, call it!
-                            if(callback != NULL)
+                            if(callback != nullptr)
                             {
                                 try
                                 {
@@ -1139,11 +1145,11 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                             map_modification_lock.readerOut();
                         }
 
-                        if((ev_attr_conf == false) && (ev_attr_ready == false))
+                        if((!ev_attr_conf) && (!ev_attr_ready))
                         {
                             delete dev_attr;
                         }
-                        else if(ev_attr_ready == false)
+                        else if(!ev_attr_ready)
                         {
                             delete attr_info_ex;
                         }
@@ -1153,7 +1159,7 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
             catch(...)
             {
                 // free the map lock if not already done
-                if(map_lock == true)
+                if(map_lock)
                 {
                     map_modification_lock.readerOut();
                 }
