@@ -61,7 +61,7 @@ void Connection::command_inout_asynch(const std::string &command, const DeviceDa
         TangoSys_OMemStream desc;
         desc << "Failed to execute command_inout on device " << dev_name();
         desc << ", command " << command << std::ends;
-        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
     }
 
     //
@@ -89,12 +89,8 @@ void Connection::command_inout_asynch(const std::string &command, const DeviceDa
 
     if(version >= 4)
     {
-        ClntIdent ci;
-        ApiUtil *au = ApiUtil::instance();
-        ci.cpp_clnt(au->get_client_pid());
-
         req_seq[0]->add_in_arg() <<= source;
-        req_seq[0]->add_in_arg() <<= ci;
+        req_seq[0]->add_in_arg() <<= get_client_identification();
     }
     else if(version >= 2)
     {
@@ -161,7 +157,7 @@ void Connection::get_asynch_replies()
 
     try
     {
-        while(orb->poll_next_response() == true)
+        while(orb->poll_next_response())
         {
             CORBA::Request_ptr req;
             orb->get_next_response(req);
@@ -214,7 +210,7 @@ void Connection::get_asynch_replies()
     //
 
     TgRequest *tg_ptr;
-    while((tg_ptr = ApiUtil::instance()->get_pasyn_table()->get_request(this)) != NULL)
+    while((tg_ptr = ApiUtil::instance()->get_pasyn_table()->get_request(this)) != nullptr)
     {
         switch(tg_ptr->req_type)
         {
@@ -254,7 +250,7 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
     errors.length(0);
 
     CORBA::NVList_ptr req_arg = req->arguments();
-    const char *cmd = NULL;
+    const char *cmd = nullptr;
     CORBA::NamedValue_ptr nv = req_arg->item(0);
     *(nv->value()) >>= cmd;
 
@@ -263,7 +259,7 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
     //
 
     CORBA::Environment_ptr env = req->env();
-    if(!CORBA::is_nil(env) && (env->exception() == NULL))
+    if(!CORBA::is_nil(env) && (env->exception() == nullptr))
     {
         //
         // Get received value
@@ -293,7 +289,7 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
         CORBA::SystemException *sys_ex;
         bool to_except = false;
 
-        if((tra = CORBA::TRANSIENT::_downcast(ex_ptr)) != NULL)
+        if((tra = CORBA::TRANSIENT::_downcast(ex_ptr)) != nullptr)
         {
             if(tra->minor() == omni::TRANSIENT_CallTimedout)
             {
@@ -321,7 +317,7 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
             }
         }
 
-        if((unk_ex = CORBA::UnknownUserException::_downcast(ex_ptr)) != NULL)
+        if((unk_ex = CORBA::UnknownUserException::_downcast(ex_ptr)) != nullptr)
         {
             //
             // It is a UserUnknownException exception. This means that the
@@ -348,7 +344,7 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
             errors[nb_err].origin = Tango::string_dup(TANGO_EXCEPTION_ORIGIN);
             errors[nb_err].reason = Tango::string_dup(API_CommandFailed);
         }
-        else if(((sys_ex = CORBA::SystemException::_downcast(ex_ptr)) != NULL) && (to_except == false))
+        else if(((sys_ex = CORBA::SystemException::_downcast(ex_ptr)) != nullptr) && (!to_except))
         {
             set_connection_state(CONNECTION_NOTOK);
 
@@ -406,7 +402,7 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
 
 void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
 {
-    std::vector<DeviceAttribute> *dev_attr = NULL;
+    std::vector<DeviceAttribute> *dev_attr = nullptr;
     Tango::DevErrorList errors(2);
     errors.length(0);
 
@@ -427,7 +423,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
     //
 
     CORBA::Environment_ptr env = req->env();
-    if(!CORBA::is_nil(env) && (env->exception() == NULL))
+    if(!CORBA::is_nil(env) && (env->exception() == nullptr))
     {
         //
         // Get received value
@@ -445,6 +441,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
 
         switch(version)
         {
+        case 6:
         case 5:
             dii_any >>= received_5;
             nb_received = received_5->length();
@@ -472,7 +469,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
         {
             if(version >= 3)
             {
-                if(version == 5)
+                if(version >= 5)
                 {
                     ApiUtil::attr_to_device(&((*received_5)[i]), version, &((*dev_attr)[i]));
                 }
@@ -482,7 +479,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
                 }
                 else
                 {
-                    ApiUtil::attr_to_device(NULL, &((*received_3)[i]), version, &((*dev_attr)[i]));
+                    ApiUtil::attr_to_device(nullptr, &((*received_3)[i]), version, &((*dev_attr)[i]));
                 }
 
                 //
@@ -507,7 +504,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
             }
             else
             {
-                ApiUtil::attr_to_device(&((*received)[i]), NULL, version, &((*dev_attr)[i]));
+                ApiUtil::attr_to_device(&((*received)[i]), nullptr, version, &((*dev_attr)[i]));
             }
         }
     }
@@ -527,7 +524,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
         //
 
         CORBA::TRANSIENT *tra;
-        if((tra = CORBA::TRANSIENT::_downcast(ex_ptr)) != NULL)
+        if((tra = CORBA::TRANSIENT::_downcast(ex_ptr)) != nullptr)
         {
             if(tra->minor() == omni::TRANSIENT_CallTimedout)
             {
@@ -562,7 +559,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
             }
         }
 
-        if((unk_ex = CORBA::UnknownUserException::_downcast(ex_ptr)) != NULL)
+        if((unk_ex = CORBA::UnknownUserException::_downcast(ex_ptr)) != nullptr)
         {
             //
             // It is a UserUnknownException exception. This means that the
@@ -595,7 +592,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
             errors[nb_err].origin = Tango::string_dup(TANGO_EXCEPTION_ORIGIN);
             errors[nb_err].reason = Tango::string_dup(API_AttributeFailed);
         }
-        else if(((sys_ex = CORBA::SystemException::_downcast(ex_ptr)) != NULL) && (to_except == false))
+        else if(((sys_ex = CORBA::SystemException::_downcast(ex_ptr)) != nullptr) && (!to_except))
         {
             set_connection_state(CONNECTION_NOTOK);
 
@@ -667,14 +664,14 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
     long nb_attr = 0;
     if(version >= 4)
     {
-        if((*(nv->value()) >>= att_4) == true)
+        if(*(nv->value()) >>= att_4)
         {
             nb_attr = att_4->length();
         }
     }
     else
     {
-        if((*(nv->value()) >>= att) == true)
+        if(*(nv->value()) >>= att)
         {
             nb_attr = att->length();
         }
@@ -685,7 +682,7 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
     //
 
     CORBA::Environment_ptr env = req->env();
-    if(!CORBA::is_nil(env) && (env->exception() != NULL))
+    if(!CORBA::is_nil(env) && (env->exception() != nullptr))
     {
         //
         // The reply is an exception
@@ -701,7 +698,7 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
         //
 
         CORBA::TRANSIENT *tra;
-        if((tra = CORBA::TRANSIENT::_downcast(ex_ptr)) != NULL)
+        if((tra = CORBA::TRANSIENT::_downcast(ex_ptr)) != nullptr)
         {
             if(tra->minor() == omni::TRANSIENT_CallTimedout)
             {
@@ -740,16 +737,16 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
             }
         }
 
-        if((unk_ex = CORBA::UnknownUserException::_downcast(ex_ptr)) != NULL)
+        if((unk_ex = CORBA::UnknownUserException::_downcast(ex_ptr)) != nullptr)
         {
             //
             // It is a UserUnknownException exception. This means that the
             // server has sent a DevFailed exception
             //
 
-            const Tango::DevFailed *serv_ex = NULL;
+            const Tango::DevFailed *serv_ex = nullptr;
             Tango::DevFailed ex;
-            const Tango::MultiDevFailed *multi_serv_ex = NULL;
+            const Tango::MultiDevFailed *multi_serv_ex = nullptr;
             Tango::MultiDevFailed m_ex;
             TangoSys_OMemStream desc;
 
@@ -787,7 +784,7 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
             }
             else
             {
-                if((unk_ex->exception() >>= multi_serv_ex) == true)
+                if(unk_ex->exception() >>= multi_serv_ex)
                 {
                     m_ex = *multi_serv_ex;
                     err_3 = Tango::NamedDevFailedList(m_ex,
@@ -831,7 +828,7 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
                 }
             }
         }
-        else if(((sys_ex = CORBA::SystemException::_downcast(ex_ptr)) != NULL) && (to_except == false))
+        else if(((sys_ex = CORBA::SystemException::_downcast(ex_ptr)) != nullptr) && (!to_except))
         {
             set_connection_state(CONNECTION_NOTOK);
 
@@ -882,14 +879,14 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
     {
         for(int i = 0; i < nb_attr; i++)
         {
-            att_name.push_back((*att_4)[i].name.in());
+            att_name.emplace_back((*att_4)[i].name.in());
         }
     }
     else
     {
         for(int i = 0; i < nb_attr; i++)
         {
-            att_name.push_back((*att)[i].name.in());
+            att_name.emplace_back((*att)[i].name.in());
         }
     }
 
@@ -922,7 +919,7 @@ void Connection::get_asynch_replies(long call_timeout)
     //
 
     TgRequest *tg_ptr;
-    while((tg_ptr = ApiUtil::instance()->get_pasyn_table()->get_request(this)) != NULL)
+    while((tg_ptr = ApiUtil::instance()->get_pasyn_table()->get_request(this)) != nullptr)
     {
         switch(tg_ptr->req_type)
         {
@@ -967,7 +964,7 @@ void Connection::get_asynch_replies(long call_timeout)
                 std::this_thread::sleep_for(std::chrono::milliseconds(20));
                 nb--;
 
-                if(orb->poll_next_response() == true)
+                if(orb->poll_next_response())
                 {
                     orb->get_next_response(req);
 
@@ -1016,7 +1013,7 @@ void Connection::get_asynch_replies(long call_timeout)
             {
                 TangoSys_OMemStream desc;
                 desc << "Still some reply(ies) for asynchronous callback call(s) to be received" << std::ends;
-                TANGO_THROW_API_EXCEPTION(ApiAsynNotThereExcept, API_AsynReplyNotArrived, desc.str());
+                TANGO_THROW_DETAILED_EXCEPTION(ApiAsynNotThereExcept, API_AsynReplyNotArrived, desc.str());
             }
         }
         else
@@ -1094,7 +1091,7 @@ void DeviceProxy::read_attributes_asynch(const std::vector<std::string> &attr_na
     {
         TangoSys_OMemStream desc;
         desc << "Failed to execute read_attributes_asynch on device " << dev_name() << std::ends;
-        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
     }
 
     //
@@ -1120,26 +1117,18 @@ void DeviceProxy::read_attributes_asynch(const std::vector<std::string> &attr_na
 
     if(version >= 5)
     {
-        ClntIdent ci;
-        ApiUtil *au = ApiUtil::instance();
-        ci.cpp_clnt(au->get_client_pid());
-
         req_seq[0] = Connection::device_5->_request("read_attributes_5");
         req_seq[0]->add_in_arg() <<= names;
         req_seq[0]->add_in_arg() <<= source;
-        req_seq[0]->add_in_arg() <<= ci;
+        req_seq[0]->add_in_arg() <<= get_client_identification();
         req_seq[0]->set_return_type(Tango::_tc_AttributeValueList_5);
     }
     else if(version == 4)
     {
-        ClntIdent ci;
-        ApiUtil *au = ApiUtil::instance();
-        ci.cpp_clnt(au->get_client_pid());
-
         req_seq[0] = Connection::device_4->_request("read_attributes_4");
         req_seq[0]->add_in_arg() <<= names;
         req_seq[0]->add_in_arg() <<= source;
-        req_seq[0]->add_in_arg() <<= ci;
+        req_seq[0]->add_in_arg() <<= get_client_identification();
         req_seq[0]->set_return_type(Tango::_tc_AttributeValueList_4);
     }
     else if(version == 3)
@@ -1211,7 +1200,7 @@ void DeviceProxy::write_attributes_asynch(const std::vector<DeviceAttribute> &at
     {
         TangoSys_OMemStream desc;
         desc << "Failed to execute read_attributes_asynch on device " << dev_name() << std::ends;
-        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
     }
 
     //
@@ -1248,13 +1237,9 @@ void DeviceProxy::write_attributes_asynch(const std::vector<DeviceAttribute> &at
 
     if(version >= 4)
     {
-        ClntIdent ci;
-        ApiUtil *au = ApiUtil::instance();
-        ci.cpp_clnt(au->get_client_pid());
-
         req_seq[0] = device_4->_request("write_attributes_4");
         req_seq[0]->add_in_arg() <<= att_4;
-        req_seq[0]->add_in_arg() <<= ci;
+        req_seq[0]->add_in_arg() <<= get_client_identification();
         req_seq[0]->exceptions()->add(Tango::_tc_MultiDevFailed);
     }
     else if(version == 3)
@@ -1320,7 +1305,7 @@ void DeviceProxy::write_attribute_asynch(const DeviceAttribute &attr, CallBack &
     {
         TangoSys_OMemStream desc;
         desc << "Failed to execute read_attributes_asynch on device " << dev_name() << std::ends;
-        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, e, API_CommandFailed, desc.str());
     }
 
     //
@@ -1346,13 +1331,9 @@ void DeviceProxy::write_attribute_asynch(const DeviceAttribute &attr, CallBack &
 
     if(version >= 4)
     {
-        ClntIdent ci;
-        ApiUtil *au = ApiUtil::instance();
-        ci.cpp_clnt(au->get_client_pid());
-
         req_seq[0] = device_4->_request("write_attributes_4");
         req_seq[0]->add_in_arg() <<= att_4;
-        req_seq[0]->add_in_arg() <<= ci;
+        req_seq[0]->add_in_arg() <<= get_client_identification();
         req_seq[0]->exceptions()->add(Tango::_tc_MultiDevFailed);
     }
     else if(version == 3)
