@@ -30,9 +30,8 @@
 #ifndef _CONNECTION_H
 #define _CONNECTION_H
 
-#include <tango/server/tango_optional.h>
-
 #include <chrono>
+#include <optional>
 
 /****************************************************************************************
  *                                                                                         *
@@ -79,7 +78,21 @@ class Connection
     int timeout;
 
     int connection_state;
+
+    // the idl version of the peer
     int version;
+
+    // the ultimate idl version supported by the server in which the peer is running - introduced for the
+    // telemetry service to offer the related features to any device inheriting from device_4impl or higher.
+    int server_version;
+
+    // returns a ClntIdent initialized according to the IDL version of the device (peer) and the ultimate IDL version
+    // supported by the server in which the peer is running. Added for the telemetry service introduced in IDLv6. Any
+    // device with IDL version >= 4 running in a server in which the ultimate version of the IDL is >= 6, will benefit
+    // from the telemetry features offered at the kernel level (low level profiling). This will limit the discontinuity
+    // in the tracing information. See ClntIdent in tango.idl v6 for details.
+    ClntIdent get_client_identification() const;
+
     Tango::DevSource source;
 
     bool check_acc;
@@ -112,16 +125,13 @@ class Connection
     class ConnectionExt
     {
       public:
-        ConnectionExt() :
-            has_alt_adr(false)
-        {
-        }
+        ConnectionExt() { }
 
         ~ConnectionExt() { }
 
         ConnectionExt &operator=(const ConnectionExt &);
 
-        bool has_alt_adr;
+        bool has_alt_adr{false};
     };
 
     std::unique_ptr<ConnectionExt> ext;
@@ -129,7 +139,7 @@ class Connection
     bool tr_reco;
     Tango::Device_3_var device_3;
 
-    tango_optional<std::chrono::steady_clock::time_point> prev_failed_t0;
+    std::optional<std::chrono::steady_clock::time_point> prev_failed_t0;
 
     Tango::Device_4_var device_4;
     omni_mutex adm_dev_mutex;
@@ -141,6 +151,8 @@ class Connection
 
     Tango::Device_5_var device_5;
 
+    Tango::Device_6_var device_6;
+
   public:
     ///@publicsection
     /**@name Miscellaneous methods */
@@ -170,11 +182,23 @@ class Connection
      *
      * @return The device IDL version
      */
-    int get_idl_version()
+    int get_idl_version() const
     {
         return version;
     }
 
+    /**
+     * Get server IDL version
+     *
+     * Get the ultimate idl version supported by the server in which the device is running
+     *
+     * @return The server IDL version
+     */
+    int get_server_idl_version() const
+    {
+        return server_version;
+    }
+
     /**
      * Get device source
      *
