@@ -105,14 +105,7 @@ class NamedDevFailedList : public Tango::DevFailed
      */
     bool call_failed()
     {
-        if((err_list.empty() == true) && (errors.length() != 0))
-        {
-            return true;
-        }
-        else
-        {
-            return false;
-        }
+        return (err_list.empty()) && (errors.length() != 0);
     }
 
     std::vector<NamedDevFailed>
@@ -418,7 +411,6 @@ MAKE_EXCEPT(AsynReplyNotArrived, ApiAsynNotThereExcept)
 MAKE_EXCEPT(EventSystemFailed, EventSystemExcept)
 MAKE_EXCEPT(DeviceUnlocked, DeviceUnlockedExcept)
 MAKE_EXCEPT(NotAllowed, NotAllowedExcept)
-MAKE_EXCEPT(ProgrammingError, ProgrammingErrorExcept)
 
 //
 // Define macros for the management of the Corba TRANSIENT exception
@@ -525,20 +517,14 @@ MAKE_EXCEPT(ProgrammingError, ProgrammingErrorExcept)
             E, (const char *) API_CommunicationFailed, desc.str(), (const char *) "Connection::command_inout()"); \
     }
 
-#define TANGO_THROW_API_EXCEPTION(ExceptionClass, reason, desc) \
-    ExceptionClass ::throw_exception(                           \
+#define TANGO_THROW_DETAILED_EXCEPTION(ExceptionClass, reason, desc) \
+    ExceptionClass ::throw_exception(                                \
         reason, desc, (std::string(TANGO_CURRENT_FUNCTION) + " at (" TANGO_FILE_AND_LINE ")").c_str())
 
-#define TANGO_RETHROW_API_EXCEPTION(ExceptionClass, original, reason, desc) \
-    ExceptionClass ::re_throw_exception(                                    \
+#define TANGO_RETHROW_DETAILED_EXCEPTION(ExceptionClass, original, reason, desc) \
+    ExceptionClass ::re_throw_exception(                                         \
         original, reason, desc, (std::string(TANGO_CURRENT_FUNCTION) + " at (" TANGO_FILE_AND_LINE ")").c_str())
 
-#define TANGO_THROW_ON_DEFAULT(switchValue) \
-    TANGO_THROW_API_EXCEPTION(              \
-        ProgrammingErrorExcept,             \
-        "Programming Error",                \
-        ((std::string("Reached unexpected default branch with value: ") + std::to_string(switchValue)).c_str()))
-
 } // namespace Tango
 
 #endif /* _APIEXCEPT_H */
