@@ -149,6 +149,7 @@ struct _DeviceInfo
     long server_version;
     std::string doc_url;
     std::string dev_type;
+    std::map<std::string, std::string> version_info;
 };
 
 typedef _DeviceInfo DeviceInfo;
@@ -508,7 +509,7 @@ class DeviceDataHistory : public DeviceData
     DeviceDataHistory(DeviceDataHistory &&);
     DeviceDataHistory &operator=(DeviceDataHistory &&);
 
-    ~DeviceDataHistory();
+    ~DeviceDataHistory() override;
 
     ///@publicsection
     /**
@@ -658,7 +659,7 @@ class DeviceAttributeHistory : public DeviceAttribute
     DeviceAttributeHistory(DeviceAttributeHistory &&);
     DeviceAttributeHistory &operator=(DeviceAttributeHistory &&);
 
-    ~DeviceAttributeHistory();
+    ~DeviceAttributeHistory() override;
 
     ///@publicsection
     /**
@@ -775,26 +776,26 @@ class DummyDeviceProxy : public Tango::Connection
     {
     }
 
-    virtual std::string get_corba_name(bool)
+    std::string get_corba_name(bool) override
     {
         std::string str;
         return str;
     }
 
-    virtual std::string build_corba_name()
+    std::string build_corba_name() override
     {
         std::string str;
         return str;
     }
 
-    virtual int get_lock_ctr()
+    int get_lock_ctr() override
     {
         return 0;
     }
 
-    virtual void set_lock_ctr(int) { }
+    void set_lock_ctr(int) override { }
 
-    virtual std::string dev_name()
+    std::string dev_name() override
     {
         std::string str;
         return str;
@@ -867,7 +868,7 @@ inline void Connection::dec_asynch_counter(asyn_req_type ty)
 inline void DeviceProxy::check_connect_adm_device()
 {
     omni_mutex_lock guard(adm_dev_mutex);
-    if(adm_device == NULL)
+    if(adm_device == nullptr)
     {
         connect_to_adm_device();
     }
@@ -902,59 +903,59 @@ inline int
 ///                    -----------
 ///
 
-#define READ_ATT_EXCEPT(NAME_CHAR, OBJ)                                                            \
-    catch(Tango::ConnectionFailed & e)                                                             \
-    {                                                                                              \
-        TangoSys_OMemStream desc;                                                                  \
-        desc << "Failed to read_attribute on device " << device_name;                              \
-        desc << ", attribute " << NAME_CHAR << std::ends;                                          \
-        TANGO_RETHROW_API_EXCEPTION(ApiConnExcept, e, API_AttributeFailed, desc.str());            \
-    }                                                                                              \
-    catch(Tango::DevFailed & e)                                                                    \
-    {                                                                                              \
-        TangoSys_OMemStream desc;                                                                  \
-        desc << "Failed to read_attribute on device " << device_name;                              \
-        desc << ", attribute " << NAME_CHAR << std::ends;                                          \
-        TANGO_RETHROW_EXCEPTION(e, API_AttributeFailed, desc.str());                               \
-    }                                                                                              \
-    catch(CORBA::TRANSIENT & trans)                                                                \
-    {                                                                                              \
-        TRANSIENT_NOT_EXIST_EXCEPT(trans, "DeviceProxy", "read_attribute", OBJ);                   \
-    }                                                                                              \
-    catch(CORBA::OBJECT_NOT_EXIST & one)                                                           \
-    {                                                                                              \
-        if(one.minor() == omni::OBJECT_NOT_EXIST_NoMatch || one.minor() == 0)                      \
-        {                                                                                          \
-            TRANSIENT_NOT_EXIST_EXCEPT(one, "DeviceProxy", "read_attribute", OBJ);                 \
-        }                                                                                          \
-        else                                                                                       \
-        {                                                                                          \
-            set_connection_state(CONNECTION_NOTOK);                                                \
-            TangoSys_OMemStream desc;                                                              \
-            desc << "Failed to read_attribute on device " << device_name << std::ends;             \
-            TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, one, API_CommunicationFailed, desc.str());  \
-        }                                                                                          \
-    }                                                                                              \
-    catch(CORBA::COMM_FAILURE & comm)                                                              \
-    {                                                                                              \
-        if(comm.minor() == omni::COMM_FAILURE_WaitingForReply)                                     \
-        {                                                                                          \
-            TRANSIENT_NOT_EXIST_EXCEPT(comm, "DeviceProxy", "read_attribute", OBJ);                \
-        }                                                                                          \
-        else                                                                                       \
-        {                                                                                          \
-            set_connection_state(CONNECTION_NOTOK);                                                \
-            TangoSys_OMemStream desc;                                                              \
-            desc << "Failed to read_attribute on device " << device_name << std::ends;             \
-            TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, comm, API_CommunicationFailed, desc.str()); \
-        }                                                                                          \
-    }                                                                                              \
-    catch(CORBA::SystemException & ce)                                                             \
-    {                                                                                              \
-        set_connection_state(CONNECTION_NOTOK);                                                    \
-        TangoSys_OMemStream desc;                                                                  \
-        desc << "Failed to read_attribute on device " << device_name << std::ends;                 \
-        TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());       \
+#define READ_ATT_EXCEPT(NAME_CHAR, OBJ)                                                                 \
+    catch(Tango::ConnectionFailed & e)                                                                  \
+    {                                                                                                   \
+        TangoSys_OMemStream desc;                                                                       \
+        desc << "Failed to read_attribute on device " << device_name;                                   \
+        desc << ", attribute " << NAME_CHAR << std::ends;                                               \
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiConnExcept, e, API_AttributeFailed, desc.str());            \
+    }                                                                                                   \
+    catch(Tango::DevFailed & e)                                                                         \
+    {                                                                                                   \
+        TangoSys_OMemStream desc;                                                                       \
+        desc << "Failed to read_attribute on device " << device_name;                                   \
+        desc << ", attribute " << NAME_CHAR << std::ends;                                               \
+        TANGO_RETHROW_EXCEPTION(e, API_AttributeFailed, desc.str());                                    \
+    }                                                                                                   \
+    catch(CORBA::TRANSIENT & trans)                                                                     \
+    {                                                                                                   \
+        TRANSIENT_NOT_EXIST_EXCEPT(trans, "DeviceProxy", "read_attribute", OBJ);                        \
+    }                                                                                                   \
+    catch(CORBA::OBJECT_NOT_EXIST & one)                                                                \
+    {                                                                                                   \
+        if(one.minor() == omni::OBJECT_NOT_EXIST_NoMatch || one.minor() == 0)                           \
+        {                                                                                               \
+            TRANSIENT_NOT_EXIST_EXCEPT(one, "DeviceProxy", "read_attribute", OBJ);                      \
+        }                                                                                               \
+        else                                                                                            \
+        {                                                                                               \
+            set_connection_state(CONNECTION_NOTOK);                                                     \
+            TangoSys_OMemStream desc;                                                                   \
+            desc << "Failed to read_attribute on device " << device_name << std::ends;                  \
+            TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, one, API_CommunicationFailed, desc.str());  \
+        }                                                                                               \
+    }                                                                                                   \
+    catch(CORBA::COMM_FAILURE & comm)                                                                   \
+    {                                                                                                   \
+        if(comm.minor() == omni::COMM_FAILURE_WaitingForReply)                                          \
+        {                                                                                               \
+            TRANSIENT_NOT_EXIST_EXCEPT(comm, "DeviceProxy", "read_attribute", OBJ);                     \
+        }                                                                                               \
+        else                                                                                            \
+        {                                                                                               \
+            set_connection_state(CONNECTION_NOTOK);                                                     \
+            TangoSys_OMemStream desc;                                                                   \
+            desc << "Failed to read_attribute on device " << device_name << std::ends;                  \
+            TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, comm, API_CommunicationFailed, desc.str()); \
+        }                                                                                               \
+    }                                                                                                   \
+    catch(CORBA::SystemException & ce)                                                                  \
+    {                                                                                                   \
+        set_connection_state(CONNECTION_NOTOK);                                                         \
+        TangoSys_OMemStream desc;                                                                       \
+        desc << "Failed to read_attribute on device " << device_name << std::ends;                      \
+        TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());       \
     }
 
 #define COPY_BASE_CONFIG(A, B)                           \
