@@ -215,14 +215,14 @@ struct ZmqDevPipeDataElt : public DevPipeDataElt
 /***    Macros to help coding       ***/
 
 #ifndef Swap16
-  #define Swap16(s) ((((s) &0xff) << 8) | (((s) >> 8) & 0xff))
+  #define Swap16(s) ((((s) & 0xff) << 8) | (((s) >> 8) & 0xff))
 #else
   #error "Swap16 has already been defined"
 #endif
 
 #ifndef Swap32
   #define Swap32(l) \
-      ((((l) &0xff000000) >> 24) | (((l) &0x00ff0000) >> 8) | (((l) &0x0000ff00) << 8) | (((l) &0x000000ff) << 24))
+      ((((l) & 0xff000000) >> 24) | (((l) & 0x00ff0000) >> 8) | (((l) & 0x0000ff00) << 8) | (((l) & 0x000000ff) << 24))
 #else
   #error "Swap32 has already been defined"
 #endif
@@ -291,7 +291,7 @@ inline void ZmqAttrValUnion::init_seq(char *base_ptr, CORBA::ULong &length, Tang
         ptr = (T *) (base_ptr + delta);
     }
 
-    if(_n.unmarshal_byte_swap() == true)
+    if(_n.unmarshal_byte_swap())
     {
         if(sizeof(T) == 2)
         {
@@ -342,12 +342,12 @@ class KeepAliveThCmd : public omni_mutex
 {
   public:
     KeepAliveThCmd() :
-        cmd_pending(false),
+
         cond(this)
     {
     }
 
-    bool cmd_pending;          // The new command flag
+    bool cmd_pending{false};   // The new command flag
     KeepAliveCmdCode cmd_code; // The command code
     omni_condition cond;
 };
@@ -623,19 +623,19 @@ class NotifdEventConsumer : public POA_CosNotifyComm::StructuredPushConsumer, pu
 
     static void cleanup()
     {
-        if(_instance != NULL)
+        if(_instance != nullptr)
         {
-            _instance = NULL;
+            _instance = nullptr;
         }
     }
 
     void push_structured_event(const CosNotification::StructuredEvent &) override;
-    virtual void cleanup_EventChannel_map() override;
+    void cleanup_EventChannel_map() override;
 
     void disconnect_structured_push_consumer() override;
     void offer_change(const CosNotification::EventTypeSeq &, const CosNotification::EventTypeSeq &) override;
 
-    virtual void get_subscription_command_name(std::string &cmd) override
+    void get_subscription_command_name(std::string &cmd) override
     {
         cmd = "EventSubscriptionChange";
     }
@@ -644,22 +644,22 @@ class NotifdEventConsumer : public POA_CosNotifyComm::StructuredPushConsumer, pu
 
   protected:
     NotifdEventConsumer(ApiUtil *ptr);
-    virtual void connect_event_channel(const std::string &, Database *, bool, DeviceData &) override;
-    virtual void connect_event_system(const std::string &,
-                                      const std::string &,
-                                      const std::string &e,
-                                      const std::vector<std::string> &,
-                                      const EvChanIte &,
-                                      EventCallBackStruct &,
-                                      DeviceData &,
-                                      size_t) override;
+    void connect_event_channel(const std::string &, Database *, bool, DeviceData &) override;
+    void connect_event_system(const std::string &,
+                              const std::string &,
+                              const std::string &e,
+                              const std::vector<std::string> &,
+                              const EvChanIte &,
+                              EventCallBackStruct &,
+                              DeviceData &,
+                              size_t) override;
 
-    virtual void set_channel_type(EventChannelStruct &ecs) override
+    void set_channel_type(EventChannelStruct &ecs) override
     {
         ecs.channel_type = NOTIFD;
     }
 
-    virtual void zmq_specific(DeviceData &, std::string &, DeviceProxy *, const std::string &) override { }
+    void zmq_specific(DeviceData &, std::string &, DeviceProxy *, const std::string &) override { }
 
     ReceivedFromAdmin initialize_received_from_admin(const Tango::DevVarLongStringArray *pArray,
                                                      const std::string &local_callback_key,
@@ -692,15 +692,15 @@ class ZmqEventConsumer : public EventConsumer, public omni_thread
 
     static void cleanup()
     {
-        if(_instance != NULL)
+        if(_instance != nullptr)
         {
-            _instance = NULL;
+            _instance = nullptr;
         }
     }
 
-    virtual void cleanup_EventChannel_map() override;
+    void cleanup_EventChannel_map() override;
 
-    virtual void get_subscription_command_name(std::string &cmd) override
+    void get_subscription_command_name(std::string &cmd) override
     {
         cmd = "ZmqEventSubscriptionChange";
     }
@@ -724,26 +724,26 @@ class ZmqEventConsumer : public EventConsumer, public omni_thread
 
   protected:
     ZmqEventConsumer(ApiUtil *ptr);
-    virtual void connect_event_channel(const std::string &, Database *, bool, DeviceData &) override;
-    virtual void disconnect_event_channel(const std::string &channel_name,
-                                          const std::string &endpoint,
-                                          const std::string &endpoint_event) override;
-    virtual void connect_event_system(const std::string &,
-                                      const std::string &,
-                                      const std::string &e,
-                                      const std::vector<std::string> &,
-                                      const EvChanIte &,
-                                      EventCallBackStruct &,
-                                      DeviceData &,
-                                      size_t) override;
-    virtual void disconnect_event(const std::string &, const std::string &) override;
+    void connect_event_channel(const std::string &, Database *, bool, DeviceData &) override;
+    void disconnect_event_channel(const std::string &channel_name,
+                                  const std::string &endpoint,
+                                  const std::string &endpoint_event) override;
+    void connect_event_system(const std::string &,
+                              const std::string &,
+                              const std::string &e,
+                              const std::vector<std::string> &,
+                              const EvChanIte &,
+                              EventCallBackStruct &,
+                              DeviceData &,
+                              size_t) override;
+    void disconnect_event(const std::string &, const std::string &) override;
 
-    virtual void set_channel_type(EventChannelStruct &ecs) override
+    void set_channel_type(EventChannelStruct &ecs) override
     {
         ecs.channel_type = ZMQ;
     }
 
-    virtual void zmq_specific(DeviceData &, std::string &, DeviceProxy *, const std::string &) override;
+    void zmq_specific(DeviceData &, std::string &, DeviceProxy *, const std::string &) override;
 
     ReceivedFromAdmin initialize_received_from_admin(const Tango::DevVarLongStringArray *pArray,
                                                      const std::string &local_callback_key,
@@ -776,9 +776,9 @@ class ZmqEventConsumer : public EventConsumer, public omni_thread
     int old_poll_nb;
     TangoMonitor subscription_monitor;
     omni_mutex sock_bound_mutex;
-    bool ctrl_socket_bound;
+    bool ctrl_socket_bound{false};
     // variable to count the number of ZMQ_DELAY_EVENT requests currently in progress:
-    int nb_current_delay_event_requests;
+    int nb_current_delay_event_requests{0};
 
     void *run_undetached(void *arg) override;
     void push_heartbeat_event(std::string &);
@@ -839,8 +839,8 @@ class DelayEvent
     void release();
 
   private:
-    bool released;
-    ZmqEventConsumer *eve_con;
+    bool released{false};
+    ZmqEventConsumer *eve_con{nullptr};
 };
 
 /********************************************************************************
@@ -903,14 +903,14 @@ class DelayedEventUnsubThread : public omni_thread
 {
   public:
     DelayedEventUnsubThread(EventConsumer *ec, int id, TangoMonitor *m) :
-        omni_thread(),
+
         event_id(id),
         ev_cons(ec),
         the_mon(m)
     {
     }
 
-    void run(void *);
+    void run(void *) override;
 
   private:
     int event_id;
@@ -935,7 +935,7 @@ class DelayedEventSubThread : public omni_thread
                           EventQueue *_ev_queue,
                           const std::string &_ev_name,
                           int _id) :
-        omni_thread(),
+
         ev_cons(ec),
         device(_device),
         attribute(_attribute),
@@ -947,7 +947,7 @@ class DelayedEventSubThread : public omni_thread
     {
     }
 
-    void run(void *);
+    void run(void *) override;
 
   private:
     EventConsumer *ev_cons;
