@@ -114,7 +114,7 @@ class AsynchRequest
     AsynchRequest &operator=(AsynchRequest &&);
 
     //- group_element_enabled accessor
-    inline bool group_element_enabled() const
+    bool group_element_enabled() const
     {
         return group_element_enabled_m;
     }
@@ -182,7 +182,7 @@ class GroupReply
      *
      * @return true if corresponding element is enabled, false otherwise
      */
-    inline bool group_element_enabled() const
+    bool group_element_enabled() const
     {
         return group_element_enabled_m;
     }
@@ -210,7 +210,7 @@ class GroupReply
      *
      * @return The error flag
      */
-    inline bool has_failed() const
+    bool has_failed() const
     {
         return has_failed_m;
     }
@@ -223,7 +223,7 @@ class GroupReply
      *
      * @return The device name
      */
-    inline const std::string &dev_name() const
+    const std::string &dev_name() const
     {
         return dev_name_m;
     }
@@ -236,7 +236,7 @@ class GroupReply
      *
      * @return The object name
      */
-    inline const std::string &obj_name() const
+    const std::string &obj_name() const
     {
         return obj_name_m;
     }
@@ -249,7 +249,7 @@ class GroupReply
      *
      * @return The error stack
      */
-    inline const DevErrorList &get_err_stack() const
+    const DevErrorList &get_err_stack() const
     {
         return exception_m.errors;
     }
@@ -293,7 +293,7 @@ class GroupCmdReply : public GroupReply
     //- ctor
     GroupCmdReply(const std::string &dev_name, const std::string &obj_name, bool group_element_enabled);
     //- dtor
-    virtual ~GroupCmdReply();
+    ~GroupCmdReply() override;
 
     GroupCmdReply(const GroupCmdReply &);
     GroupCmdReply &operator=(const GroupCmdReply &);
@@ -379,7 +379,7 @@ class GroupAttrReply : public GroupReply
     //- ctor
     GroupAttrReply(const std::string &dev_name, const std::string &obj_name, bool group_element_enabled);
     //- dtor
-    virtual ~GroupAttrReply();
+    ~GroupAttrReply() override;
 
     GroupAttrReply(const GroupAttrReply &);
     GroupAttrReply &operator=(const GroupAttrReply &);
@@ -471,7 +471,7 @@ class GroupReplyList : public std::vector<GroupReply>
      *
      * This methods empty the inherited vector and reset the error flag
      */
-    inline void reset()
+    void reset()
     {
         clear();
         has_failed_m = false;
@@ -490,7 +490,7 @@ class GroupReplyList : public std::vector<GroupReply>
 
   private:
     //- has_failed_m: true if at least one error occurred, false otherwise
-    bool has_failed_m;
+    bool has_failed_m{false};
 };
 
 //=============================================================================
@@ -549,7 +549,7 @@ class GroupCmdReplyList : public std::vector<GroupCmdReply>
      *
      * This methods empty the inherited vector and reset the error flag
      */
-    inline void reset()
+    void reset()
     {
         clear();
         has_failed_m = false;
@@ -568,7 +568,7 @@ class GroupCmdReplyList : public std::vector<GroupCmdReply>
 
   private:
     //- has_failed_m: true if at least one error occurred, false otherwise
-    bool has_failed_m;
+    bool has_failed_m{false};
 };
 
 //=============================================================================
@@ -626,7 +626,7 @@ class GroupAttrReplyList : public std::vector<GroupAttrReply>
      *
      * This methods empty the inherited vector and reset the error flag
      */
-    inline void reset()
+    void reset()
     {
         clear();
         has_failed_m = false;
@@ -645,7 +645,7 @@ class GroupAttrReplyList : public std::vector<GroupAttrReply>
 
   private:
     //- has_failed_m: true if at least one error occurred, false otherwise
-    bool has_failed_m;
+    bool has_failed_m{false};
 };
 
 //=============================================================================
@@ -707,15 +707,15 @@ class GroupElement
     //- Misc.
     //---------------------------------------------
     //-
-    inline const std::string &get_name() const
+    const std::string &get_name() const
     {
         return name;
     }
 
     //-
-    inline const std::string get_fully_qualified_name() const
+    std::string get_fully_qualified_name() const
     {
-        if(parent)
+        if(parent != nullptr)
         {
             return parent->get_fully_qualified_name() + "." + name;
         }
@@ -723,19 +723,19 @@ class GroupElement
     }
 
     //-
-    inline void enable()
+    void enable()
     {
         enabled = true;
     }
 
     //-
-    inline void disable()
+    void disable()
     {
         enabled = false;
     }
 
     //-
-    inline bool is_enabled() const
+    bool is_enabled() const
     {
         return enabled;
     }
@@ -752,7 +752,7 @@ class GroupElement
 
   protected:
     //- ctor: creates an GroupElement named <name>
-    GroupElement(const std::string &name, GroupElement *parent = 0);
+    GroupElement(const std::string &name, GroupElement *parent = nullptr);
     //- dtor
     virtual ~GroupElement();
 
@@ -845,7 +845,7 @@ class Group : public GroupElement
      * Tango::Group::get_group() (respectively to @e Tango::Group::get_device()). Use the @e Tango::Group::remove()
      * method instead.
      */
-    virtual ~Group();
+    ~Group() override;
     //@}
 
     //---------------------------------------------
@@ -975,7 +975,7 @@ class Group : public GroupElement
      * @param [in] fwd The forward flag
      * @return True if the hierarchy contains the element
      */
-    virtual bool contains(const std::string &pattern, bool fwd = true);
+    bool contains(const std::string &pattern, bool fwd = true) override;
     /**
      * Returns a reference to the specified device
      *
@@ -1005,7 +1005,7 @@ class Group : public GroupElement
      * @param [in] device_name The device name
      * @return True if the hierarchy contains the element
      */
-    virtual DeviceProxy *get_device(const std::string &device_name);
+    DeviceProxy *get_device(const std::string &device_name) override;
     /**
      * Returns a reference to the "idx-th" device in the hierarchy
      *
@@ -1022,7 +1022,7 @@ class Group : public GroupElement
      * @param [in] idx The device name
      * @return device reference
      */
-    virtual DeviceProxy *get_device(long idx);
+    DeviceProxy *get_device(long idx) override;
     /**
      * Returns a reference to the "idx-th" device in the hierarchy
      *
@@ -1037,7 +1037,7 @@ class Group : public GroupElement
      * @param [in] idx The device name
      * @return device reference
      */
-    virtual DeviceProxy *operator[](long idx);
+    DeviceProxy *operator[](long idx) override;
     /**
      * Returns a reference to the specified group
      *
@@ -1163,7 +1163,7 @@ class Group : public GroupElement
     bool is_enabled(const std::string &device_name, bool fwd = true)
     {
         GroupElement *ge = this->find_i(device_name, fwd);
-        return ge ? ge->is_enabled() : false;
+        return ge != nullptr ? ge->is_enabled() : false;
     }
 
     //-
@@ -1187,7 +1187,7 @@ class Group : public GroupElement
      * @param [in] fwd The forward flag
      * @return True if all devices are alive
      */
-    virtual bool ping(bool fwd = true);
+    bool ping(bool fwd = true) override;
     /**
      * Set client side timeout for all devices in the group
      *
@@ -1196,7 +1196,7 @@ class Group : public GroupElement
      *
      * @param [in] tmo_ms The timeout value
      */
-    virtual void set_timeout_millis(int tmo_ms);
+    void set_timeout_millis(int tmo_ms) override;
 
     //- command execution
     //---------------------------------------------
@@ -1686,9 +1686,9 @@ class Group : public GroupElement
     //- Misc.
     //---------------------------------------------
     //-
-    virtual void dump(int indent_level = 0);
+    void dump(int indent_level = 0) override;
     //-
-    virtual void dump(TangoSys_OMemStream &oms, int indent_level = 0);
+    void dump(TangoSys_OMemStream &oms, int indent_level = 0) override;
     //@}
 
   private:
@@ -1699,21 +1699,21 @@ class Group : public GroupElement
     //-
     void remove_i(const std::string &p, bool fwd = true);
     //-
-    GroupElement *find_i(const std::string &n, bool fwd = true);
+    GroupElement *find_i(const std::string &n, bool fwd = true) override;
     //-
     GroupElements get_hiearchy();
     //-
     Group *get_group_i(const std::string &n);
     //-
-    long get_size_i(bool fwd);
+    long get_size_i(bool fwd) override;
     //-
     void push_async_request(long rid, bool fwded);
     //-
     void pop_async_request(long rid);
     //-
-    virtual bool is_device_i();
+    bool is_device_i() override;
     //-
-    virtual bool is_group_i();
+    bool is_group_i() override;
 
 #ifdef TANGO_GROUP_HAS_THREAD_SAFE_IMPL
     omni_mutex elements_mutex;
@@ -1731,25 +1731,25 @@ class Group : public GroupElement
     Group &operator=(const Group &);
 
     //- private part of the asynch impl
-    virtual long command_inout_asynch_i(const std::string &c, bool fgt, bool fwd, long ari);
-    virtual long command_inout_asynch_i(const std::string &c, const DeviceData &d, bool fgt, bool fwd, long ari);
+    long command_inout_asynch_i(const std::string &c, bool fgt, bool fwd, long ari) override;
+    long command_inout_asynch_i(const std::string &c, const DeviceData &d, bool fgt, bool fwd, long ari) override;
     virtual long
         command_inout_asynch_i(const std::string &c, const std::vector<DeviceData> &d, bool fgt, bool fwd, long ari);
     template <typename T>
     long command_inout_asynch_i(const std::string &c, /*const*/ std::vector<T> &d, bool fgt, bool fwd, long ari);
-    virtual GroupCmdReplyList command_inout_reply_i(long req_id, long tmo_ms);
+    GroupCmdReplyList command_inout_reply_i(long req_id, long tmo_ms) override;
 
-    virtual long read_attribute_asynch_i(const std::string &a, bool fwd, long ari);
-    virtual GroupAttrReplyList read_attribute_reply_i(long req_id, long tmo_ms);
+    long read_attribute_asynch_i(const std::string &a, bool fwd, long ari) override;
+    GroupAttrReplyList read_attribute_reply_i(long req_id, long tmo_ms) override;
 
-    virtual long read_attributes_asynch_i(const std::vector<std::string> &al, bool fwd, long ari);
-    virtual GroupAttrReplyList read_attributes_reply_i(long req_id, long tmo_ms);
+    long read_attributes_asynch_i(const std::vector<std::string> &al, bool fwd, long ari) override;
+    GroupAttrReplyList read_attributes_reply_i(long req_id, long tmo_ms) override;
 
-    virtual long write_attribute_asynch_i(const DeviceAttribute &d, bool fwd, long ari);
+    long write_attribute_asynch_i(const DeviceAttribute &d, bool fwd, long ari) override;
     virtual long write_attribute_asynch_i(const std::vector<DeviceAttribute> &d, bool fwd, long ari);
     template <typename T>
     long write_attribute_asynch_i(const std::string &a, /*const*/ std::vector<T> &d, bool fwd, long ari);
-    virtual GroupReplyList write_attribute_reply_i(long req_id, long tmo_ms);
+    GroupReplyList write_attribute_reply_i(long req_id, long tmo_ms) override;
 };
 
 //=============================================================================
@@ -1765,29 +1765,29 @@ class GroupDeviceElement : public GroupElement
     //- Group management
     //---------------------------------------------
     //-
-    virtual DeviceProxy *get_device(const std::string &n);
+    DeviceProxy *get_device(const std::string &n) override;
     //-
-    virtual DeviceProxy *get_device(long idx);
+    DeviceProxy *get_device(long idx) override;
     //-
-    virtual DeviceProxy *operator[](long idx);
+    DeviceProxy *operator[](long idx) override;
 
     //---------------------------------------------
     //- a la DeviceProxy interface
     //---------------------------------------------
     //-
-    virtual bool ping(bool fwd = true);
+    bool ping(bool fwd = true) override;
     //-
-    virtual void set_timeout_millis(int tmo_ms);
+    void set_timeout_millis(int tmo_ms) override;
 
     //---------------------------------------------
     //- Misc
     //---------------------------------------------
     //-
-    virtual void dump(int indent_level = 0);
+    void dump(int indent_level = 0) override;
     //-
-    virtual void dump(TangoSys_OMemStream &oms, int indent_level = 0);
+    void dump(TangoSys_OMemStream &oms, int indent_level = 0) override;
     //-
-    virtual bool is_connected();
+    bool is_connected() override;
 
   private:
     //- the device proxy
@@ -1805,7 +1805,7 @@ class GroupDeviceElement : public GroupElement
     //- ctor: creates a GroupDeviceElement named <name> with timeout set to tmo_ms milliseconds
     GroupDeviceElement(const std::string &name, int tmo_ms);
     //- dtor: release resources
-    virtual ~GroupDeviceElement();
+    ~GroupDeviceElement() override;
 
     //- build connection to the device (may throw DevFailed)
     DeviceProxy *connect();
@@ -1813,31 +1813,31 @@ class GroupDeviceElement : public GroupElement
     void disconnect();
 
     //- a trick to get a valid device proxy or an exception
-    inline DeviceProxy *dev_proxy()
+    DeviceProxy *dev_proxy()
     {
-        return dp ? dp : connect();
+        return dp != nullptr ? dp : connect();
     }
 
     //- element identification
-    virtual bool is_device_i();
-    virtual bool is_group_i();
+    bool is_device_i() override;
+    bool is_group_i() override;
 
     //- size (group interface)
-    virtual long get_size_i(bool fwd = true);
+    long get_size_i(bool fwd = true) override;
 
     //- private part of the asynch impl
-    virtual long command_inout_asynch_i(const std::string &c, bool fgt, bool fwd, long ari);
-    virtual long command_inout_asynch_i(const std::string &c, const DeviceData &d, bool fgt, bool fwd, long ari);
-    virtual GroupCmdReplyList command_inout_reply_i(long req_id, long tmo_ms);
+    long command_inout_asynch_i(const std::string &c, bool fgt, bool fwd, long ari) override;
+    long command_inout_asynch_i(const std::string &c, const DeviceData &d, bool fgt, bool fwd, long ari) override;
+    GroupCmdReplyList command_inout_reply_i(long req_id, long tmo_ms) override;
 
-    virtual long read_attribute_asynch_i(const std::string &a, bool fwd, long ari);
-    virtual GroupAttrReplyList read_attribute_reply_i(long req_id, long tmo_ms);
+    long read_attribute_asynch_i(const std::string &a, bool fwd, long ari) override;
+    GroupAttrReplyList read_attribute_reply_i(long req_id, long tmo_ms) override;
 
-    virtual long read_attributes_asynch_i(const std::vector<std::string> &al, bool fwd, long ari);
-    virtual GroupAttrReplyList read_attributes_reply_i(long req_id, long tmo_ms);
+    long read_attributes_asynch_i(const std::vector<std::string> &al, bool fwd, long ari) override;
+    GroupAttrReplyList read_attributes_reply_i(long req_id, long tmo_ms) override;
 
-    virtual long write_attribute_asynch_i(const DeviceAttribute &d, bool fwd, long ari);
-    virtual GroupReplyList write_attribute_reply_i(long req_id, long tmo_ms);
+    long write_attribute_asynch_i(const DeviceAttribute &d, bool fwd, long ari) override;
+    GroupReplyList write_attribute_reply_i(long req_id, long tmo_ms) override;
 };
 
 //=============================================================================
@@ -1847,7 +1847,7 @@ template <typename T>
 bool GroupCmdReply::operator>>(T &dest)
 {
     bool result = true;
-    if(GroupReply::group_element_enabled_m == false)
+    if(!GroupReply::group_element_enabled_m)
     {
         if(exception_enabled)
         {
@@ -1862,7 +1862,7 @@ bool GroupCmdReply::operator>>(T &dest)
         }
         result = false;
     }
-    else if(GroupReply::has_failed_m == true)
+    else if(GroupReply::has_failed_m)
     {
         if(exception_enabled)
         {
@@ -1914,7 +1914,7 @@ template <typename T>
 bool GroupAttrReply::operator>>(T &dest)
 {
     bool result = true;
-    if(GroupReply::group_element_enabled_m == false)
+    if(!GroupReply::group_element_enabled_m)
     {
         if(exception_enabled)
         {
@@ -1929,7 +1929,7 @@ bool GroupAttrReply::operator>>(T &dest)
         }
         result = false;
     }
-    else if(GroupReply::has_failed_m == true)
+    else if(GroupReply::has_failed_m)
     {
         if(exception_enabled)
         {
@@ -2009,7 +2009,7 @@ long Group::command_inout_asynch_i(const std::string &c, /*const*/ std::vector<T
         TangoSys_OMemStream desc;
         desc << "the size of the input argument list must equal the number of device in the group"
              << " [expected:" << gsize << " - got:" << d.size() << "]" << std::ends;
-        TANGO_THROW_API_EXCEPTION(ApiDataExcept, API_MethodArgument, desc.str().c_str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept, API_MethodArgument, desc.str().c_str());
     }
 
     if(ari == -1)
@@ -2035,7 +2035,7 @@ long Group::command_inout_asynch_i(const std::string &c, /*const*/ std::vector<T
         }
     }
 
-    if(fgt == false)
+    if(!fgt)
     {
         push_async_request(ari, fwd);
     }
@@ -2079,7 +2079,7 @@ long Group::write_attribute_asynch_i(const std::string &a, /*const*/ std::vector
         TangoSys_OMemStream desc;
         desc << "the size of the input argument list must equal the number of device in the group"
              << " [expected:" << gsize << " - got:" << d.size() << "]" << std::ends;
-        TANGO_THROW_API_EXCEPTION(ApiDataExcept, API_MethodArgument, desc.str().c_str());
+        TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept, API_MethodArgument, desc.str().c_str());
     }
 
     if(ari == -1)
