@@ -973,83 +973,5 @@ inline Tango::DevVarEncodedArray **Attribute::get_value_storage()
     return &value.enc_seq;
 }
 
-template <>
-inline Tango::DevULong64 (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_ulo64;
-}
-
-template <>
-inline Tango::DevLong64 (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_lo64;
-}
-
-template <>
-inline Tango::DevULong (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_ulo;
-}
-
-template <>
-inline Tango::DevState (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_state;
-}
-
-template <>
-inline Tango::DevShort (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_sh;
-}
-
-template <>
-inline Tango::DevLong (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_lo;
-}
-
-template <>
-inline Tango::DevFloat (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_fl;
-}
-
-template <>
-inline Tango::DevDouble (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_db;
-}
-
-template <>
-inline Tango::DevString (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_str;
-}
-
-template <>
-inline Tango::DevUShort (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_ush;
-}
-
-template <>
-inline Tango::DevBoolean (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_boo;
-}
-
-template <>
-inline Tango::DevUChar (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_cha;
-}
-
-template <>
-inline Tango::DevEncoded (&Attribute::get_tmp_storage())[2]
-{
-    return tmp_enc;
-}
-
 } // namespace Tango
 #endif // _ATTRIBUTE_SPEC_TPP
