@@ -15,13 +15,13 @@ struct AttributeEventSubscriptionState
 {
     std::string attribute_name;
 
-    EventClientLibVersions change_event_clients = {};
-    EventClientLibVersions archive_event_clients = {};
-    EventClientLibVersions periodic_event_clients = {};
-    EventClientLibVersions user_event_clients = {};
-    EventClientLibVersions attr_conf_event_clients = {};
+    EventClientLibVersions change_event_clients;
+    EventClientLibVersions alarm_event_clients;
+    EventClientLibVersions archive_event_clients;
+    EventClientLibVersions periodic_event_clients;
+    EventClientLibVersions user_event_clients;
+    EventClientLibVersions attr_conf_event_clients;
 
-    bool has_quality_event_clients = false;
     bool has_data_ready_event_clients = false;
 
     bool has_zmq_event_channel = false;
