@@ -97,6 +97,18 @@ class Except
      * @param ex The exception object reference
      */
     static void print_exception(const CORBA::Exception &ex);
+
+    //@}
+    /**@name Exception related method */
+    //@{
+    /**
+     * Print a TANGO exception.
+     *
+     * Print all the details of a TANGO exception to os.
+     *
+     * @param ex The exception object reference
+     */
+    static void print_exception(const CORBA::Exception &ex, std::ostream &os);
     //@}
 
     /**@name Error stack related method */
@@ -131,7 +143,7 @@ class Except
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(const char *reason, const char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -164,7 +176,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(const char *reason, const char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -198,7 +210,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(const char *reason, char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -231,7 +243,7 @@ class Except
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(const char *reason, char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -266,7 +278,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(char *reason, const char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -300,7 +312,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(char *reason, const char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -335,7 +347,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(char *reason, char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -370,7 +382,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(char *reason, char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -405,10 +417,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const std::string &reason,
-                                                    const std::string &desc,
-                                                    const std::string &origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const std::string &reason,
+                                             const std::string &desc,
+                                             const std::string &origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -439,10 +451,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const std::string &reason,
-                                                    const std::string &desc,
-                                                    const char *origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const std::string &reason,
+                                             const std::string &desc,
+                                             const char *origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -473,10 +485,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const std::string &reason,
-                                                    const char *desc,
-                                                    const std::string &origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const std::string &reason,
+                                             const char *desc,
+                                             const std::string &origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -507,10 +519,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const std::string &reason,
-                                                    const char *desc,
-                                                    const char *origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const std::string &reason,
+                                             const char *desc,
+                                             const char *origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -541,10 +553,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const char *reason,
-                                                    const std::string &desc,
-                                                    const std::string &origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const char *reason,
+                                             const std::string &desc,
+                                             const std::string &origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -575,10 +587,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const char *reason,
-                                                    const std::string &desc,
-                                                    const char *origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const char *reason,
+                                             const std::string &desc,
+                                             const char *origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -609,10 +621,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const char *reason,
-                                                    const char *desc,
-                                                    const std::string &origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const char *reason,
+                                             const char *desc,
+                                             const std::string &origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -644,10 +656,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const std::string &reason,
-                                                    const std::string &desc,
-                                                    char *origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const std::string &reason,
+                                             const std::string &desc,
+                                             char *origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -680,10 +692,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(const std::string &reason,
-                                                    char *desc,
-                                                    const std::string &origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(const std::string &reason,
+                                             char *desc,
+                                             const std::string &origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -717,7 +729,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(const std::string &reason, char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -752,10 +764,10 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_exception(char *reason,
-                                                    const std::string &desc,
-                                                    const std::string &origin,
-                                                    Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_exception(char *reason,
+                                             const std::string &desc,
+                                             const std::string &origin,
+                                             Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
 
@@ -788,7 +800,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(char *reason, const std::string &desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -823,7 +835,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void
+    [[noreturn]] static void
         throw_exception(char *reason, char *desc, const std::string &origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::DevErrorList errors(1);
@@ -861,11 +873,11 @@ class Except
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const char *reason,
-                                                       const char *desc,
-                                                       const char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const char *reason,
+                                                const char *desc,
+                                                const char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -898,7 +910,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, const char *reason, const char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -933,7 +945,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, const char *reason, char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -967,7 +979,7 @@ class Except
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, const char *reason, char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -1003,7 +1015,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, char *reason, const char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -1038,7 +1050,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, char *reason, const char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -1074,7 +1086,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, char *reason, char *desc, const char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -1110,7 +1122,7 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(
+    [[noreturn]] static void re_throw_exception(
         Tango::DevFailed &ex, char *reason, char *desc, char *origin, Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
@@ -1146,11 +1158,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       const std::string &desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                const std::string &desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1182,11 +1194,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       const std::string &desc,
-                                                       const char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                const std::string &desc,
+                                                const char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1218,11 +1230,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       const char *desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                const char *desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1254,11 +1266,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       const char *desc,
-                                                       const char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                const char *desc,
+                                                const char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1290,11 +1302,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const char *reason,
-                                                       const std::string &desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const char *reason,
+                                                const std::string &desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1326,11 +1338,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const char *reason,
-                                                       const std::string &desc,
-                                                       const char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const char *reason,
+                                                const std::string &desc,
+                                                const char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1362,11 +1374,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const char *reason,
-                                                       const char *desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const char *reason,
+                                                const char *desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1399,11 +1411,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       const std::string &desc,
-                                                       char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                const std::string &desc,
+                                                char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1437,11 +1449,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       char *desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                char *desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1475,11 +1487,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       const std::string &reason,
-                                                       char *desc,
-                                                       char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                const std::string &reason,
+                                                char *desc,
+                                                char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1514,11 +1526,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       char *reason,
-                                                       const std::string &desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                char *reason,
+                                                const std::string &desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1552,11 +1564,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       char *reason,
-                                                       const std::string &desc,
-                                                       char *origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                char *reason,
+                                                const std::string &desc,
+                                                char *origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1591,11 +1603,11 @@ class Except
      * to read <b>DevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void re_throw_exception(Tango::DevFailed &ex,
-                                                       char *reason,
-                                                       char *desc,
-                                                       const std::string &origin,
-                                                       Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void re_throw_exception(Tango::DevFailed &ex,
+                                                char *reason,
+                                                char *desc,
+                                                const std::string &origin,
+                                                Tango::ErrSeverity sever = Tango::ERR)
     {
         long nb_err = ex.errors.length();
         ex.errors.length(nb_err + 1);
@@ -1698,11 +1710,11 @@ class Except
      * to read <b>MultiDevFailed</b> exception specification
      */
 
-    [[noreturn]] static inline void throw_named_exception(const char *att_name,
-                                                          const char *reason,
-                                                          const char *desc,
-                                                          const char *origin,
-                                                          Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_named_exception(const char *att_name,
+                                                   const char *reason,
+                                                   const char *desc,
+                                                   const char *origin,
+                                                   Tango::ErrSeverity sever = Tango::ERR)
     {
         Tango::NamedDevErrorList errors(1);
 
@@ -1739,11 +1751,11 @@ class Except
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>MultiDevFailed</b> exception specification
      */
-    [[noreturn]] static inline void throw_named_exception(std::vector<std::string> &atts,
-                                                          const char *reason,
-                                                          const char *desc,
-                                                          const char *origin,
-                                                          Tango::ErrSeverity sever = Tango::ERR)
+    [[noreturn]] static void throw_named_exception(std::vector<std::string> &atts,
+                                                   const char *reason,
+                                                   const char *desc,
+                                                   const char *origin,
+                                                   Tango::ErrSeverity sever = Tango::ERR)
     {
         unsigned int a_size = (unsigned int) atts.size();
         Tango::NamedDevErrorList errors(a_size);
