@@ -60,7 +60,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
     // Check that the device is polled
     //
 
-    if(dev->is_polled() == false)
+    if(!dev->is_polled())
     {
         TangoSys_OMemStream o;
         o << "Device " << dev->get_name() << " is not polled" << std::ends;
@@ -82,7 +82,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
     //
 
     Tango::Attribute &att = dev->get_device_attr()->get_attr_by_name(att_name.c_str());
-    Tango::WAttribute *w_att_ptr = NULL;
+    Tango::WAttribute *w_att_ptr = nullptr;
     Tango::AttrWriteType w_type = att.get_writable();
     if(w_type == Tango::READ_WRITE)
     {
@@ -111,7 +111,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
     {
         for(size_t i = 0; i < nb_elt; i++)
         {
-            if((data.get_data())[i].wr_ptr != NULL)
+            if((data.get_data())[i].wr_ptr != nullptr)
             {
                 TangoSys_OMemStream o;
                 o << "The attribute " << att_name;
@@ -150,7 +150,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
     {
         for(size_t i = 0; i < nb_elt; i++)
         {
-            if((data.get_data())[i].wr_ptr != NULL)
+            if((data.get_data())[i].wr_ptr != nullptr)
             {
                 TangoSys_OMemStream o;
                 o << "The attribute " << att_name;
@@ -215,7 +215,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
 
     for(i = 0; i < nb_elt; i++)
     {
-        save_except = NULL;
+        save_except = nullptr;
         attr_failed = false;
 
         if((data.get_data())[i].err.length() != 0)
@@ -333,7 +333,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
                 }
                 else if(w_type == Tango::READ_WRITE)
                 {
-                    if((data.get_data())[i].wr_ptr != NULL)
+                    if((data.get_data())[i].wr_ptr != nullptr)
                     {
                         w_att_ptr->set_write_value(
                             (T *) (data.get_data())[i].wr_ptr, (data.get_data())[i].wr_x, (data.get_data())[i].wr_y);
@@ -412,9 +412,9 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
 
         try
         {
-            std::vector<PollObj *>::iterator ite = dev->get_polled_obj_by_type_name(Tango::POLL_ATTR, obj_name);
+            auto ite = dev->get_polled_obj_by_type_name(Tango::POLL_ATTR, obj_name);
 
-            if(attr_failed == false)
+            if(!attr_failed)
             {
                 if(idl_vers >= 5)
                 {
@@ -444,7 +444,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
         }
         catch(Tango::DevFailed &)
         {
-            if(attr_failed == false)
+            if(!attr_failed)
             {
                 if(idl_vers >= 5)
                 {
@@ -492,7 +492,7 @@ void Util::fill_cmd_polling_buffer(DeviceImpl *dev, std::string &cmd_name, CmdHi
     // Check that the device is polled
     //
 
-    if(dev->is_polled() == false)
+    if(!dev->is_polled())
     {
         TangoSys_OMemStream o;
         o << "Device " << dev->get_name() << " is not polled" << std::ends;
@@ -546,7 +546,7 @@ void Util::fill_cmd_polling_buffer(DeviceImpl *dev, std::string &cmd_name, CmdHi
 
     for(i = 0; i < nb_elt; i++)
     {
-        save_except = NULL;
+        save_except = nullptr;
         cmd_failed = false;
 
         if((data.get_data())[i].err.length() != 0)
@@ -597,10 +597,10 @@ void Util::fill_cmd_polling_buffer(DeviceImpl *dev, std::string &cmd_name, CmdHi
 
         try
         {
-            std::vector<PollObj *>::iterator ite = dev->get_polled_obj_by_type_name(Tango::POLL_CMD, obj_name);
+            auto ite = dev->get_polled_obj_by_type_name(Tango::POLL_CMD, obj_name);
             auto when = make_poll_time((data.get_data())[i].tp);
             auto zero = PollClock::duration::zero();
-            if(cmd_failed == false)
+            if(!cmd_failed)
             {
                 (*ite)->insert_data(any_ptr, when, zero);
             }
@@ -611,7 +611,7 @@ void Util::fill_cmd_polling_buffer(DeviceImpl *dev, std::string &cmd_name, CmdHi
         }
         catch(Tango::DevFailed &)
         {
-            if(cmd_failed == false)
+            if(!cmd_failed)
             {
                 delete any_ptr;
             }
