@@ -87,7 +87,7 @@ class WAttribute : public Attribute
     /**
      * The WAttribute desctructor.
      */
-    ~WAttribute();
+    ~WAttribute() override;
 
     //@}
 
@@ -543,9 +543,7 @@ class WAttribute : public Attribute
      * @param y The attribute set value y length. Default value is 0
 
      */
-    template <class T,
-              typename std::enable_if<!std::is_enum<T>::value || std::is_same<T, Tango::DevState>::value, T>::type * =
-                  nullptr>
+    template <class T, std::enable_if_t<!std::is_enum_v<T> || std::is_same_v<T, Tango::DevState>, T> * = nullptr>
     void set_write_value(T *val, size_t x = 1, size_t y = 0);
     /**@name Set new value for attribute
      * Miscellaneous method to set a WAttribute value
@@ -560,9 +558,7 @@ class WAttribute : public Attribute
      * @param y The attribute set value y length. Default value is 0
 
      */
-    template <class T,
-              typename std::enable_if<std::is_enum<T>::value && !std::is_same<T, Tango::DevState>::value, T>::type * =
-                  nullptr>
+    template <class T, std::enable_if_t<std::is_enum_v<T> && !std::is_same_v<T, Tango::DevState>, T> * = nullptr>
     void set_write_value(T *val, size_t x = 1, size_t y = 0);
 
     /**@name Set new value for attribute
@@ -617,7 +613,7 @@ class WAttribute : public Attribute
 
     void set_write_value(Tango::DevEncoded *, long x = 1, long y = 0); // Dummy method for compiler
 
-    virtual void set_rvalue();
+    void set_rvalue() override;
 
     void rollback();
 
@@ -786,12 +782,12 @@ class WAttribute : public Attribute
 
   protected:
     /// @privatesection
-    virtual bool check_rds_alarm();
+    bool check_rds_alarm() override;
 
   private:
-    inline void check_length(const unsigned int nb_data, unsigned long x, unsigned long y)
+    void check_length(const unsigned int nb_data, unsigned long x, unsigned long y)
     {
-        if((!y && nb_data != x) || (y && nb_data != (x * y)))
+        if(((y == 0u) && nb_data != x) || ((y != 0u) && nb_data != (x * y)))
         {
             TANGO_THROW_EXCEPTION(API_AttrIncorrectDataNumber, "Incorrect data number");
         }
@@ -815,10 +811,7 @@ class WAttribute : public Attribute
      *          - max : The max allowed value
      */
     template <typename T>
-    void check_data_limits(const size_t,
-                           const typename tango_type_traits<T>::ArrayType &,
-                           Attr_CheckVal &,
-                           Attr_CheckVal &);
+    void check_data_limits(size_t, const typename tango_type_traits<T>::ArrayType &, Attr_CheckVal &, Attr_CheckVal &);
 
     /**
      * Check that provided enum is within limits.
@@ -828,7 +821,7 @@ class WAttribute : public Attribute
      * @param data_size number of elements in the buffer
      */
     template <class T>
-    void check_enum(const typename tango_type_traits<T>::ArrayType &, const size_t);
+    void check_enum(const typename tango_type_traits<T>::ArrayType &, size_t);
 
     /**
      * description :     Check the value sent by the caller and copy incoming data
@@ -985,18 +978,18 @@ class WAttribute : public Attribute
     Tango::DevVarCharArray uchar_array_val;
 
     const Tango::DevShort *short_ptr;
-    const Tango::DevLong *long_ptr;
-    const Tango::DevDouble *double_ptr;
-    const Tango::ConstDevString *str_ptr;
-    const Tango::DevFloat *float_ptr;
-    const Tango::DevBoolean *boolean_ptr;
-    const Tango::DevUShort *ushort_ptr;
-    const Tango::DevUChar *uchar_ptr;
-    const Tango::DevEncoded *encoded_ptr;
+    const Tango::DevLong *long_ptr{nullptr};
+    const Tango::DevDouble *double_ptr{nullptr};
+    const Tango::ConstDevString *str_ptr{nullptr};
+    const Tango::DevFloat *float_ptr{nullptr};
+    const Tango::DevBoolean *boolean_ptr{nullptr};
+    const Tango::DevUShort *ushort_ptr{nullptr};
+    const Tango::DevUChar *uchar_ptr{nullptr};
+    const Tango::DevEncoded *encoded_ptr{nullptr};
 
-    bool string_allocated;
-    bool memorized;
-    bool memorized_init;
+    bool string_allocated{false};
+    bool memorized{false};
+    bool memorized_init{false};
     std::string mem_value;
     struct timeval write_date;
 
@@ -1020,15 +1013,15 @@ class WAttribute : public Attribute
     Tango::DevVarULong64Array ulong64_array_val;
     Tango::DevVarStateArray state_array_val;
 
-    const Tango::DevLong64 *long64_ptr;
-    const Tango::DevULong *ulong_ptr;
-    const Tango::DevULong64 *ulong64_ptr;
-    const Tango::DevState *state_ptr;
+    const Tango::DevLong64 *long64_ptr{nullptr};
+    const Tango::DevULong *ulong_ptr{nullptr};
+    const Tango::DevULong64 *ulong64_ptr{nullptr};
+    const Tango::DevState *state_ptr{nullptr};
 
-    bool uswv;                  // User set_write_value
-    DevErrorList mem_exception; // Exception received at start-up in case writing the
-                                // memorized att. failed
-    bool mem_write_failed;      // Flag set to true if the memorized att setting failed
+    bool uswv{false};             // User set_write_value
+    DevErrorList mem_exception;   // Exception received at start-up in case writing the
+                                  // memorized att. failed
+    bool mem_write_failed{false}; // Flag set to true if the memorized att setting failed
 };
 
 } // namespace Tango
