@@ -33,6 +33,8 @@
 #ifndef _WATTRIBUTE_TPP
 #define _WATTRIBUTE_TPP
 
+#include <tango/common/utils/type_info.h>
+
 namespace Tango
 {
 
@@ -119,22 +121,18 @@ inline const Tango::DevVarEncodedArray &get_value(const AttrValUnion &att_union)
     return att_union.encoded_att_value();
 }
 
-template <
-    typename T,
-    typename std::enable_if<!(std::is_same<T, Tango::DevDouble>::value || std::is_same<T, Tango::DevFloat>::value),
-                            T>::type * = nullptr>
+template <typename T,
+          std::enable_if_t<!(std::is_same_v<T, Tango::DevDouble> || std::is_same_v<T, Tango::DevFloat>), T> * = nullptr>
 void check_nan(const std::string &, const T &, const size_t)
 {
 }
 
 template <typename T,
-          typename std::enable_if<(std::is_same<T, Tango::DevDouble>::value || std::is_same<T, Tango::DevFloat>::value),
-                                  T>::type * = nullptr>
-void check_nan(const std::string &, const T &, const size_t);
+          std::enable_if_t<(std::is_same_v<T, Tango::DevDouble> || std::is_same_v<T, Tango::DevFloat>), T> * = nullptr>
+void check_nan(const std::string &, const T &, size_t);
 
 template <typename T,
-          typename std::enable_if<(std::is_same<T, Tango::DevDouble>::value || std::is_same<T, Tango::DevFloat>::value),
-                                  T>::type *>
+          std::enable_if_t<(std::is_same_v<T, Tango::DevDouble> || std::is_same_v<T, Tango::DevFloat>), T> *>
 void check_nan(const std::string &name, const T &val, const size_t i)
 {
     if(std::isfinite(val) == 0)
@@ -249,7 +247,7 @@ void WAttribute::set_min_value(const T &new_min_value)
     //
 
     Tango::Util *tg = Tango::Util::instance();
-    Tango::TangoMonitor *mon_ptr = NULL;
+    Tango::TangoMonitor *mon_ptr = nullptr;
     if(!tg->is_svr_starting() && !tg->is_device_restarting(d_name))
     {
         mon_ptr = &(get_att_device()->get_att_conf_monitor());
@@ -303,7 +301,7 @@ void WAttribute::set_min_value(const T &new_min_value)
             db_data.push_back(prop_dd);
 
             bool retry = true;
-            while(retry == true)
+            while(retry)
             {
                 try
                 {
@@ -386,7 +384,7 @@ void WAttribute::get_min_value(T &min_val)
         TANGO_THROW_EXCEPTION(API_IncompatibleAttrDataType, err_msg.str().c_str());
     }
 
-    if(check_min_value == false)
+    if(!check_min_value)
     {
         TANGO_THROW_EXCEPTION(API_AttrNotAllowed, "Minimum value not defined for this attribute");
     }
@@ -466,7 +464,7 @@ void WAttribute::set_max_value(const T &new_max_value)
     //
 
     Tango::Util *tg = Tango::Util::instance();
-    Tango::TangoMonitor *mon_ptr = NULL;
+    Tango::TangoMonitor *mon_ptr = nullptr;
     if(!tg->is_svr_starting() && !tg->is_device_restarting(d_name))
     {
         mon_ptr = &(get_att_device()->get_att_conf_monitor());
@@ -520,7 +518,7 @@ void WAttribute::set_max_value(const T &new_max_value)
             db_data.push_back(prop_dd);
 
             bool retry = true;
-            while(retry == true)
+            while(retry)
             {
                 try
                 {
@@ -603,7 +601,7 @@ void WAttribute::get_max_value(T &max_val)
         TANGO_THROW_EXCEPTION(API_IncompatibleAttrDataType, err_msg.str().c_str());
     }
 
-    if(check_max_value == false)
+    if(!check_max_value)
     {
         TANGO_THROW_EXCEPTION(API_AttrNotAllowed, "Maximum value not defined for this attribute");
     }
@@ -706,7 +704,7 @@ void WAttribute::check_data_limits<Tango::DevEncoded>(const size_t nb_data,
 
     Tango::Util *tg = Tango::Util::instance();
     Tango::TangoMonitor *mon_ptr = nullptr;
-    if(tg->is_svr_starting() == false && tg->is_device_restarting(d_name) == false)
+    if(!tg->is_svr_starting() && !tg->is_device_restarting(d_name))
     {
         mon_ptr = &(get_att_device()->get_att_conf_monitor());
     }
@@ -845,7 +843,7 @@ void WAttribute::_copy_any_data(const T &data)
         // do nothing
         break;
     default:
-        TANGO_THROW_ON_DEFAULT(data_type);
+        TANGO_ASSERT_ON_DEFAULT(data_type);
     }
 }
 
@@ -926,18 +924,10 @@ void WAttribute::_update_any_written_value(const T &any, std::size_t x, std::siz
         break;
 
     default:
-        TANGO_THROW_ON_DEFAULT(data_type);
+        TANGO_ASSERT_ON_DEFAULT(data_type);
     }
 }
 
-namespace detail
-{
-
-std::string corba_any_to_type_name(const CORBA::Any &any);
-std::string attr_union_dtype_to_type_name(Tango::AttributeDataType d);
-
-} // namespace detail
-
 template <class T>
 void WAttribute::_update_written_value(const CORBA::Any &any, std::size_t x, std::size_t y)
 {
