@@ -55,8 +55,10 @@ Attr::Attr(const char *att_name, long att_type, AttrWriteType att_writable, cons
     mem_init(true),
     poll_period(0),
     fire_change_event(false),
+    fire_alarm_event(false),
     fire_archive_event(false),
     check_change_event(false),
+    check_alarm_event(false),
     check_archive_event(false),
     fire_dr_event(false),
     ext(new AttrExt),
@@ -68,6 +70,8 @@ Attr::Attr(const char *att_name, long att_type, AttrWriteType att_writable, cons
 
     fire_change_event = false;
     check_change_event = true;
+    fire_alarm_event = false;
+    check_alarm_event = true;
     fire_archive_event = false;
     check_archive_event = true;
     fire_dr_event = false;
@@ -118,6 +122,8 @@ Attr::Attr(const char *att_name, long att_type, DispLevel level, AttrWriteType a
 
     fire_change_event = false;
     check_change_event = true;
+    fire_alarm_event = false;
+    check_alarm_event = true;
     fire_archive_event = false;
     check_archive_event = true;
     fire_dr_event = false;
@@ -162,6 +168,8 @@ Attr::Attr(const char *att_name, Tango::DispLevel disp) :
 {
     fire_change_event = false;
     check_change_event = true;
+    fire_alarm_event = false;
+    check_alarm_event = true;
     fire_archive_event = false;
     check_archive_event = true;
     fire_dr_event = false;
@@ -179,8 +187,10 @@ Attr::Attr(const Attr &sou)
     disp_level = sou.disp_level;
     poll_period = sou.poll_period;
     fire_change_event = sou.fire_change_event;
+    fire_alarm_event = sou.fire_alarm_event;
     fire_archive_event = sou.fire_archive_event;
     check_change_event = sou.check_change_event;
+    check_alarm_event = sou.check_alarm_event;
     check_archive_event = sou.check_archive_event;
     fire_dr_event = sou.fire_dr_event;
     class_properties = sou.class_properties;
@@ -211,7 +221,7 @@ void Attr::check_type()
         unsuported = false;
     }
 
-    if(unsuported == true)
+    if(unsuported)
     {
         TANGO_LOG_DEBUG << "Attr::check_type throwing exception" << std::endl;
         TangoSys_OMemStream o;
@@ -254,104 +264,99 @@ void Attr::set_default_properties(UserDefaultAttrProp &prop_list)
 
     std::bitset<num_ranges> ranges;
 
-    if((prop_list.label.empty() == false) && (TG_strcasecmp(prop_list.label.c_str(), AlrmValueNotSpec) != 0) &&
+    if((!prop_list.label.empty()) && (TG_strcasecmp(prop_list.label.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.label.c_str(), NotANumber) != 0))
     {
-        user_default_properties.push_back(AttrProperty("label", prop_list.label));
+        user_default_properties.emplace_back("label", prop_list.label);
     }
 
-    if(prop_list.description.empty() == false &&
-       (TG_strcasecmp(prop_list.description.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.description.empty() && (TG_strcasecmp(prop_list.description.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.description.c_str(), NotANumber) != 0))
     {
-        user_default_properties.push_back(AttrProperty("description", prop_list.description));
+        user_default_properties.emplace_back("description", prop_list.description);
     }
 
-    if(prop_list.unit.empty() == false && (TG_strcasecmp(prop_list.unit.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.unit.empty() && (TG_strcasecmp(prop_list.unit.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.unit.c_str(), NotANumber) != 0))
     {
-        user_default_properties.push_back(AttrProperty("unit", prop_list.unit));
+        user_default_properties.emplace_back("unit", prop_list.unit);
     }
 
-    if(prop_list.standard_unit.empty() == false &&
-       (TG_strcasecmp(prop_list.standard_unit.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.standard_unit.empty() && (TG_strcasecmp(prop_list.standard_unit.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.standard_unit.c_str(), NotANumber) != 0))
     {
-        user_default_properties.push_back(AttrProperty("standard_unit", prop_list.standard_unit));
+        user_default_properties.emplace_back("standard_unit", prop_list.standard_unit);
     }
 
-    if(prop_list.display_unit.empty() == false &&
-       (TG_strcasecmp(prop_list.display_unit.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.display_unit.empty() && (TG_strcasecmp(prop_list.display_unit.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.display_unit.c_str(), NotANumber) != 0))
     {
-        user_default_properties.push_back(AttrProperty("display_unit", prop_list.display_unit));
+        user_default_properties.emplace_back("display_unit", prop_list.display_unit);
     }
 
-    if(prop_list.format.empty() == false && (TG_strcasecmp(prop_list.format.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.format.empty() && (TG_strcasecmp(prop_list.format.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.format.c_str(), NotANumber) != 0))
     {
-        user_default_properties.push_back(AttrProperty("format", prop_list.format));
+        user_default_properties.emplace_back("format", prop_list.format);
     }
 
-    if(prop_list.min_value.empty() == false && (TG_strcasecmp(prop_list.min_value.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.min_value.empty() && (TG_strcasecmp(prop_list.min_value.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.min_value.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.min_value, "min_value");
-        user_default_properties.push_back(AttrProperty("min_value", prop_list.min_value));
+        user_default_properties.emplace_back("min_value", prop_list.min_value);
         ranges.set(min_value);
     }
 
-    if(prop_list.max_value.empty() == false && (TG_strcasecmp(prop_list.max_value.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.max_value.empty() && (TG_strcasecmp(prop_list.max_value.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.max_value.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.max_value, "max_value");
-        user_default_properties.push_back(AttrProperty("max_value", prop_list.max_value));
+        user_default_properties.emplace_back("max_value", prop_list.max_value);
         ranges.set(max_value);
     }
 
-    if(prop_list.min_alarm.empty() == false && (TG_strcasecmp(prop_list.min_alarm.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.min_alarm.empty() && (TG_strcasecmp(prop_list.min_alarm.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.min_alarm.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.min_alarm, "min_alarm");
-        user_default_properties.push_back(AttrProperty("min_alarm", prop_list.min_alarm));
+        user_default_properties.emplace_back("min_alarm", prop_list.min_alarm);
         ranges.set(min_alarm);
     }
 
-    if(prop_list.max_alarm.empty() == false && (TG_strcasecmp(prop_list.max_alarm.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.max_alarm.empty() && (TG_strcasecmp(prop_list.max_alarm.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.max_alarm.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.max_alarm, "max_alarm");
-        user_default_properties.push_back(AttrProperty("max_alarm", prop_list.max_alarm));
+        user_default_properties.emplace_back("max_alarm", prop_list.max_alarm);
         ranges.set(max_alarm);
     }
 
-    if(prop_list.min_warning.empty() == false &&
-       (TG_strcasecmp(prop_list.min_warning.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.min_warning.empty() && (TG_strcasecmp(prop_list.min_warning.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.min_warning.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.min_warning, "min_warning");
-        user_default_properties.push_back(AttrProperty("min_warning", prop_list.min_warning));
+        user_default_properties.emplace_back("min_warning", prop_list.min_warning);
         ranges.set(min_warning);
     }
 
-    if(prop_list.max_warning.empty() == false &&
-       (TG_strcasecmp(prop_list.max_warning.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.max_warning.empty() && (TG_strcasecmp(prop_list.max_warning.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.max_warning.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.max_warning, "max_warning");
-        user_default_properties.push_back(AttrProperty("max_warning", prop_list.max_warning));
+        user_default_properties.emplace_back("max_warning", prop_list.max_warning);
         ranges.set(max_warning);
     }
 
-    if(prop_list.delta_val.empty() == false && (TG_strcasecmp(prop_list.delta_val.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.delta_val.empty() && (TG_strcasecmp(prop_list.delta_val.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.delta_val.c_str(), NotANumber) != 0))
     {
         validate_def_prop(prop_list.delta_val, "delta_val");
-        user_default_properties.push_back(AttrProperty("delta_val", prop_list.delta_val));
+        user_default_properties.emplace_back("delta_val", prop_list.delta_val);
         ranges.set(delta_val);
     }
 
-    if(prop_list.delta_t.empty() == false && (TG_strcasecmp(prop_list.delta_t.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.delta_t.empty() && (TG_strcasecmp(prop_list.delta_t.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.delta_t.c_str(), "0") != 0) &&
        (TG_strcasecmp(prop_list.delta_t.c_str(), NotANumber) != 0))
     {
@@ -363,27 +368,27 @@ void Attr::set_default_properties(UserDefaultAttrProp &prop_list)
         {
             throw_invalid_def_prop("delta_t", "DevLong");
         }
-        user_default_properties.push_back(AttrProperty("delta_t", prop_list.delta_t));
+        user_default_properties.emplace_back("delta_t", prop_list.delta_t);
         ranges.set(delta_t);
     }
 
-    if(prop_list.abs_change.empty() == false && (TG_strcasecmp(prop_list.abs_change.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.abs_change.empty() && (TG_strcasecmp(prop_list.abs_change.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.abs_change.c_str(), NotANumber) != 0))
     {
         validate_def_change_prop(prop_list.abs_change, "abs_change");
-        user_default_properties.push_back(AttrProperty("abs_change", prop_list.abs_change));
+        user_default_properties.emplace_back("abs_change", prop_list.abs_change);
     }
 
-    if(prop_list.rel_change.empty() == false && (TG_strcasecmp(prop_list.rel_change.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.rel_change.empty() && (TG_strcasecmp(prop_list.rel_change.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.rel_change.c_str(), NotANumber) != 0))
     {
         validate_def_change_prop(prop_list.rel_change, "rel_change");
-        user_default_properties.push_back(AttrProperty("rel_change", prop_list.rel_change));
+        user_default_properties.emplace_back("rel_change", prop_list.rel_change);
     }
 
     TangoSys_MemStream def_event_period;
     def_event_period << (int) (DEFAULT_EVENT_PERIOD);
-    if(prop_list.period.empty() == false && (TG_strcasecmp(prop_list.period.c_str(), AlrmValueNotSpec) != 0) &&
+    if(!prop_list.period.empty() && (TG_strcasecmp(prop_list.period.c_str(), AlrmValueNotSpec) != 0) &&
        (prop_list.period != def_event_period.str()) && (TG_strcasecmp(prop_list.period.c_str(), NotANumber) != 0))
     {
         TangoSys_MemStream str;
@@ -394,29 +399,28 @@ void Attr::set_default_properties(UserDefaultAttrProp &prop_list)
         {
             throw_invalid_def_prop("event_period", "DevLong");
         }
-        user_default_properties.push_back(AttrProperty("event_period", prop_list.period));
+        user_default_properties.emplace_back("event_period", prop_list.period);
     }
 
-    if(prop_list.archive_abs_change.empty() == false &&
+    if(!prop_list.archive_abs_change.empty() &&
        (TG_strcasecmp(prop_list.archive_abs_change.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.archive_abs_change.c_str(), NotANumber) != 0))
     {
         validate_def_change_prop(prop_list.archive_abs_change, "archive_abs_change");
-        user_default_properties.push_back(AttrProperty("archive_abs_change", prop_list.archive_abs_change));
+        user_default_properties.emplace_back("archive_abs_change", prop_list.archive_abs_change);
     }
 
-    if(prop_list.archive_rel_change.empty() == false &&
+    if(!prop_list.archive_rel_change.empty() &&
        (TG_strcasecmp(prop_list.archive_rel_change.c_str(), AlrmValueNotSpec) != 0) &&
        (TG_strcasecmp(prop_list.archive_rel_change.c_str(), NotANumber) != 0))
     {
         validate_def_change_prop(prop_list.archive_rel_change, "archive_rel_change");
-        user_default_properties.push_back(AttrProperty("archive_rel_change", prop_list.archive_rel_change));
+        user_default_properties.emplace_back("archive_rel_change", prop_list.archive_rel_change);
     }
 
     TangoSys_MemStream def_archive_period;
-    def_archive_period << (int) (INT_MAX);
-    if(prop_list.archive_period.empty() == false &&
-       (TG_strcasecmp(prop_list.archive_period.c_str(), AlrmValueNotSpec) != 0) &&
+    def_archive_period << INT_MAX;
+    if(!prop_list.archive_period.empty() && (TG_strcasecmp(prop_list.archive_period.c_str(), AlrmValueNotSpec) != 0) &&
        (prop_list.archive_period != def_archive_period.str()) &&
        (TG_strcasecmp(prop_list.archive_period.c_str(), NotANumber) != 0))
     {
@@ -428,12 +432,12 @@ void Attr::set_default_properties(UserDefaultAttrProp &prop_list)
         {
             throw_invalid_def_prop("archive_period", "DevLong");
         }
-        user_default_properties.push_back(AttrProperty("archive_period", prop_list.archive_period));
+        user_default_properties.emplace_back("archive_period", prop_list.archive_period);
     }
 
-    if(prop_list.enum_labels.empty() == false)
+    if(!prop_list.enum_labels.empty())
     {
-        user_default_properties.push_back(AttrProperty("enum_labels", prop_list.enum_labels));
+        user_default_properties.emplace_back("enum_labels", prop_list.enum_labels);
     }
 
     if(ranges.test(min_value) && ranges.test(max_value))
