@@ -54,7 +54,7 @@ void copy_data(const CORBA::Any &hist, CORBA::Any live)
 {
     const typename tango_type_traits<T>::ArrayType *tmp;
     hist >>= tmp;
-    typename tango_type_traits<T>::ArrayType *new_tmp = new typename tango_type_traits<T>::ArrayType(
+    auto *new_tmp = new typename tango_type_traits<T>::ArrayType(
         tmp->length(), tmp->length(), const_cast<T *>(tmp->get_buffer()), false);
     live <<= new_tmp;
 }
@@ -123,9 +123,9 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
 {
     TANGO_LOG_DEBUG << "Device_2Impl::command_inout_2 arrived, source = " << source << ", command = " << in_cmd
                     << std::endl;
-    PollObj *polled_cmd = NULL;
+    PollObj *polled_cmd = nullptr;
     bool polling_failed = false;
-    CORBA::Any *ret = NULL;
+    CORBA::Any *ret = nullptr;
 
     //
     // Record operation request in black box
@@ -136,9 +136,9 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
     // is already done
     //
 
-    if(store_in_bb == true)
+    if(store_in_bb)
     {
-        blackbox_ptr->insert_cmd(in_cmd, 2, source);
+        blackbox_ptr->insert_cmd(in_cmd, idl_version, source);
 
         //
         // Do not check lock validity if State or Status is requested using command
@@ -155,7 +155,7 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
         // If the lock is not valid any more, clear it
         //
 
-        if(state_status_cmd == false)
+        if(!state_status_cmd)
         {
             check_lock("command_inout2", in_cmd);
         }
@@ -218,7 +218,7 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
             {
                 if(poll_list[i]->get_name() == cmd_str)
                 {
-                    if((state_cmd == true) || (status_cmd == true))
+                    if((state_cmd) || (status_cmd))
                     {
                         if(poll_list[i]->get_type() == Tango::POLL_ATTR)
                         {
@@ -241,7 +241,7 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
             // Throw exception if the command is not polled
             //
 
-            if(found == false)
+            if(!found)
             {
                 TangoSys_OMemStream o;
                 o << "Command " << in_cmd << " not polled" << std::ends;
@@ -318,7 +318,7 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
             // Check that some data is available in cache
             //
 
-            if(polled_cmd->is_ring_empty() == true)
+            if(polled_cmd->is_ring_empty())
             {
                 TangoSys_OMemStream o;
                 o << "No data available in cache for command " << in_cmd << std::ends;
@@ -361,7 +361,7 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
         if(source == Tango::CACHE)
         {
             TANGO_LOG_DEBUG << "Device_2Impl: Returning data from polling buffer" << std::endl;
-            if((state_cmd == true) || (status_cmd == true))
+            if((state_cmd) || (status_cmd))
             {
                 long vers = get_dev_idl_version();
                 omni_mutex_lock sync(*polled_cmd);
@@ -388,10 +388,10 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
         }
         else
         {
-            if(polling_failed == false)
+            if(!polling_failed)
             {
                 TANGO_LOG_DEBUG << "Device_2Impl: Returning data from polling buffer" << std::endl;
-                if((state_cmd == true) || (status_cmd == true))
+                if((state_cmd) || (status_cmd))
                 {
                     long vers = get_dev_idl_version();
                     omni_mutex_lock sync(*polled_cmd);
@@ -419,7 +419,7 @@ CORBA::Any *Device_2Impl::command_inout_2(const char *in_cmd, const CORBA::Any &
         }
     }
 
-    if((source != Tango::CACHE) && (polling_failed == true))
+    if((source != Tango::CACHE) && (polling_failed))
     {
         AutoTangoMonitor sync(this);
         store_in_bb = false;
@@ -447,28 +447,25 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
 
     bool att_in_fault = false;
     bool polling_failed = false;
-    Tango::AttributeValueList *back = NULL;
+    Tango::AttributeValueList *back = nullptr;
 
     //
-    //  Write the device name into the per thread data for
-    //  sub device diagnostics.
+    //  Write the device name into the per thread data for sub device diagnostics.
     //  Keep the old name, to put it back at the end!
-    //  During device access inside the same server,
-    //  the thread stays the same!
+    //  During device access inside the same server, the thread stays the same!
     //
     SubDevDiag &sub = (Tango::Util::instance())->get_sub_dev_diag();
     std::string last_associated_device = sub.get_associated_device();
     sub.set_associated_device(get_name());
 
-    // Catch all execeptions to set back the associated device after
-    // execution
+    // Catch all execeptions to set back the associated device after execution
     try
     {
         //
         // Record operation request in black box
         //
 
-        blackbox_ptr->insert_attr(names, 2, source);
+        blackbox_ptr->insert_attr(names, idl_version, source);
 
         //
         // If the source parameter specifies device, call the read_attributes method
@@ -530,7 +527,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                 // Check that device supports the wanted attribute
                 //
 
-                if(all_attr == false)
+                if(!all_attr)
                 {
                     for(i = 0; i < real_names.length(); i++)
                     {
@@ -544,7 +541,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                 //
 
                 std::vector<long> non_polled;
-                if(all_attr == false)
+                if(!all_attr)
                 {
                     for(i = 0; i < real_names.length(); i++)
                     {
@@ -570,7 +567,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
 
                 bool found;
                 std::vector<long> poll_period;
-                if(non_polled.empty() == false)
+                if(!non_polled.empty())
                 {
                     //
                     // Check that it is possible to start polling for the non polled attribute
@@ -599,7 +596,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                                 }
                             }
 
-                            if(found == true)
+                            if(found)
                             {
                                 TangoSys_OMemStream o;
                                 o << "Attribute " << real_names[non_polled[i]] << " not polled" << std::ends;
@@ -615,7 +612,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                     Tango::Util *tg = Tango::Util::instance();
                     DServer *adm_dev = tg->get_dserver_device();
 
-                    DevVarLongStringArray *send = new DevVarLongStringArray();
+                    auto *send = new DevVarLongStringArray();
                     send->lvalue.length(1);
                     send->svalue.length(3);
                     send->svalue[0] = device_name.c_str();
@@ -651,7 +648,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                 }
                 catch(std::bad_alloc &)
                 {
-                    back = NULL;
+                    back = nullptr;
                     TANGO_THROW_EXCEPTION(API_MemoryAllocation, "Can't allocate memory in server");
                 }
 
@@ -663,7 +660,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                 for(i = 0; i < nb_attr; i++)
                 {
                     std::vector<PollObj *> &poll_list = get_poll_obj_list();
-                    PollObj *polled_attr = NULL;
+                    PollObj *polled_attr = nullptr;
                     unsigned long j;
                     for(j = 0; j < poll_list.size(); j++)
                     {
@@ -679,10 +676,10 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                     // Check that some data is available in cache
                     //
 
-                    if(polled_attr->is_ring_empty() == true)
+                    if(polled_attr->is_ring_empty())
                     {
                         delete back;
-                        back = NULL;
+                        back = nullptr;
 
                         TangoSys_OMemStream o;
                         o << "No data available in cache for attribute " << real_names[i] << std::ends;
@@ -703,7 +700,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                         if(diff_d > polled_attr->get_authorized_delta())
                         {
                             delete back;
-                            back = NULL;
+                            back = nullptr;
 
                             TangoSys_OMemStream o;
                             o << "Data in cache for attribute " << real_names[i];
@@ -737,7 +734,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                         if(w_type != Tango::READ)
                         {
                             delete back;
-                            back = NULL;
+                            back = nullptr;
 
                             TangoSys_OMemStream o;
                             o << "Client too old to get data for attribute " << real_names[i].in();
@@ -772,7 +769,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                                     if(type == Tango::DEV_ENCODED)
                                     {
                                         delete back;
-                                        back = NULL;
+                                        back = nullptr;
 
                                         TangoSys_OMemStream o;
                                         o << "Data type for attribute " << real_names[i] << " is DEV_ENCODED.";
@@ -799,7 +796,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                                     if(type == Tango::DEV_ENCODED)
                                     {
                                         delete back;
-                                        back = NULL;
+                                        back = nullptr;
 
                                         TangoSys_OMemStream o;
                                         o << "Data type for attribute " << real_names[i] << " is DEV_ENCODED.";
@@ -827,7 +824,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                                     if(type == Tango::DEV_ENCODED)
                                     {
                                         delete back;
-                                        back = NULL;
+                                        back = nullptr;
 
                                         TangoSys_OMemStream o;
                                         o << "Data type for attribute " << real_names[i] << " is DEV_ENCODED.";
@@ -867,7 +864,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
                 {
                     throw;
                 }
-                if(att_in_fault == true)
+                if(att_in_fault)
                 {
                     throw;
                 }
@@ -880,7 +877,7 @@ Tango::AttributeValueList *Device_2Impl::read_attributes_2(const Tango::DevVarSt
         // attribute from device
         //
 
-        if((source == Tango::CACHE_DEV) && (polling_failed == true))
+        if((source == Tango::CACHE_DEV) && (polling_failed))
         {
             delete back;
 
@@ -944,7 +941,7 @@ Tango::DevCmdInfoList_2 *Device_2Impl::command_list_query_2()
     long nb_cmd_dev = get_local_command_list().size();
     long nb_cmd = nb_cmd_class + nb_cmd_dev;
     TANGO_LOG_DEBUG << nb_cmd << " command(s) for device" << std::endl;
-    Tango::DevCmdInfoList_2 *back = NULL;
+    Tango::DevCmdInfoList_2 *back = nullptr;
 
     try
     {
@@ -1050,7 +1047,7 @@ Tango::DevCmdInfo_2 *Device_2Impl::command_query_2(const char *command)
 {
     TANGO_LOG_DEBUG << "DeviceImpl::command_query_2 arrived" << std::endl;
 
-    Tango::DevCmdInfo_2 *back = NULL;
+    Tango::DevCmdInfo_2 *back = nullptr;
     std::string cmd(command);
     std::transform(cmd.begin(), cmd.end(), cmd.begin(), ::tolower);
 
@@ -1092,7 +1089,7 @@ Tango::DevCmdInfo_2 *Device_2Impl::command_query_2(const char *command)
         }
     }
 
-    if(found == false)
+    if(!found)
     {
         nb_cmd = get_local_command_list().size();
         for(i = 0; i < nb_cmd; i++)
@@ -1106,7 +1103,7 @@ Tango::DevCmdInfo_2 *Device_2Impl::command_query_2(const char *command)
         }
     }
 
-    if(found == true)
+    if(found)
     {
         back->cmd_name = Tango::string_dup(cmd_ptr->get_name().c_str());
         back->cmd_tag = 0;
@@ -1184,7 +1181,7 @@ Tango::AttributeConfigList_2 *Device_2Impl::get_attribute_config_2(const Tango::
     TANGO_LOG_DEBUG << "Device_2Impl::get_attribute_config_2 arrived" << std::endl;
 
     long nb_attr = names.length();
-    Tango::AttributeConfigList_2 *back = NULL;
+    Tango::AttributeConfigList_2 *back = nullptr;
     bool all_attr = false;
 
     //
@@ -1251,7 +1248,7 @@ Tango::AttributeConfigList_2 *Device_2Impl::get_attribute_config_2(const Tango::
     {
         try
         {
-            if(all_attr == true)
+            if(all_attr)
             {
                 Attribute &attr = dev_attr->get_attr_by_ind(i);
                 attr.get_properties((*back)[i]);
@@ -1299,7 +1296,7 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
     AutoTangoMonitor sync(&mon);
 
     TANGO_LOG_DEBUG << "Device_2Impl::command_inout_history_2 arrived" << std::endl;
-    Tango::DevCmdHistoryList *back = NULL;
+    Tango::DevCmdHistoryList *back = nullptr;
 
     std::string cmd_str(command);
 
@@ -1338,14 +1335,14 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
     // Check that the command is polled
     //
 
-    PollObj *polled_cmd = NULL;
+    PollObj *polled_cmd = nullptr;
     std::vector<PollObj *> &poll_list = get_poll_obj_list();
     unsigned long i;
     for(i = 0; i < poll_list.size(); i++)
     {
         if(poll_list[i]->get_name() == cmd_str)
         {
-            if((state_cmd == true) || (status_cmd == true))
+            if((state_cmd) || (status_cmd))
             {
                 if(poll_list[i]->get_type() == Tango::POLL_ATTR)
                 {
@@ -1362,7 +1359,7 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
         }
     }
 
-    if(polled_cmd == NULL)
+    if(polled_cmd == nullptr)
     {
         TangoSys_OMemStream o;
         o << "Command " << cmd_str << " not polled" << std::ends;
@@ -1373,7 +1370,7 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
     // Check that some data is available in cache
     //
 
-    if(polled_cmd->is_ring_empty() == true)
+    if(polled_cmd->is_ring_empty())
     {
         TangoSys_OMemStream o;
         o << "No data available in cache for command " << cmd_str << std::ends;
@@ -1411,9 +1408,9 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
     // retrieved the history as attributes and transfer this as command
     //
 
-    if((state_cmd == true) || (status_cmd == true))
+    if((state_cmd) || (status_cmd))
     {
-        Tango::DevAttrHistoryList_3 *back_attr = NULL;
+        Tango::DevAttrHistoryList_3 *back_attr = nullptr;
         try
         {
             back_attr = new Tango::DevAttrHistoryList_3(n);
@@ -1424,7 +1421,7 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
             TANGO_THROW_EXCEPTION(API_MemoryAllocation, "Can't allocate memory in server");
         }
 
-        if(status_cmd == true)
+        if(status_cmd)
         {
             if(vers >= 4)
             {
@@ -1461,7 +1458,7 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
                 (*back)[k].time = (*back_attr)[k].value.time;
                 (*back)[k].cmd_failed = (*back_attr)[k].attr_failed;
                 (*back)[k].errors = (*back_attr)[k].value.err_list;
-                if((*back)[k].cmd_failed == false)
+                if(!(*back)[k].cmd_failed)
                 {
                     Tango::DevState sta;
                     (*back_attr)[k].value.value >>= sta;
@@ -1509,8 +1506,8 @@ Tango::DevAttrHistoryList *Device_2Impl::read_attribute_history_2(const char *na
     blackbox_ptr->insert_op(Op_Read_Attr_history_2);
 
     long vers = get_dev_idl_version();
-    Tango::DevAttrHistoryList *back = NULL;
-    Tango::DevAttrHistoryList_3 *back_3 = NULL;
+    Tango::DevAttrHistoryList *back = nullptr;
+    Tango::DevAttrHistoryList_3 *back_3 = nullptr;
     std::vector<PollObj *> &poll_list = get_poll_obj_list();
     long nb_poll = poll_list.size();
 
@@ -1529,7 +1526,7 @@ Tango::DevAttrHistoryList *Device_2Impl::read_attribute_history_2(const char *na
     //
 
     long j;
-    PollObj *polled_attr = NULL;
+    PollObj *polled_attr = nullptr;
     for(j = 0; j < nb_poll; j++)
     {
         if((poll_list[j]->get_type() == Tango::POLL_ATTR) && (poll_list[j]->get_name() == attr_str))
@@ -1538,7 +1535,7 @@ Tango::DevAttrHistoryList *Device_2Impl::read_attribute_history_2(const char *na
             break;
         }
     }
-    if(polled_attr == NULL)
+    if(polled_attr == nullptr)
     {
         TangoSys_OMemStream o;
         o << "Attribute " << attr_str << " not polled" << std::ends;
@@ -1549,7 +1546,7 @@ Tango::DevAttrHistoryList *Device_2Impl::read_attribute_history_2(const char *na
     // Check that some data is available in cache
     //
 
-    if(polled_attr->is_ring_empty() == true)
+    if(polled_attr->is_ring_empty())
     {
         TangoSys_OMemStream o;
         o << "No data available in cache for attribute " << attr_str << std::ends;
@@ -1624,13 +1621,13 @@ Tango::DevAttrHistoryList *Device_2Impl::read_attribute_history_2(const char *na
 CORBA::Any *Device_2Impl::attr2cmd(AttributeValue_3 &att_val, bool state, bool status)
 {
     CORBA::Any *any = new CORBA::Any();
-    if(state == true)
+    if(state)
     {
         Tango::DevState sta;
         att_val.value >>= sta;
         (*any) <<= sta;
     }
-    else if(status == true)
+    else if(status)
     {
         Tango::DevVarStringArray *dvsa;
         att_val.value >>= dvsa;
@@ -1643,12 +1640,12 @@ CORBA::Any *Device_2Impl::attr2cmd(AttributeValue_3 &att_val, bool state, bool s
 CORBA::Any *Device_2Impl::attr2cmd(AttributeValue_4 &att_val, bool state, bool status)
 {
     CORBA::Any *any = new CORBA::Any();
-    if(state == true)
+    if(state)
     {
         const Tango::DevState &sta = att_val.value.dev_state_att();
         (*any) <<= sta;
     }
-    else if(status == true)
+    else if(status)
     {
         Tango::DevVarStringArray &dvsa = att_val.value.string_att_value();
         (*any) <<= dvsa[0];
@@ -1660,12 +1657,12 @@ CORBA::Any *Device_2Impl::attr2cmd(AttributeValue_4 &att_val, bool state, bool s
 CORBA::Any *Device_2Impl::attr2cmd(AttributeValue_5 &att_val, bool state, bool status)
 {
     CORBA::Any *any = new CORBA::Any();
-    if(state == true)
+    if(state)
     {
         const Tango::DevState &sta = att_val.value.dev_state_att();
         (*any) <<= sta;
     }
-    else if(status == true)
+    else if(status)
     {
         Tango::DevVarStringArray &dvsa = att_val.value.string_att_value();
         (*any) <<= dvsa[0];
