@@ -61,6 +61,7 @@
 #include <tango/server/device_4.h>
 #include <tango/server/eventsupplier.h>
 #include <tango/server/device_3_templ.h>
+#include <tango/internal/telemetry/telemetry_kernel_macros.h>
 
 namespace Tango
 {
@@ -141,7 +142,7 @@ Tango::DevAttrHistory_4 *Device_4Impl::read_attribute_history_4(const char *name
 
     blackbox_ptr->insert_op(Op_Read_Attr_history_4);
 
-    Tango::DevAttrHistory_4 *back = NULL;
+    Tango::DevAttrHistory_4 *back = nullptr;
     std::vector<PollObj *> &poll_list = get_poll_obj_list();
     long nb_poll = poll_list.size();
 
@@ -160,7 +161,7 @@ Tango::DevAttrHistory_4 *Device_4Impl::read_attribute_history_4(const char *name
     //
 
     long j;
-    PollObj *polled_attr = NULL;
+    PollObj *polled_attr = nullptr;
     for(j = 0; j < nb_poll; j++)
     {
         if((poll_list[j]->get_type() == Tango::POLL_ATTR) && (poll_list[j]->get_name() == attr_str))
@@ -169,7 +170,7 @@ Tango::DevAttrHistory_4 *Device_4Impl::read_attribute_history_4(const char *name
             break;
         }
     }
-    if(polled_attr == NULL)
+    if(polled_attr == nullptr)
     {
         TangoSys_OMemStream o;
         o << "Attribute " << attr_str << " not polled" << std::ends;
@@ -180,7 +181,7 @@ Tango::DevAttrHistory_4 *Device_4Impl::read_attribute_history_4(const char *name
     // Check that some data is available in cache
     //
 
-    if(polled_attr->is_ring_empty() == true)
+    if(polled_attr->is_ring_empty())
     {
         TangoSys_OMemStream o;
         o << "No data available in cache for attribute " << attr_str << std::ends;
@@ -257,7 +258,7 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
     AutoTangoMonitor sync(&mon);
 
     TANGO_LOG_DEBUG << "Device_4Impl::command_inout_history_4 arrived" << std::endl;
-    Tango::DevCmdHistory_4 *back = NULL;
+    Tango::DevCmdHistory_4 *back = nullptr;
 
     std::string cmd_str(command);
 
@@ -296,14 +297,14 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
     // Check that the command is polled
     //
 
-    PollObj *polled_cmd = NULL;
+    PollObj *polled_cmd = nullptr;
     std::vector<PollObj *> &poll_list = get_poll_obj_list();
     unsigned long i;
     for(i = 0; i < poll_list.size(); i++)
     {
         if(poll_list[i]->get_name() == cmd_str)
         {
-            if((state_cmd == true) || (status_cmd == true))
+            if((state_cmd) || (status_cmd))
             {
                 if(poll_list[i]->get_type() == Tango::POLL_ATTR)
                 {
@@ -320,7 +321,7 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
         }
     }
 
-    if(polled_cmd == NULL)
+    if(polled_cmd == nullptr)
     {
         TangoSys_OMemStream o;
         o << "Command " << cmd_str << " not polled" << std::ends;
@@ -331,7 +332,7 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
     // Check that some data is available in cache
     //
 
-    if(polled_cmd->is_ring_empty() == true)
+    if(polled_cmd->is_ring_empty())
     {
         TangoSys_OMemStream o;
         o << "No data available in cache for command " << cmd_str << std::ends;
@@ -369,9 +370,9 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
     // retrieved the history as attributes and transfer this as command
     //
 
-    if((state_cmd == true) || (status_cmd == true))
+    if((state_cmd) || (status_cmd))
     {
-        Tango::DevAttrHistory_4 *back_attr = NULL;
+        Tango::DevAttrHistory_4 *back_attr = nullptr;
         try
         {
             back_attr = new Tango::DevAttrHistory_4;
@@ -382,7 +383,7 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
             TANGO_THROW_EXCEPTION(API_MemoryAllocation, "Can't allocate memory in server");
         }
 
-        if(status_cmd == true)
+        if(status_cmd)
         {
             polled_cmd->get_attr_history(n, back_attr, Tango::DEV_STRING, SCALAR);
 
@@ -455,6 +456,12 @@ CORBA::Any *Device_4Impl::command_inout_4(const char *in_cmd,
                                           Tango::DevSource source,
                                           const Tango::ClntIdent &cl_id)
 {
+    // Reference comment for multiple locations:
+    // HERE, WE ARE REPLYING TO A CLIENT  RPC - WE CAN HARDLY FIND A MORE "UPSTREAM"
+    // POINT IN THE CALL STACK TO SETUP THE TELEMETRY CONTEXT - WE CONSEQUENTLY HAVE
+    // TO CONSIDER THIS LOCATION AS THE ENTRY POINT OF THE CORRESPONDING TANGO RPC
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({{"tango.operation.argument", in_cmd}}));
+
     TANGO_LOG_DEBUG << "Device_4Impl::command_inout_4 arrived, source = " << source << ", command = " << in_cmd
                     << std::endl;
 
@@ -462,7 +469,7 @@ CORBA::Any *Device_4Impl::command_inout_4(const char *in_cmd,
     // Record operation request in black box
     //
 
-    blackbox_ptr->insert_cmd_cl_ident(in_cmd, cl_id, 4, source);
+    blackbox_ptr->insert_cmd_cl_ident(in_cmd, cl_id, idl_version, source);
 
     //
     // Do not check lock validity if State or Status is requested using command
@@ -479,7 +486,7 @@ CORBA::Any *Device_4Impl::command_inout_4(const char *in_cmd,
     // If the lock is not valid any more, clear it
     //
 
-    if(state_status_cmd == false)
+    if(!state_status_cmd)
     {
         check_lock("command_inout4", in_cmd);
     }
@@ -490,6 +497,8 @@ CORBA::Any *Device_4Impl::command_inout_4(const char *in_cmd,
 
     store_in_bb = false;
     return (command_inout_2(in_cmd, in_data, source));
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+-------------------------------------------------------------------------
@@ -505,6 +514,9 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
                                                              Tango::DevSource source,
                                                              const Tango::ClntIdent &cl_id)
 {
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_4Impl::read_attributes_4 arrived for dev " << get_name() << ", att[0] = " << names[0]
                     << std::endl;
 
@@ -512,9 +524,9 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
     // Record operation request in black box
     //
 
-    if(store_in_bb == true)
+    if(store_in_bb)
     {
-        blackbox_ptr->insert_attr(names, cl_id, 4, source);
+        blackbox_ptr->insert_attr(names, cl_id, idl_version, source);
     }
     store_in_bb = true;
 
@@ -559,7 +571,7 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
 
     try
     {
-        Tango::AttributeValue_4 *l_back = new Tango::AttributeValue_4[nb_names];
+        auto *l_back = new Tango::AttributeValue_4[nb_names];
         aid.data_4 = new Tango::AttributeValueList_4(nb_names, nb_names, l_back, true);
 
         for(unsigned long loop = 0; loop < nb_names; loop++)
@@ -611,13 +623,13 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
         Tango::DevVarStringArray local_names(nb_names);
         Tango::DevVarStringArray fwd_names(nb_names);
 
-        if(with_fwd_att == true)
+        if(with_fwd_att)
         {
             for(size_t loop = 0; loop < nb_names; loop++)
             {
                 Attribute &att = dev_attr->get_attr_by_name(real_names[loop]);
 
-                if(att.is_fwd_att() == true)
+                if(att.is_fwd_att())
                 {
                     size_t nb_fwd = 0;
                     fwd_att_in_call = true;
@@ -636,7 +648,7 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
             }
         }
 
-        if(fwd_att_in_call == false)
+        if(!fwd_att_in_call)
         {
             //
             // No fwd attributes in call, get values from local cache
@@ -750,6 +762,8 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
     }
 
     return aid.data_4;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+-------------------------------------------------------------------------
@@ -765,15 +779,19 @@ Tango::AttributeValueList_4 *Device_4Impl::read_attributes_4(const Tango::DevVar
 void Device_4Impl::write_attributes_4(const Tango::AttributeValueList_4 &values, const Tango::ClntIdent &cl_id)
 {
     AutoTangoMonitor sync(this, true);
+
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_4Impl::write_attributes_4 arrived" << std::endl;
 
     //
     // Record operation request in black box
     //
 
-    if(store_in_bb == true)
+    if(store_in_bb)
     {
-        blackbox_ptr->insert_attr(values, cl_id, 4);
+        blackbox_ptr->insert_attr(values, cl_id, idl_version);
     }
     store_in_bb = true;
 
@@ -787,7 +805,9 @@ void Device_4Impl::write_attributes_4(const Tango::AttributeValueList_4 &values,
     // Call the Device_3Impl write_attributes
     //
 
-    return write_attributes_34(NULL, &values);
+    write_attributes_34(nullptr, &values);
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+-------------------------------------------------------------------------
@@ -806,6 +826,10 @@ void Device_4Impl::write_attributes_4(const Tango::AttributeValueList_4 &values,
 void Device_4Impl::set_attribute_config_4(const Tango::AttributeConfigList_3 &new_conf, const Tango::ClntIdent &cl_id)
 {
     AutoTangoMonitor sync(this, true);
+
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_4Impl::set_attribute_config_4 arrived" << std::endl;
 
     //
@@ -834,7 +858,9 @@ void Device_4Impl::set_attribute_config_4(const Tango::AttributeConfigList_3 &ne
     //
 
     store_in_bb = false;
-    return set_attribute_config_3_local(new_conf, new_conf[0], false, 4);
+    set_attribute_config_3_local(new_conf, new_conf[0], false, idl_version);
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+-------------------------------------------------------------------------
@@ -854,6 +880,10 @@ Tango::AttributeValueList_4 *Device_4Impl::write_read_attributes_4(const Tango::
                                                                    const Tango::ClntIdent &cl_id)
 {
     AutoTangoMonitor sync(this, true);
+
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_4Impl::write_read_attributes_4 arrived" << std::endl;
 
     //
@@ -864,7 +894,7 @@ Tango::AttributeValueList_4 *Device_4Impl::write_read_attributes_4(const Tango::
     dvsa.length(1);
     dvsa[0] = Tango::string_dup(values[0].name);
 
-    blackbox_ptr->insert_wr_attr(values, dvsa, cl_id, 4);
+    blackbox_ptr->insert_wr_attr(values, dvsa, cl_id, idl_version);
 
     //
     // Check if the device is locked and by who
@@ -910,6 +940,8 @@ Tango::AttributeValueList_4 *Device_4Impl::write_read_attributes_4(const Tango::
     read_val_ptr = read_attributes_4(att_name, Tango::DEV, dummy_cl_id);
 
     return read_val_ptr;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 } // namespace Tango
