@@ -56,6 +56,7 @@
 #include <tango/server/device_5.h>
 #include <tango/server/eventsupplier.h>
 #include <tango/server/device_3_templ.h>
+#include <tango/internal/telemetry/telemetry_kernel_macros.h>
 
 namespace Tango
 {
@@ -122,6 +123,9 @@ Tango::AttributeValueList_5 *Device_5Impl::read_attributes_5(const Tango::DevVar
                                                              Tango::DevSource source,
                                                              const Tango::ClntIdent &cl_id)
 {
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_5Impl::read_attributes_5 arrived for dev " << get_name() << ", att[0] = " << names[0]
                     << std::endl;
 
@@ -129,9 +133,9 @@ Tango::AttributeValueList_5 *Device_5Impl::read_attributes_5(const Tango::DevVar
     // Record operation request in black box
     //
 
-    if(store_in_bb == true)
+    if(store_in_bb)
     {
-        blackbox_ptr->insert_attr(names, cl_id, 5, source);
+        blackbox_ptr->insert_attr(names, cl_id, idl_version, source);
     }
     store_in_bb = true;
 
@@ -175,7 +179,7 @@ Tango::AttributeValueList_5 *Device_5Impl::read_attributes_5(const Tango::DevVar
 
     try
     {
-        Tango::AttributeValue_5 *l_back = new Tango::AttributeValue_5[nb_names];
+        auto *l_back = new Tango::AttributeValue_5[nb_names];
         aid.data_5 = new Tango::AttributeValueList_5(nb_names, nb_names, l_back, true);
 
         for(unsigned long loop = 0; loop < nb_names; loop++)
@@ -226,13 +230,13 @@ Tango::AttributeValueList_5 *Device_5Impl::read_attributes_5(const Tango::DevVar
         Tango::DevVarStringArray local_names(nb_names);
         Tango::DevVarStringArray fwd_names(nb_names);
 
-        if(with_fwd_att == true)
+        if(with_fwd_att)
         {
             for(size_t loop = 0; loop < nb_names; loop++)
             {
                 Attribute &att = dev_attr->get_attr_by_name(real_names[loop]);
 
-                if(att.is_fwd_att() == true)
+                if(att.is_fwd_att())
                 {
                     size_t nb_fwd = 0;
                     fwd_att_in_call = true;
@@ -251,7 +255,7 @@ Tango::AttributeValueList_5 *Device_5Impl::read_attributes_5(const Tango::DevVar
             }
         }
 
-        if(fwd_att_in_call == false)
+        if(!fwd_att_in_call)
         {
             //
             // No fwd attributes in call, get values from local cache
@@ -365,6 +369,8 @@ Tango::AttributeValueList_5 *Device_5Impl::read_attributes_5(const Tango::DevVar
     }
 
     return aid.data_5;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -383,13 +389,17 @@ Tango::AttributeValueList_5 *Device_5Impl::write_read_attributes_5(const Tango::
                                                                    const Tango::ClntIdent &cl_id)
 {
     AutoTangoMonitor sync(this, true);
+
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_5Impl::write_read_attributes_5 arrived" << std::endl;
 
     //
     // Record operation request in black box
     //
 
-    blackbox_ptr->insert_wr_attr(values, r_names, cl_id, 5);
+    blackbox_ptr->insert_wr_attr(values, r_names, cl_id, idl_version);
 
     //
     // Check if the device is locked and by who
@@ -427,7 +437,7 @@ Tango::AttributeValueList_5 *Device_5Impl::write_read_attributes_5(const Tango::
     for(unsigned int loop = 0; loop < r_w_att.size(); ++loop)
     {
         Tango::Attribute &att = dev_attr->get_attr_by_name(values[loop].name);
-        if(att.is_fwd_att() == true)
+        if(att.is_fwd_att())
         {
             Tango::FwdAttribute &fwd_att = static_cast<FwdAttribute &>(att);
             fwd_att_root_dev_name.push_back(fwd_att.get_fwd_dev_name());
@@ -444,7 +454,7 @@ Tango::AttributeValueList_5 *Device_5Impl::write_read_attributes_5(const Tango::
     Util *tg = Util::instance();
     RootAttRegistry &rar = tg->get_root_att_reg();
 
-    if(fwd_att_root_dev_name.empty() == false)
+    if(!fwd_att_root_dev_name.empty())
     {
         std::vector<std::string>::iterator ite;
         for(ite = fwd_att_root_dev_name.begin(); ite != fwd_att_root_dev_name.end(); ++ite)
@@ -479,7 +489,7 @@ Tango::AttributeValueList_5 *Device_5Impl::write_read_attributes_5(const Tango::
     }
     catch(...)
     {
-        if(fwd_att_root_dev_name.empty() == false)
+        if(!fwd_att_root_dev_name.empty())
         {
             std::vector<std::string>::iterator ite;
             for(ite = fwd_att_root_dev_name.begin(); ite != fwd_att_root_dev_name.end(); ++ite)
@@ -496,7 +506,7 @@ Tango::AttributeValueList_5 *Device_5Impl::write_read_attributes_5(const Tango::
     // Unlock devices (if case there are some due to forwarded attributes)
     //
 
-    if(fwd_att_root_dev_name.empty() == false)
+    if(!fwd_att_root_dev_name.empty())
     {
         std::vector<std::string>::iterator ite;
         for(ite = fwd_att_root_dev_name.begin(); ite != fwd_att_root_dev_name.end(); ++ite)
@@ -507,6 +517,8 @@ Tango::AttributeValueList_5 *Device_5Impl::write_read_attributes_5(const Tango::
     }
 
     return read_val_ptr;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -539,7 +551,7 @@ Tango::AttributeConfigList_5 *Device_5Impl::get_attribute_config_5(const Tango::
     TANGO_LOG_DEBUG << "Device_5Impl::get_attribute_config_5 arrived" << std::endl;
 
     long nb_attr = names.length();
-    Tango::AttributeConfigList_5 *back = NULL;
+    Tango::AttributeConfigList_5 *back = nullptr;
     bool all_attr = false;
 
     //
@@ -592,7 +604,7 @@ Tango::AttributeConfigList_5 *Device_5Impl::get_attribute_config_5(const Tango::
     {
         try
         {
-            if(all_attr == true)
+            if(all_attr)
             {
                 Attribute &attr = dev_attr->get_attr_by_ind(i);
                 attr.get_properties((*back)[i]);
@@ -637,6 +649,10 @@ Tango::AttributeConfigList_5 *Device_5Impl::get_attribute_config_5(const Tango::
 void Device_5Impl::set_attribute_config_5(const Tango::AttributeConfigList_5 &new_conf, const Tango::ClntIdent &cl_id)
 {
     AutoTangoMonitor sync(this, true);
+
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_5Impl::set_attribute_config_5 arrived" << std::endl;
 
     //
@@ -653,7 +669,8 @@ void Device_5Impl::set_attribute_config_5(const Tango::AttributeConfigList_5 &ne
 
     bool from_fwd_cb = false;
     Tango::LockerLanguage cl_lang = cl_id._d();
-    if(cl_lang == Tango::CPP && cl_id.cpp_clnt() == 0)
+    if((cl_lang == Tango::CPP && cl_id.cpp_clnt() == 0) ||
+       (cl_lang == Tango::CPP_6 && cl_id.cpp_clnt_6().cpp_clnt == 0))
     {
         from_fwd_cb = true;
     }
@@ -662,7 +679,7 @@ void Device_5Impl::set_attribute_config_5(const Tango::AttributeConfigList_5 &ne
     // Record operation request in black box
     //
 
-    if(from_fwd_cb == false)
+    if(!from_fwd_cb)
     {
         blackbox_ptr->insert_op(Op_Set_Attr_Config_5, cl_id);
     }
@@ -677,7 +694,9 @@ void Device_5Impl::set_attribute_config_5(const Tango::AttributeConfigList_5 &ne
     // Call the Device_3Impl set_attribute_config
     //
 
-    return set_attribute_config_3_local(new_conf, new_conf[0], from_fwd_cb, 5);
+    set_attribute_config_3_local(new_conf, new_conf[0], from_fwd_cb, idl_version);
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+-------------------------------------------------------------------------------------------------------------------
@@ -730,7 +749,7 @@ Tango::DevAttrHistory_5 *Device_5Impl::read_attribute_history_5(const char *name
     //
 
     long j;
-    PollObj *polled_attr = NULL;
+    PollObj *polled_attr = nullptr;
     for(j = 0; j < nb_poll; j++)
     {
         if((poll_list[j]->get_type() == Tango::POLL_ATTR) && (poll_list[j]->get_name() == attr_str))
@@ -739,7 +758,7 @@ Tango::DevAttrHistory_5 *Device_5Impl::read_attribute_history_5(const char *name
             break;
         }
     }
-    if((polled_attr == NULL) && (att.is_fwd_att() == false))
+    if((polled_attr == nullptr) && (!att.is_fwd_att()))
     {
         TangoSys_OMemStream o;
         o << "Attribute " << attr_str << " not polled" << std::ends;
@@ -750,7 +769,7 @@ Tango::DevAttrHistory_5 *Device_5Impl::read_attribute_history_5(const char *name
     // If it is a forwarded attribute, get data from the root attribute
     //
 
-    if(att.is_fwd_att() == true)
+    if(att.is_fwd_att())
     {
         try
         {
@@ -770,7 +789,7 @@ Tango::DevAttrHistory_5 *Device_5Impl::read_attribute_history_5(const char *name
         // Check that some data is available in cache
         //
 
-        if(polled_attr->is_ring_empty() == true)
+        if(polled_attr->is_ring_empty())
         {
             TangoSys_OMemStream o;
             o << "No data available in cache for attribute " << attr_str << std::ends;
@@ -896,7 +915,7 @@ Tango::PipeConfigList *Device_5Impl::get_pipe_config_5(const Tango::DevVarString
     {
         try
         {
-            if(all_pipe == true)
+            if(all_pipe)
             {
                 Pipe *pi_ptr = pipe_list[i];
                 (*back)[i].name = Tango::string_dup(pi_ptr->get_name().c_str());
@@ -950,6 +969,10 @@ Tango::PipeConfigList *Device_5Impl::get_pipe_config_5(const Tango::DevVarString
 void Device_5Impl::set_pipe_config_5(const Tango::PipeConfigList &new_conf, const Tango::ClntIdent &cl_id)
 {
     AutoTangoMonitor sync(this, true);
+
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({}));
+
     TANGO_LOG_DEBUG << "Device_5Impl::set_pipe_config_5 arrived for " << new_conf.length() << " pipe(s)" << std::endl;
 
     //
@@ -1021,6 +1044,8 @@ void Device_5Impl::set_pipe_config_5(const Tango::PipeConfigList &new_conf, cons
         e.errors[0].reason = Tango::string_dup(s.c_str());
         throw;
     }
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -1043,6 +1068,9 @@ void Device_5Impl::set_pipe_config_5(const Tango::PipeConfigList &new_conf, cons
 
 Tango::DevPipeData *Device_5Impl::read_pipe_5(const char *name, const Tango::ClntIdent &cl_id)
 {
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({{"tango.operation.argument", name}}));
+
     TANGO_LOG_DEBUG << "Device_5Impl::read_pipe_5 arrived for pipe " << name << std::endl;
     DevPipeData *back = nullptr;
 
@@ -1056,9 +1084,9 @@ Tango::DevPipeData *Device_5Impl::read_pipe_5(const char *name, const Tango::Cln
     // Record operation request in black box
     //
 
-    if(store_in_bb == true)
+    if(store_in_bb)
     {
-        blackbox_ptr->insert_attr(name, cl_id, 5);
+        blackbox_ptr->insert_attr(name, cl_id, idl_version);
     }
     store_in_bb = true;
 
@@ -1107,7 +1135,7 @@ Tango::DevPipeData *Device_5Impl::read_pipe_5(const char *name, const Tango::Cln
         // Call the is_allowed method
         //
 
-        if(pi.is_allowed(this, READ_REQ) == false)
+        if(!pi.is_allowed(this, READ_REQ))
         {
             std::stringstream o;
             o << "It is currently not allowed to read pipe " << name;
@@ -1176,7 +1204,7 @@ Tango::DevPipeData *Device_5Impl::read_pipe_5(const char *name, const Tango::Cln
         // Check that the wanted pipe set value has been updated
         //
 
-        if(pi.get_value_flag() == false)
+        if(!pi.get_value_flag())
         {
             if(pi.get_pipe_serial_model() == PIPE_BY_KERNEL)
             {
@@ -1254,6 +1282,8 @@ Tango::DevPipeData *Device_5Impl::read_pipe_5(const char *name, const Tango::Cln
 
     TANGO_LOG_DEBUG << "Leaving Device_5Impl::read_pipe_5" << std::endl;
     return back;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -1273,6 +1303,9 @@ Tango::DevPipeData *Device_5Impl::read_pipe_5(const char *name, const Tango::Cln
 
 void Device_5Impl::write_pipe_5(const Tango::DevPipeData &pi_value, const Tango::ClntIdent &cl_id)
 {
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({{"tango.operation.argument", pi_value.name.in()}}));
+
     std::string pipe_name(pi_value.name.in());
     TANGO_LOG_DEBUG << "Device_5Impl::write_pipe_5 arrived for pipe " << pipe_name << std::endl;
 
@@ -1286,7 +1319,7 @@ void Device_5Impl::write_pipe_5(const Tango::DevPipeData &pi_value, const Tango:
     // Record operation in blackbox
     //
 
-    if(store_in_bb == true)
+    if(store_in_bb)
     {
         blackbox_ptr->insert_attr(pi_value, cl_id, 0);
     }
@@ -1344,7 +1377,7 @@ void Device_5Impl::write_pipe_5(const Tango::DevPipeData &pi_value, const Tango:
         // Call the is_allowed method
         //
 
-        if(pi.is_allowed(this, WRITE_REQ) == false)
+        if(!pi.is_allowed(this, WRITE_REQ))
         {
             std::stringstream o;
             o << "It is currently not allowed to write pipe " << pipe_name;
@@ -1393,6 +1426,8 @@ void Device_5Impl::write_pipe_5(const Tango::DevPipeData &pi_value, const Tango:
     //
 
     TANGO_LOG_DEBUG << "Leaving Device_5Impl::write_pipe_5" << std::endl;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -1417,6 +1452,9 @@ Tango::DevPipeData *Device_5Impl::write_read_pipe_5(const Tango::DevPipeData &pi
 {
     AutoTangoMonitor sync(this, true);
 
+    // see comment in Device_4Impl::command_inout_4
+    TANGO_TELEMETRY_KERNEL_TRACE_BEGIN(({{"tango.operation.argument", pi_value.name.in()}}));
+
     std::string pipe_name(pi_value.name.in());
     TANGO_LOG_DEBUG << "Device_5Impl::write_read_pipe_5 arrived for pipe " << pipe_name << std::endl;
 
@@ -1447,6 +1485,8 @@ Tango::DevPipeData *Device_5Impl::write_read_pipe_5(const Tango::DevPipeData &pi
     DevPipeData *back = read_pipe_5(pi_value.name.in(), cl_id);
 
     return back;
+
+    TANGO_TELEMETRY_TRACE_END();
 }
 
 } // namespace Tango
