@@ -42,16 +42,24 @@
 
 #ifndef _TG_WINDOWS_
   #include <unistd.h>
-  #include <signal.h>
+  #include <csignal>
   #include <dlfcn.h>
 #endif /* _TG_WINDOWS_ */
 
-#include <stdlib.h>
+#include <cstdlib>
 
 namespace Tango
 {
 
-ClassFactoryFuncPtr DServer::class_factory_func_ptr = NULL;
+void call_delete(DeviceClass *dev_class_ptr)
+{
+    TANGO_LOG_DEBUG << "Tango::call_delete" << std::endl;
+    delete dev_class_ptr;
+}
+
+DeviceClassDeleter wrapper_compatible_delete = call_delete;
+
+ClassFactoryFuncPtr DServer::class_factory_func_ptr = nullptr;
 
 //+------------------------------------------------------------------------------------------------------------------
 //
@@ -74,6 +82,8 @@ ClassFactoryFuncPtr DServer::class_factory_func_ptr = NULL;
 DServer::DServer(DeviceClass *cl_ptr, const char *n, const char *d, Tango::DevState s, const char *st) :
     TANGO_BASE_CLASS(cl_ptr, n, d, s, st)
 {
+    TANGO_LOG_DEBUG << "Entering DServer::DServer constructor" << std::endl;
+
     process_name = Tango::Util::instance()->get_ds_exec_name();
     instance_name = Tango::Util::instance()->get_ds_inst_name();
 
@@ -84,7 +94,7 @@ DServer::DServer(DeviceClass *cl_ptr, const char *n, const char *d, Tango::DevSt
     fqdn = "tango://";
     Tango::Util *tg = Tango::Util::instance();
     Database *db = tg->get_database();
-    if(db != NULL)
+    if(db != nullptr)
     {
         fqdn = fqdn + db->get_db_host() + ':' + db->get_db_port() + "/dserver/" + full_name;
     }
@@ -93,24 +103,19 @@ DServer::DServer(DeviceClass *cl_ptr, const char *n, const char *d, Tango::DevSt
         fqdn = "dserver/" + full_name;
     }
 
-    last_heartbeat = time(NULL);
+    last_heartbeat = Tango::get_current_system_datetime();
     last_heartbeat_zmq = last_heartbeat;
     heartbeat_started = false;
 
     polling_th_pool_size = DEFAULT_POLLING_THREADS_POOL_SIZE;
     optimize_pool_usage = true;
+
+    TANGO_LOG_DEBUG << "Leaving DServer::DServer constructor" << std::endl;
 }
 
 bool less_than(Command *a, Command *b)
 {
-    if(a->get_name() < b->get_name())
-    {
-        return true;
-    }
-    else
-    {
-        return false;
-    }
+    return a->get_name() < b->get_name();
 }
 
 void DServer::init_device()
@@ -136,7 +141,7 @@ void DServer::init_device()
     // Destroy already registered classes
     //
 
-    if(class_list.empty() == false)
+    if(!class_list.empty())
     {
         delete_devices();
     }
@@ -164,7 +169,7 @@ void DServer::init_device()
         // Create user TDSOM implementation
         //
 
-        if(class_factory_func_ptr == NULL)
+        if(class_factory_func_ptr == nullptr)
         {
             class_factory();
         }
@@ -174,7 +179,7 @@ void DServer::init_device()
         }
         class_factory_done = true;
 
-        if(class_list.empty() == false)
+        if(!class_list.empty())
         {
             //
             // Set the class list pointer in the Util class and add the DServer object class
@@ -300,7 +305,7 @@ void DServer::init_device()
                     //
 
                     std::vector<std::string> &list = class_list[i]->get_nodb_name_list();
-                    Tango::DevVarStringArray *dev_list_nodb = new Tango::DevVarStringArray();
+                    auto *dev_list_nodb = new Tango::DevVarStringArray();
 
                     tg->get_cmd_line_name_list(class_list[i]->get_name(), list);
                     if(i == class_list.size() - 1)
@@ -308,12 +313,12 @@ void DServer::init_device()
                         tg->get_cmd_line_name_list(NoClass, list);
                     }
 
-                    if(list.empty() == true)
+                    if(list.empty())
                     {
                         class_list[i]->device_name_factory(list);
                     }
 
-                    if(list.empty() == true)
+                    if(list.empty())
                     {
                         dev_list_nodb->length(1);
                         (*dev_list_nodb)[0] = Tango::string_dup("NoName");
@@ -354,16 +359,16 @@ void DServer::init_device()
 
         TangoSys_OMemStream o;
 
-        if(class_factory_done == false)
+        if(!class_factory_done)
         {
             long class_err = class_list.size() + 1;
             o << "Can't allocate memory in server while creating class number " << class_err << std::ends;
-            if(class_list.empty() == false)
+            if(!class_list.empty())
             {
                 for(unsigned long j = 0; j < class_list.size(); j++)
                 {
                     class_list[j]->release_devices_mon();
-                    delete class_list[j];
+                    wrapper_compatible_delete(class_list[j]);
                 }
                 class_list.clear();
             }
@@ -375,7 +380,7 @@ void DServer::init_device()
             for(unsigned long j = i; j < class_list.size(); j++)
             {
                 class_list[j]->release_devices_mon();
-                delete class_list[j];
+                wrapper_compatible_delete(class_list[j]);
             }
             class_list.erase(class_list.begin() + i, class_list.end());
         }
@@ -390,14 +395,14 @@ void DServer::init_device()
         // error occurs during the command or device factories, erase only the following classes
         //
 
-        if(class_factory_done == false)
+        if(!class_factory_done)
         {
-            if(class_list.empty() == false)
+            if(!class_list.empty())
             {
                 for(unsigned long j = 0; j < class_list.size(); j++)
                 {
                     class_list[j]->release_devices_mon();
-                    delete class_list[j];
+                    wrapper_compatible_delete(class_list[j]);
                 }
                 class_list.clear();
             }
@@ -407,7 +412,7 @@ void DServer::init_device()
             for(unsigned long j = i; j < class_list.size(); j++)
             {
                 class_list[j]->release_devices_mon();
-                delete class_list[j];
+                wrapper_compatible_delete(class_list[j]);
             }
             class_list.erase(class_list.begin() + i, class_list.end());
         }
@@ -422,13 +427,13 @@ void DServer::init_device()
         // error occurs during the command or device factories, erase only the following classes
         //
 
-        if(class_factory_done == false)
+        if(!class_factory_done)
         {
-            if(class_list.empty() == false)
+            if(!class_list.empty())
             {
                 for(unsigned long j = 0; j < class_list.size(); j++)
                 {
-                    delete class_list[j];
+                    wrapper_compatible_delete(class_list[j]);
                 }
                 class_list.clear();
             }
@@ -437,7 +442,7 @@ void DServer::init_device()
         {
             for(unsigned long j = i; j < class_list.size(); j++)
             {
-                delete class_list[j];
+                wrapper_compatible_delete(class_list[j]);
             }
             class_list.erase(class_list.begin() + i, class_list.end());
         }
@@ -489,11 +494,11 @@ DServer::~DServer()
     // Destroy already registered classes
     //
 
-    if(class_list.empty() == false)
+    if(!class_list.empty())
     {
         for(long i = class_list.size() - 1; i >= 0; i--)
         {
-            delete class_list[i];
+            wrapper_compatible_delete(class_list[i]);
         }
         class_list.clear();
     }
@@ -511,7 +516,7 @@ DServer::~DServer()
 
 void DServer::delete_devices()
 {
-    if(class_list.empty() == false)
+    if(!class_list.empty())
     {
         for(long i = class_list.size() - 1; i >= 0; i--)
         {
@@ -560,13 +565,13 @@ void DServer::delete_devices()
                 // Wait for POA to destroy the object before going to the next one. Limit this waiting time to 200 mS
                 //
 
-                std::vector<DeviceImpl *>::iterator it = devs.begin();
+                auto it = devs.begin();
                 devs.erase(it);
             }
             devs.clear();
             CORBA::release(r_poa);
 
-            delete class_list[i];
+            wrapper_compatible_delete(class_list[i]);
 
             class_list.pop_back();
         }
@@ -613,7 +618,7 @@ Tango::DevVarStringArray *DServer::query_class()
     TANGO_LOG_DEBUG << "In query_class command" << std::endl;
 
     long nb_class = class_list.size();
-    Tango::DevVarStringArray *ret = NULL;
+    Tango::DevVarStringArray *ret = nullptr;
 
     try
     {
@@ -652,7 +657,7 @@ Tango::DevVarStringArray *DServer::query_device()
     TANGO_LOG_DEBUG << "In query_device command" << std::endl;
 
     long nb_class = class_list.size();
-    Tango::DevVarStringArray *ret = NULL;
+    Tango::DevVarStringArray *ret = nullptr;
     std::vector<std::string> vs;
 
     try
@@ -769,7 +774,7 @@ void DServer::restart(const std::string &d_name)
                 break;
             }
         }
-        if(found == true)
+        if(found)
         {
             break;
         }
@@ -807,7 +812,7 @@ void DServer::restart(const std::string &d_name)
             ev_client = event_supplier_zmq->any_dev_intr_client(dev_to_del);
         }
 
-        if(ev_client == true)
+        if(ev_client)
         {
             di.get_interface(dev_to_del);
         }
@@ -855,12 +860,12 @@ void DServer::restart(const std::string &d_name)
     // Also get device locker parameters if device locked
     //
 
-    client_addr *cl_addr = NULL;
-    client_addr *old_cl_addr = NULL;
+    client_addr *cl_addr = nullptr;
+    client_addr *old_cl_addr = nullptr;
     time_t l_date = 0;
     DevLong l_ctr = 0, l_valid = 0;
 
-    if(dev_to_del->is_device_locked() == true)
+    if(dev_to_del->is_device_locked())
     {
         cl_addr = dev_to_del->get_locker();
         old_cl_addr = dev_to_del->get_old_locker();
@@ -874,7 +879,7 @@ void DServer::restart(const std::string &d_name)
     // If the device was polled, stop polling
     //
 
-    if(dev_pol.empty() == false)
+    if(!dev_pol.empty())
     {
         dev_to_del->stop_polling(false);
     }
@@ -887,7 +892,7 @@ void DServer::restart(const std::string &d_name)
     {
         tg->add_restarting_device(lower_d_name);
         PortableServer::POA_ptr r_poa = tg->get_poa();
-        if(dev_to_del->get_exported_flag() == true)
+        if(dev_to_del->get_exported_flag())
         {
             r_poa->deactivate_object(dev_to_del->get_obj_id().in());
         }
@@ -951,7 +956,7 @@ void DServer::restart(const std::string &d_name)
     // Re-start device polling (if any)
     //
 
-    DevVarLongStringArray *send = new DevVarLongStringArray();
+    auto *send = new DevVarLongStringArray();
     send->lvalue.length(1);
     send->svalue.length(3);
 
@@ -992,7 +997,7 @@ void DServer::restart(const std::string &d_name)
     // Find the new device
     //
 
-    DeviceImpl *new_dev = NULL;
+    DeviceImpl *new_dev = nullptr;
 
     std::vector<Tango::DeviceImpl *> &d_list = dev_cl->get_device_list();
 
@@ -1028,7 +1033,7 @@ void DServer::restart(const std::string &d_name)
     for(unsigned int j = 0; j < att_list.size(); ++j)
     {
         mcast_event_for_att(new_dev->get_name_lower(), att_list[j]->get_name_lower(), m_cast);
-        if(m_cast.empty() == false)
+        if(!m_cast.empty())
         {
             att_list[j]->set_mcast_event(m_cast);
         }
@@ -1045,7 +1050,7 @@ void DServer::restart(const std::string &d_name)
     // Re-lock device if necessary
     //
 
-    if(cl_addr != NULL)
+    if(cl_addr != nullptr)
     {
         new_dev->set_locking_param(cl_addr, old_cl_addr, l_date, l_ctr, l_valid);
     }
@@ -1054,9 +1059,9 @@ void DServer::restart(const std::string &d_name)
     // Fire device interface change event if needed
     //
 
-    if(ev_client == true)
+    if(ev_client)
     {
-        if(di.has_changed(new_dev) == true)
+        if(di.has_changed(new_dev))
         {
             TANGO_LOG_DEBUG << "Device interface has changed !!!!!!!!!!!!!!!!!!!" << std::endl;
 
@@ -1138,6 +1143,16 @@ void ServRestartThread::run(void *ptr)
 
     dev->init_logger();
 
+    //
+    // Setup telemetry
+    //
+#if defined(TANGO_USE_TELEMETRY)
+    // initialize the telemetry interface
+    dev->initialize_telemetry_interface();
+    // attach the device's telemetry interface
+    Tango::telemetry::Interface::set_current(dev->telemetry());
+#endif
+
     //
     // Reset initial state and status
     //
@@ -1233,7 +1248,7 @@ Tango::DevVarStringArray *DServer::query_class_prop(std::string &class_name)
     TANGO_LOG_DEBUG << "In query_class_prop command" << std::endl;
 
     long nb_class = class_list.size();
-    Tango::DevVarStringArray *ret = NULL;
+    Tango::DevVarStringArray *ret = nullptr;
 
     //
     // Find the wanted class in server and throw exception if not found
@@ -1300,7 +1315,7 @@ Tango::DevVarStringArray *DServer::query_dev_prop(std::string &class_name)
     TANGO_LOG_DEBUG << "In query_dev_prop command" << std::endl;
 
     long nb_class = class_list.size();
-    Tango::DevVarStringArray *ret = NULL;
+    Tango::DevVarStringArray *ret = nullptr;
 
     //
     // Find the wanted class in server and throw exception if not found
@@ -1361,6 +1376,8 @@ Tango::DevVarStringArray *DServer::query_dev_prop(std::string &class_name)
 //
 //-----------------------------------------------------------------------------------------------------------------
 
+KillThread *DServer::kill_thread = nullptr;
+
 void DServer::kill()
 {
     NoSyncModelTangoMonitor mon(this);
@@ -1371,9 +1388,9 @@ void DServer::kill()
     // Create the thread and start it
     //
 
-    KillThread *t = new KillThread;
+    kill_thread = new KillThread;
 
-    t->start();
+    kill_thread->start();
 }
 
 void *KillThread::run_undetached(TANGO_UNUSED(void *ptr))
@@ -1389,7 +1406,16 @@ void *KillThread::run_undetached(TANGO_UNUSED(void *ptr))
     Tango::Util *tg = Tango::Util::instance();
     tg->shutdown_ds();
 
-    return NULL;
+    return nullptr;
+}
+
+void DServer::wait_for_kill_thread()
+{
+    if(kill_thread != nullptr)
+    {
+        kill_thread->join(nullptr);
+        kill_thread = nullptr;
+    }
 }
 
 //+----------------------------------------------------------------------------------------------------------------
@@ -1401,17 +1427,49 @@ void *KillThread::run_undetached(TANGO_UNUSED(void *ptr))
 //        Create a Cpp Tango class from its name
 //
 //------------------------------------------------------------------------------------------------------------------
+void DServer::_create_cpp_class(const std::string &class_name,
+                                const std::string &param,
+                                const std::vector<std::string> &prefixes)
+{
+    create_cpp_class(class_name, param, prefixes);
+}
 
 void DServer::create_cpp_class(const char *cl_name, const char *par_name)
 {
-    TANGO_LOG_DEBUG << "In DServer::create_cpp_class for " << cl_name << ", " << par_name << std::endl;
-    std::string class_name(cl_name);
+    create_cpp_class(cl_name, par_name, {});
+}
+
+void DServer::create_cpp_class(const std::string &class_name,
+                               const std::string &par_name,
+                               const std::vector<std::string> &prefixes = {})
+{
+    typedef Tango::DeviceClass *(*Cpp_creator_ptr)(const char *);
+    TANGO_LOG_DEBUG << "In DServer::create_cpp_class for " << class_name << ", " << par_name << std::endl;
     std::string lib_name = class_name;
+    std::vector<std::string> local_prefixes = prefixes;
+
+    if(std::none_of(prefixes.cbegin(), prefixes.cend(), [](const std::string &prefix) { return prefix == "lib"; }))
+    {
+        local_prefixes.insert(local_prefixes.begin(), "lib");
+    }
+
+    std::map<std::string, std::string> error_msgs;
+    auto format_error = [&]()
+    {
+        std::stringstream ret;
+        ret << "Trying to load shared library " << class_name << " failed.\n";
+        for(auto const &[lib, error] : error_msgs)
+        {
+            ret << " - Library name: " << lib << " failed with error: " << error << "\n";
+        }
+        return ret.str();
+    };
 
 #ifdef _TG_WINDOWS_
+    bool lib_loaded = false;
     HMODULE mod;
 
-    if((mod = LoadLibrary(lib_name.c_str())) == NULL)
+    auto fetch_error_msg = [&error_msgs](const std::string &key)
     {
         char *str = 0;
 
@@ -1424,13 +1482,27 @@ void DServer::create_cpp_class(const char *cl_name, const char *par_name)
                         0,
                         NULL);
 
-        std::cerr << "Error: " << str << std::endl;
-
-        TangoSys_OMemStream o;
-        o << "Trying to load shared library " << lib_name << " failed. It returns error: " << str << std::ends;
+        error_msgs.emplace(key, str);
         ::LocalFree((HLOCAL) str);
-
-        TANGO_THROW_EXCEPTION(API_ClassNotFound, o.str());
+    };
+    if((mod = LoadLibrary(lib_name.c_str())) == NULL)
+    {
+        fetch_error_msg(lib_name);
+        for(const auto &prefix : prefixes)
+        {
+            lib_name = prefix + class_name;
+            if((mod = LoadLibrary(lib_name.c_str())) != NULL)
+            {
+                lib_loaded = true;
+                break;
+            }
+            fetch_error_msg(lib_name);
+        }
+        if(!lib_loaded)
+        {
+            std::string error = format_error();
+            TANGO_THROW_EXCEPTION(API_ClassNotFound, error);
+        }
     }
 
     TANGO_LOG_DEBUG << "GetModuleHandle is a success" << std::endl;
@@ -1445,7 +1517,8 @@ void DServer::create_cpp_class(const char *cl_name, const char *par_name)
     if((proc = GetProcAddress(mod, sym_name.c_str())) == NULL)
     {
         TangoSys_OMemStream o;
-        o << "Class " << cl_name << " does not have the C creator function (_create_<Class name>_class)" << std::ends;
+        o << "Class " << class_name << " does not have the C creator function (_create_<Class name>_class)"
+          << std::ends;
 
         TANGO_THROW_EXCEPTION(API_ClassNotFound, o.str());
     }
@@ -1454,15 +1527,33 @@ void DServer::create_cpp_class(const char *cl_name, const char *par_name)
     Cpp_creator_ptr mt = (Cpp_creator_ptr) proc;
 #else
     void *lib_ptr;
+  #if defined(__APPLE__)
+    lib_name = lib_name + ".dylib";
+  #else
     lib_name = lib_name + ".so";
+  #endif
+
+    auto fetch_error_msg = [&error_msgs](const std::string &key) { error_msgs.emplace(key, dlerror()); };
 
     lib_ptr = dlopen(lib_name.c_str(), RTLD_NOW);
-    if(lib_ptr == NULL)
+    if(lib_ptr == nullptr)
     {
-        TangoSys_OMemStream o;
-        o << "Trying to load shared library " << lib_name << " failed. It returns error: " << dlerror() << std::ends;
-
-        TANGO_THROW_EXCEPTION(API_ClassNotFound, o.str());
+        fetch_error_msg(lib_name);
+        for(const auto &prefix : prefixes)
+        {
+            auto tmp_lib_name = prefix + lib_name;
+            lib_ptr = dlopen(tmp_lib_name.c_str(), RTLD_NOW);
+            if(lib_ptr != nullptr)
+            {
+                break;
+            }
+            fetch_error_msg(lib_name);
+        }
+        if(lib_ptr == nullptr)
+        {
+            std::string error = format_error();
+            TANGO_THROW_EXCEPTION(API_ClassNotFound, error);
+        }
     }
 
     TANGO_LOG_DEBUG << "dlopen is a success" << std::endl;
@@ -1476,10 +1567,11 @@ void DServer::create_cpp_class(const char *cl_name, const char *par_name)
     TANGO_LOG_DEBUG << "Symbol name = " << sym_name << std::endl;
 
     sym = dlsym(lib_ptr, sym_name.c_str());
-    if(sym == NULL)
+    if(sym == nullptr)
     {
         TangoSys_OMemStream o;
-        o << "Class " << cl_name << " does not have the C creator function (_create_<Class name>_class)" << std::ends;
+        o << "Class " << class_name << " does not have the C creator function (_create_<Class name>_class)"
+          << std::ends;
 
         TANGO_THROW_EXCEPTION(API_ClassNotFound, o.str());
     }
@@ -1488,7 +1580,7 @@ void DServer::create_cpp_class(const char *cl_name, const char *par_name)
 
     Cpp_creator_ptr mt = (Cpp_creator_ptr) sym;
 #endif /* _TG_WINDOWS_ */
-    Tango::DeviceClass *dc = (*mt)(par_name);
+    Tango::DeviceClass *dc = (*mt)(par_name.c_str());
     add_class(dc);
 }
 
@@ -1517,9 +1609,9 @@ void DServer::get_dev_prop(Tango::Util *tg)
     {
         DbData db_data;
 
-        db_data.push_back(DbDatum("polling_threads_pool_size"));
-        db_data.push_back(DbDatum("polling_threads_pool_conf"));
-        db_data.push_back(DbDatum("polling_before_9"));
+        db_data.emplace_back("polling_threads_pool_size");
+        db_data.emplace_back("polling_threads_pool_conf");
+        db_data.emplace_back("polling_before_9");
 
         try
         {
@@ -1538,7 +1630,7 @@ void DServer::get_dev_prop(Tango::Util *tg)
         // If the prop is not defined in db and if the user has defined it in the Util class, takes the user definition
         //
 
-        if(db_data[0].is_empty() == false)
+        if(!db_data[0].is_empty())
         {
             db_data[0] >> polling_th_pool_size;
         }
@@ -1551,7 +1643,7 @@ void DServer::get_dev_prop(Tango::Util *tg)
             }
         }
 
-        if(db_data[1].is_empty() == false)
+        if(!db_data[1].is_empty())
         {
             std::vector<std::string> tmp_vect;
             db_data[1] >> tmp_vect;
@@ -1581,7 +1673,7 @@ void DServer::get_dev_prop(Tango::Util *tg)
 
                 rebuilt_str = rebuilt_str + tmp_str;
 
-                if(ended == true)
+                if(ended)
                 {
                     polling_th_pool_conf.push_back(rebuilt_str);
                     rebuilt_str.clear();
@@ -1597,7 +1689,7 @@ void DServer::get_dev_prop(Tango::Util *tg)
         // Polling before 9 algorithm property
         //
 
-        if(db_data[2].is_empty() == false)
+        if(!db_data[2].is_empty())
         {
             polling_bef_9_def = true;
             db_data[2] >> polling_bef_9;
@@ -1627,12 +1719,12 @@ void DServer::get_dev_prop(Tango::Util *tg)
 
 void DServer::check_lock_owner(DeviceImpl *dev, const char *cmd_name, const char *dev_name)
 {
-    if(dev->is_device_locked() == true)
+    if(dev->is_device_locked())
     {
-        if(dev->valid_lock() == true)
+        if(dev->valid_lock())
         {
             client_addr *cl = get_client_ident();
-            if(cl->client_ident == true)
+            if(cl->client_ident)
             {
                 if(*cl != *(dev->get_locker()))
                 {
@@ -1662,7 +1754,8 @@ void DServer::check_lock_owner(DeviceImpl *dev, const char *cmd_name, const char
 //
 // description :
 //        Get the properties defining which event has to be transported using multicast protocol. Also retrieve
-//        property for Nan allowed in writing attribute
+//        property for Nan allowed in writing attribute and whether alarm events should be sent on calls
+//        to push_change_event.
 //
 // args :
 //         in :
@@ -1680,13 +1773,14 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
 
         DbData db_data;
 
-        db_data.push_back(DbDatum("MulticastEvent"));
-        db_data.push_back(DbDatum("MulticastHops"));
-        db_data.push_back(DbDatum("MulticastRate"));
-        db_data.push_back(DbDatum("MulticastIvl"));
-        db_data.push_back(DbDatum("DSEventBufferHwm"));
-        db_data.push_back(DbDatum("EventBufferHwm"));
-        db_data.push_back(DbDatum("WAttrNaNAllowed"));
+        db_data.emplace_back("MulticastEvent");
+        db_data.emplace_back("MulticastHops");
+        db_data.emplace_back("MulticastRate");
+        db_data.emplace_back("MulticastIvl");
+        db_data.emplace_back("DSEventBufferHwm");
+        db_data.emplace_back("EventBufferHwm");
+        db_data.emplace_back("WAttrNaNAllowed");
+        db_data.emplace_back(AUTO_ALARM_ON_CHANGE_PROP_NAME);
 
         try
         {
@@ -1704,7 +1798,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
 
             for(unsigned int i = 0; i < nb_elt; ++i)
             {
-                if(is_ip_address(mcast_event_prop[i]) == true)
+                if(is_ip_address(mcast_event_prop[i]))
                 {
                     //
                     // Check multicast address validity
@@ -1734,24 +1828,24 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
                         {
                             if(nb_elt > i + 4)
                             {
-                                if((is_event_name(mcast_event_prop[i + 2]) == false) &&
-                                   (is_event_name(mcast_event_prop[i + 3]) == false) &&
-                                   (is_event_name(mcast_event_prop[i + 4]) == false))
+                                if((!is_event_name(mcast_event_prop[i + 2])) &&
+                                   (!is_event_name(mcast_event_prop[i + 3])) &&
+                                   (!is_event_name(mcast_event_prop[i + 4])))
                                 {
                                     uncoherent = true;
                                 }
                             }
                             else if(nb_elt > i + 3)
                             {
-                                if((is_event_name(mcast_event_prop[i + 2]) == false) &&
-                                   (is_event_name(mcast_event_prop[i + 3]) == false))
+                                if((!is_event_name(mcast_event_prop[i + 2])) &&
+                                   (!is_event_name(mcast_event_prop[i + 3])))
                                 {
                                     uncoherent = true;
                                 }
                             }
                             else
                             {
-                                if(is_event_name(mcast_event_prop[i + 2]) == false)
+                                if(!is_event_name(mcast_event_prop[i + 2]))
                                 {
                                     uncoherent = true;
                                 }
@@ -1764,7 +1858,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
                     // case
                     //
 
-                    if(uncoherent == true)
+                    if(uncoherent)
                     {
                         std::cerr << "Database CtrlSystem/MulticastEvent property is uncoherent" << std::endl;
                         std::cerr << "Prop syntax = mcast ip adr (must be between 224.x.y.z and 239.x.y.z) - port - "
@@ -1797,7 +1891,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
             //
 
             mcast_hops = MCAST_HOPS;
-            if(db_data[1].is_empty() == false)
+            if(!db_data[1].is_empty())
             {
                 db_data[1] >> mcast_hops;
             }
@@ -1807,7 +1901,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
             //
 
             mcast_rate = PGM_RATE;
-            if(db_data[2].is_empty() == false)
+            if(!db_data[2].is_empty())
             {
                 db_data[2] >> mcast_rate;
                 mcast_rate = mcast_rate * 1024;
@@ -1818,7 +1912,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
             //
 
             mcast_ivl = PGM_IVL;
-            if(db_data[3].is_empty() == false)
+            if(!db_data[3].is_empty())
             {
                 db_data[3] >> mcast_ivl;
                 mcast_ivl = mcast_ivl * 1000;
@@ -1829,7 +1923,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
             //
 
             zmq_pub_event_hwm = PUB_HWM;
-            if(db_data[4].is_empty() == false)
+            if(!db_data[4].is_empty())
             {
                 db_data[4] >> zmq_pub_event_hwm;
             }
@@ -1839,7 +1933,7 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
             //
 
             zmq_sub_event_hwm = SUB_HWM;
-            if(db_data[5].is_empty() == false)
+            if(!db_data[5].is_empty())
             {
                 db_data[5] >> zmq_sub_event_hwm;
             }
@@ -1848,12 +1942,23 @@ void DServer::get_event_misc_prop(Tango::Util *tg)
             // Nan allowed in writing attribute
             //
 
-            if(db_data[6].is_empty() == false)
+            if(!db_data[6].is_empty())
             {
                 bool new_val;
                 db_data[6] >> new_val;
                 tg->set_wattr_nan_allowed(new_val);
             }
+
+            //
+            // Alarm events are pushed on calls to push_change_event
+            //
+
+            if(!db_data[7].is_empty())
+            {
+                bool new_val;
+                db_data[7] >> new_val;
+                tg->set_auto_alarm_on_change_event(new_val);
+            }
         }
         catch(Tango::DevFailed &)
         {
@@ -1902,23 +2007,23 @@ void DServer::mcast_event_for_att(const std::string &dev_name,
 
     for(unsigned int i = 0; i < nb_elt; ++i)
     {
-        if(is_ip_address(mcast_event_prop[i]) == true)
+        if(is_ip_address(mcast_event_prop[i]))
         {
             ip_adr_ind = i;
             continue;
         }
 
-        if(is_event_name(mcast_event_prop[i]) == true)
+        if(is_event_name(mcast_event_prop[i]))
         {
             if(mcast_event_prop[i].find(full_att_name) == 0)
             {
                 std::string::size_type pos = mcast_event_prop[i].rfind('.');
                 std::string tmp = mcast_event_prop[i].substr(pos + 1);
                 tmp = tmp + ':' + mcast_event_prop[ip_adr_ind] + ':' + mcast_event_prop[ip_adr_ind + 1];
-                if(is_event_name(mcast_event_prop[ip_adr_ind + 2]) == false)
+                if(!is_event_name(mcast_event_prop[ip_adr_ind + 2]))
                 {
                     tmp = tmp + ':' + mcast_event_prop[ip_adr_ind + 2];
-                    if(is_event_name(mcast_event_prop[ip_adr_ind + 3]) == false)
+                    if(!is_event_name(mcast_event_prop[ip_adr_ind + 3]))
                     {
                         tmp = tmp + ':' + mcast_event_prop[ip_adr_ind + 3];
                     }
@@ -2011,7 +2116,7 @@ void DServer::mem_devices_interface(std::map<std::string, DevIntr> &_map)
 {
     ZmqEventSupplier *event_supplier_zmq = Util::instance()->get_zmq_event_supplier();
 
-    if(class_list.empty() == false)
+    if(!class_list.empty())
     {
         for(long i = class_list.size() - 1; i >= 0; i--)
         {
@@ -2019,7 +2124,7 @@ void DServer::mem_devices_interface(std::map<std::string, DevIntr> &_map)
             size_t nb_dev = devs.size();
             for(size_t loop = 0; loop < nb_dev; loop++)
             {
-                if(event_supplier_zmq->any_dev_intr_client(devs[loop]) == true &&
+                if(event_supplier_zmq->any_dev_intr_client(devs[loop]) &&
                    devs[loop]->get_dev_idl_version() >= MIN_IDL_DEV_INTR)
                 {
                     TANGO_LOG_DEBUG << "Memorize dev interface for device " << devs[loop]->get_name() << std::endl;
@@ -2057,7 +2162,7 @@ void DServer::changed_devices_interface(std::map<std::string, DevIntr> &_map)
     for(pos = _map.begin(); pos != _map.end(); ++pos)
     {
         DeviceImpl *dev = tg->get_device_by_name(pos->first);
-        if(pos->second.has_changed(dev) == true)
+        if(pos->second.has_changed(dev))
         {
             TANGO_LOG_DEBUG << "Device interface for device " << dev->get_name() << " has changed !!!!!!!!!!!!!!!!!!!"
                             << std::endl;
