@@ -67,9 +67,9 @@ Tango::DevVarStringArray *DServer::polled_device()
             long nb_dev = class_list[i]->get_device_list().size();
             for(long j = 0; j < nb_dev; j++)
             {
-                if((class_list[i]->get_device_list())[j]->is_polled() == true)
+                if((class_list[i]->get_device_list())[j]->is_polled())
                 {
-                    dev_name.push_back((class_list[i]->get_device_list())[j]->get_name().c_str());
+                    dev_name.emplace_back((class_list[i]->get_device_list())[j]->get_name().c_str());
                 }
             }
         }
@@ -83,9 +83,9 @@ Tango::DevVarStringArray *DServer::polled_device()
     // Return an empty sequence if no devices are polled
     //
 
-    if(dev_name.empty() == true)
+    if(dev_name.empty())
     {
-        Tango::DevVarStringArray *ret = new Tango::DevVarStringArray();
+        auto *ret = new Tango::DevVarStringArray();
         ret->length(0);
         return ret;
     }
@@ -96,7 +96,7 @@ Tango::DevVarStringArray *DServer::polled_device()
 
     sort(dev_name.begin(), dev_name.end());
     long nb_dev = dev_name.size();
-    Tango::DevVarStringArray *ret = new Tango::DevVarStringArray(nb_dev);
+    auto *ret = new Tango::DevVarStringArray(nb_dev);
     ret->length(nb_dev);
     for(long k = 0; k < nb_dev; k++)
     {
@@ -194,16 +194,16 @@ Tango::DevVarStringArray *DServer::dev_poll_status(const std::string &dev_name)
     std::map<PollClock::duration, std::vector<std::string>> polled_together;
 
     bool poll_bef_9 = false;
-    if(polling_bef_9_def == true)
+    if(polling_bef_9_def)
     {
         poll_bef_9 = polling_bef_9;
     }
-    else if(tg->is_polling_bef_9_def() == true)
+    else if(tg->is_polling_bef_9_def())
     {
         poll_bef_9 = tg->get_polling_bef_9();
     }
 
-    if(poll_bef_9 == false)
+    if(!poll_bef_9)
     {
         for(i = 0; i < nb_poll_obj; i++)
         {
@@ -299,7 +299,6 @@ Tango::DevVarStringArray *DServer::dev_poll_status(const std::string &dev_name)
 
         std::stringstream s;
         std::string tmp_str;
-        std::string per;
 
         auto po = poll_list[i]->get_upd();
 
@@ -343,7 +342,7 @@ Tango::DevVarStringArray *DServer::dev_poll_status(const std::string &dev_name)
         // Add a message if the data ring is empty
         //
 
-        if(poll_list[i]->is_ring_empty() == true)
+        if(poll_list[i]->is_ring_empty())
         {
             returned_info = returned_info + "\nNo data recorded yet";
         }
@@ -509,7 +508,7 @@ Tango::DevVarStringArray *DServer::dev_poll_status(const std::string &dev_name)
                 {
                     last_err = poll_list[i]->is_last_an_error_i_3();
                 }
-                if(last_err == true)
+                if(last_err)
                 {
                     if(type == Tango::POLL_CMD)
                     {
@@ -551,7 +550,7 @@ Tango::DevVarStringArray *DServer::dev_poll_status(const std::string &dev_name)
             // of "attributes" by "command" in the returned string
             //
 
-            if(duplicate == true)
+            if(duplicate)
             {
                 std::string::size_type pos = returned_info.find("attribute");
                 while(pos != std::string::npos)
@@ -619,7 +618,7 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
     //
 
     Tango::Util *tg = Tango::Util::instance();
-    DeviceImpl *dev = NULL;
+    DeviceImpl *dev = nullptr;
     try
     {
         dev = tg->get_device_by_name((argin->svalue)[0]);
@@ -753,7 +752,7 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
     // Refuse to do the job for forwarded attribute
     //
 
-    if(obj_type == PollAttribute && attr_ptr->is_fwd_att() == true)
+    if(obj_type == PollAttribute && attr_ptr->is_fwd_att())
     {
         std::stringstream ss;
         ss << "Attribute " << obj_name << " is a forwarded attribute.\n";
@@ -798,11 +797,11 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
         TANGO_LOG_DEBUG << "POLLING: Creating a thread to poll device " << (argin->svalue)[0] << std::endl;
 
         bool poll_bef_9 = false;
-        if(polling_bef_9_def == true)
+        if(polling_bef_9_def)
         {
             poll_bef_9 = polling_bef_9;
         }
-        else if(tg->is_polling_bef_9_def() == true)
+        else if(tg->is_polling_bef_9_def())
         {
             poll_bef_9 = tg->get_polling_bef_9();
         }
@@ -828,7 +827,7 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
     if(th_id != poll_th_id)
     {
         omni_mutex_lock sync(mon);
-        if(shared_cmd.cmd_pending == true)
+        if(shared_cmd.cmd_pending)
         {
             mon.wait();
         }
@@ -848,12 +847,12 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
 
         omni_thread *th = omni_thread::self();
         int th_id = th->id();
-        if(th_id != poll_th_id && local_request == false)
+        if(th_id != poll_th_id && !local_request)
         {
-            while(shared_cmd.cmd_pending == true)
+            while(shared_cmd.cmd_pending)
             {
                 int interupted = mon.wait(DEFAULT_TIMEOUT);
-                if((shared_cmd.cmd_pending == true) && (interupted == false))
+                if((shared_cmd.cmd_pending) && (interupted == 0))
                 {
                     TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                     delete poll_list.back();
@@ -892,92 +891,78 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
     th_info->nb_polled_objects++;
 
     //
-    // Update polling parameters in database (if wanted and possible). If the property is already there
+    // Update the polling parameters for the device. If the property is already there
     // (it should not but...), only update its polling period
     //
 
-    if((with_db_upd == true) && (Tango::Util::instance()->use_db()))
     {
         TangoSys_MemStream s;
         std::string upd_str;
         s << upd;
         s >> upd_str;
-        bool found = false;
 
-        DbDatum db_info("polled_cmd");
-        if(type == Tango::POLL_CMD)
+        std::vector<std::string> &non_auto_list =
+            type == Tango::POLL_CMD ? dev->get_non_auto_polled_cmd() : dev->get_non_auto_polled_attr();
+
+        auto end = non_auto_list.end();
+        auto it = std::remove_if(non_auto_list.begin(),
+                                 end,
+                                 [&](const std::string &other)
+                                 { return TG_strcasecmp(other.c_str(), obj_name.c_str()) == 0; });
+        bool found_in_non_auto = it != end;
+
+        non_auto_list.erase(it, end);
+
+        std::vector<std::string> &obj_list = type == Tango::POLL_CMD ? dev->get_polled_cmd() : dev->get_polled_attr();
+
+        if(!found_in_non_auto)
         {
-            std::vector<std::string> &non_auto_list = dev->get_non_auto_polled_cmd();
-            std::vector<std::string>::iterator ite;
-            for(ite = non_auto_list.begin(); ite < non_auto_list.end(); ++ite)
+            for(i = 0; i < obj_list.size(); i = i + 2)
             {
-                if(TG_strcasecmp((*ite).c_str(), obj_name.c_str()) == 0)
+                if(TG_strcasecmp(obj_list[i].c_str(), obj_name.c_str()) == 0)
                 {
-                    non_auto_list.erase(ite);
-                    db_info.name = "non_auto_polled_cmd";
-                    db_info << non_auto_list;
-                    found = true;
+                    obj_list[i + 1] = upd_str;
                     break;
                 }
             }
-            if(found == false)
+            if(i == obj_list.size())
             {
-                std::vector<std::string> &cmd_list = dev->get_polled_cmd();
-                for(i = 0; i < cmd_list.size(); i = i + 2)
-                {
-                    if(TG_strcasecmp(cmd_list[i].c_str(), obj_name.c_str()) == 0)
-                    {
-                        cmd_list[i + 1] = upd_str;
-                        break;
-                    }
-                }
-                if(i == cmd_list.size())
-                {
-                    cmd_list.push_back(obj_name);
-                    cmd_list.push_back(upd_str);
-                }
-                db_info << cmd_list;
+                obj_list.push_back(obj_name);
+                obj_list.push_back(upd_str);
             }
         }
-        else
+
+        //
+        // Update polling parameters in database (if wanted and possible).
+
+        if((with_db_upd) && (Tango::Util::instance()->use_db()))
         {
-            std::vector<std::string> &non_auto_list = dev->get_non_auto_polled_attr();
-            std::vector<std::string>::iterator ite;
-            for(ite = non_auto_list.begin(); ite < non_auto_list.end(); ++ite)
+            DbDatum db_info;
+            if(type == Tango::POLL_CMD && found_in_non_auto)
             {
-                if(TG_strcasecmp((*ite).c_str(), obj_name.c_str()) == 0)
-                {
-                    non_auto_list.erase(ite);
-                    db_info.name = "non_auto_polled_attr";
-                    db_info << non_auto_list;
-                    found = true;
-                    break;
-                }
+                db_info.name = "non_auto_polled_cmd";
+                db_info << non_auto_list;
             }
-            if(found == false)
+            else if(type == Tango::POLL_CMD)
+            {
+                db_info.name = "polled_cmd";
+                db_info << obj_list;
+            }
+            else if(found_in_non_auto)
+            {
+                db_info.name = "non_auto_polled_cmd";
+                db_info << non_auto_list;
+            }
+            else
             {
                 db_info.name = "polled_attr";
-                std::vector<std::string> &attr_list = dev->get_polled_attr();
-                for(i = 0; i < attr_list.size(); i = i + 2)
-                {
-                    if(TG_strcasecmp(attr_list[i].c_str(), obj_name.c_str()) == 0)
-                    {
-                        attr_list[i + 1] = upd_str;
-                        break;
-                    }
-                }
-                if(i == attr_list.size())
-                {
-                    attr_list.push_back(obj_name);
-                    attr_list.push_back(upd_str);
-                }
-                db_info << attr_list;
+                db_info << obj_list;
             }
-        }
 
-        DbData send_data;
-        send_data.push_back(db_info);
-        dev->get_db_device()->put_property(send_data);
+            DbData send_data;
+            send_data.push_back(db_info);
+            dev->get_db_device()->put_property(send_data);
+        }
     }
 
     //
@@ -1008,10 +993,10 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
             conf_entry = conf_entry + ',' + dev_name;
         }
 
-        if((with_db_upd == true) && (Tango::Util::instance()->use_db()))
+        if((with_db_upd) && (Tango::Util::instance()->use_db()))
         {
             DbData send_data;
-            send_data.push_back(DbDatum("polling_threads_pool_conf"));
+            send_data.emplace_back("polling_threads_pool_conf");
 
             std::vector<std::string> &ppc = tg->get_poll_pool_conf();
 
@@ -1108,7 +1093,7 @@ void DServer::upd_obj_polling_period(const Tango::DevVarLongStringArray *argin,
     //
 
     Tango::Util *tg = Tango::Util::instance();
-    DeviceImpl *dev = NULL;
+    DeviceImpl *dev = nullptr;
     try
     {
         dev = tg->get_device_by_name((argin->svalue)[0]);
@@ -1125,7 +1110,7 @@ void DServer::upd_obj_polling_period(const Tango::DevVarLongStringArray *argin,
     // Check that the device is polled
     //
 
-    if(dev->is_polled() == false)
+    if(!dev->is_polled())
     {
         TangoSys_OMemStream o;
         o << "Device " << (argin->svalue)[0] << " is not polled" << std::ends;
@@ -1179,7 +1164,7 @@ void DServer::upd_obj_polling_period(const Tango::DevVarLongStringArray *argin,
         TANGO_THROW_EXCEPTION(API_NotSupported, o.str());
     }
 
-    std::vector<PollObj *>::iterator ite = dev->get_polled_obj_by_type_name(type, obj_name);
+    auto ite = dev->get_polled_obj_by_type_name(type, obj_name);
 
     //
     // Check that the requested polling period is not below the one authorized (if defined)
@@ -1232,7 +1217,7 @@ void DServer::upd_obj_polling_period(const Tango::DevVarLongStringArray *argin,
     if(th_id != poll_th_id)
     {
         omni_mutex_lock sync(mon);
-        if(shared_cmd.cmd_pending == true)
+        if(shared_cmd.cmd_pending)
         {
             mon.wait();
         }
@@ -1268,55 +1253,46 @@ void DServer::upd_obj_polling_period(const Tango::DevVarLongStringArray *argin,
     // Add object name and update period if the object is not known in the property
     //
 
-    if((with_db_upd == true) && (Tango::Util::instance()->use_db()))
     {
         TangoSys_MemStream s;
         std::string upd_str;
         s << (argin->lvalue)[0] << std::ends;
         s >> upd_str;
 
-        DbDatum db_info("polled_attr");
-        if(type == Tango::POLL_CMD)
+        std::vector<std::string> &obj_list = type == Tango::POLL_CMD ? dev->get_polled_cmd() : dev->get_polled_attr();
+
+        for(i = 0; i < obj_list.size(); i = i + 2)
         {
-            db_info.name = "polled_cmd";
-            std::vector<std::string> &cmd_list = dev->get_polled_cmd();
-            for(i = 0; i < cmd_list.size(); i = i + 2)
+            if(TG_strcasecmp(obj_list[i].c_str(), obj_name.c_str()) == 0)
             {
-                if(TG_strcasecmp(cmd_list[i].c_str(), obj_name.c_str()) == 0)
-                {
-                    cmd_list[i + 1] = upd_str;
-                    break;
-                }
+                obj_list[i + 1] = upd_str;
+                break;
             }
-            if(i == cmd_list.size())
-            {
-                cmd_list.push_back(obj_name);
-                cmd_list.push_back(upd_str);
-            }
-            db_info << cmd_list;
         }
-        else
+        if(i == obj_list.size())
         {
-            std::vector<std::string> &attr_list = dev->get_polled_attr();
-            for(i = 0; i < attr_list.size(); i = i + 2)
-            {
-                if(TG_strcasecmp(attr_list[i].c_str(), obj_name.c_str()) == 0)
-                {
-                    attr_list[i + 1] = upd_str;
-                    break;
-                }
-            }
-            if(i == attr_list.size())
-            {
-                attr_list.push_back(obj_name);
-                attr_list.push_back(upd_str);
-            }
-            db_info << attr_list;
+            obj_list.push_back(obj_name);
+            obj_list.push_back(upd_str);
         }
 
-        DbData send_data;
-        send_data.push_back(db_info);
-        dev->get_db_device()->put_property(send_data);
+        if((with_db_upd) && (Tango::Util::instance()->use_db()))
+        {
+            DbDatum db_info;
+            if(type == Tango::POLL_CMD)
+            {
+                db_info.name = "polled_cmd";
+                db_info << obj_list;
+            }
+            else
+            {
+                db_info.name = "polled_attr";
+                db_info << obj_list;
+            }
+
+            DbData send_data;
+            send_data.push_back(db_info);
+            dev->get_db_device()->put_property(send_data);
+        }
     }
 }
 
@@ -1363,7 +1339,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
     //
 
     Tango::Util *tg = Tango::Util::instance();
-    DeviceImpl *dev = NULL;
+    DeviceImpl *dev = nullptr;
     try
     {
         dev = tg->get_device_by_name((*argin)[0]);
@@ -1380,7 +1356,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
     // Check that the device is polled
     //
 
-    if(dev->is_polled() == false)
+    if(!dev->is_polled())
     {
         TangoSys_OMemStream o;
         o << "Device " << (*argin)[0] << " is not polled" << std::ends;
@@ -1432,7 +1408,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
         TANGO_THROW_EXCEPTION(API_NotSupported, o.str());
     }
 
-    std::vector<PollObj *>::iterator ite = dev->get_polled_obj_by_type_name(type, obj_name);
+    auto ite = dev->get_polled_obj_by_type_name(type, obj_name);
     auto tmp_upd = (*ite)->get_upd();
 
     PollingThreadInfo *th_info = nullptr;
@@ -1443,7 +1419,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
     // Find out which thread is in charge of the device.
     //
 
-    if(tg->is_svr_shutting_down() == false)
+    if(!tg->is_svr_shutting_down())
     {
         poll_th_id = tg->get_polling_thread_id_by_name((*argin)[0]);
         if(poll_th_id == 0)
@@ -1460,7 +1436,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
         // Test whether the polling thread is still running!
         //
 
-        if(th_info->poll_th != NULL)
+        if(th_info->poll_th != nullptr)
         {
             //
             // Send command to the polling thread
@@ -1473,7 +1449,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
             if(th_id != poll_th_id)
             {
                 omni_mutex_lock sync(mon);
-                if(shared_cmd.cmd_pending == true)
+                if(shared_cmd.cmd_pending)
                 {
                     mon.wait();
                 }
@@ -1500,12 +1476,12 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
 
                 if(th_id != poll_th_id)
                 {
-                    if(local_request == false)
+                    if(!local_request)
                     {
-                        while(shared_cmd.cmd_pending == true)
+                        while(shared_cmd.cmd_pending)
                         {
                             int interupted = mon.wait(DEFAULT_TIMEOUT);
-                            if((shared_cmd.cmd_pending == true) && (interupted == false))
+                            if((shared_cmd.cmd_pending) && (interupted == 0))
                             {
                                 TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                                 TANGO_THROW_EXCEPTION(API_CommandTimedOut, "Polling thread blocked !!!");
@@ -1568,96 +1544,80 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
     // Mark the device as non polled if this was the last polled object
     //
 
-    if(poll_list.empty() == true)
+    if(poll_list.empty())
     {
         dev->is_polled(false);
     }
 
     //
-    // Update database property. This means remove object entry in the polling properties if they exist or add it to the
-    // list of device not polled for automatic polling defined at command/attribute level.
+    // Update database property. This means either:
+    //  (i) remove object entry in the polling properties if they exist; or
+    //  (ii) add it to the list of device not polled for automatic polling defined at command/attribute level.
     // Do this if possible and wanted.
     //
 
-    if((with_db_upd == true) && (Tango::Util::instance()->use_db()))
     {
-        DbData send_data;
-        DbDatum db_info("polled_attr");
-        bool update_needed = false;
+        bool removed_from_list = false;      // true in case (i) above
+        bool added_to_non_auto_list = false; // true in case (ii) above
 
-        if(type == Tango::POLL_CMD)
+        std::vector<std::string> &obj_list = type == Tango::POLL_CMD ? dev->get_polled_cmd() : dev->get_polled_attr();
+        std::vector<std::string> &non_auto_list =
+            type == Tango::POLL_CMD ? dev->get_non_auto_polled_cmd() : dev->get_non_auto_polled_attr();
+
+        for(auto it = obj_list.begin(); it < obj_list.end(); it += 2)
         {
-            db_info.name = "polled_cmd";
-            std::vector<std::string> &cmd_list = dev->get_polled_cmd();
-            std::vector<std::string>::iterator s_ite;
-            for(s_ite = cmd_list.begin(); s_ite < cmd_list.end(); s_ite += 2)
+            if(TG_strcasecmp(it->c_str(), obj_name.c_str()) == 0)
             {
-                if(TG_strcasecmp((*s_ite).c_str(), obj_name.c_str()) == 0)
-                {
-                    s_ite = cmd_list.erase(s_ite);
-                    cmd_list.erase(s_ite);
-                    db_info << cmd_list;
-                    update_needed = true;
-                    break;
-                }
-            }
-            if(update_needed == false)
-            {
-                std::vector<std::string> &non_auto_cmd = dev->get_non_auto_polled_cmd();
-                for(s_ite = non_auto_cmd.begin(); s_ite < non_auto_cmd.end(); ++s_ite)
-                {
-                    if(TG_strcasecmp((*s_ite).c_str(), obj_name.c_str()) == 0)
-                    {
-                        break;
-                    }
-                }
-                if(s_ite == non_auto_cmd.end())
-                {
-                    non_auto_cmd.push_back(obj_name);
-                    db_info.name = "non_auto_polled_cmd";
-                    db_info << non_auto_cmd;
-                    update_needed = true;
-                }
-            }
-        }
-        else
-        {
-            std::vector<std::string> &attr_list = dev->get_polled_attr();
-            std::vector<std::string>::iterator s_ite;
-            for(s_ite = attr_list.begin(); s_ite < attr_list.end(); s_ite += 2)
-            {
-                if(TG_strcasecmp((*s_ite).c_str(), obj_name.c_str()) == 0)
-                {
-                    s_ite = attr_list.erase(s_ite);
-                    attr_list.erase(s_ite);
-                    db_info << attr_list;
-                    update_needed = true;
-                    break;
-                }
-            }
-            if(update_needed == false)
-            {
-                std::vector<std::string> &non_auto_attr = dev->get_non_auto_polled_attr();
-                for(s_ite = non_auto_attr.begin(); s_ite < non_auto_attr.end(); ++s_ite)
-                {
-                    if(TG_strcasecmp((*s_ite).c_str(), obj_name.c_str()) == 0)
-                    {
-                        break;
-                    }
-                }
-                if(s_ite == non_auto_attr.end())
-                {
-                    non_auto_attr.push_back(obj_name);
-                    db_info.name = "non_auto_polled_attr";
-                    db_info << non_auto_attr;
-                    update_needed = true;
-                }
+                it = obj_list.erase(it); // remove name
+                obj_list.erase(it);      // remove polling period
+                removed_from_list = true;
+                break;
             }
         }
 
-        if(update_needed == true)
+        if(!removed_from_list)
+        {
+            auto it = std::find_if(non_auto_list.begin(),
+                                   non_auto_list.end(),
+                                   [&](const std::string &other)
+                                   { return TG_strcasecmp(other.c_str(), obj_name.c_str()) == 0; });
+
+            if(it == non_auto_list.end())
+            {
+                non_auto_list.push_back(obj_name);
+                added_to_non_auto_list = true;
+            }
+        }
+
+        bool update_needed = removed_from_list || added_to_non_auto_list;
+        TANGO_ASSERT(!(removed_from_list && added_to_non_auto_list));
+
+        if(update_needed && with_db_upd && Tango::Util::instance()->use_db())
         {
             DbData send_data;
+            DbDatum db_info;
+
+            if(type == Tango::POLL_CMD && removed_from_list)
+            {
+                db_info.name = "polled_cmd";
+                db_info << obj_list;
+            }
+            else if(type == Tango::POLL_CMD)
+            {
+                db_info.name = "non_auto_polled_cmd";
+                db_info << non_auto_list;
+            }
+            else if(removed_from_list)
+            {
+                db_info.name = "polled_attr";
+                db_info << obj_list;
+            }
+            else
+            {
+                db_info.name = "non_auto_polled_attr";
+                db_info << non_auto_list;
+            }
+
             send_data.push_back(db_info);
             if(db_info.size() == 0)
             {
@@ -1678,7 +1638,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
     //
 
     bool kill_thread = false;
-    if(poll_list.empty() == true)
+    if(poll_list.empty())
     {
         int ind;
         std::string dev_name((*argin)[0]);
@@ -1709,7 +1669,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
         }
         else
         {
-            std::vector<std::string>::iterator iter = pool_conf.begin() + ind;
+            auto iter = pool_conf.begin() + ind;
             pool_conf.erase(iter);
             kill_thread = true;
         }
@@ -1721,7 +1681,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
         // (case of a polled command which itself decide to stop its own polling)
         //
 
-        if(kill_thread == true && tg->is_svr_shutting_down() == false && th_id != poll_th_id)
+        if(kill_thread && !tg->is_svr_shutting_down() && th_id != poll_th_id)
         {
             TangoMonitor &mon = th_info->poll_mon;
             PollThCmd &shared_cmd = th_info->shared_data;
@@ -1746,10 +1706,10 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
         // Update db
         //
 
-        if((with_db_upd == true) && (Tango::Util::instance()->use_db()))
+        if((with_db_upd) && (Tango::Util::instance()->use_db()))
         {
             DbData send_data;
-            send_data.push_back(DbDatum("polling_threads_pool_conf"));
+            send_data.emplace_back("polling_threads_pool_conf");
             send_data[0] << tg->get_poll_pool_conf();
 
             tg->get_dserver_device()->get_db_device()->put_property(send_data);
@@ -1774,18 +1734,22 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
         ss << "No event possible on attribute " << obj_name << ". Polling has just being stopped!";
         ex.errors[0].desc = Tango::string_dup(ss.str().c_str());
 
-        if(att.periodic_event_subscribed() == true)
+        if(att.periodic_event_subscribed())
         {
             att.fire_error_periodic_event(&ex);
         }
-        if(att.archive_event_subscribed() == true && att.is_archive_event() == false)
+        if(att.archive_event_subscribed() && !att.is_archive_event())
         {
             dev->push_archive_event(obj_name, &ex);
         }
-        if(att.change_event_subscribed() == true && att.is_change_event() == false)
+        if(att.change_event_subscribed() && !att.is_change_event())
         {
             dev->push_change_event(obj_name, &ex);
         }
+        if(att.alarm_event_subscribed() && !att.is_alarm_event())
+        {
+            dev->push_alarm_event(obj_name, &ex);
+        }
     }
 
     //
@@ -1793,7 +1757,7 @@ void DServer::rem_obj_polling(const Tango::DevVarStringArray *argin, bool with_d
     // is done
     //
 
-    if(kill_thread == true && tg->is_svr_shutting_down() == false && th_id == poll_th_id && local_request == true)
+    if(kill_thread && !tg->is_svr_shutting_down() && th_id == poll_th_id && local_request)
     {
         tg->remove_polling_thread_info_by_id(poll_th_id);
 
@@ -1836,7 +1800,7 @@ void DServer::stop_polling()
 
         {
             omni_mutex_lock sync(mon);
-            if(shared_cmd.cmd_pending == true)
+            if(shared_cmd.cmd_pending)
             {
                 mon.wait();
             }
@@ -1845,11 +1809,11 @@ void DServer::stop_polling()
 
             mon.signal();
 
-            while(shared_cmd.cmd_pending == true)
+            while(shared_cmd.cmd_pending)
             {
                 interupted = mon.wait(DEFAULT_TIMEOUT);
 
-                if((shared_cmd.cmd_pending == true) && (interupted == false))
+                if((shared_cmd.cmd_pending) && (interupted == 0))
                 {
                     TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                     TANGO_THROW_EXCEPTION(API_CommandTimedOut, "Polling thread blocked !!!");
@@ -1899,7 +1863,7 @@ void DServer::start_polling()
 
         {
             omni_mutex_lock sync(mon);
-            if(shared_cmd.cmd_pending == true)
+            if(shared_cmd.cmd_pending)
             {
                 mon.wait();
             }
@@ -1908,11 +1872,11 @@ void DServer::start_polling()
 
             mon.signal();
 
-            while(shared_cmd.cmd_pending == true)
+            while(shared_cmd.cmd_pending)
             {
                 int interupted = mon.wait(DEFAULT_TIMEOUT);
 
-                if((shared_cmd.cmd_pending == true) && (interupted == false))
+                if((shared_cmd.cmd_pending) && (interupted == 0))
                 {
                     TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                     TANGO_THROW_EXCEPTION(API_CommandTimedOut, "Polling thread blocked !!!");
@@ -1937,7 +1901,7 @@ void DServer::start_polling(PollingThreadInfo *th_info)
 
     {
         omni_mutex_lock sync(mon);
-        if(shared_cmd.cmd_pending == true)
+        if(shared_cmd.cmd_pending)
         {
             mon.wait();
         }
@@ -1946,11 +1910,11 @@ void DServer::start_polling(PollingThreadInfo *th_info)
 
         mon.signal();
 
-        while(shared_cmd.cmd_pending == true)
+        while(shared_cmd.cmd_pending)
         {
             int interupted = mon.wait(DEFAULT_TIMEOUT);
 
-            if((shared_cmd.cmd_pending == true) && (interupted == false))
+            if((shared_cmd.cmd_pending) && (interupted == 0))
             {
                 TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                 TANGO_THROW_EXCEPTION(API_CommandTimedOut,
@@ -1988,7 +1952,7 @@ void DServer::add_event_heartbeat()
 
     {
         omni_mutex_lock sync(mon);
-        if(shared_cmd.cmd_pending == true)
+        if(shared_cmd.cmd_pending)
         {
             mon.wait();
         }
@@ -2006,10 +1970,10 @@ void DServer::add_event_heartbeat()
         int th_id = omni_thread::self()->id();
         if(th_id != tg->get_heartbeat_thread_id())
         {
-            while(shared_cmd.cmd_pending == true)
+            while(shared_cmd.cmd_pending)
             {
                 int interupted = mon.wait(DEFAULT_TIMEOUT);
-                if((shared_cmd.cmd_pending == true) && (interupted == false))
+                if((shared_cmd.cmd_pending) && (interupted == 0))
                 {
                     TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                     TANGO_THROW_EXCEPTION(API_CommandTimedOut, "Polling thread blocked !!!");
@@ -2047,7 +2011,7 @@ void DServer::rem_event_heartbeat()
 
     {
         omni_mutex_lock sync(mon);
-        if(shared_cmd.cmd_pending == true)
+        if(shared_cmd.cmd_pending)
         {
             mon.wait();
         }
@@ -2065,10 +2029,10 @@ void DServer::rem_event_heartbeat()
         int th_id = omni_thread::self()->id();
         if(th_id != tg->get_heartbeat_thread_id())
         {
-            while(shared_cmd.cmd_pending == true)
+            while(shared_cmd.cmd_pending)
             {
                 int interupted = mon.wait(DEFAULT_TIMEOUT);
-                if((shared_cmd.cmd_pending == true) && (interupted == false))
+                if((shared_cmd.cmd_pending) && (interupted == 0))
                 {
                     TANGO_LOG_DEBUG << "TIME OUT" << std::endl;
                     TANGO_THROW_EXCEPTION(API_CommandTimedOut, "Polling thread blocked !!!");
@@ -2115,7 +2079,7 @@ void DServer::check_upd_authorized(DeviceImpl *dev, int upd, PollObjType obj_typ
         v_ptr = &(dev->get_attr_min_poll_period());
     }
 
-    std::vector<std::string>::iterator ite = find(v_ptr->begin(), v_ptr->end(), obj_name);
+    auto ite = find(v_ptr->begin(), v_ptr->end(), obj_name);
     if(ite != v_ptr->end())
     {
         ++ite;
