@@ -36,13 +36,13 @@
 #include <tango/server/dserversignal.h>
 
 #ifndef _TG_WINDOWS_
-  #include <errno.h>
+  #include <cerrno>
 #endif
 
 namespace Tango
 {
 
-DServerSignal *DServerSignal::_instance = NULL;
+std::unique_ptr<DServerSignal> DServerSignal::_instance = nullptr;
 DevSigAction DServerSignal::reg_sig[_NSIG];
 std::string DServerSignal::sig_name[_NSIG];
 #ifdef _TG_WINDOWS_
@@ -63,18 +63,23 @@ int DServerSignal::win_signo = 0;
 
 DServerSignal *DServerSignal::instance()
 {
-    if(_instance == NULL)
+    if(_instance == nullptr)
     {
         try
         {
-            _instance = new DServerSignal();
+            _instance.reset(new DServerSignal());
         }
         catch(std::bad_alloc &)
         {
             throw;
         }
     }
-    return _instance;
+    return _instance.get();
+}
+
+void DServerSignal::cleanup_singleton()
+{
+    _instance.reset(nullptr);
 }
 
 //+-----------------------------------------------------------------------------------------------------------------
@@ -211,7 +216,7 @@ DServerSignal::DServerSignal() :
     sigdelset(&sigs_to_block, SIGTSTP);
     sigdelset(&sigs_to_block, SIGUSR1);
     sigdelset(&sigs_to_block, SIGUSR2);
-    sigprocmask(SIG_BLOCK, &sigs_to_block, NULL);
+    sigprocmask(SIG_BLOCK, &sigs_to_block, nullptr);
 #else  /* _TG_WINDOWS_ */
     win_ev = CreateEvent(NULL, FALSE, FALSE, NULL);
 
@@ -234,6 +239,29 @@ DServerSignal::DServerSignal() :
     TANGO_LOG_DEBUG << "leaving DServerSignal constructor" << std::endl;
 }
 
+DServerSignal::~DServerSignal()
+{
+    // Request that ThSig stops just in case we have got here because some other
+    // thread is shutting the server down, in which case the ThSig might be
+    // waiting forever for a signal.
+    sig_th_should_stop = true;
+#ifndef _TG_WINDOWS_
+    pthread_kill(sig_th->my_thread, SIGINT);
+#else
+    win_signo = SIGINT;
+    SetEvent(win_ev);
+#endif
+    try
+    {
+        sig_th->join(nullptr);
+    }
+    catch(...)
+    {
+        // We are in the middle of shutting down and we don't care if we cannot
+        // join the thread, so we just continue here.
+    }
+}
+
 //+------------------------------------------------------------------------------------------------------------------
 //
 // method :
@@ -267,7 +295,7 @@ void DServerSignal::register_class_signal(long signo, bool handler, DeviceClass
     }
 
 #ifndef _TG_WINDOWS_
-    if((auto_signal(signo) == true) && (handler == true))
+    if((auto_signal(signo)) && (handler))
     {
         TangoSys_OMemStream o;
         o << "Signal " << sig_name[signo] << "is not authorized using your own handler" << std::ends;
@@ -279,9 +307,9 @@ void DServerSignal::register_class_signal(long signo, bool handler, DeviceClass
     // If nothing is registered for this signal, install the OS signal handler
     //
 
-    if(auto_signal(signo) == false)
+    if(!auto_signal(signo))
     {
-        if((reg_sig[signo].registered_devices.empty() == true) && (reg_sig[signo].registered_classes.empty() == true))
+        if((reg_sig[signo].registered_devices.empty()) && (reg_sig[signo].registered_classes.empty()))
         {
 #ifdef _TG_WINDOWS_
             register_handler(signo);
@@ -296,7 +324,7 @@ void DServerSignal::register_class_signal(long signo, bool handler, DeviceClass
     // Otherwise, record class pointer
     //
 
-    std::vector<DeviceClass *>::iterator f = find_class(signo, cl_ptr);
+    auto f = find_class(signo, cl_ptr);
 
     if(f == reg_sig[signo].registered_classes.end())
     {
@@ -369,7 +397,7 @@ void DServerSignal::register_dev_signal(long signo, bool handler, DeviceImpl *de
     }
 
 #ifndef _TG_WINDOWS_
-    if((auto_signal(signo) == true) && (handler == true))
+    if((auto_signal(signo)) && (handler))
     {
         TangoSys_OMemStream o;
         o << "Signal " << sig_name[signo] << "is not authorized using your own handler" << std::ends;
@@ -381,9 +409,9 @@ void DServerSignal::register_dev_signal(long signo, bool handler, DeviceImpl *de
     // If nothing is registered for this signal, install the OS signal handler
     //
 
-    if(auto_signal(signo) == false)
+    if(!auto_signal(signo))
     {
-        if((reg_sig[signo].registered_devices.empty() == true) && (reg_sig[signo].registered_classes.empty() == true))
+        if((reg_sig[signo].registered_devices.empty()) && (reg_sig[signo].registered_classes.empty()))
         {
 #ifdef _TG_WINDOWS_
             register_handler(signo);
@@ -398,7 +426,7 @@ void DServerSignal::register_dev_signal(long signo, bool handler, DeviceImpl *de
     // Otherwise, record class pointer
     //
 
-    std::vector<DeviceImpl *>::iterator f = find_device(signo, dev_ptr);
+    auto f = find_device(signo, dev_ptr);
 
     if(f == reg_sig[signo].registered_devices.end())
     {
@@ -471,7 +499,7 @@ void DServerSignal::unregister_class_signal(long signo, DeviceClass *cl_ptr)
     // Otherwise, record class pointer
     //
 
-    std::vector<DeviceClass *>::iterator f = find_class(signo, cl_ptr);
+    auto f = find_class(signo, cl_ptr);
 
     if(f == reg_sig[signo].registered_classes.end())
     {
@@ -486,9 +514,9 @@ void DServerSignal::unregister_class_signal(long signo, DeviceClass *cl_ptr)
     // If nothing is registered for this signal, unregister the OS signal handler and (eventually) the event handler
     //
 
-    if(auto_signal(signo) == false)
+    if(!auto_signal(signo))
     {
-        if((reg_sig[signo].registered_classes.empty() == true) && (reg_sig[signo].registered_devices.empty() == true))
+        if((reg_sig[signo].registered_classes.empty()) && (reg_sig[signo].registered_devices.empty()))
         {
             unregister_handler(signo);
         }
@@ -528,7 +556,7 @@ void DServerSignal::unregister_dev_signal(long signo, DeviceImpl *dev_ptr)
     // Otherwise, leave method
     //
 
-    std::vector<DeviceImpl *>::iterator f = find_device(signo, dev_ptr);
+    auto f = find_device(signo, dev_ptr);
 
     if(f == reg_sig[signo].registered_devices.end())
     {
@@ -543,9 +571,9 @@ void DServerSignal::unregister_dev_signal(long signo, DeviceImpl *dev_ptr)
     // If nothing is registered for this signal, unregister the OS signal handler and eventually the event handler
     //
 
-    if(auto_signal(signo) == false)
+    if(!auto_signal(signo))
     {
-        if((reg_sig[signo].registered_classes.empty() == true) && (reg_sig[signo].registered_devices.empty() == true))
+        if((reg_sig[signo].registered_classes.empty()) && (reg_sig[signo].registered_devices.empty()))
         {
             unregister_handler(signo);
         }
@@ -576,7 +604,7 @@ void DServerSignal::unregister_dev_signal(DeviceImpl *dev_ptr)
         // Check if device is registered for this signal. If yes, remove it. Otherwise, go to next signal
         //
 
-        std::vector<DeviceImpl *>::iterator f = find_device(i, dev_ptr);
+        auto f = find_device(i, dev_ptr);
 
         if(f == reg_sig[i].registered_devices.end())
         {
@@ -591,9 +619,9 @@ void DServerSignal::unregister_dev_signal(DeviceImpl *dev_ptr)
         // If nothing is registered for this signal, unregister the OS signal handler
         //
 
-        if(auto_signal(i) == false)
+        if(!auto_signal(i))
         {
-            if((reg_sig[i].registered_classes.empty() == true) && (reg_sig[i].registered_devices.empty() == true))
+            if((reg_sig[i].registered_classes.empty()) && (reg_sig[i].registered_devices.empty()))
             {
                 unregister_handler(i);
             }
@@ -625,7 +653,7 @@ void DServerSignal::unregister_class_signal(DeviceClass *cl_ptr)
         // Check if classes is registered for this signal. If yes, remove it. Otherwise, go to next signal
         //
 
-        std::vector<DeviceClass *>::iterator f = find_class(i, cl_ptr);
+        auto f = find_class(i, cl_ptr);
 
         if(f == reg_sig[i].registered_classes.end())
         {
@@ -640,9 +668,9 @@ void DServerSignal::unregister_class_signal(DeviceClass *cl_ptr)
         // If nothing is registered for this signal, unregister the OS signal handler
         //
 
-        if(auto_signal(i) == false)
+        if(!auto_signal(i))
         {
-            if((reg_sig[i].registered_classes.empty() == true) && (reg_sig[i].registered_devices.empty() == true))
+            if((reg_sig[i].registered_classes.empty()) && (reg_sig[i].registered_devices.empty()))
             {
                 unregister_handler(i);
             }
@@ -680,13 +708,13 @@ void DServerSignal::register_handler(long signo, bool handler)
         TANGO_THROW_EXCEPTION(API_CantInstallSignal, o.str());
     }
 #else
-    if(handler == true)
+    if(handler)
     {
         sigset_t sigs_to_unblock;
         sigemptyset(&sigs_to_unblock);
         sigaddset(&sigs_to_unblock, signo);
 
-        if(pthread_sigmask(SIG_UNBLOCK, &sigs_to_unblock, NULL) != 0)
+        if(pthread_sigmask(SIG_UNBLOCK, &sigs_to_unblock, nullptr) != 0)
         {
             TangoSys_OMemStream o;
             o << "Can't install signal " << signo << ". OS error = " << errno << std::ends;
@@ -699,7 +727,7 @@ void DServerSignal::register_handler(long signo, bool handler)
         sa.sa_handler = DServerSignal::main_sig_handler;
         sigemptyset(&sa.sa_mask);
 
-        if(sigaction((int) signo, &sa, 0) == -1)
+        if(sigaction((int) signo, &sa, nullptr) == -1)
         {
             TangoSys_OMemStream o;
             o << "Can't install signal " << signo << ". OS error = " << errno << std::ends;
@@ -710,7 +738,7 @@ void DServerSignal::register_handler(long signo, bool handler)
     {
         omni_mutex_lock sy(*this);
 
-        while(sig_to_install == true)
+        while(sig_to_install)
         {
             wait();
         }
@@ -749,7 +777,7 @@ void DServerSignal::unregister_handler(long signo)
         TANGO_THROW_EXCEPTION(API_CantInstallSignal, o.str());
     }
 #else
-    if(reg_sig[signo].own_handler == true)
+    if(reg_sig[signo].own_handler)
     {
         struct sigaction sa;
 
@@ -757,7 +785,7 @@ void DServerSignal::unregister_handler(long signo)
         sa.sa_handler = SIG_DFL;
         sigemptyset(&sa.sa_mask);
 
-        if(sigaction((int) signo, &sa, 0) == -1)
+        if(sigaction((int) signo, &sa, nullptr) == -1)
         {
             TangoSys_OMemStream o;
             o << "Can't install signal " << signo << ". OS error = " << errno << std::ends;
@@ -768,7 +796,7 @@ void DServerSignal::unregister_handler(long signo)
     {
         omni_mutex_lock sy(*this);
 
-        while(sig_to_remove == true)
+        while(sig_to_remove)
         {
             wait();
         }
@@ -819,7 +847,7 @@ void DServerSignal::main_sig_handler(int signo)
     // First, execute all the handlers installed at the class level
     //
 
-    if(act_ptr->registered_classes.empty() == false)
+    if(!act_ptr->registered_classes.empty())
     {
         long nb_class = act_ptr->registered_classes.size();
         for(long j = 0; j < nb_class; j++)
@@ -832,7 +860,7 @@ void DServerSignal::main_sig_handler(int signo)
     // Then, execute all the handlers installed at the device level
     //
 
-    if(act_ptr->registered_devices.empty() == false)
+    if(!act_ptr->registered_devices.empty())
     {
         long nb_dev = act_ptr->registered_devices.size();
         for(long j = 0; j < nb_dev; j++)
