@@ -55,11 +55,11 @@ EncodedAttribute::EncodedAttribute() :
     ext(nullptr)
 {
     buffer_array = (unsigned char **) calloc(1, sizeof(unsigned char *));
-    buffer_array[0] = NULL;
+    buffer_array[0] = nullptr;
     buffSize_array = (std::size_t *) calloc(1, sizeof(std::size_t));
     buffSize_array[0] = 0;
-    format = NULL;
-    mutex_array = NULL;
+    format = nullptr;
+    mutex_array = nullptr;
     index = 0;
     buf_elt_nb = 1;
 }
@@ -72,14 +72,14 @@ EncodedAttribute::EncodedAttribute(int si, bool excl) :
     buffSize_array = (std::size_t *) calloc(si, sizeof(std::size_t));
     for(int i = 0; i < si; i++)
     {
-        buffer_array[i] = NULL;
+        buffer_array[i] = nullptr;
         buffSize_array[i] = 0;
     }
-    format = NULL;
+    format = nullptr;
     index = 0;
     buf_elt_nb = si;
 
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array = new omni_mutex[si];
     }
@@ -96,7 +96,7 @@ EncodedAttribute::~EncodedAttribute()
     SAFE_FREE(buffer_array);
     SAFE_FREE(buffSize_array);
 
-    if(mutex_array != NULL)
+    if(mutex_array != nullptr)
     {
         delete[] mutex_array;
     }
@@ -106,7 +106,7 @@ EncodedAttribute::~EncodedAttribute()
 
 void EncodedAttribute::encode_jpeg_gray8(unsigned char *gray8, int width, int height, double quality)
 {
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array[index].lock();
     }
@@ -122,7 +122,7 @@ void EncodedAttribute::encode_jpeg_gray8(unsigned char *gray8, int width, int he
 
 void EncodedAttribute::encode_jpeg_rgb32(unsigned char *rgb32, int width, int height, double quality)
 {
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array[index].lock();
     }
@@ -138,7 +138,7 @@ void EncodedAttribute::encode_jpeg_rgb32(unsigned char *rgb32, int width, int he
 
 void EncodedAttribute::encode_jpeg_rgb24(unsigned char *rgb24, int width, int height, double quality)
 {
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array[index].lock();
     }
@@ -152,11 +152,11 @@ void EncodedAttribute::encode_jpeg_rgb24(unsigned char *rgb24, int width, int he
 
 // ----------------------------------------------------------------------------
 
-void EncodedAttribute::encode_gray8(unsigned char *gray8, int width, int height)
+void EncodedAttribute::encode_gray8(const unsigned char *gray8, int width, int height)
 {
     long unsigned int newSize = width * height + 4;
 
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array[index].lock();
     }
@@ -184,11 +184,11 @@ void EncodedAttribute::encode_gray8(unsigned char *gray8, int width, int height)
 
 // ----------------------------------------------------------------------------
 
-void EncodedAttribute::encode_gray16(unsigned short *gray16, int width, int height)
+void EncodedAttribute::encode_gray16(const unsigned short *gray16, int width, int height)
 {
     long unsigned int newSize = width * height * 2 + 4;
 
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array[index].lock();
     }
@@ -226,11 +226,11 @@ void EncodedAttribute::encode_gray16(unsigned short *gray16, int width, int heig
 
 // ----------------------------------------------------------------------------
 
-void EncodedAttribute::encode_rgb24(unsigned char *rgb24, int width, int height)
+void EncodedAttribute::encode_rgb24(const unsigned char *rgb24, int width, int height)
 {
     long unsigned int newSize = width * height * 3 + 4;
 
-    if(manage_exclusion == true)
+    if(manage_exclusion)
     {
         mutex_array[index].lock();
     }
@@ -265,24 +265,24 @@ void EncodedAttribute::decode_rgb32(DeviceAttribute *attr, int *width, int *heig
     }
 
     DevVarEncodedArray_var &encDataSeq = attr->get_Encoded_data();
-    if(encDataSeq.operator->() == NULL)
+    if(encDataSeq.operator->() == nullptr)
     {
-        TANGO_THROW_API_EXCEPTION(ApiDataExcept,
-                                  API_IncompatibleAttrArgumentType,
-                                  "Cannot extract, data in DeviceAttribute object is not DevEncoded");
+        TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept,
+                                       API_IncompatibleAttrArgumentType,
+                                       "Cannot extract, data in DeviceAttribute object is not DevEncoded");
     }
 
     std::string local_format(encDataSeq.in()[0].encoded_format);
 
-    int isRGB = (strcmp(local_format.c_str(), RGB_24) == 0);
-    int isJPEG = (strcmp(local_format.c_str(), JPEG_RGB) == 0);
+    bool isRGB = strcmp(local_format.c_str(), RGB_24) == 0;
+    bool isJPEG = strcmp(local_format.c_str(), JPEG_RGB) == 0;
 
-    if(!isRGB && !isJPEG)
+    if((!isRGB) && (!isJPEG))
     {
         TANGO_THROW_EXCEPTION(API_WrongFormat, "Not a color format");
     }
 
-    unsigned char *rawBuff = NULL;
+    unsigned char *rawBuff = nullptr;
 
     DevVarEncodedArray &encData = encDataSeq.inout();
     DevVarCharArray &encBuff = encData[0].encoded_data;
@@ -343,24 +343,24 @@ void EncodedAttribute::decode_gray8(DeviceAttribute *attr, int *width, int *heig
     }
 
     DevVarEncodedArray_var &encDataSeq = attr->get_Encoded_data();
-    if(encDataSeq.operator->() == NULL)
+    if(encDataSeq.operator->() == nullptr)
     {
-        TANGO_THROW_API_EXCEPTION(ApiDataExcept,
-                                  API_IncompatibleAttrArgumentType,
-                                  "Cannot extract, data in DeviceAttribute object is not DevEncoded");
+        TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept,
+                                       API_IncompatibleAttrArgumentType,
+                                       "Cannot extract, data in DeviceAttribute object is not DevEncoded");
     }
 
     std::string local_format(encDataSeq.in()[0].encoded_format);
 
-    int isGrey = (strcmp(local_format.c_str(), GRAY_8) == 0);
-    int isJPEG = (strcmp(local_format.c_str(), JPEG_GRAY_8) == 0);
+    bool isGrey = strcmp(local_format.c_str(), GRAY_8) == 0;
+    bool isJPEG = strcmp(local_format.c_str(), JPEG_GRAY_8) == 0;
 
-    if(!isGrey && !isJPEG)
+    if((!isGrey) && (!isJPEG))
     {
         TANGO_THROW_EXCEPTION(API_WrongFormat, "Not a grayscale 8bit format");
     }
 
-    unsigned char *rawBuff = NULL;
+    unsigned char *rawBuff = nullptr;
 
     DevVarEncodedArray &encData = encDataSeq.inout();
     DevVarCharArray &encBuff = encData[0].encoded_data;
@@ -408,23 +408,23 @@ void EncodedAttribute::decode_gray16(DeviceAttribute *attr, int *width, int *hei
     }
 
     DevVarEncodedArray_var &encDataSeq = attr->get_Encoded_data();
-    if(encDataSeq.operator->() == NULL)
+    if(encDataSeq.operator->() == nullptr)
     {
-        TANGO_THROW_API_EXCEPTION(ApiDataExcept,
-                                  API_IncompatibleAttrArgumentType,
-                                  "Cannot extract, data in DeviceAttribute object is not DevEncoded");
+        TANGO_THROW_DETAILED_EXCEPTION(ApiDataExcept,
+                                       API_IncompatibleAttrArgumentType,
+                                       "Cannot extract, data in DeviceAttribute object is not DevEncoded");
     }
 
     std::string local_format(encDataSeq.in()[0].encoded_format);
 
-    int isGrey = (strcmp(local_format.c_str(), GRAY_16) == 0);
+    bool isGrey = strcmp(local_format.c_str(), GRAY_16) == 0;
 
     if(!isGrey)
     {
         TANGO_THROW_EXCEPTION(API_WrongFormat, "Not a grayscale 16 bits format");
     }
 
-    unsigned char *rawBuff = NULL;
+    unsigned char *rawBuff = nullptr;
 
     DevVarEncodedArray &encData = encDataSeq.inout();
     DevVarCharArray &encBuff = encData[0].encoded_data;
@@ -463,9 +463,32 @@ void EncodedAttribute::decode_gray16(DeviceAttribute *attr, int *width, int *hei
     }
 }
 
-#ifdef TANGO_USE_JPEG
 namespace
 {
+template <EncodedAttribute::Feature f>
+constexpr bool is_feature_supported();
+
+template <>
+constexpr bool is_feature_supported<EncodedAttribute::Feature::JPEG>()
+{
+#ifdef TANGO_USE_JPEG
+    return true;
+#else
+    return false;
+#endif
+}
+
+template <>
+constexpr bool is_feature_supported<EncodedAttribute::Feature::JPEG_WITH_ALPHA>()
+{
+#ifdef JCS_EXTENSIONS
+    return true;
+#else
+    return false;
+#endif
+}
+
+#ifdef TANGO_USE_JPEG
 enum class color_space
 {
     RGB,
@@ -518,13 +541,13 @@ template <typename JpegCompressDecompressStruct>
 }
 
 // ----------------------------------------------------------------
-static void jpeg_encode_rgb(int width,
-                            int height,
-                            unsigned char *rgb,
-                            double quality,
-                            std::size_t *jpegSize,
-                            unsigned char **jpegData,
-                            color_space type)
+void jpeg_encode_rgb(int width,
+                     int height,
+                     unsigned char *rgb,
+                     double quality,
+                     std::size_t *jpegSize,
+                     unsigned char **jpegData,
+                     color_space type)
 {
     jpeg_compress_struct cinfo{};
     jpeg_error_mgr jerr{};
@@ -553,7 +576,7 @@ static void jpeg_encode_rgb(int width,
         cinfo.input_components = 4;
         cinfo.in_color_space = JCS_EXT_RGBA;
   #else
-        TANGO_THROW_API_EXCEPTION(
+        TANGO_THROW_DETAILED_EXCEPTION(
             ApiNonSuppExcept, API_UnsupportedFeature, "JPEG implementation does not support alpha channel");
   #endif
         break;
@@ -587,10 +610,28 @@ static void jpeg_encode_rgb(int width,
     // Depending on the implementation, if done before it will return 4096 all the time
     *jpegSize = size;
 }
+#endif // TANGO_USE_JPEG
 } // namespace
 
 // --------------------------------------------------------------------------
 
+bool EncodedAttribute::is_feature_supported(const Feature &feat) const noexcept
+{
+    switch(feat)
+    {
+    case Feature::JPEG:
+        return ::is_feature_supported<Feature::JPEG>();
+        break;
+    case Feature::JPEG_WITH_ALPHA:
+        return ::is_feature_supported<Feature::JPEG_WITH_ALPHA>();
+        break;
+    default:
+        return false;
+        break;
+    }
+}
+
+#ifdef TANGO_USE_JPEG
 void EncodedAttribute::jpeg_encode_rgb32(
     int width, int height, unsigned char *rgb32, double quality, std::size_t *jpegSize, unsigned char **jpegData)
 {
@@ -657,27 +698,24 @@ void EncodedAttribute::jpeg_decode(
     jpeg_finish_decompress(&cinfo);
     jpeg_destroy_decompress(&cinfo);
 }
-
 #else
-
 void EncodedAttribute::jpeg_encode_rgb32(int, int, unsigned char *, double, std::size_t *, unsigned char **)
 {
-    TANGO_THROW_API_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
+    TANGO_THROW_DETAILED_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
 }
 
 void EncodedAttribute::jpeg_encode_rgb24(int, int, unsigned char *, double, std::size_t *, unsigned char **)
 {
-    TANGO_THROW_API_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
+    TANGO_THROW_DETAILED_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
 }
 
 void EncodedAttribute::jpeg_encode_gray8(int, int, unsigned char *, double, std::size_t *, unsigned char **)
 {
-    TANGO_THROW_API_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
+    TANGO_THROW_DETAILED_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
 }
 
 void EncodedAttribute::jpeg_decode(std::size_t, unsigned char *, int *, int *, unsigned char *&)
 {
-    TANGO_THROW_API_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
+    TANGO_THROW_DETAILED_EXCEPTION(ApiNonSuppExcept, API_UnsupportedFeature, "Tango was built without jpeg support");
 }
-
 #endif // TANGO_USE_JPEG
