@@ -75,7 +75,7 @@ DevLong DServer::event_subscription_change(const Tango::DevVarStringArray *argin
     // If we receive this command while the DS is in its shuting down sequence, do nothing
     //
 
-    if(tg->get_heartbeat_thread_object() == NULL)
+    if(tg->get_heartbeat_thread_object() == nullptr)
     {
         TangoSys_OMemStream o;
         o << "The device server is shutting down! You can no longer subscribe for events" << std::ends;
@@ -88,7 +88,7 @@ DevLong DServer::event_subscription_change(const Tango::DevVarStringArray *argin
     //
 
     NotifdEventSupplier *ev;
-    if((ev = tg->get_notifd_event_supplier()) == NULL)
+    if((ev = tg->get_notifd_event_supplier()) == nullptr)
     {
         tg->create_notifd_event_supplier();
         ev = tg->get_notifd_event_supplier();
@@ -98,7 +98,7 @@ DevLong DServer::event_subscription_change(const Tango::DevVarStringArray *argin
     // If we are using a file as database, gives port number to event supplier
     //
 
-    if(Util::instance()->use_file_db() && ev != NULL)
+    if(Util::instance()->use_file_db() && ev != nullptr)
     {
         ev->file_db_svr();
     }
@@ -113,13 +113,13 @@ DevLong DServer::event_subscription_change(const Tango::DevVarStringArray *argin
     int client_release = 0;
     client_addr *cl = get_client_ident();
 
-    if(cl == NULL)
+    if(cl == nullptr)
     {
         client_release = 4;
     }
     else
     {
-        if(cl->client_ident == true)
+        if(cl->client_ident)
         {
             client_release = 4;
         }
@@ -151,7 +151,7 @@ DevLong DServer::event_subscription_change(const Tango::DevVarStringArray *argin
     // Init one subscription command flag in Eventsupplier
     //
 
-    if(ev != NULL && ev->get_one_subscription_cmd() == false)
+    if(ev != nullptr && !ev->get_one_subscription_cmd())
     {
         ev->set_one_subscription_cmd(true);
     }
@@ -204,7 +204,7 @@ void DServer::event_subscription(DeviceImpl &device,
 
     if(channel_type == NOTIFD)
     {
-        if(attribute.is_fwd_att() == true)
+        if(attribute.is_fwd_att())
         {
             std::stringstream ss;
             ss << "The attribute " << obj_name << " is a forwarded attribute.";
@@ -215,7 +215,7 @@ void DServer::event_subscription(DeviceImpl &device,
     }
     else
     {
-        if(attribute.is_fwd_att() == true && client_lib_version < 5)
+        if(attribute.is_fwd_att() && client_lib_version < 5)
         {
             std::stringstream ss;
             ss << "The attribute " << obj_name << " is a forwarded attribute.";
@@ -242,7 +242,7 @@ void DServer::event_subscription(DeviceImpl &device,
     }
     else if(event == "data_ready")
     {
-        if(attribute.is_fwd_att() == false && attribute.is_data_ready_event() == false)
+        if(!attribute.is_fwd_att() && !attribute.is_data_ready_event())
         {
             TangoSys_OMemStream o;
             o << "The attribute ";
@@ -258,7 +258,7 @@ void DServer::event_subscription(DeviceImpl &device,
         // If the polling is necessary to send events, check whether the polling is started for the requested attribute.
         //
 
-        if(attribute.is_polled() == false)
+        if(!attribute.is_polled())
         {
             TangoSys_OMemStream o;
             o << "The polling (necessary to send events) for the attribute ";
@@ -267,21 +267,30 @@ void DServer::event_subscription(DeviceImpl &device,
 
             if(event == "change")
             {
-                if(attribute.is_fwd_att() == false && attribute.is_change_event() == false)
+                if(!attribute.is_fwd_att() && !attribute.is_change_event())
+                {
+                    TANGO_THROW_EXCEPTION(API_AttributePollingNotStarted, o.str());
+                }
+            }
+            else if(event == "alarm")
+            {
+                bool alarm_on_change = Util::instance()->is_auto_alarm_on_change_event() && attribute.is_change_event();
+                // allow subscribing to alarm events without polling if change events are pushed
+                if(!attribute.is_fwd_att() && !(attribute.is_alarm_event() || alarm_on_change))
                 {
                     TANGO_THROW_EXCEPTION(API_AttributePollingNotStarted, o.str());
                 }
             }
             else if(event == "archive")
             {
-                if(attribute.is_fwd_att() == false && attribute.is_archive_event() == false)
+                if(!attribute.is_fwd_att() && !attribute.is_archive_event())
                 {
                     TANGO_THROW_EXCEPTION(API_AttributePollingNotStarted, o.str());
                 }
             }
             else
             {
-                if(attribute.is_fwd_att() == false)
+                if(!attribute.is_fwd_att())
                 {
                     TANGO_THROW_EXCEPTION(API_AttributePollingNotStarted, o.str());
                 }
@@ -303,7 +312,7 @@ void DServer::event_subscription(DeviceImpl &device,
                    (attribute.get_data_type() != Tango::DEV_ENCODED) &&
                    (attribute.get_data_type() != Tango::DEV_STATE) && (attribute.get_data_type() != Tango::DEV_ENUM))
                 {
-                    if(attribute.is_check_change_criteria() == true)
+                    if(attribute.is_check_change_criteria())
                     {
                         if((attribute.rel_change[0] == INT_MAX) && (attribute.rel_change[1] == INT_MAX) &&
                            (attribute.abs_change[0] == INT_MAX) && (attribute.abs_change[1] == INT_MAX))
@@ -332,7 +341,7 @@ void DServer::event_subscription(DeviceImpl &device,
                    (attribute.get_data_type() != Tango::DEV_ENCODED) &&
                    (attribute.get_data_type() != Tango::DEV_STATE) && (attribute.get_data_type() != Tango::DEV_ENUM))
                 {
-                    if(attribute.is_check_archive_criteria() == true)
+                    if(attribute.is_check_archive_criteria())
                     {
                         if((attribute.archive_abs_change[0] == INT_MAX) &&
                            (attribute.archive_abs_change[1] == INT_MAX) &&
@@ -459,7 +468,7 @@ MulticastParameters
         }
     }
 
-    if(found == false)
+    if(!found)
     {
         result.rate = 0;
         result.recovery_ivl = 0;
@@ -491,13 +500,13 @@ void DServer::store_subscribed_client_info(DeviceImpl &device,
 
         TANGO_LOG_DEBUG << "DServer::store_subscribed_client_info(): update pipe subscription\n";
         omni_mutex_lock oml(EventSupplier::get_event_mutex());
-        pipe.set_event_subscription(time(NULL));
+        pipe.set_event_subscription(Tango::get_current_system_datetime());
     }
     else if(event_name == EventName[INTERFACE_CHANGE_EVENT])
     {
         TANGO_LOG_DEBUG << "DServer::store_subscribed_client_info(): update device interface_change subscription\n";
         omni_mutex_lock oml(EventSupplier::get_event_mutex());
-        device.set_event_intr_change_subscription(time(NULL));
+        device.set_event_intr_change_subscription(Tango::get_current_system_datetime());
 
         if(client_lib_version != 0)
         {
@@ -533,11 +542,11 @@ void DServer::store_subscribed_client_info(DeviceImpl &device,
             omni_mutex_lock oml(EventSupplier::get_event_mutex());
             attribute.set_change_event_sub(client_lib_version);
         }
-        else if(event_name == "quality")
+        else if(event_name == "alarm")
         {
-            TANGO_LOG_DEBUG << "DServer::store_subscribed_client_info(): update quality_change subscription\n";
+            TANGO_LOG_DEBUG << "DServer::store_subscribed_client_info(): update alarm subscription\n";
             omni_mutex_lock oml(EventSupplier::get_event_mutex());
-            attribute.set_quality_event_sub();
+            attribute.set_alarm_event_sub(client_lib_version);
         }
         else if(event_name == "periodic")
         {
@@ -561,7 +570,7 @@ void DServer::store_subscribed_client_info(DeviceImpl &device,
         {
             Tango::Util *tg = Tango::Util::instance();
             EventType event_type = CHANGE_EVENT;
-            std::string mutable_event_name = event_name;
+            const std::string &mutable_event_name = event_name;
             tg->event_name_2_event_type(mutable_event_name, event_type);
 
             omni_mutex_lock oml(EventSupplier::get_event_mutex());
@@ -575,7 +584,7 @@ void DServer::store_subscribed_client_info(DeviceImpl &device,
 
     try
     {
-        if(get_heartbeat_started() == false)
+        if(!get_heartbeat_started())
         {
             add_event_heartbeat();
             set_heartbeat_started(true);
@@ -641,7 +650,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         ret_data->lvalue[0] = (Tango::DevLong) tg->get_tango_lib_release();
 
         ZmqEventSupplier *ev;
-        if((ev = tg->get_zmq_event_supplier()) != NULL)
+        if((ev = tg->get_zmq_event_supplier()) != nullptr)
         {
             std::string tmp_str("Heartbeat: ");
             tmp_str = tmp_str + ev->get_heartbeat_endpoint();
@@ -679,7 +688,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
                     if(ev->get_alternate_event_endpoint().size() != 0)
                     {
                         std::string ev_end = ev->get_alternate_event_endpoint()[loop];
-                        if(ev_end.empty() == false)
+                        if(!ev_end.empty())
                         {
                             tmp_str = "Alternate event: " + ev_end;
                         }
@@ -726,7 +735,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
             }
         }
 
-        if(found == false)
+        if(!found)
         {
             std::stringstream ss;
             ss << "The event type you sent (" << event << ") is not  valid event type";
@@ -778,6 +787,10 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
                     {
                         client_release = 3;
                     }
+                    else if(event == EventName[ALARM_EVENT])
+                    {
+                        client_release = 6;
+                    }
                     else
                     {
                         //
@@ -789,13 +802,13 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
 
                         client_addr *cl = get_client_ident();
 
-                        if(cl == NULL)
+                        if(cl == nullptr)
                         {
                             client_release = 4;
                         }
                         else
                         {
-                            if(cl->client_ident == true)
+                            if(cl->client_ident)
                             {
                                 client_release = 4;
                             }
@@ -817,7 +830,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         // If we receive this command while the DS is in its shuting down sequence, do nothing
         //
 
-        if(tg->get_heartbeat_thread_object() == NULL)
+        if(tg->get_heartbeat_thread_object() == nullptr)
         {
             TangoSys_OMemStream o;
             o << "The device server is shutting down! You can no longer subscribe for events" << std::ends;
@@ -830,7 +843,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         //
 
         ZmqEventSupplier *ev;
-        if((ev = tg->get_zmq_event_supplier()) == NULL)
+        if((ev = tg->get_zmq_event_supplier()) == nullptr)
         {
             tg->create_zmq_event_supplier();
             ev = tg->get_zmq_event_supplier();
@@ -842,7 +855,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         // device and client supports IDL5 and lib 9 (For attribute conf. change event)
         //
 
-        DeviceImpl *dev = NULL;
+        DeviceImpl *dev = nullptr;
 
         try
         {
@@ -888,7 +901,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         //
 
         bool new_client = ev->update_connected_client(get_client_ident());
-        if(new_client == true)
+        if(new_client)
         {
             ev->set_double_send();
         }
@@ -898,26 +911,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         // db in a file
         //
 
-        std::string ev_name = ev->get_fqdn_prefix();
-        if(Util::instance()->use_file_db())
-        {
-            int size = ev_name.size();
-            if(ev_name[size - 1] == '#')
-            {
-                ev_name.erase(size - 1);
-            }
-        }
-
-        ev_name = ev_name + dev->get_name_lower();
-        if(intr_change == false)
-        {
-            ev_name = ev_name + '/' + obj_name_lower;
-        }
-        if(Util::instance()->use_file_db() && ev != NULL)
-        {
-            ev_name = ev_name + MODIFIER_DBASE_NO;
-        }
-        ev_name = ev_name + '.' + event;
+        std::string ev_name = ev->create_full_event_name(dev, event, obj_name_lower, intr_change);
 
         //
         // If the event is defined as using mcast transport, get caller host
@@ -966,7 +960,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         // Init one subscription command flag in Eventsupplier
         //
 
-        if(ev->get_one_subscription_cmd() == false)
+        if(!ev->get_one_subscription_cmd())
         {
             ev->set_one_subscription_cmd(true);
         }
@@ -975,13 +969,13 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         // For forwarded attribute, eventually subscribe to events coming from root attribute
         //
 
-        if(intr_change == false && pipe_event == false)
+        if(!intr_change && !pipe_event)
         {
             Attribute &attribute = dev->get_device_attr()->get_attr_by_name(obj_name.c_str());
             EventType et;
             tg->event_name_2_event_type(event, et);
 
-            if(attribute.is_fwd_att() == true && et != ATTR_CONF_EVENT)
+            if(attribute.is_fwd_att() && et != ATTR_CONF_EVENT)
             {
                 FwdAttribute &fwd_att = static_cast<FwdAttribute &>(attribute);
                 std::string root_name = fwd_att.get_fwd_dev_name() + "/" + fwd_att.get_fwd_att_name();
@@ -994,7 +988,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
                 // polling is not started for the root attribute is sent at subscription time
                 //
 
-                if(already_there == true)
+                if(already_there)
                 {
                     rar.unsubscribe_user_event(fwd_att.get_fwd_dev_name(), fwd_att.get_fwd_att_name(), et);
                 }
@@ -1026,7 +1020,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         }
         else
         {
-            if(local_call == true)
+            if(local_call)
             {
                 std::string &event_endpoint = ev->get_event_endpoint();
                 ret_data->svalue[1] = Tango::string_dup(event_endpoint.c_str());
@@ -1058,10 +1052,10 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         size_t size = ret_data->svalue.length();
         ret_data->svalue.length(size + 2);
 
-        std::string event_topic = "";
+        std::string event_topic;
         bool add_compat_info = false;
         if((event != EventName[PIPE_EVENT]) && (event != EventName[INTERFACE_CHANGE_EVENT]) &&
-           (event != EventName[DATA_READY_EVENT]))
+           (event != EventName[DATA_READY_EVENT]) && (event != EventName[ALARM_EVENT]))
         {
             add_compat_info = true;
         }
@@ -1115,7 +1109,7 @@ void DServer::event_confirm_subscription(const Tango::DevVarStringArray *argin)
     unsigned int nb_event = argin->length() / 3;
 
     std::string old_dev;
-    DeviceImpl *dev = NULL;
+    DeviceImpl *dev = nullptr;
 
     for(unsigned int loop = 0; loop < nb_event; loop++)
     {
