@@ -40,6 +40,11 @@ namespace Tango
 char Except::mess[256];
 omni_mutex Except::the_mutex;
 
+void Except::print_exception(const CORBA::Exception &e)
+{
+    print_exception(e, std::cerr);
+}
+
 //+----------------------------------------------------------------------------
 //
 // method :         print_exception
@@ -51,7 +56,7 @@ omni_mutex Except::the_mutex;
 //
 //-----------------------------------------------------------------------------
 
-void Except::print_exception(const CORBA::Exception &e)
+void Except::print_exception(const CORBA::Exception &e, std::ostream &os)
 {
     const CORBA::SystemException *se;
 
@@ -59,10 +64,10 @@ void Except::print_exception(const CORBA::Exception &e)
     // For a CORBA::SystemException, use the OB function
     //
 
-    if((se = dynamic_cast<const CORBA::SystemException *>(&e)) != NULL)
+    if((se = dynamic_cast<const CORBA::SystemException *>(&e)) != nullptr)
     {
         Tango::Except::the_mutex.lock();
-        std::cerr << print_CORBA_SystemException(se) << std::endl;
+        os << print_CORBA_SystemException(se) << std::endl;
         Tango::Except::the_mutex.unlock();
     }
 
@@ -70,7 +75,7 @@ void Except::print_exception(const CORBA::Exception &e)
     // If it is a CORBA::UserException
     //
 
-    else if(dynamic_cast<const CORBA::UserException *>(&e) != NULL)
+    else if(dynamic_cast<const CORBA::UserException *>(&e) != nullptr)
     {
         const Tango::DevFailed *te;
         const Tango::NamedDevFailedList *mdf;
@@ -79,68 +84,67 @@ void Except::print_exception(const CORBA::Exception &e)
         // Print the Tango::NamedDevFailedList exception contents
         //
 
-        if((mdf = dynamic_cast<const Tango::NamedDevFailedList *>(&e)) != NULL)
+        if((mdf = dynamic_cast<const Tango::NamedDevFailedList *>(&e)) != nullptr)
         {
-            std::cerr << "Tango NamedDevFailedList exception" << std::endl;
+            os << "Tango NamedDevFailedList exception" << std::endl;
             for(unsigned long i = 0; i < mdf->err_list.size(); i++)
             {
-                std::cerr << "   Exception for object " << mdf->err_list[i].name << std::endl;
-                std::cerr << "   Index of object in call (starting at 0) = " << mdf->err_list[i].idx_in_call
-                          << std::endl;
+                os << "   Exception for object " << mdf->err_list[i].name << std::endl;
+                os << "   Index of object in call (starting at 0) = " << mdf->err_list[i].idx_in_call << std::endl;
                 for(unsigned long j = 0; j < mdf->err_list[i].err_stack.length(); j++)
                 {
-                    std::cerr << "       Severity = ";
+                    os << "       Severity = ";
                     switch(mdf->err_list[i].err_stack[j].severity)
                     {
                     case Tango::WARN:
-                        std::cerr << "WARNING ";
+                        os << "WARNING ";
                         break;
 
                     case Tango::ERR:
-                        std::cerr << "ERROR ";
+                        os << "ERROR ";
                         break;
 
                     case Tango::PANIC:
-                        std::cerr << "PANIC ";
+                        os << "PANIC ";
                         break;
 
                     default:
-                        std::cerr << "Unknown severity code";
+                        os << "Unknown severity code";
                         break;
                     }
-                    std::cerr << std::endl;
-                    std::cerr << "       Error reason = " << mdf->err_list[i].err_stack[j].reason.in() << std::endl;
-                    std::cerr << "       Desc : " << mdf->err_list[i].err_stack[j].desc.in() << std::endl;
-                    std::cerr << "       Origin : " << mdf->err_list[i].err_stack[j].origin.in() << std::endl;
+                    os << std::endl;
+                    os << "       Error reason = " << mdf->err_list[i].err_stack[j].reason.in() << std::endl;
+                    os << "       Desc : " << mdf->err_list[i].err_stack[j].desc.in() << std::endl;
+                    os << "       Origin : " << mdf->err_list[i].err_stack[j].origin.in() << std::endl;
                 }
             }
-            std::cerr << "   Summary exception" << std::endl;
+            os << "   Summary exception" << std::endl;
             for(unsigned long j = 0; j < mdf->errors.length(); j++)
             {
-                std::cerr << "       Severity = ";
+                os << "       Severity = ";
                 switch(mdf->errors[j].severity)
                 {
                 case Tango::WARN:
-                    std::cerr << "WARNING ";
+                    os << "WARNING ";
                     break;
 
                 case Tango::ERR:
-                    std::cerr << "ERROR ";
+                    os << "ERROR ";
                     break;
 
                 case Tango::PANIC:
-                    std::cerr << "PANIC ";
+                    os << "PANIC ";
                     break;
 
                 default:
-                    std::cerr << "Unknown severity code";
+                    os << "Unknown severity code";
                     break;
                 }
-                std::cerr << std::endl;
-                std::cerr << "       Error reason = " << mdf->errors[j].reason.in() << std::endl;
-                std::cerr << "       Desc : " << mdf->errors[j].desc.in() << std::endl;
-                std::cerr << "       Origin : " << mdf->errors[j].origin.in() << std::endl;
-                std::cerr << std::endl;
+                os << std::endl;
+                os << "       Error reason = " << mdf->errors[j].reason.in() << std::endl;
+                os << "       Desc : " << mdf->errors[j].desc.in() << std::endl;
+                os << "       Origin : " << mdf->errors[j].origin.in() << std::endl;
+                os << std::endl;
             }
         }
 
@@ -148,35 +152,35 @@ void Except::print_exception(const CORBA::Exception &e)
         // Print the Tango::DevFailed exception contents
         //
 
-        else if((te = dynamic_cast<const Tango::DevFailed *>(&e)) != NULL)
+        else if((te = dynamic_cast<const Tango::DevFailed *>(&e)) != nullptr)
         {
             for(unsigned long i = 0; i < te->errors.length(); i++)
             {
-                std::cerr << "Tango exception" << std::endl;
-                std::cerr << "Severity = ";
+                os << "Tango exception" << std::endl;
+                os << "Severity = ";
                 switch(te->errors[i].severity)
                 {
                 case Tango::WARN:
-                    std::cerr << "WARNING ";
+                    os << "WARNING ";
                     break;
 
                 case Tango::ERR:
-                    std::cerr << "ERROR ";
+                    os << "ERROR ";
                     break;
 
                 case Tango::PANIC:
-                    std::cerr << "PANIC ";
+                    os << "PANIC ";
                     break;
 
                 default:
-                    std::cerr << "Unknown severity code";
+                    os << "Unknown severity code";
                     break;
                 }
-                std::cerr << std::endl;
-                std::cerr << "Error reason = " << te->errors[i].reason.in() << std::endl;
-                std::cerr << "Desc : " << te->errors[i].desc.in() << std::endl;
-                std::cerr << "Origin : " << te->errors[i].origin.in() << std::endl;
-                std::cerr << std::endl;
+                os << std::endl;
+                os << "Error reason = " << te->errors[i].reason.in() << std::endl;
+                os << "Desc : " << te->errors[i].desc.in() << std::endl;
+                os << "Origin : " << te->errors[i].origin.in() << std::endl;
+                os << std::endl;
             }
         }
 
@@ -186,7 +190,7 @@ void Except::print_exception(const CORBA::Exception &e)
 
         else
         {
-            std::cerr << "Unknown CORBA user exception" << std::endl;
+            os << "Unknown CORBA user exception" << std::endl;
         }
     }
 
@@ -196,7 +200,7 @@ void Except::print_exception(const CORBA::Exception &e)
 
     else
     {
-        std::cerr << "Unknown exception type !!!!!!" << std::endl;
+        os << "Unknown exception type !!!!!!" << std::endl;
     }
 }
 
@@ -239,15 +243,15 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
     // We are using CORBA _downcast() method !!!
     //
 
-    if(CORBA::UNKNOWN::_downcast(e) != 0)
+    if(CORBA::UNKNOWN::_downcast(e) != nullptr)
     {
         ::strcpy(mess, "UNKNOWN CORBA system exception");
     }
-    else if((bad = CORBA::BAD_PARAM::_downcast(e)) != 0)
+    else if((bad = CORBA::BAD_PARAM::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "BAD_PARAM CORBA system exception: ");
         const char *err_msg = bad->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -256,11 +260,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((mem = CORBA::NO_MEMORY::_downcast(e)) != 0)
+    else if((mem = CORBA::NO_MEMORY::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "NO_MEMORY CORBA system exception: ");
         const char *err_msg = mem->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -269,11 +273,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((lim = CORBA::IMP_LIMIT::_downcast(e)) != 0)
+    else if((lim = CORBA::IMP_LIMIT::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "IMP_LIMIT CORBA system exception: ");
         const char *tmp = lim->NP_minorString();
-        if(tmp == NULL)
+        if(tmp == nullptr)
         {
             ::strcat(mess, "Unknown minor code: ");
             TangoSys_MemStream st;
@@ -286,11 +290,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, tmp);
         }
     }
-    else if((comm = CORBA::COMM_FAILURE::_downcast(e)) != NULL)
+    else if((comm = CORBA::COMM_FAILURE::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "COMM_FAILURE CORBA system exception: ");
         const char *tmp = comm->NP_minorString();
-        if(tmp == NULL)
+        if(tmp == nullptr)
         {
             ::strcat(mess, "Unknown minor code: ");
             TangoSys_MemStream st;
@@ -304,11 +308,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, tmp);
         }
     }
-    else if((inv = CORBA::INV_OBJREF::_downcast(e)) != NULL)
+    else if((inv = CORBA::INV_OBJREF::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "INV_OBJREF CORBA system exception: ");
         const char *err_msg = inv->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -317,11 +321,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((perm = CORBA::NO_PERMISSION::_downcast(e)) != NULL)
+    else if((perm = CORBA::NO_PERMISSION::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "NO_PERMISSION CORBA system exception: ");
         const char *err_msg = perm->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -330,11 +334,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((inter = CORBA::INTERNAL::_downcast(e)) != NULL)
+    else if((inter = CORBA::INTERNAL::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "INTERNAL CORBA system exception: ");
         const char *err_msg = inter->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -343,11 +347,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((mar = CORBA::MARSHAL::_downcast(e)) != NULL)
+    else if((mar = CORBA::MARSHAL::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "MARSHAL CORBA system exception: ");
         const char *err_msg = mar->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -356,11 +360,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((ini = CORBA::INITIALIZE::_downcast(e)) != NULL)
+    else if((ini = CORBA::INITIALIZE::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "INITIALIZE CORBA system exception: ");
         const char *err_msg = ini->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -369,11 +373,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((impl = CORBA::NO_IMPLEMENT::_downcast(e)) != NULL)
+    else if((impl = CORBA::NO_IMPLEMENT::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "NO_IMPLEMENT CORBA system exception: ");
         const char *err_msg = impl->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -382,11 +386,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((type = CORBA::BAD_TYPECODE::_downcast(e)) != NULL)
+    else if((type = CORBA::BAD_TYPECODE::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "BAD_TYPECODE CORBA system exception: ");
         const char *err_msg = type->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -395,11 +399,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((op = CORBA::BAD_OPERATION::_downcast(e)) != NULL)
+    else if((op = CORBA::BAD_OPERATION::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "BAD_OPERATION CORBA system exception: ");
         const char *err_msg = op->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -408,11 +412,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((res = CORBA::NO_RESOURCES::_downcast(e)) != NULL)
+    else if((res = CORBA::NO_RESOURCES::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "NO_RESOURCES CORBA system exception: ");
         const char *err_msg = res->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -421,11 +425,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((resp = CORBA::NO_RESPONSE::_downcast(e)) != NULL)
+    else if((resp = CORBA::NO_RESPONSE::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "NO_RESPONSE CORBA system exception: ");
         const char *err_msg = resp->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -434,11 +438,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((inv_ord = CORBA::BAD_INV_ORDER::_downcast(e)) != NULL)
+    else if((inv_ord = CORBA::BAD_INV_ORDER::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "BAD_INV_ORDER CORBA system exception: ");
         const char *err_msg = inv_ord->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -447,11 +451,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((tra = CORBA::TRANSIENT::_downcast(e)) != NULL)
+    else if((tra = CORBA::TRANSIENT::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "TRANSIENT CORBA system exception: ");
         const char *tmp = tra->NP_minorString();
-        if(tmp == NULL)
+        if(tmp == nullptr)
         {
             ::strcat(mess, "Unknown minor code: ");
             TangoSys_MemStream st;
@@ -465,11 +469,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, tmp);
         }
     }
-    else if((adap = CORBA::OBJ_ADAPTER::_downcast(e)) != NULL)
+    else if((adap = CORBA::OBJ_ADAPTER::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "OBJ_ADAPTER CORBA system exception: ");
         const char *err_msg = adap->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -478,11 +482,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((not_ex = CORBA::OBJECT_NOT_EXIST::_downcast(e)) != NULL)
+    else if((not_ex = CORBA::OBJECT_NOT_EXIST::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "OBJECT_NOT_EXIST CORBA system exception: ");
         const char *err_msg = not_ex->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -491,11 +495,11 @@ char *Except::print_CORBA_SystemException(const CORBA::SystemException *e)
             ::strcat(mess, err_msg);
         }
     }
-    else if((pol = CORBA::INV_POLICY::_downcast(e)) != NULL)
+    else if((pol = CORBA::INV_POLICY::_downcast(e)) != nullptr)
     {
         ::strcpy(mess, "INV_POLICY CORBA system exception: ");
         const char *err_msg = pol->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(mess, "ORB has returned NULL pointer !");
         }
@@ -554,15 +558,15 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
     // We are using CORBA _downcast() method !!!
     //
 
-    if(CORBA::UNKNOWN::_downcast(e) != 0)
+    if(CORBA::UNKNOWN::_downcast(e) != nullptr)
     {
         ::strcpy(error_msg, "UNKNOWN CORBA system exception");
     }
-    else if((bad = CORBA::BAD_PARAM::_downcast(e)) != 0)
+    else if((bad = CORBA::BAD_PARAM::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "BAD_PARAM CORBA system exception: ");
         const char *err_msg = bad->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -571,11 +575,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((mem = CORBA::NO_MEMORY::_downcast(e)) != 0)
+    else if((mem = CORBA::NO_MEMORY::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "NO_MEMORY CORBA system exception: ");
         const char *err_msg = mem->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -584,11 +588,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((lim = CORBA::IMP_LIMIT::_downcast(e)) != 0)
+    else if((lim = CORBA::IMP_LIMIT::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "IMP_LIMIT CORBA system exception: ");
         const char *tmp = lim->NP_minorString();
-        if(tmp == NULL)
+        if(tmp == nullptr)
         {
             ::strcat(error_msg, "Unknown minor code: ");
             TangoSys_MemStream st;
@@ -601,11 +605,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, tmp);
         }
     }
-    else if((comm = CORBA::COMM_FAILURE::_downcast(e)) != NULL)
+    else if((comm = CORBA::COMM_FAILURE::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "COMM_FAILURE CORBA system exception: ");
         const char *tmp = comm->NP_minorString();
-        if(tmp == NULL)
+        if(tmp == nullptr)
         {
             ::strcat(error_msg, "Unknown minor code: ");
             TangoSys_MemStream st;
@@ -619,11 +623,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, tmp);
         }
     }
-    else if((inv = CORBA::INV_OBJREF::_downcast(e)) != NULL)
+    else if((inv = CORBA::INV_OBJREF::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "INV_OBJREF CORBA system exception: ");
         const char *err_msg = inv->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -632,11 +636,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((perm = CORBA::NO_PERMISSION::_downcast(e)) != NULL)
+    else if((perm = CORBA::NO_PERMISSION::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "NO_PERMISSION CORBA system exception: ");
         const char *err_msg = perm->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -645,11 +649,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((inter = CORBA::INTERNAL::_downcast(e)) != NULL)
+    else if((inter = CORBA::INTERNAL::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "INTERNAL CORBA system exception: ");
         const char *err_msg = inter->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -658,11 +662,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((mar = CORBA::MARSHAL::_downcast(e)) != NULL)
+    else if((mar = CORBA::MARSHAL::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "MARSHAL CORBA system exception: ");
         const char *err_msg = mar->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -671,11 +675,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((ini = CORBA::INITIALIZE::_downcast(e)) != NULL)
+    else if((ini = CORBA::INITIALIZE::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "INITIALIZE CORBA system exception: ");
         const char *err_msg = ini->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -684,11 +688,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((impl = CORBA::NO_IMPLEMENT::_downcast(e)) != NULL)
+    else if((impl = CORBA::NO_IMPLEMENT::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "NO_IMPLEMENT CORBA system exception: ");
         const char *err_msg = impl->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -697,11 +701,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((type = CORBA::BAD_TYPECODE::_downcast(e)) != NULL)
+    else if((type = CORBA::BAD_TYPECODE::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "BAD_TYPECODE CORBA system exception: ");
         const char *err_msg = type->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -710,11 +714,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((op = CORBA::BAD_OPERATION::_downcast(e)) != NULL)
+    else if((op = CORBA::BAD_OPERATION::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "BAD_OPERATION CORBA system exception: ");
         const char *err_msg = op->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -723,11 +727,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((res = CORBA::NO_RESOURCES::_downcast(e)) != NULL)
+    else if((res = CORBA::NO_RESOURCES::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "NO_RESOURCES CORBA system exception: ");
         const char *err_msg = res->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -736,11 +740,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((resp = CORBA::NO_RESPONSE::_downcast(e)) != NULL)
+    else if((resp = CORBA::NO_RESPONSE::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "NO_RESPONSE CORBA system exception: ");
         const char *err_msg = resp->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -749,11 +753,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((inv_ord = CORBA::BAD_INV_ORDER::_downcast(e)) != NULL)
+    else if((inv_ord = CORBA::BAD_INV_ORDER::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "BAD_INV_ORDER CORBA system exception: ");
         const char *err_msg = inv_ord->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -762,11 +766,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((tra = CORBA::TRANSIENT::_downcast(e)) != NULL)
+    else if((tra = CORBA::TRANSIENT::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "TRANSIENT CORBA system exception: ");
         const char *tmp = tra->NP_minorString();
-        if(tmp == NULL)
+        if(tmp == nullptr)
         {
             ::strcat(error_msg, "Unknown minor code: ");
             TangoSys_MemStream st;
@@ -780,11 +784,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, tmp);
         }
     }
-    else if((adap = CORBA::OBJ_ADAPTER::_downcast(e)) != NULL)
+    else if((adap = CORBA::OBJ_ADAPTER::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "OBJ_ADAPTER CORBA system exception: ");
         const char *err_msg = adap->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -793,11 +797,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((not_ex = CORBA::OBJECT_NOT_EXIST::_downcast(e)) != NULL)
+    else if((not_ex = CORBA::OBJECT_NOT_EXIST::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "OBJECT_NOT_EXIST CORBA system exception: ");
         const char *err_msg = not_ex->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
@@ -806,11 +810,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
             ::strcat(error_msg, err_msg);
         }
     }
-    else if((pol = CORBA::INV_POLICY::_downcast(e)) != NULL)
+    else if((pol = CORBA::INV_POLICY::_downcast(e)) != nullptr)
     {
         ::strcpy(error_msg, "INV_POLICY CORBA system exception: ");
         const char *err_msg = pol->NP_minorString();
-        if(err_msg == NULL)
+        if(err_msg == nullptr)
         {
             ::strcat(error_msg, "ORB has returned NULL pointer !");
         }
