@@ -136,7 +136,7 @@ void FwdAttribute::set_att_config(const Tango::AttributeConfig_5 &conf)
     size_t enum_labels_nb = conf.enum_labels.length();
     for(size_t loop = 0; loop < enum_labels_nb; loop++)
     {
-        enum_labels.push_back(conf.enum_labels[loop].in());
+        enum_labels.emplace_back(conf.enum_labels[loop].in());
     }
 
     //
@@ -259,7 +259,7 @@ void FwdAttribute::set_att_config(const Tango::AttributeConfig_5 &conf)
         delta_t_defined = true;
     }
 
-    if(delta_t_defined == true && delta_val_defined == true)
+    if(delta_t_defined && delta_val_defined)
     {
         alarm_conf.set(rds);
     }
@@ -346,7 +346,7 @@ void FwdAttribute::set_att_config(AttributeInfoEx *aie_ptr)
         break;
 
     default:
-        TANGO_THROW_ON_DEFAULT(aie_ptr->memorized);
+        TANGO_ASSERT_ON_DEFAULT(aie_ptr->memorized);
     }
 
     writable_attr_name = aie_ptr->writable_attr_name;
@@ -490,7 +490,7 @@ void FwdAttribute::set_att_config(AttributeInfoEx *aie_ptr)
         delta_t_defined = true;
     }
 
-    if(delta_t_defined == true && delta_val_defined == true)
+    if(delta_t_defined && delta_val_defined)
     {
         alarm_conf.set(rds);
     }
@@ -646,7 +646,7 @@ void FwdAttribute::upd_att_config(const Tango::AttributeConfig_5 &conf)
     // Send new config to root attribute if received configuration if different than the one we already have
     //
 
-    if(new_att_conf(nullptr, &conf) == true)
+    if(new_att_conf(nullptr, &conf))
     {
         AttributeInfoListEx aile;
         AttributeInfoEx aie;
@@ -674,7 +674,7 @@ void FwdAttribute::upd_att_config(const Tango::AttributeConfig_3 &conf)
     // Send new config to root attribute if received configuration if different than the one we already have
     //
 
-    if(new_att_conf(&conf, nullptr) == true)
+    if(new_att_conf(&conf, nullptr))
     {
         AttributeInfoListEx aile;
         AttributeInfoEx aie;
@@ -720,13 +720,13 @@ bool FwdAttribute::new_att_conf(const Tango::AttributeConfig_3 *conf3, const Tan
     else
     {
         ret = new_att_conf_base(*conf5);
-        if(ret == false)
+        if(!ret)
         {
             if(conf5->memorized != is_memorized())
             {
                 ret = true;
             }
-            else if(conf5->memorized == true)
+            else if(conf5->memorized)
             {
                 if(conf5->mem_init != is_memorized_init())
                 {
@@ -792,11 +792,11 @@ void FwdAttribute::upd_att_label(const char *new_label)
         // set class default value if defined, otherwise use the user default or library defaults
 
         bool found = prop_in_list("label", label, nb_class, def_class_prop);
-        if(found == false)
+        if(!found)
         {
             found = prop_in_list("label", label, nb_user, def_user_prop);
             remove_db = true;
-            if(found == false)
+            if(!found)
             {
                 label = name;
             }
@@ -808,7 +808,7 @@ void FwdAttribute::upd_att_label(const char *new_label)
 
         bool found = prop_in_list("label", label, nb_user, def_user_prop);
         remove_db = true;
-        if(found == false)
+        if(!found)
         {
             label = name;
         }
@@ -831,7 +831,7 @@ void FwdAttribute::upd_att_label(const char *new_label)
     // Store new value in DB
     //
 
-    if(store_db == true)
+    if(store_db)
     {
         DbDatum db_prop(name);
         DbDatum db_lab("label");
@@ -859,11 +859,11 @@ void FwdAttribute::upd_att_label(const char *new_label)
     // Remove value from DB because label is now the default one (class, user or lib)
     //
 
-    if(remove_db == true)
+    if(remove_db)
     {
         DbData db_data;
-        db_data.push_back(DbDatum(name));
-        db_data.push_back(DbDatum("label"));
+        db_data.emplace_back(name);
+        db_data.emplace_back("label");
 
         try
         {
@@ -937,7 +937,7 @@ DevAttrHistory_5 *FwdAttribute::read_root_att_history(long n)
                 dp->set_connection_state(CONNECTION_NOTOK);
                 TangoSys_OMemStream desc;
                 desc << "Attribute_history failed on device " << get_fwd_dev_name() << std::ends;
-                TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, one, API_CommunicationFailed, desc.str());
+                TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, one, API_CommunicationFailed, desc.str());
             }
         }
         catch(CORBA::COMM_FAILURE &comm)
@@ -951,7 +951,7 @@ DevAttrHistory_5 *FwdAttribute::read_root_att_history(long n)
                 dp->set_connection_state(CONNECTION_NOTOK);
                 TangoSys_OMemStream desc;
                 desc << "Attribute_history failed on device " << get_fwd_dev_name() << std::ends;
-                TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, comm, API_CommunicationFailed, desc.str());
+                TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, comm, API_CommunicationFailed, desc.str());
             }
         }
         catch(CORBA::SystemException &ce)
@@ -959,7 +959,7 @@ DevAttrHistory_5 *FwdAttribute::read_root_att_history(long n)
             dp->set_connection_state(CONNECTION_NOTOK);
             TangoSys_OMemStream desc;
             desc << "Attribute_history failed on device " << get_fwd_dev_name() << std::ends;
-            TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
+            TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
         }
     }
 
@@ -1039,18 +1039,14 @@ AttributeValueList_5 *FwdAttribute::write_read_root_att(Tango::AttributeValueLis
                 TangoSys_OMemStream desc;
                 desc << "Writing attribute(s) on device " << get_fwd_dev_name() << " is not authorized" << std::ends;
 
-                TANGO_THROW_API_EXCEPTION(NotAllowedExcept, API_ReadOnlyMode, desc.str());
+                TANGO_THROW_DETAILED_EXCEPTION(NotAllowedExcept, API_ReadOnlyMode, desc.str());
             }
 
             //
             // Now, call the root device server
             //
 
-            ClntIdent ci;
-            ApiUtil *au = ApiUtil::instance();
-            ci.cpp_clnt(au->get_client_pid());
-
-            attr_value_list_5 = dev5->write_read_attributes_5(values, dvsa, ci);
+            attr_value_list_5 = dev5->write_read_attributes_5(values, dvsa, dp->get_client_identification());
 
             ctr = 2;
         }
@@ -1078,7 +1074,7 @@ AttributeValueList_5 *FwdAttribute::write_read_root_att(Tango::AttributeValueLis
 
             if(::strcmp(e.errors[0].reason, DEVICE_UNLOCKED_REASON) == 0)
             {
-                TANGO_RETHROW_API_EXCEPTION(DeviceUnlockedExcept, e, DEVICE_UNLOCKED_REASON, desc.str());
+                TANGO_RETHROW_DETAILED_EXCEPTION(DeviceUnlockedExcept, e, DEVICE_UNLOCKED_REASON, desc.str());
             }
             else
             {
@@ -1100,7 +1096,7 @@ AttributeValueList_5 *FwdAttribute::write_read_root_att(Tango::AttributeValueLis
                 dp->set_connection_state(CONNECTION_NOTOK);
                 TangoSys_OMemStream desc;
                 desc << "Failed to execute write_read_attribute on device " << get_fwd_dev_name() << std::ends;
-                TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, one, API_CommunicationFailed, desc.str());
+                TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, one, API_CommunicationFailed, desc.str());
             }
         }
         catch(CORBA::COMM_FAILURE &comm)
@@ -1114,7 +1110,7 @@ AttributeValueList_5 *FwdAttribute::write_read_root_att(Tango::AttributeValueLis
                 dp->set_connection_state(CONNECTION_NOTOK);
                 TangoSys_OMemStream desc;
                 desc << "Failed to execute write_attribute on device " << get_fwd_dev_name() << std::ends;
-                TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, comm, API_CommunicationFailed, desc.str());
+                TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, comm, API_CommunicationFailed, desc.str());
             }
         }
         catch(CORBA::SystemException &ce)
@@ -1123,7 +1119,7 @@ AttributeValueList_5 *FwdAttribute::write_read_root_att(Tango::AttributeValueLis
 
             TangoSys_OMemStream desc;
             desc << "Failed to execute write_attributes on device " << get_fwd_dev_name() << std::ends;
-            TANGO_RETHROW_API_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
+            TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, ce, API_CommunicationFailed, desc.str());
         }
     }
 
