@@ -54,8 +54,8 @@ Dur duration_abs(Dur d)
 
 } // namespace
 
-DeviceImpl *PollThread::dev_to_del = NULL;
-std::string PollThread::name_to_del = "";
+DeviceImpl *PollThread::dev_to_del = nullptr;
+std::string PollThread::name_to_del;
 PollObjType PollThread::type_to_del = Tango::POLL_CMD;
 
 //+-----------------------------------------------------------------------------------------------------------------
@@ -78,12 +78,11 @@ PollThread::PollThread(PollThCmd &cmd, TangoMonitor &m, bool heartbeat) :
     shared_cmd(cmd),
     p_mon(m),
     sleep(std::chrono::milliseconds(1)),
-    polling_stop(true),
+
     attr_names(1),
-    tune_ctr(1),
-    need_two_tuning(false),
-    send_heartbeat(heartbeat),
-    heartbeat_ctr(0)
+
+    send_heartbeat(heartbeat)
+
 {
     local_cmd.cmd_pending = false;
 
@@ -94,7 +93,7 @@ PollThread::PollThread(PollThCmd &cmd, TangoMonitor &m, bool heartbeat) :
     previous_nb_late = 0;
     polling_bef_9 = false;
 
-    if(heartbeat == true)
+    if(heartbeat)
     {
         polling_stop = false;
     }
@@ -127,15 +126,15 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
     // Declare a work item to check the for new sub devices regularly.
     //
 
-    if(send_heartbeat == true)
+    if(send_heartbeat)
     {
         WorkItem wo;
 
-        wo.dev = NULL;
-        wo.poll_list = NULL;
+        wo.dev = nullptr;
+        wo.poll_list = nullptr;
         wo.type = STORE_SUBDEV;
         wo.update = std::chrono::minutes(30);
-        wo.name.push_back(std::string("Sub device property storage"));
+        wo.name.emplace_back("Sub device property storage");
         wo.needed_time = PollClock::duration::zero();
 
         now = PollClock::now();
@@ -147,7 +146,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
     // The infinite loop
     //
 
-    while(1)
+    while(true)
     {
         try
         {
@@ -175,7 +174,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
             if(tune_ctr <= 0)
             {
                 tune_list(true);
-                if(need_two_tuning == true)
+                if(need_two_tuning)
                 {
                     unsigned long nb_works = works.size();
                     tune_ctr = (nb_works << 2);
@@ -193,7 +192,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
         {
             std::cerr << "OUPS !! A omni thread fatal exception received by a polling thread !!!!!!!!" << std::endl;
 #ifndef _TG_WINDOWS_
-            time_t t = time(NULL);
+            const time_t t = Tango::get_current_system_datetime();
             std::cerr << ctime(&t);
 #endif
             std::cerr << "Trying to re-enter the main loop" << std::endl;
@@ -203,7 +202,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
             std::cerr << "OUPS !! A Tango::DevFailed exception received by a polling thread !!!!!!!!" << std::endl;
             Tango::Except::print_exception(e);
 #ifndef _TG_WINDOWS_
-            time_t t = time(NULL);
+            const time_t t = Tango::get_current_system_datetime();
             std::cerr << ctime(&t);
 #endif
             std::cerr << "Trying to re-enter the main loop" << std::endl;
@@ -213,7 +212,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
             std::cerr << "OUPS !! A CORBA::Exception exception received by a polling thread !!!!!!!!" << std::endl;
             Tango::Except::print_exception(e);
 #ifndef _TG_WINDOWS_
-            time_t t = time(NULL);
+            const time_t t = Tango::get_current_system_datetime();
             std::cerr << ctime(&t);
 #endif
             std::cerr << "Trying to re-enter the main loop" << std::endl;
@@ -224,7 +223,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
                       << std::endl;
             std::cerr << ex.what() << std::endl;
 #ifndef _TG_WINDOWS_
-            time_t t = time(NULL);
+            const time_t t = Tango::get_current_system_datetime();
             std::cerr << ctime(&t);
 #endif
             std::cerr << "Trying to re-enter the main loop" << std::endl;
@@ -239,7 +238,7 @@ void *PollThread::run_undetached(TANGO_UNUSED(void *ptr))
         }
     }
 
-    return NULL;
+    return nullptr;
 }
 
 //+----------------------------------------------------------------------------------------------------------------
@@ -271,9 +270,9 @@ PollCmdType PollThread::get_command()
     // Wait on monitor
     //
 
-    if((shared_cmd.cmd_pending == false) && (shared_cmd.trigger == false))
+    if((!shared_cmd.cmd_pending) && (!shared_cmd.trigger))
     {
-        if(works.empty() == true)
+        if(works.empty())
         {
             p_mon.wait();
         }
@@ -290,12 +289,12 @@ PollCmdType PollThread::get_command()
     // Test if it is a new command. If yes, copy its data locally
     //
 
-    if(shared_cmd.cmd_pending == true)
+    if(shared_cmd.cmd_pending)
     {
         local_cmd = shared_cmd;
         ret = POLL_COMMAND;
     }
-    else if(shared_cmd.trigger == true)
+    else if(shared_cmd.trigger)
     {
         local_cmd = shared_cmd;
         ret = POLL_TRIGGER;
@@ -349,7 +348,7 @@ void PollThread::execute_cmd()
         PollObjType new_type = (*wo.poll_list)[local_cmd.index]->get_type();
 
         bool found = false;
-        if(new_type == POLL_ATTR && wo.dev->get_dev_idl_version() >= 4 && polling_bef_9 == false)
+        if(new_type == POLL_ATTR && wo.dev->get_dev_idl_version() >= 4 && !polling_bef_9)
         {
             ite = find_if(works.begin(),
                           works.end(),
@@ -362,7 +361,7 @@ void PollThread::execute_cmd()
             }
         }
 
-        if(found == false)
+        if(!found)
         {
             wo.type = new_type;
             wo.update = new_upd;
@@ -419,7 +418,7 @@ void PollThread::execute_cmd()
                         if(*ite_str == PollThread::name_to_del)
                         {
                             ite->name.erase(ite_str);
-                            if(ite->name.empty() == true)
+                            if(ite->name.empty())
                             {
                                 works.erase(ite);
                             }
@@ -427,7 +426,7 @@ void PollThread::execute_cmd()
                             break;
                         }
                     }
-                    if(found == true)
+                    if(found)
                     {
                         break;
                     }
@@ -556,7 +555,7 @@ void PollThread::execute_cmd()
                                 if(*ite_str == PollThread::name_to_del)
                                 {
                                     ite->name.erase(ite_str);
-                                    if(ite->name.empty() == true)
+                                    if(ite->name.empty())
                                     {
                                         works.erase(ite);
                                     }
@@ -567,7 +566,7 @@ void PollThread::execute_cmd()
                                 }
                             }
 
-                            if(found == true)
+                            if(found)
                             {
                                 break;
                             }
@@ -588,7 +587,7 @@ void PollThread::execute_cmd()
                 tune_ctr = 0;
                 found_in_work_list = true;
 
-                if(found == false)
+                if(!found)
                 {
                     rem_upd.emplace_back(local_cmd.new_upd, PollThread::name_to_del);
                 }
@@ -616,7 +615,7 @@ void PollThread::execute_cmd()
                             if(*ite_str == PollThread::name_to_del)
                             {
                                 ite->name.erase(ite_str);
-                                if(ite->name.empty() == true)
+                                if(ite->name.empty())
                                 {
                                     works.erase(ite);
                                 }
@@ -625,7 +624,7 @@ void PollThread::execute_cmd()
                                 break;
                             }
                         }
-                        if(found == true)
+                        if(found)
                         {
                             break;
                         }
@@ -650,7 +649,7 @@ void PollThread::execute_cmd()
         // case 2-2 as described above (polling thread itself updating polling period of the object it actually polls)
         //
 
-        if(found_in_work_list == false)
+        if(!found_in_work_list)
         {
             bool found = false;
             for(et_ite = ext_trig_works.begin(); et_ite != ext_trig_works.end(); ++et_ite)
@@ -669,7 +668,7 @@ void PollThread::execute_cmd()
                 }
             }
 
-            if(found == true)
+            if(found)
             {
                 wo.dev = local_cmd.dev;
                 wo.poll_list = &(wo.dev->get_poll_obj_list());
@@ -693,11 +692,11 @@ void PollThread::execute_cmd()
 
     case Tango::POLL_ADD_HEARTBEAT:
         TANGO_LOG_DEBUG << "Received a add heartbeat command" << std::endl;
-        wo.dev = NULL;
-        wo.poll_list = NULL;
+        wo.dev = nullptr;
+        wo.poll_list = nullptr;
         wo.type = EVENT_HEARTBEAT;
         wo.update = std::chrono::milliseconds(9000);
-        wo.name.push_back(std::string("Event heartbeat"));
+        wo.name.emplace_back("Event heartbeat");
         wo.needed_time = TIME_NEEDED_HEARTBEAT;
 
         wo.wake_up_date = now;
@@ -783,7 +782,7 @@ void PollThread::one_more_poll()
     WorkItem tmp = works.front();
     works.pop_front();
 
-    if(polling_stop == false)
+    if(!polling_stop)
     {
         switch(tmp.type)
         {
@@ -814,7 +813,7 @@ void PollThread::one_more_poll()
     // For case where the polling thread itself modify the polling period of the object it already polls
     //
 
-    if(auto_upd.empty() == false)
+    if(!auto_upd.empty())
     {
         for(const auto &entry : auto_upd)
         {
@@ -822,7 +821,7 @@ void PollThread::one_more_poll()
             tmp.name.erase(pos, tmp.name.end());
         }
 
-        if(tmp.name.empty() == false)
+        if(!tmp.name.empty())
         {
             tmp.wake_up_date += tmp.update;
             insert_in_list(tmp);
@@ -846,7 +845,7 @@ void PollThread::one_more_poll()
                 ++ite;
             }
 
-            if(found == false)
+            if(!found)
             {
                 WorkItem new_tmp;
                 new_tmp.update = entry.first;
@@ -870,7 +869,7 @@ void PollThread::one_more_poll()
 
     else
     {
-        if(rem_upd.empty() == false)
+        if(!rem_upd.empty())
         {
             for(const auto &entry : rem_upd)
             {
@@ -878,7 +877,7 @@ void PollThread::one_more_poll()
                 tmp.name.erase(pos, tmp.name.end());
             }
 
-            if(tmp.name.empty() == false)
+            if(!tmp.name.empty())
             {
                 tmp.wake_up_date += tmp.update;
                 insert_in_list(tmp);
@@ -954,7 +953,7 @@ void PollThread::one_more_trigg()
     //
 
     WorkItem tmp = *et_ite;
-    if(polling_stop == false)
+    if(!polling_stop)
     {
         if(tmp.type == Tango::POLL_CMD)
         {
@@ -1086,7 +1085,7 @@ void PollThread::insert_in_list(WorkItem &new_work)
 
 void PollThread::add_insert_in_list(WorkItem &new_work)
 {
-    if(new_work.type == POLL_ATTR && new_work.dev->get_dev_idl_version() >= 4 && polling_bef_9 == false)
+    if(new_work.type == POLL_ATTR && new_work.dev->get_dev_idl_version() >= 4 && !polling_bef_9)
     {
         std::list<WorkItem>::iterator ite;
         ite = find_if(works.begin(),
@@ -1145,7 +1144,7 @@ void PollThread::tune_list(bool from_needed)
     // update period
     //
 
-    if(from_needed == true)
+    if(from_needed)
     {
         PollClock::duration needed_sum = PollClock::duration::zero();
         PollClock::duration min_upd = PollClock::duration::zero();
@@ -1279,12 +1278,12 @@ void PollThread::compute_sleep_time()
 {
     print_list();
 
-    if(works.empty() == false)
+    if(!works.empty())
     {
         bool discard = false;
         unsigned int nb_late = 0;
 
-        if(polling_bef_9 == false)
+        if(!polling_bef_9)
         {
             //
             // Compute for how many items the polling thread is late
@@ -1335,7 +1334,7 @@ void PollThread::compute_sleep_time()
                     {
                         previous_nb_late = nb_late;
                     }
-                    sleep = tango_nullopt;
+                    sleep = std::nullopt;
                 }
             }
         }
@@ -1349,7 +1348,7 @@ void PollThread::compute_sleep_time()
         //
 
         //        TANGO_LOG_DEBUG << "discard = " << boolalpha << discard << std::endl;
-        if(nb_late == 0 || discard == true)
+        if(nb_late == 0 || discard)
         {
             previous_nb_late = 0;
 
@@ -1359,7 +1358,7 @@ void PollThread::compute_sleep_time()
             {
                 if((after - next) < DISCARD_THRESHOLD)
                 {
-                    sleep = tango_nullopt;
+                    sleep = std::nullopt;
                 }
                 else
                 {
@@ -1382,7 +1381,7 @@ void PollThread::compute_sleep_time()
 
                     if(duration_abs(next - after) < DISCARD_THRESHOLD)
                     {
-                        sleep = tango_nullopt;
+                        sleep = std::nullopt;
                     }
                     else
                     {
@@ -1423,8 +1422,8 @@ void PollThread::compute_sleep_time()
 
 void PollThread::err_out_of_sync(WorkItem &to_do)
 {
-    EventSupplier *event_supplier_nd = NULL;
-    EventSupplier *event_supplier_zmq = NULL;
+    EventSupplier *event_supplier_nd = nullptr;
+    EventSupplier *event_supplier_zmq = nullptr;
 
     //
     // Retrieve the event supplier(s) for this attribute
@@ -1435,16 +1434,16 @@ void PollThread::err_out_of_sync(WorkItem &to_do)
     {
         Attribute &att = to_do.dev->get_device_attr()->get_attr_by_name(to_do.name[ctr].c_str());
 
-        if(att.use_notifd_event() == true && event_supplier_nd == NULL)
+        if(att.use_notifd_event() && event_supplier_nd == nullptr)
         {
             event_supplier_nd = Util::instance()->get_notifd_event_supplier();
         }
-        if(att.use_zmq_event() == true && event_supplier_zmq == NULL)
+        if(att.use_zmq_event() && event_supplier_zmq == nullptr)
         {
             event_supplier_zmq = Util::instance()->get_zmq_event_supplier();
         }
 
-        if((event_supplier_nd != NULL) || (event_supplier_zmq != NULL))
+        if((event_supplier_nd != nullptr) || (event_supplier_zmq != nullptr))
         {
             Tango::DevErrorList errs;
             errs.length(1);
@@ -1483,31 +1482,31 @@ void PollThread::err_out_of_sync(WorkItem &to_do)
             //
 
             SendEventType send_event;
-            if(event_supplier_nd != NULL)
+            if(event_supplier_nd != nullptr)
             {
                 send_event = event_supplier_nd->detect_and_push_events(
                     to_do.dev, ad, &except, to_do.name[ctr], PollClock::now());
             }
-            if(event_supplier_zmq != NULL)
+            if(event_supplier_zmq != nullptr)
             {
-                if(event_supplier_nd != NULL)
+                if(event_supplier_nd != nullptr)
                 {
                     std::vector<std::string> f_names;
                     std::vector<double> f_data;
                     std::vector<std::string> f_names_lg;
                     std::vector<long> f_data_lg;
 
-                    if(send_event.change == true)
+                    if(send_event.change)
                     {
                         event_supplier_zmq->push_event_loop(
                             to_do.dev, CHANGE_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, &except);
                     }
-                    if(send_event.archive == true)
+                    if(send_event.archive)
                     {
                         event_supplier_zmq->push_event_loop(
                             to_do.dev, ARCHIVE_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, &except);
                     }
-                    if(send_event.periodic == true)
+                    if(send_event.periodic)
                     {
                         event_supplier_zmq->push_event_loop(
                             to_do.dev, PERIODIC_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, &except);
@@ -1542,8 +1541,8 @@ void PollThread::poll_cmd(WorkItem &to_do)
     TANGO_LOG_DEBUG << "----------> Time = " << std::fixed << duration_s(now.time_since_epoch()) << " s"
                     << ", Dev name = " << to_do.dev->get_name() << ", Cmd name = " << to_do.name[0] << std::endl;
 
-    CORBA::Any *argout = NULL;
-    Tango::DevFailed *save_except = NULL;
+    CORBA::Any *argout = nullptr;
+    Tango::DevFailed *save_except = nullptr;
 
     std::vector<PollObj *>::iterator ite;
     bool cmd_failed = false;
@@ -1573,7 +1572,7 @@ void PollThread::poll_cmd(WorkItem &to_do)
     {
         to_do.dev->get_poll_monitor().get_monitor();
         ite = to_do.dev->get_polled_obj_by_type_name(to_do.type, to_do.name[0]);
-        if(cmd_failed == false)
+        if(!cmd_failed)
         {
             (*ite)->insert_data(argout, before_cmd, needed_time);
         }
@@ -1585,7 +1584,7 @@ void PollThread::poll_cmd(WorkItem &to_do)
     }
     catch(Tango::DevFailed &)
     {
-        if(cmd_failed == false)
+        if(!cmd_failed)
         {
             delete argout;
         }
@@ -1627,11 +1626,11 @@ void PollThread::poll_attr(WorkItem &to_do)
     TANGO_LOG_DEBUG << "----------> Time = " << std::fixed << duration_s(now.time_since_epoch()) << " s"
                     << ", Dev name = " << to_do.dev->get_name() << ", Attr name = " << att_list << std::endl;
 
-    Tango::AttributeValueList *argout = NULL;
-    Tango::AttributeValueList_3 *argout_3 = NULL;
-    Tango::AttributeValueList_4 *argout_4 = NULL;
-    Tango::AttributeValueList_5 *argout_5 = NULL;
-    Tango::DevFailed *save_except = NULL;
+    Tango::AttributeValueList *argout = nullptr;
+    Tango::AttributeValueList_3 *argout_3 = nullptr;
+    Tango::AttributeValueList_4 *argout_4 = nullptr;
+    Tango::AttributeValueList_5 *argout_5 = nullptr;
+    Tango::DevFailed *save_except = nullptr;
     bool attr_failed = false;
     std::vector<PollObj *>::iterator ite;
     std::map<size_t, Tango::DevFailed *> map_except;
@@ -1686,7 +1685,7 @@ void PollThread::poll_attr(WorkItem &to_do)
         {
             if(nb_obj == 1)
             {
-                if((attr_failed == false) && ((*argout_5)[0].err_list.length() != 0))
+                if((!attr_failed) && ((*argout_5)[0].err_list.length() != 0))
                 {
                     attr_failed = true;
                     save_except = new Tango::DevFailed((*argout_5)[0].err_list);
@@ -1697,7 +1696,7 @@ void PollThread::poll_attr(WorkItem &to_do)
             {
                 for(size_t ctr = 0; ctr < nb_obj; ctr++)
                 {
-                    if((attr_failed == false) && ((*argout_5)[ctr].err_list.length() != 0))
+                    if((!attr_failed) && ((*argout_5)[ctr].err_list.length() != 0))
                     {
                         Tango::DevFailed *tmp_except = new Tango::DevFailed((*argout_5)[ctr].err_list);
                         map_except.insert(std::pair<size_t, Tango::DevFailed *>(ctr, tmp_except));
@@ -1709,7 +1708,7 @@ void PollThread::poll_attr(WorkItem &to_do)
         {
             if(nb_obj == 1)
             {
-                if((attr_failed == false) && ((*argout_4)[0].err_list.length() != 0))
+                if((!attr_failed) && ((*argout_4)[0].err_list.length() != 0))
                 {
                     attr_failed = true;
                     save_except = new Tango::DevFailed((*argout_4)[0].err_list);
@@ -1720,7 +1719,7 @@ void PollThread::poll_attr(WorkItem &to_do)
             {
                 for(size_t ctr = 0; ctr < nb_obj; ctr++)
                 {
-                    if((attr_failed == false) && ((*argout_4)[ctr].err_list.length() != 0))
+                    if((!attr_failed) && ((*argout_4)[ctr].err_list.length() != 0))
                     {
                         Tango::DevFailed *tmp_except = new Tango::DevFailed((*argout_4)[ctr].err_list);
                         map_except.insert(std::pair<size_t, Tango::DevFailed *>(ctr, tmp_except));
@@ -1730,7 +1729,7 @@ void PollThread::poll_attr(WorkItem &to_do)
         }
         else
         {
-            if((attr_failed == false) && ((*argout_3)[0].err_list.length() != 0))
+            if((!attr_failed) && ((*argout_3)[0].err_list.length() != 0))
             {
                 attr_failed = true;
                 save_except = new Tango::DevFailed((*argout_3)[0].err_list);
@@ -1746,25 +1745,25 @@ void PollThread::poll_attr(WorkItem &to_do)
     // accordingly
     //
 
-    EventSupplier *event_supplier_nd = NULL;
-    EventSupplier *event_supplier_zmq = NULL;
+    EventSupplier *event_supplier_nd = nullptr;
+    EventSupplier *event_supplier_zmq = nullptr;
 
     for(size_t ctr = 0; ctr < nb_obj; ctr++)
     {
         Attribute &att = to_do.dev->get_device_attr()->get_attr_by_name(to_do.name[ctr].c_str());
 
-        if(att.use_notifd_event() == true && event_supplier_nd == NULL)
+        if(att.use_notifd_event() && event_supplier_nd == nullptr)
         {
             event_supplier_nd = Util::instance()->get_notifd_event_supplier();
         }
-        if(att.use_zmq_event() == true && event_supplier_zmq == NULL)
+        if(att.use_zmq_event() && event_supplier_zmq == nullptr)
         {
             event_supplier_zmq = Util::instance()->get_zmq_event_supplier();
         }
 
-        if((event_supplier_nd != NULL) || (event_supplier_zmq != NULL))
+        if((event_supplier_nd != nullptr) || (event_supplier_zmq != nullptr))
         {
-            if(attr_failed == true)
+            if(attr_failed)
             {
                 struct EventSupplier::SuppliedEventData ad;
                 ::memset(&ad, 0, sizeof(ad));
@@ -1793,31 +1792,31 @@ void PollThread::poll_attr(WorkItem &to_do)
                 //
 
                 SendEventType send_event;
-                if(event_supplier_nd != NULL)
+                if(event_supplier_nd != nullptr)
                 {
                     send_event = event_supplier_nd->detect_and_push_events(
                         to_do.dev, ad, save_except, to_do.name[ctr], before_cmd);
                 }
-                if(event_supplier_zmq != NULL)
+                if(event_supplier_zmq != nullptr)
                 {
-                    if(event_supplier_nd != NULL)
+                    if(event_supplier_nd != nullptr)
                     {
                         std::vector<std::string> f_names;
                         std::vector<double> f_data;
                         std::vector<std::string> f_names_lg;
                         std::vector<long> f_data_lg;
 
-                        if(send_event.change == true)
+                        if(send_event.change)
                         {
                             event_supplier_zmq->push_event_loop(
                                 to_do.dev, CHANGE_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, save_except);
                         }
-                        if(send_event.archive == true)
+                        if(send_event.archive)
                         {
                             event_supplier_zmq->push_event_loop(
                                 to_do.dev, ARCHIVE_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, save_except);
                         }
-                        if(send_event.periodic == true)
+                        if(send_event.periodic)
                         {
                             event_supplier_zmq->push_event_loop(to_do.dev,
                                                                 PERIODIC_EVENT,
@@ -1867,7 +1866,7 @@ void PollThread::poll_attr(WorkItem &to_do)
 
                 SendEventType send_event;
 
-                std::map<size_t, Tango::DevFailed *>::iterator ite2 = map_except.find(ctr);
+                auto ite2 = map_except.find(ctr);
                 Tango::DevFailed *tmp_except;
                 if(ite2 == map_except.end())
                 {
@@ -1878,31 +1877,31 @@ void PollThread::poll_attr(WorkItem &to_do)
                     tmp_except = ite2->second;
                 }
 
-                if(event_supplier_nd != NULL)
+                if(event_supplier_nd != nullptr)
                 {
                     send_event = event_supplier_nd->detect_and_push_events(
                         to_do.dev, ad, tmp_except, to_do.name[ctr], before_cmd);
                 }
-                if(event_supplier_zmq != NULL)
+                if(event_supplier_zmq != nullptr)
                 {
-                    if(event_supplier_nd != NULL)
+                    if(event_supplier_nd != nullptr)
                     {
                         std::vector<std::string> f_names;
                         std::vector<double> f_data;
                         std::vector<std::string> f_names_lg;
                         std::vector<long> f_data_lg;
 
-                        if(send_event.change == true)
+                        if(send_event.change)
                         {
                             event_supplier_zmq->push_event_loop(
                                 to_do.dev, CHANGE_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, tmp_except);
                         }
-                        if(send_event.periodic == true)
+                        if(send_event.periodic)
                         {
                             event_supplier_zmq->push_event_loop(
                                 to_do.dev, PERIODIC_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, tmp_except);
                         }
-                        if(send_event.archive == true)
+                        if(send_event.archive)
                         {
                             event_supplier_zmq->push_event_loop(
                                 to_do.dev, ARCHIVE_EVENT, f_names, f_data, f_names_lg, f_data_lg, ad, att, tmp_except);
@@ -1935,7 +1934,7 @@ void PollThread::poll_attr(WorkItem &to_do)
         for(size_t ctr = 0; ctr < nb_obj; ctr++)
         {
             ite = to_do.dev->get_polled_obj_by_type_name(to_do.type, to_do.name[ctr]);
-            if(attr_failed == false)
+            if(!attr_failed)
             {
                 if(nb_obj == 1)
                 {
@@ -1960,10 +1959,10 @@ void PollThread::poll_attr(WorkItem &to_do)
                 {
                     if(idl_vers >= 5)
                     {
-                        std::map<size_t, Tango::DevFailed *>::iterator ite2 = map_except.find(ctr);
+                        auto ite2 = map_except.find(ctr);
                         if(ite2 == map_except.end())
                         {
-                            Tango::AttributeValueList_5 *new_argout_5 = new Tango::AttributeValueList_5(1);
+                            auto *new_argout_5 = new Tango::AttributeValueList_5(1);
                             new_argout_5->length(1);
                             (*new_argout_5)[0].value.union_no_data(true);
                             robb_data((*argout_5)[ctr], (*new_argout_5)[0]);
@@ -1978,10 +1977,10 @@ void PollThread::poll_attr(WorkItem &to_do)
                     }
                     else
                     {
-                        std::map<size_t, Tango::DevFailed *>::iterator ite2 = map_except.find(ctr);
+                        auto ite2 = map_except.find(ctr);
                         if(ite2 == map_except.end())
                         {
-                            Tango::AttributeValueList_4 *new_argout_4 = new Tango::AttributeValueList_4(1);
+                            auto *new_argout_4 = new Tango::AttributeValueList_4(1);
                             new_argout_4->length(1);
                             (*new_argout_4)[0].value.union_no_data(true);
                             robb_data((*argout_4)[ctr], (*new_argout_4)[0]);
@@ -2016,7 +2015,7 @@ void PollThread::poll_attr(WorkItem &to_do)
             }
         }
 
-        if(nb_obj != 1 && attr_failed == false)
+        if(nb_obj != 1 && !attr_failed)
         {
             if(idl_vers >= 5)
             {
@@ -2032,7 +2031,7 @@ void PollThread::poll_attr(WorkItem &to_do)
     }
     catch(Tango::DevFailed &)
     {
-        if(attr_failed == false)
+        if(!attr_failed)
         {
             if(idl_vers >= 5)
             {
@@ -2076,13 +2075,13 @@ void PollThread::eve_heartbeat()
 
     EventSupplier *event_supplier;
     event_supplier = Util::instance()->get_zmq_event_supplier();
-    if((event_supplier != NULL) && (send_heartbeat == true) && (event_supplier->get_one_subscription_cmd() == true))
+    if((event_supplier != nullptr) && (send_heartbeat) && (event_supplier->get_one_subscription_cmd()))
     {
         event_supplier->push_heartbeat_event();
     }
 
     event_supplier = Util::instance()->get_notifd_event_supplier();
-    if((event_supplier != NULL) && (send_heartbeat == true) && (event_supplier->get_one_subscription_cmd() == true))
+    if((event_supplier != nullptr) && (send_heartbeat) && (event_supplier->get_one_subscription_cmd()))
     {
         event_supplier->push_heartbeat_event();
     }
