@@ -60,7 +60,7 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
         // TANGO_LOG << "Event name = " << ev->event << std::endl;
         // TANGO_LOG << "Error flag = " << std::boolalpha << ev->err << std::endl;
 
-        if(ev->err == false)
+        if(!ev->err)
         {
             std::string att_name = ev->attr_name;
 
@@ -95,7 +95,7 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
                                 // create one from the AttributeInfoEx
                                 //
 
-                                FwdAttrConfEventData *ev_fwd = static_cast<FwdAttrConfEventData *>(ev);
+                                auto *ev_fwd = static_cast<FwdAttrConfEventData *>(ev);
                                 AttributeConfig_5 *ptr = const_cast<AttributeConfig_5 *>(ev_fwd->get_fwd_attr_conf());
                                 if(ptr == nullptr)
                                 {
@@ -111,7 +111,7 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
 
                                 conf_list[0].name = ite->second.local_att_name.c_str();
                                 conf_list[0].root_attr_name = ite->first.c_str();
-                                if(ite->second.local_label.empty() == false)
+                                if(!ite->second.local_label.empty())
                                 {
                                     conf_list[0].label = ite->second.local_label.c_str();
                                 }
@@ -152,9 +152,9 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
                                 bool rel_ok = rar->check_root_dev_release(root_dev_name);
 
                                 Device_5Impl *the_dev = static_cast<Device_5Impl *>(ite3->second);
-                                if(rel_ok == true)
+                                if(rel_ok)
                                 {
-                                    if(ite->second.local_label.empty() == false)
+                                    if(!ite->second.local_label.empty())
                                     {
                                         ev->attr_conf->label = ite->second.local_label;
                                     }
@@ -183,8 +183,7 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
                                                    local_att_lower.end(),
                                                    local_att_lower.begin(),
                                                    ::tolower);
-                                    std::vector<std::string>::iterator pos =
-                                        find(poll_attr_list.begin(), poll_attr_list.end(), local_att_lower);
+                                    auto pos = find(poll_attr_list.begin(), poll_attr_list.end(), local_att_lower);
                                     if(pos != poll_attr_list.end())
                                     {
                                         DevVarLongStringArray send;
@@ -212,7 +211,6 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
                                 }
                                 else
                                 {
-                                    std::string root_att_name = att_name.substr(pos + 1);
                                     the_dev->update_wrong_conf_att(att_name, FWD_TOO_OLD_ROOT_DEVICE);
                                     the_dev->set_run_att_conf_loop(true);
                                 }
@@ -284,7 +282,7 @@ void RootAttRegistry::RootAttUserCallBack::push_event(Tango::EventData *ev)
 
         std::string event_name = EVENT_COMPAT_IDL5 + ev->event;
 
-        if(ev->err == true)
+        if(ev->err)
         {
             DevFailed df(ev->errors);
             zes->push_event(dev, event_name, dummy_vs, dummy_vd, dummy_vs, dummy_vl, ad, local_att_name, &df, true);
@@ -349,7 +347,7 @@ void RootAttRegistry::RootAttUserCallBack::push_event(Tango::DataReadyEventData
         EventSupplier::SuppliedEventData ad;
         ::memset(&ad, 0, sizeof(ad));
 
-        if(ev->err == true)
+        if(ev->err)
         {
             DevFailed df(ev->errors);
             zes->push_event(dev, ev->event, dummy_vs, dummy_vd, dummy_vs, dummy_vl, ad, local_att_name, &df, true);
@@ -484,9 +482,9 @@ void RootAttRegistry::RootAttConfCallBack::remove_att(const std::string &root_at
         // corresponding DeviceImpl entry
         //
 
-        if(used_elsewhere == false)
+        if(!used_elsewhere)
         {
-            std::map<std::string, DeviceImpl *>::iterator ite_dp = local_dis.find(local_dev_name);
+            auto ite_dp = local_dis.find(local_dev_name);
             local_dis.erase(ite_dp);
         }
     }
@@ -670,7 +668,7 @@ bool RootAttRegistry::RootAttConfCallBack::is_root_dev_not_started_err()
     std::map<std::string, struct NameFwdAttr>::iterator ite;
     for(ite = map_attrdesc.begin(); ite != map_attrdesc.end(); ++ite)
     {
-        if(ite->second.fwd_attr != NULL)
+        if(ite->second.fwd_attr != nullptr)
         {
             if(ite->second.fwd_attr->get_err_kind() == FWD_ROOT_DEV_NOT_STARTED)
             {
@@ -752,7 +750,7 @@ void RootAttRegistry::add_root_att(const std::string &device_name,
 
     std::string a_name = device_name + '/' + att_name;
     bool already_there = cbp.is_root_att_in_map(a_name);
-    if(already_there == false)
+    if(!already_there)
     {
         cbp.add_att(a_name, local_dev_name, local_att_name, attdesc, dev);
         int event_id;
@@ -767,7 +765,7 @@ void RootAttRegistry::add_root_att(const std::string &device_name,
             if(::strcmp(e.errors[0].reason.in(), API_AttrNotFound) == 0)
             {
                 bool loop = check_loop(device_name, att_name, local_dev_name, local_att_name);
-                if(loop == true)
+                if(loop)
                 {
                     attdesc->set_err_kind(FWD_CONF_LOOP);
                 }
@@ -809,7 +807,7 @@ void RootAttRegistry::add_root_att(const std::string &device_name,
     else
     {
         Tango::Util *tg = Util::instance();
-        if(tg->is_device_restarting(local_dev_name) == false)
+        if(!tg->is_device_restarting(local_dev_name))
         {
             attdesc->set_err_kind(FWD_DOUBLE_USED);
             cbp.update_err_kind(a_name, attdesc->get_err_kind());
@@ -861,7 +859,7 @@ void RootAttRegistry::clear_attrdesc(const std::string &dev_name, const std::str
 void RootAttRegistry::remove_root_att(const std::string &root_dev_name, const std::string &root_att_name)
 {
     std::string full_root_att_name = root_dev_name + '/' + root_att_name;
-    std::map<std::string, DeviceProxy *>::iterator pos = dps.find(root_dev_name);
+    auto pos = dps.find(root_dev_name);
 
     //
     // Unsubscribe from all user events registered on this forwarded attribute (if any)
@@ -896,7 +894,7 @@ void RootAttRegistry::remove_root_att(const std::string &root_dev_name, const st
     // Unsubscribe from the event and if the root device is not used elsewhere, remove its device proxy
     //
 
-    std::map<std::string, int>::iterator ite = map_event_id.find(full_root_att_name);
+    auto ite = map_event_id.find(full_root_att_name);
     if(ite != map_event_id.end())
     {
         if(pos != dps.end())
@@ -1268,7 +1266,7 @@ void RootAttRegistry::unsubscribe_user_event(const std::string &dev_name, const
             }
         }
 
-        if(v_ue.empty() == true)
+        if(v_ue.empty())
         {
             map_event_id_user.erase(pos);
         }
@@ -1291,7 +1289,7 @@ void RootAttRegistry::auto_unsub()
     // Return immediately if there is no user events
     //
 
-    if(map_event_id_user.empty() == true)
+    if(map_event_id_user.empty())
     {
         return;
     }
@@ -1300,7 +1298,7 @@ void RootAttRegistry::auto_unsub()
     // A loop on each events
     //
 
-    time_t now = time(NULL);
+    const time_t now = Tango::get_current_system_datetime();
 
     {
         WriterLock wl(id_user_lock);
@@ -1341,12 +1339,12 @@ void RootAttRegistry::auto_unsub()
                         delta_t = now - att.get_change5_event_sub();
                         break;
 
-                    case PERIODIC_EVENT:
-                        delta_t = now - att.get_periodic5_event_sub();
+                    case ALARM_EVENT:
+                        delta_t = now - att.get_alarm6_event_sub();
                         break;
 
-                    case QUALITY_EVENT:
-                        delta_t = now - att.get_quality_event_sub();
+                    case PERIODIC_EVENT:
+                        delta_t = now - att.get_periodic5_event_sub();
                         break;
 
                     case ARCHIVE_EVENT:
@@ -1367,7 +1365,7 @@ void RootAttRegistry::auto_unsub()
                         break;
 
                     default:
-                        TANGO_THROW_ON_DEFAULT(posi->event_type);
+                        TANGO_ASSERT_ON_DEFAULT(posi->event_type);
                         ;
                     }
                 }
@@ -1393,7 +1391,7 @@ void RootAttRegistry::auto_unsub()
             // Remove entry in map if no more events on this forwarded attribute
             //
 
-            if(ite->second.empty() == true)
+            if(ite->second.empty())
             {
                 map_event_id_user.erase(ite);
             }
@@ -1453,7 +1451,7 @@ bool RootAttRegistry::check_loop(const std::string &device_name,
         //
 
         DbData db_data;
-        db_data.push_back(DbDatum(att_name));
+        db_data.emplace_back(att_name);
 
         if(db_port == tg_port && db_host == tg_host)
         {
@@ -1488,7 +1486,7 @@ bool RootAttRegistry::check_loop(const std::string &device_name,
             // equal, it is a loop!
             //
 
-            if(prop_found == true)
+            if(prop_found)
             {
                 std::transform(new_root_att.begin(), new_root_att.end(), new_root_att.begin(), ::tolower);
                 std::string full_local_att_name = local_dev_name + '/' + local_att_name;
