@@ -68,24 +68,9 @@ namespace Tango
 
 WAttribute::WAttribute(std::vector<AttrProperty> &prop_list, Attr &tmp_attr, const std::string &dev_name, long idx) :
     Attribute(prop_list, tmp_attr, dev_name, idx),
-    long_ptr(NULL),
-    double_ptr(NULL),
-    str_ptr(NULL),
-    float_ptr(NULL),
-    boolean_ptr(NULL),
-    ushort_ptr(NULL),
-    uchar_ptr(NULL),
-    encoded_ptr(NULL),
-    string_allocated(false),
-    memorized(false),
-    memorized_init(false),
-    w_ext(new WAttributeExt),
-    long64_ptr(NULL),
-    ulong_ptr(NULL),
-    ulong64_ptr(NULL),
-    state_ptr(NULL),
-    uswv(false),
-    mem_write_failed(false)
+
+    w_ext(new WAttributeExt)
+
 {
     //
     // Init some data
@@ -146,7 +131,7 @@ WAttribute::WAttribute(std::vector<AttrProperty> &prop_list, Attr &tmp_attr, con
     set_memorized(tmp_attr.get_memorized());
     set_memorized_init(tmp_attr.get_memorized_init());
 
-    if(is_memorized() == true)
+    if(is_memorized())
     {
         try
         {
@@ -480,8 +465,12 @@ void WAttribute::rollback()
         dev_state_val = old_dev_state_val;
         break;
 
+    case Tango::DEV_ENCODED:
+        TANGO_THROW_EXCEPTION(API_NotSupportedFeature, "This is a not supported call in case of DevEncoded attribute");
+        break;
+
     default:
-        TANGO_THROW_ON_DEFAULT(data_type);
+        TANGO_ASSERT_ON_DEFAULT(data_type);
     }
 }
 
@@ -556,8 +545,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                short delta = (data_format == Tango::SCALAR) ? short_array_val[0] - tmp_sh[0]
-                                                             : short_array_val[i] - (*value.sh_seq)[i];
+                short delta = short_array_val[i] - (*value.sh_seq)[i];
                 if(abs(delta) >= delta_val.sh)
                 {
                     quality = Tango::ATTR_ALARM;
@@ -574,8 +562,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                DevLong delta = (data_format == Tango::SCALAR) ? long_array_val[0] - tmp_lo[0]
-                                                               : long_array_val[i] - (*value.lg_seq)[i];
+                DevLong delta = long_array_val[i] - (*value.lg_seq)[i];
                 if(abs(delta) >= delta_val.lg)
                 {
                     quality = Tango::ATTR_ALARM;
@@ -592,8 +579,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                DevLong64 delta = (data_format == Tango::SCALAR) ? long64_array_val[0] - get_tmp_scalar_long64()[0]
-                                                                 : long64_array_val[i] - (*value.lg64_seq)[i];
+                DevLong64 delta = long64_array_val[i] - (*value.lg64_seq)[i];
 
                 DevLong64 abs_delta;
                 if(delta < 0)
@@ -624,10 +610,10 @@ bool WAttribute::check_rds_alarm()
                 // check for NAN values
                 if(data_format == Tango::SCALAR)
                 {
-                    if(std::isnan(double_array_val[0]) || std::isnan(tmp_db[0]))
+                    if(std::isnan(double_array_val[0]) || std::isnan((*value.db_seq)[0]))
                     {
                         // send an alarm if only read or set value are NAN
-                        if(!(std::isnan(double_array_val[0]) && std::isnan(tmp_db[0])))
+                        if(!(std::isnan(double_array_val[0]) && std::isnan((*value.db_seq)[0])))
                         {
                             quality = Tango::ATTR_ALARM;
                             alarm.set(rds);
@@ -651,8 +637,7 @@ bool WAttribute::check_rds_alarm()
                     }
                 }
 
-                double delta = (data_format == Tango::SCALAR) ? double_array_val[0] - tmp_db[0]
-                                                              : double_array_val[i] - (*value.db_seq)[i];
+                double delta = double_array_val[i] - (*value.db_seq)[i];
                 if(fabs(delta) >= delta_val.db)
                 {
                     quality = Tango::ATTR_ALARM;
@@ -672,10 +657,10 @@ bool WAttribute::check_rds_alarm()
                 // check for NAN values
                 if(data_format == Tango::SCALAR)
                 {
-                    if(std::isnan(float_array_val[0]) || std::isnan(tmp_fl[0]))
+                    if(std::isnan(float_array_val[0]) || std::isnan((*value.fl_seq)[0]))
                     {
                         // send an alarm if only read or set value are NAN
-                        if(!(std::isnan(float_array_val[0]) && std::isnan(tmp_fl[0])))
+                        if(!(std::isnan(float_array_val[0]) && std::isnan((*value.fl_seq)[0])))
                         {
                             quality = Tango::ATTR_ALARM;
                             alarm.set(rds);
@@ -699,8 +684,7 @@ bool WAttribute::check_rds_alarm()
                     }
                 }
 
-                float delta = (data_format == Tango::SCALAR) ? float_array_val[0] - tmp_fl[0]
-                                                             : float_array_val[i] - (*value.fl_seq)[i];
+                float delta = float_array_val[i] - (*value.fl_seq)[i];
                 double delta_d = (double) delta;
                 if(((float) fabs(delta_d)) >= delta_val.fl)
                 {
@@ -718,8 +702,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                unsigned short delta = (data_format == Tango::SCALAR) ? ushort_array_val[0] - tmp_ush[0]
-                                                                      : ushort_array_val[i] - (*value.ush_seq)[i];
+                unsigned short delta = ushort_array_val[i] - (*value.ush_seq)[i];
                 if(delta >= delta_val.ush)
                 {
                     quality = Tango::ATTR_ALARM;
@@ -736,8 +719,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                unsigned char delta = (data_format == Tango::SCALAR) ? uchar_array_val[0] - tmp_cha[0]
-                                                                     : uchar_array_val[i] - (*value.cha_seq)[i];
+                unsigned char delta = uchar_array_val[i] - (*value.cha_seq)[i];
                 if(delta >= delta_val.uch)
                 {
                     quality = Tango::ATTR_ALARM;
@@ -754,8 +736,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                DevLong delta = (data_format == Tango::SCALAR) ? ulong_array_val[0] - get_tmp_scalar_ulong()[0]
-                                                               : ulong_array_val[i] - (*value.ulg_seq)[i];
+                DevLong delta = ulong_array_val[i] - (*value.ulg_seq)[i];
                 if((unsigned int) abs(delta) >= delta_val.ulg)
                 {
                     quality = Tango::ATTR_ALARM;
@@ -772,8 +753,7 @@ bool WAttribute::check_rds_alarm()
             nb_data = (nb_written > nb_read) ? nb_read : nb_written;
             for(i = 0; i < nb_data; i++)
             {
-                DevLong64 delta = (data_format == Tango::SCALAR) ? ulong64_array_val[0] - get_tmp_scalar_ulong64()[0]
-                                                                 : ulong64_array_val[i] - (*value.ulg64_seq)[i];
+                DevLong64 delta = ulong64_array_val[i] - (*value.ulg64_seq)[i];
 
                 DevULong64 abs_delta;
                 if(delta < 0)
@@ -900,7 +880,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
     switch(data_type)
     {
     case Tango::DEV_SHORT:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> sh_val;
@@ -951,7 +931,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_LONG:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> lg_val;
@@ -1002,7 +982,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_LONG64:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> lg64_val;
@@ -1053,7 +1033,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_DOUBLE:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> db_val;
@@ -1104,7 +1084,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_FLOAT:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> fl_val;
@@ -1155,7 +1135,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_USHORT:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> ush_val;
@@ -1206,7 +1186,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_UCHAR:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> uch_val;
@@ -1257,7 +1237,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_ULONG:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> ulg_val;
@@ -1308,7 +1288,7 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         break;
 
     case Tango::DEV_ULONG64:
-        if(svr_starting == true)
+        if(svr_starting)
         {
             ss << mem_value;
             ss >> ulg64_val;
@@ -1358,152 +1338,25 @@ bool WAttribute::mem_value_below_above(MinMaxValueCheck check_type, std::string
         }
         break;
 
+    case Tango::DEV_ENUM:
+        [[fallthrough]];
+    case Tango::DEV_STRING:
+        [[fallthrough]];
+    case Tango::DEV_BOOLEAN:
+        [[fallthrough]];
+    case Tango::DEV_STATE:
+    {
+        TangoSys_OMemStream msg;
+        msg << "This is a not supported call in case of " << data_type_to_string(data_type) << " attribute";
+        TANGO_THROW_EXCEPTION(API_NotSupportedFeature, msg.str().c_str());
+    }
+    break;
+
     default:
-        TANGO_THROW_ON_DEFAULT(data_type);
+        TANGO_ASSERT_ON_DEFAULT(data_type);
     }
 
     return ret;
 }
 
-namespace detail
-{
-
-template <class T>
-bool try_type(const CORBA::TypeCode_ptr type, std::string &result)
-{
-    if(type->equivalent(tango_type_traits<T>::corba_type_code()))
-    {
-        result = data_type_to_string(tango_type_traits<T>::type_value());
-        return true;
-    }
-
-    return false;
-}
-
-std::string corba_any_to_type_name(const CORBA::Any &any)
-{
-    CORBA::TypeCode_ptr type = any.type();
-
-    std::string result;
-    if(try_type<Tango::DevVarShortArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarUShortArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarLongArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarULongArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarLong64Array>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarULong64Array>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarDoubleArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarStringArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarUCharArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarFloatArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarBooleanArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarStateArray>(type, result))
-    {
-        goto end;
-    }
-    if(try_type<Tango::DevVarEncodedArray>(type, result))
-    {
-        goto end;
-    }
-
-    {
-        TangoSys_OMemStream oss;
-        oss << "UnknownCorbaAny<kind=" << type->kind();
-
-        // `TypeCode`s for basic data types do not have a `name()`, as they can
-        // be distinguished with only their `kind()`.
-
-        try
-        {
-            const char *name = type->name();
-            oss << ",name=" << name;
-        }
-        catch(const CORBA::TypeCode::BadKind &)
-        {
-            /* ignore */
-        }
-
-        oss << ">" << std::ends;
-        result = oss.str();
-    }
-
-end:
-    CORBA::release(type);
-    return result;
-}
-
-std::string attr_union_dtype_to_type_name(Tango::AttributeDataType d)
-{
-    switch(d)
-    {
-    case Tango::ATT_BOOL:
-        return data_type_to_string(DEVVAR_BOOLEANARRAY);
-    case Tango::ATT_SHORT:
-        return data_type_to_string(DEVVAR_SHORTARRAY);
-    case Tango::ATT_LONG:
-        return data_type_to_string(DEVVAR_LONGARRAY);
-    case Tango::ATT_LONG64:
-        return data_type_to_string(DEVVAR_LONG64ARRAY);
-    case Tango::ATT_FLOAT:
-        return data_type_to_string(DEVVAR_FLOATARRAY);
-    case Tango::ATT_DOUBLE:
-        return data_type_to_string(DEVVAR_DOUBLEARRAY);
-    case Tango::ATT_UCHAR:
-        return data_type_to_string(DEVVAR_CHARARRAY);
-    case Tango::ATT_USHORT:
-        return data_type_to_string(DEVVAR_USHORTARRAY);
-    case Tango::ATT_ULONG:
-        return data_type_to_string(DEVVAR_ULONGARRAY);
-    case Tango::ATT_ULONG64:
-        return data_type_to_string(DEVVAR_ULONG64ARRAY);
-    case Tango::ATT_STRING:
-        return data_type_to_string(DEVVAR_STRINGARRAY);
-    case Tango::ATT_STATE:
-        return data_type_to_string(DEVVAR_STATEARRAY);
-    case Tango::ATT_ENCODED:
-        return data_type_to_string(DEVVAR_ENCODEDARRAY);
-    case Tango::DEVICE_STATE: /* fallthrough */
-    case Tango::ATT_NO_DATA:  /* fallthrough */
-    default:
-    {
-        TangoSys_OMemStream oss;
-        oss << "UnknownAttrValUnion<dtype=" << d << ">";
-        return oss.str();
-    }
-    }
-}
-
-} // namespace detail
 } // namespace Tango
