@@ -46,7 +46,6 @@
   #include <netdb.h>
   #include <sys/socket.h>
   #include <netinet/in.h>
-  #include <arpa/inet.h>
 #endif /* _TG_WINDOWS_ */
 
 using namespace CORBA;
@@ -60,7 +59,7 @@ static const char *TangoHeartbeatPortEnvVar = "TANGO_ZMQ_HEARTBEAT_PORT";
 // check and use environment variables for zmq ports
 static void get_zmq_port_from_envvar(const char *, std::string &);
 
-ZmqEventSupplier *ZmqEventSupplier::_instance = NULL;
+ZmqEventSupplier *ZmqEventSupplier::_instance = nullptr;
 
 /************************************************************************/
 /*                                                                           */
@@ -102,11 +101,8 @@ void get_zmq_port_from_envvar(const char *zmq_port_env_var, std::string &endpoin
 
 ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
     EventSupplier(tg),
-    zmq_context(1),
-    event_pub_sock(NULL),
-    name_specified(false),
-    double_send(0),
-    double_send_heartbeat(false)
+    zmq_context(1)
+
 {
     _instance = this;
 
@@ -157,7 +153,7 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
     std::string canon_name;
     std::string specified_ip;
 
-    if(specified_name == true)
+    if(specified_name)
     {
         auto results = detail::resolve_hostname_address(specified_addr);
         specified_ip = results.front();
@@ -173,11 +169,11 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
         canon_name = h_name.substr(0, pos);
     }
 
-    if(specified_addr.empty() == false && (specified_addr != "localhost"))
+    if(!specified_addr.empty() && (specified_addr != "localhost"))
     {
         heartbeat_endpoint = heartbeat_endpoint + specified_ip + ':';
         ip_specified = true;
-        if(specified_name == true)
+        if(specified_name)
         {
             name_specified = true;
         }
@@ -202,7 +198,7 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
     catch(...)
     {
         delete heartbeat_pub_sock;
-        heartbeat_pub_sock = NULL;
+        heartbeat_pub_sock = nullptr;
         throw;
     }
 
@@ -212,7 +208,7 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
     // If needed, replace * by host IP address in endpoint string
     //
 
-    if(specified_ip.empty() == true)
+    if(specified_ip.empty())
     {
         ApiUtil *au = ApiUtil::instance();
         std::vector<std::string> adrs;
@@ -232,7 +228,7 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
                     continue;
                 }
 
-                if(first_set == false)
+                if(!first_set)
                 {
                     heartbeat_endpoint.replace(pos, 1, adrs[i]);
                     host_ip = adrs[i];
@@ -251,7 +247,7 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
             host_ip = adrs[0];
         }
     }
-    else if(specified_name == true)
+    else if(specified_name)
     {
         std::string::size_type start = heartbeat_endpoint.find("//");
         start = start + 2;
@@ -320,7 +316,7 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
             }
         }
 
-        if(db_ds == false)
+        if(!db_ds)
         {
             heartbeat_event_name = heartbeat_event_name + MODIFIER_DBASE_NO;
         }
@@ -338,7 +334,7 @@ ZmqEventSupplier *ZmqEventSupplier::create(Util *tg)
     // Does the ZmqEventSupplier singleton exist already ? if so simply return it
     //
 
-    if(_instance != NULL)
+    if(_instance != nullptr)
     {
         return _instance;
     }
@@ -373,7 +369,7 @@ ZmqEventSupplier::~ZmqEventSupplier()
     delete heartbeat_pub_sock;
     delete event_pub_sock;
 
-    if(event_mcast.empty() == false)
+    if(!event_mcast.empty())
     {
         std::map<std::string, McastSocketPub>::iterator ite, ite_stop;
         ite = event_mcast.begin();
@@ -423,7 +419,7 @@ void ZmqEventSupplier::tango_bind(zmq::socket_t *sock, std::string &endpoint)
     }
     catch(...)
     {
-        TANGO_THROW_API_EXCEPTION(EventSystemExcept, API_ZmqInitFailed, "Can't bind the ZMQ socket!");
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_ZmqInitFailed, "Can't bind the ZMQ socket!");
     }
 }
 
@@ -446,7 +442,7 @@ unsigned char ZmqEventSupplier::test_endian()
 {
     int test_var = 1;
     unsigned char *cptr = (unsigned char *) &test_var;
-    return (!(cptr[0] == 0));
+    return static_cast<unsigned char>(!(cptr[0] == 0));
 }
 
 //+-----------------------------------------------------------------------------------------------------------------
@@ -461,7 +457,7 @@ unsigned char ZmqEventSupplier::test_endian()
 
 void ZmqEventSupplier::create_event_socket()
 {
-    if(event_pub_sock == NULL)
+    if(event_pub_sock == nullptr)
     {
         omni_mutex_lock oml(event_mutex);
         //
@@ -485,7 +481,7 @@ void ZmqEventSupplier::create_event_socket()
 
         event_endpoint = "tcp://";
 
-        if(ip_specified == true)
+        if(ip_specified)
         {
             event_endpoint = event_endpoint + user_ip + ':';
         }
@@ -523,7 +519,7 @@ void ZmqEventSupplier::create_event_socket()
         catch(...)
         {
             delete event_pub_sock;
-            event_pub_sock = NULL;
+            event_pub_sock = nullptr;
             throw;
         }
 
@@ -532,10 +528,10 @@ void ZmqEventSupplier::create_event_socket()
         //
         auto port_str = detail::get_port_from_endpoint(event_endpoint);
 
-        if(ip_specified == false)
+        if(!ip_specified)
         {
             event_endpoint.replace(6, 1, host_ip);
-            if(alt_ip.empty() == false)
+            if(!alt_ip.empty())
             {
                 for(size_t loop = 0; loop < alt_ip.size(); loop++)
                 {
@@ -543,7 +539,7 @@ void ZmqEventSupplier::create_event_socket()
                 }
             }
         }
-        else if(name_specified == true)
+        else if(name_specified)
         {
             std::string::size_type start = event_endpoint.find("//");
             start = start + 2;
@@ -589,9 +585,9 @@ void ZmqEventSupplier::create_mcast_event_socket(const std::string &mcast_data,
 
     if((ite = event_mcast.find(ev_name)) != event_mcast.end())
     {
-        if(local_call == true)
+        if(local_call)
         {
-            if(ite->second.local_client == false)
+            if(!ite->second.local_client)
             {
                 create_event_socket();
 
@@ -600,7 +596,7 @@ void ZmqEventSupplier::create_mcast_event_socket(const std::string &mcast_data,
         }
         else
         {
-            if(ite->second.local_client == true && ite->second.pub_socket == NULL)
+            if(ite->second.local_client && ite->second.pub_socket == nullptr)
             {
                 create_mcast_socket(mcast_data, rate, ite->second);
             }
@@ -616,11 +612,11 @@ void ZmqEventSupplier::create_mcast_event_socket(const std::string &mcast_data,
         McastSocketPub ms;
         ms.double_send = true;
 
-        if(local_call == true)
+        if(local_call)
         {
             create_event_socket();
 
-            ms.pub_socket = NULL;
+            ms.pub_socket = nullptr;
             ms.local_client = true;
         }
         else
@@ -634,7 +630,7 @@ void ZmqEventSupplier::create_mcast_event_socket(const std::string &mcast_data,
         // Insert element in map
         //
 
-        if(event_mcast.insert(make_pair(ev_name, ms)).second == false)
+        if(!event_mcast.insert(make_pair(ev_name, ms)).second)
         {
             TangoSys_OMemStream o;
             o << "Can't insert multicast transport parameter for event ";
@@ -671,7 +667,7 @@ void ZmqEventSupplier::create_mcast_socket(const std::string &mcast_data, int ra
     ms.pub_socket = new zmq::socket_t(zmq_context, ZMQ_PUB);
 
     ms.endpoint = MCAST_PROT;
-    if(ip_specified == true)
+    if(ip_specified)
     {
         ms.endpoint = ms.endpoint + user_ip + ';';
     }
@@ -808,7 +804,7 @@ void ZmqEventSupplier::init_event_cptr(const std::string &event_name)
     pos = event_cptr.find(event_name);
     if(pos == event_cptr.end())
     {
-        if(event_cptr.insert(make_pair(event_name, 1)).second == false)
+        if(!event_cptr.insert(make_pair(event_name, 1)).second)
         {
             TangoSys_OMemStream o;
             o << "Can't insert event counter for event ";
@@ -841,7 +837,7 @@ void ZmqEventSupplier::push_heartbeat_event()
 
     Tango::Util *tg = Tango::Util::instance();
     DServer *adm_dev = tg->get_dserver_device();
-    now_time = time(NULL);
+    now_time = Tango::get_current_system_datetime();
     delta_time = now_time - adm_dev->last_heartbeat_zmq;
     TANGO_LOG_DEBUG << "ZmqEventSupplier::push_heartbeat_event(): delta time since last heartbeat " << delta_time
                     << std::endl;
@@ -861,7 +857,7 @@ void ZmqEventSupplier::push_heartbeat_event()
                         << heartbeat_event_name << std::endl;
         TANGO_LOG_DEBUG << "ZmqEventSupplier::push_heartbeat_event(): delta _time " << delta_time << std::endl;
 
-        if(double_send_heartbeat == true)
+        if(double_send_heartbeat)
         {
             nb_event = 2;
             double_send_heartbeat = false;
@@ -889,12 +885,12 @@ void ZmqEventSupplier::push_heartbeat_event()
 
                 if(nb_event == 1)
                 {
-                    if(omniORB::trace(20))
+                    if(omniORB::trace(20) != 0)
                     {
                         omniORB::logger log;
                         log << "ZMQ: Pushing some data" << '\n';
                     }
-                    if(omniORB::trace(30))
+                    if(omniORB::trace(30) != 0)
                     {
                         {
                             omniORB::logger log;
@@ -959,11 +955,11 @@ void ZmqEventSupplier::push_heartbeat_event()
             catch(...)
             {
                 TANGO_LOG_DEBUG << "ZmqEventSupplier::push_heartbeat_event() failed !\n";
-                if(endian_mess_sent == true)
+                if(endian_mess_sent)
                 {
                     endian_mess_heartbeat.copy(endian_mess_heartbeat_2);
                 }
-                if(call_mess_sent == true)
+                if(call_mess_sent)
                 {
                     heartbeat_call_mess.copy(heartbeat_call_mess_2);
                 }
@@ -1036,7 +1032,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
                                   DevFailed *except,
                                   bool inc_cptr)
 {
-    if(device_impl == NULL)
+    if(device_impl == nullptr)
     {
         return;
     }
@@ -1053,7 +1049,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
     //
 
     omni_thread *th_id = omni_thread::self();
-    if(th_id == NULL)
+    if(th_id == nullptr)
     {
         th_id = omni_thread::create_dummy();
     }
@@ -1117,7 +1113,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
     else
     {
         bool print = false;
-        if(intr_change == false && pipe_event == false)
+        if(!intr_change && !pipe_event)
         {
             Attribute &att = device_impl->get_device_attr()->get_attr_by_name(obj_name.c_str());
 
@@ -1167,8 +1163,15 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
                     print = true;
                 }
             }
+            else if(local_event_type == "alarm")
+            {
+                if(att.event_alarm6_subscription != 0)
+                {
+                    print = true;
+                }
+            }
         }
-        else if(pipe_event == true)
+        else if(pipe_event)
         {
             Pipe &pi =
                 device_impl->get_device_class()->get_pipe_by_name(obj_name.c_str(), device_impl->get_name_lower());
@@ -1185,7 +1188,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
             }
         }
 
-        if(print == true)
+        if(print)
         {
             TANGO_LOG_DEBUG << "-----> Can't find event counter for event " << event_name << " in map!!!!!!!!!!"
                             << std::endl;
@@ -1194,14 +1197,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
 
     ZmqCallInfo event_call;
     event_call.version = ZMQ_EVENT_PROT_VERSION;
-    if(except == NULL)
-    {
-        event_call.call_is_except = false;
-    }
-    else
-    {
-        event_call.call_is_except = true;
-    }
+    event_call.call_is_except = except != nullptr;
     event_call.ctr = ev_ctr;
 
     cdrMemoryStream event_call_cdr;
@@ -1220,7 +1216,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
     //
     std::future<void> large_message_future;
 
-    if(ev_value.zmq_mess != NULL)
+    if(ev_value.zmq_mess != nullptr)
     {
         //
         // It's a forwarded attribute, therefore, use the already marshalled message
@@ -1243,17 +1239,17 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
         padding >>= data_call_cdr;
         padding >>= data_call_cdr;
 
-        if(except == NULL)
+        if(except == nullptr)
         {
-            if(ev_value.attr_val != NULL)
+            if(ev_value.attr_val != nullptr)
             {
                 *(ev_value.attr_val) >>= data_call_cdr;
             }
-            else if(ev_value.attr_val_3 != NULL)
+            else if(ev_value.attr_val_3 != nullptr)
             {
                 *(ev_value.attr_val_3) >>= data_call_cdr;
             }
-            else if(ev_value.attr_val_4 != NULL)
+            else if(ev_value.attr_val_4 != nullptr)
             {
                 //
                 // Get number of data exchanged by this event. If this value is greater than a threshold, set a flag
@@ -1290,7 +1286,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
                     }
                 }
             }
-            else if(ev_value.attr_val_5 != NULL)
+            else if(ev_value.attr_val_5 != nullptr)
             {
                 //
                 // Get number of data exchanged by this event. If this value is greater than a threshold, set a flag
@@ -1327,23 +1323,23 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
                     }
                 }
             }
-            else if(ev_value.attr_conf_2 != NULL)
+            else if(ev_value.attr_conf_2 != nullptr)
             {
                 *(ev_value.attr_conf_2) >>= data_call_cdr;
             }
-            else if(ev_value.attr_conf_3 != NULL)
+            else if(ev_value.attr_conf_3 != nullptr)
             {
                 *(ev_value.attr_conf_3) >>= data_call_cdr;
             }
-            else if(ev_value.attr_conf_5 != NULL)
+            else if(ev_value.attr_conf_5 != nullptr)
             {
                 *(ev_value.attr_conf_5) >>= data_call_cdr;
             }
-            else if(ev_value.attr_dat_ready != NULL)
+            else if(ev_value.attr_dat_ready != nullptr)
             {
                 *(ev_value.attr_dat_ready) >>= data_call_cdr;
             }
-            else if(ev_value.pipe_val != NULL)
+            else if(ev_value.pipe_val != nullptr)
             {
                 size_t nb_data = get_blob_data_nb(ev_value.pipe_val->data_blob.blob_data);
                 if(nb_data >= LARGE_DATA_THRESHOLD)
@@ -1363,7 +1359,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
             except->errors >>= data_call_cdr;
         }
 
-        if(pipe_event == false)
+        if(!pipe_event)
         {
             mess_size = data_call_cdr.bufSize() - sizeof(CORBA::Long);
             mess_ptr = (char *) data_call_cdr.bufPtr() + sizeof(CORBA::Long);
@@ -1379,7 +1375,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
         // zmq message with no-copy option
         //
 
-        if(large_data == true)
+        if(large_data)
         {
             std::promise<void> *large_message_promise = new std::promise<void>();
             large_message_future = large_message_promise->get_future();
@@ -1407,12 +1403,12 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
         // For debug and logging purposes
         //
 
-        if(omniORB::trace(20))
+        if(omniORB::trace(20) != 0)
         {
             omniORB::logger log;
             log << "ZMQ: Pushing some data" << '\n';
         }
-        if(omniORB::trace(30))
+        if(omniORB::trace(30) != 0)
         {
             {
                 omniORB::logger log;
@@ -1453,28 +1449,28 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
         zmq::message_t *data_mess_ptr = &data_mess;
 
         std::map<std::string, McastSocketPub>::iterator mcast_ite;
-        std::map<std::string, McastSocketPub>::iterator mcast_ite_end = event_mcast.end();
+        auto mcast_ite_end = event_mcast.end();
 
         int local_double_send = double_send;
         bool mcast_event = false;
 
-        if(event_mcast.empty() == false)
+        if(!event_mcast.empty())
         {
             if((mcast_ite = event_mcast.find(event_name)) != mcast_ite_end)
             {
-                if(mcast_ite->second.local_client == false)
+                if(!mcast_ite->second.local_client)
                 {
                     pub = mcast_ite->second.pub_socket;
                 }
                 else
                 {
-                    if(mcast_ite->second.pub_socket != NULL)
+                    if(mcast_ite->second.pub_socket != nullptr)
                     {
                         send_nb = 2;
                         pub = mcast_ite->second.pub_socket;
                     }
                 }
-                if(mcast_ite->second.double_send == true)
+                if(mcast_ite->second.double_send)
                 {
                     local_double_send++;
                 }
@@ -1486,7 +1482,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
         if(local_double_send > 0)
         {
             send_nb = 2;
-            if(mcast_event == false)
+            if(!mcast_event)
             {
                 double_send--;
             }
@@ -1546,13 +1542,13 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
             send_nb--;
             if(send_nb == 1)
             {
-                if((event_mcast.empty() == false) && (mcast_ite != mcast_ite_end))
+                if((!event_mcast.empty()) && (mcast_ite != mcast_ite_end))
                 {
                     //
                     // Case of multicast socket with a local client. Send the event also on the local socket
                     //
 
-                    if(mcast_ite->second.local_client == true)
+                    if(mcast_ite->second.local_client)
                     {
                         zmq::socket_t *old_pub = pub;
                         pub = event_pub_sock;
@@ -1595,7 +1591,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
         // Increment event counter if required
         //
 
-        if(ev_cptr_ite != event_cptr.end() && inc_cptr == true)
+        if(ev_cptr_ite != event_cptr.end() && inc_cptr)
         {
             ev_cptr_ite->second++;
         }
@@ -1617,7 +1613,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
     catch(...)
     {
         TANGO_LOG_DEBUG << "ZmqEventSupplier::push_event() failed !!!!!!!!!!!\n";
-        if(endian_mess_sent == true)
+        if(endian_mess_sent)
         {
             endian_mess.copy(endian_mess_2);
         }
@@ -1652,7 +1648,7 @@ std::string ZmqEventSupplier::create_full_event_name(DeviceImpl *device_impl,
     }
 
     full_event_name = full_event_name + device_impl->get_name_lower();
-    if(intr_change == false)
+    if(!intr_change)
     {
         full_event_name = full_event_name + '/' + obj_name_lower;
     }
@@ -1683,7 +1679,7 @@ bool ZmqEventSupplier::update_connected_client(client_addr *cl)
     // Immediately return if client identification not possible. (Very old client....)
     //
 
-    if(cl == NULL)
+    if(cl == nullptr)
     {
         return ret;
     }
@@ -1769,16 +1765,20 @@ void ZmqEventSupplier::push_event_loop(DeviceImpl *device_impl,
         struct SuppliedEventData sent_value;
         ::memset(&sent_value, 0, sizeof(sent_value));
 
-        if(*ite == 5)
+        // We only need the IDL5 compatibility prefix for event types that
+        // existed before IDL5 was released, i.e. not for ALARM_EVENT.
+
+        if(*ite >= 5 && event_type != ALARM_EVENT)
         {
             ev_name = EVENT_COMPAT_IDL5 + ev_name;
             name_changed = true;
         }
 
-        if(except == NULL)
+        if(except == nullptr)
         {
             switch(*ite)
             {
+            case 6:
             case 5:
             {
                 convert_att_event_to_5(attr_value, sent_value, need_free, att);
@@ -1811,17 +1811,17 @@ void ZmqEventSupplier::push_event_loop(DeviceImpl *device_impl,
                    inc_ctr);
 
         inc_ctr = false;
-        if(need_free == true)
+        if(need_free)
         {
-            if(sent_value.attr_val_5 != NULL)
+            if(sent_value.attr_val_5 != nullptr)
             {
                 delete sent_value.attr_val_5;
             }
-            else if(sent_value.attr_val_4 != NULL)
+            else if(sent_value.attr_val_4 != nullptr)
             {
                 delete sent_value.attr_val_4;
             }
-            else if(sent_value.attr_val_3 != NULL)
+            else if(sent_value.attr_val_3 != nullptr)
             {
                 delete sent_value.attr_val_3;
             }
@@ -1830,7 +1830,7 @@ void ZmqEventSupplier::push_event_loop(DeviceImpl *device_impl,
                 delete sent_value.attr_val;
             }
         }
-        if(name_changed == true)
+        if(name_changed)
         {
             ev_name = EventName[event_type];
         }
@@ -1989,8 +1989,15 @@ size_t ZmqEventSupplier::get_data_elt_data_nb(DevPipeDataElt &dvde)
         }
         break;
 
+        case DEVICE_STATE:
+            [[fallthrough]];
+        case ATT_NO_DATA:
+            TANGO_THROW_EXCEPTION(API_PipeWrongArg,
+                                  "Unsupported data type in data element! (ATT_NO_DATA, DEVICE_STATE)");
+            break;
+
         default:
-            TANGO_THROW_ON_DEFAULT(dvde.value._d());
+            TANGO_ASSERT_ON_DEFAULT(dvde.value._d());
         }
     }
 
