@@ -1,3 +1,5 @@
+// NOLINTBEGIN(*)
+
 // BUG Report:
 // a change of the attribute configuration setting to "Not specified"
 // is lost if a DevRestart or ServerRestart is done.
@@ -14,7 +16,7 @@
 //
 // contact: georg.kasper@frm2.tum.de
 
-#include "common.h"
+#include "old_common.h"
 
 const char *const notset = "Not specified";
 
@@ -276,3 +278,5 @@ void reset_to_default(Tango::AttributeInfoEx &ai, string &att_name)
 }
 
 // eof
+
+// NOLINTEND(*)
