@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 class EventCallBack : public Tango::CallBack
 {
@@ -62,7 +64,7 @@ int main(int argc, char **argv)
     }
 
     std::string device_name = argv[1];
-    long sleeping_time = atol(argv[2]);
+    auto sleeping_time = parse_as<long>(argv[2]);
 
     try
     {
@@ -120,3 +122,5 @@ int main(int argc, char **argv)
 
     return 0;
 }
+
+// NOLINTEND(*)
