@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
@@ -11,7 +13,7 @@ int main(int argc, char **argv)
     }
 
     string device_name = argv[1];
-    int loop = atoi(argv[2]);
+    auto loop = parse_as<int>(argv[2]);
 
     try
     {
@@ -1223,3 +1225,5 @@ int main(int argc, char **argv)
 
     return 0;
 }
+
+// NOLINTEND(*)
