@@ -1,18 +1,21 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
     DeviceProxy *device;
 
-    if(argc != 4)
+    if(argc != 5)
     {
-        TEST_LOG << "usage: copy_devproxy <device1> <device2> <device3>" << endl;
+        TEST_LOG << "usage: copy_devproxy <device1> <device2> <device3> <idlver>" << endl;
         exit(-1);
     }
 
     string device1_name(argv[1]);
     string device2_name(argv[2]);
     string device3_name(argv[3]);
+    int idlver = parse_as<int>(argv[4]);
 
     try
     {
@@ -34,7 +37,7 @@ int main(int argc, char **argv)
 
         assert(dev2.name() == device1_name);
 #ifndef COMPAT
-        assert(dev2.get_idl_version() == 5);
+        assert(dev2.get_idl_version() == idlver);
 #endif
     }
     catch(Tango::DevFailed &e)
@@ -54,7 +57,7 @@ int main(int argc, char **argv)
 
     assert(dev3.name() == device1_name);
 #ifndef COMPAT
-    assert(dev3.get_idl_version() == 5);
+    assert(dev3.get_idl_version() == idlver);
 #endif
 
     TEST_LOG << "   Assignement operator --> OK" << endl;
@@ -62,3 +65,5 @@ int main(int argc, char **argv)
     delete device;
     return 0;
 }
+
+// NOLINTEND(*)
