@@ -1,5 +1,4 @@
-#ifndef AlwaysHookTestSuite_h
-#define AlwaysHookTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "compare_test.h"
 #include "cxx_common.h"
@@ -28,8 +27,8 @@ class AlwaysHookTestSuite : public CxxTest::TestSuite
         dserver_name = "dserver/" + CxxTest::TangoPrinter::get_param("fulldsname");
         outpath = CxxTest::TangoPrinter::get_param("outpath");
         refpath = CxxTest::TangoPrinter::get_param("refpath");
-        loglevel = atoi(CxxTest::TangoPrinter::get_param("loglevel").c_str());
-        dsloglevel = atoi(CxxTest::TangoPrinter::get_param("dsloglevel").c_str());
+        TS_ASSERT_THROWS_NOTHING(loglevel = parse_as<int>(CxxTest::TangoPrinter::get_param("loglevel")));
+        TS_ASSERT_THROWS_NOTHING(dsloglevel = parse_as<int>(CxxTest::TangoPrinter::get_param("dsloglevel")));
 
         CxxTest::TangoPrinter::validate_args();
 
@@ -55,7 +54,7 @@ class AlwaysHookTestSuite : public CxxTest::TestSuite
         //
 
         ref_file = refpath + file_name;
-        out_file = outpath + file_name;
+        out_file = CmpTst::CompareTest::make_filename_unique(outpath + file_name);
         CmpTst::CompareTest::clean_on_startup(ref_file, out_file);
     }
 
@@ -216,6 +215,7 @@ class AlwaysHookTestSuite : public CxxTest::TestSuite
             map<string, string> key_val_map;
             key_val_map["DSERVER"] = dserver_name;
             key_val_map["DEVICE1"] = device1_name;
+            key_val_map["FILE"] = out_file;
             CmpTst::CompareTest::ref_replace_keywords(ref_file, key_val_map);
 
             map<string, string> prefix_num_map;
@@ -239,4 +239,5 @@ class AlwaysHookTestSuite : public CxxTest::TestSuite
         }
     }
 };
-#endif // AlwaysHookTestSuite_h
+
+// NOLINTEND(*)
