@@ -1,5 +1,4 @@
-#ifndef AttrTestSuite_h
-#define AttrTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -424,4 +423,5 @@ class AttrTestSuite : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(str, "Setting value date and quality");
     }
 };
-#endif // AttrTestSuite_h
+
+// NOLINTEND(*)
