@@ -1,5 +1,4 @@
-#ifndef AttrConfTestSuite_h
-#define AttrConfTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -341,4 +340,5 @@ class AttrConfTestSuite : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(att_inf.format, "Not specified");
     }
 };
-#endif // AttrConfTestSuite_h
+
+// NOLINTEND(*)
