@@ -1,5 +1,4 @@
-#ifndef AttrMiscTestSuite_h
-#define AttrMiscTestSuite_h
+// NOLINTBEGIN(*)
 
 #include <tango/server/tango_current_function.h>
 
@@ -70,7 +69,7 @@ class AttrMiscTestSuite : public CxxTest::TestSuite
 
     virtual ~SUITE_NAME()
     {
-        time_t ti = time(NULL);
+        time_t ti = Tango::get_current_system_datetime();
         TEST_LOG << "Destroying suite at " << ctime(&ti) << endl;
         DevLong lg;
         DeviceData din;
@@ -255,7 +254,7 @@ class AttrMiscTestSuite : public CxxTest::TestSuite
                 device1->set_timeout_millis(25*def_timeout);
                 CxxTest::TangoPrinter::restore_set("timeout");
 
-        time_t ti = time(NULL);
+        time_t ti = Tango::get_current_system_datetime();
         TEST_LOG << "Calling SetGetProperties at " << ctime(&ti) << endl;
         struct timeval start,stop;
         gettimeofday(&start,NULL);
@@ -1206,4 +1205,5 @@ class AttrMiscTestSuite : public CxxTest::TestSuite
                                 TS_ASSERT(std::string(e.errors[0].reason.in()) == API_AttrValueNotSet));
     }
 };
-#endif // AttrMiscTestSuite_h
+
+// NOLINTEND(*)
