@@ -1,5 +1,4 @@
-#ifndef AttrWriteTestSuite_h
-#define AttrWriteTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -210,4 +209,5 @@ class AttrWriteTestSuite : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(bl, false);
     }
 };
-#endif // AttrWriteTestSuite_h
+
+// NOLINTEND(*)
