@@ -1,5 +1,4 @@
-#ifndef AttrProp_h
-#define AttrProp_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -131,4 +130,5 @@ class AttrPropTestSuite : public CxxTest::TestSuite
         MultiAttrProp<DevUShort> mapush;
     }
 };
-#endif // AttrProp_h
+
+// NOLINTEND(*)
