@@ -1,5 +1,4 @@
-#ifndef BlackboxTestSuite_h
-#define BlackboxTestSuite_h
+// NOLINTBEGIN(*)
 
 #ifdef _TG_WINDOWS_
   #include <process.h> // needed to obtain process id
@@ -29,7 +28,7 @@ class BlackboxTestSuite : public CxxTest::TestSuite
         device3_name = CxxTest::TangoPrinter::get_param("device3");
         dserver_name = "dserver/" + CxxTest::TangoPrinter::get_param("fulldsname");
         client_host = CxxTest::TangoPrinter::get_param("clienthost");
-        server_version = atoi(CxxTest::TangoPrinter::get_param("serverversion").c_str());
+        TS_ASSERT_THROWS_NOTHING(server_version = parse_as<int>(CxxTest::TangoPrinter::get_param("serverversion")));
         dbserver_name = CxxTest::TangoPrinter::get_param("dbserver");
 
         CxxTest::TangoPrinter::validate_args();
@@ -138,6 +137,7 @@ class BlackboxTestSuite : public CxxTest::TestSuite
             break;
         case 4:
         case 5:
+        case 6:
             version_str = "_4";
             break;
         default:
@@ -293,11 +293,12 @@ class BlackboxTestSuite : public CxxTest::TestSuite
                         TS_ASSERT_EQUALS(e.errors[0].severity, Tango::ERR));*/
         delete device3;
 
-        reference_str = "Operation ping requested from " + client_host;
+        reference_str = "Operation info requested from " + client_host;
         TS_ASSERT_THROWS_NOTHING(blackbox_out = device2->black_box(1));
         out_str = (*blackbox_out)[0];
         out_str.erase(0, out_str.rfind(": ") + 2);
         TS_ASSERT_EQUALS(out_str, reference_str);
     }
 };
-#endif // BlackboxTestSuite_h
+
+// NOLINTEND(*)
