@@ -1,5 +1,4 @@
-#ifndef CmdTypesTestSuite_h
-#define CmdTypesTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -1276,4 +1275,5 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(da2.get_type(), DEV_ENUM);
     }
 };
-#endif // CmdTypesTestSuite_h
+
+// NOLINTEND(*)
