@@ -1,5 +1,4 @@
-#ifndef DevicePipeBlobTestSuite_h
-#define DevicePipeBlobTestSuite_h
+// NOLINTBEGIN(*)
 
 #include <ctime>
 #include <cstdio>
@@ -78,4 +77,5 @@ class DevicePipeBlobTestSuite : public CxxTest::TestSuite
         TS_ASSERT_DIFFERS((*data)[2].inner_blob_name.in(), scalar);
     }
 };
-#endif // DevicePipeBlobTestSuite_h
+
+// NOLINTEND(*)
