@@ -1,5 +1,4 @@
-#ifndef DServerCmdTestSuite_h
-#define DServerCmdTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "compare_test.h"
 
@@ -31,8 +30,8 @@ class DServerCmdTestSuite : public CxxTest::TestSuite
         dserver_name = "dserver/" + CxxTest::TangoPrinter::get_param("fulldsname");
         outpath = CxxTest::TangoPrinter::get_param("outpath");
         refpath = CxxTest::TangoPrinter::get_param("refpath");
-        loglevel = atoi(CxxTest::TangoPrinter::get_param("loglevel").c_str());
-        dsloglevel = atoi(CxxTest::TangoPrinter::get_param("dsloglevel").c_str());
+        TS_ASSERT_THROWS_NOTHING(loglevel = parse_as<int>(CxxTest::TangoPrinter::get_param("loglevel")));
+        TS_ASSERT_THROWS_NOTHING(dsloglevel = parse_as<int>(CxxTest::TangoPrinter::get_param("dsloglevel")));
 
         CxxTest::TangoPrinter::validate_args();
 
@@ -56,7 +55,7 @@ class DServerCmdTestSuite : public CxxTest::TestSuite
         //
 
         ref_file = refpath + file_name;
-        out_file = outpath + file_name;
+        out_file = CmpTst::CompareTest::make_filename_unique(outpath + file_name);
         CmpTst::CompareTest::clean_on_startup(ref_file, out_file);
     }
 
@@ -222,7 +221,11 @@ class DServerCmdTestSuite : public CxxTest::TestSuite
         din << dserver_name;
         TS_ASSERT_THROWS_NOTHING(dout = dserver->command_inout("GetLoggingTarget", din));
         dout >> logging_target_out;
+#if defined(TANGO_USE_TELEMETRY)
+        TS_ASSERT_EQUALS((*logging_target_out).length(), 2u); // console::cout + telemetry
+#else
         TS_ASSERT_EQUALS((*logging_target_out).length(), 1u); // console::cout
+#endif // TANGO_USE_TELEMETRY
 
         // set logging level to 5
         DevVarLongStringArray dserver_level_in;
@@ -288,7 +291,11 @@ class DServerCmdTestSuite : public CxxTest::TestSuite
         din << dserver_name;
         TS_ASSERT_THROWS_NOTHING(dout = dserver->command_inout("GetLoggingTarget", din));
         dout >> check_logging_target;
+#if defined(TANGO_USE_TELEMETRY)
+        TS_ASSERT_EQUALS((*check_logging_target).length(), 2u); // console::cout + telemetry
+#else
         TS_ASSERT_EQUALS((*check_logging_target).length(), 1u); // console::cout
+#endif // TANGO_USE_TELEMETRY
     }
 
     // Test comparing input with output
@@ -337,4 +344,4 @@ class DServerCmdTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // DServerCmdTestSuite_h
+// NOLINTEND(*)
