@@ -1,5 +1,4 @@
-#ifndef DServerMiscTestSuite_h
-#define DServerMiscTestSuite_h
+// NOLINTBEGIN(*)
 
 #include <thread>
 #include <chrono>
@@ -29,7 +28,7 @@ class DServerMiscTestSuite : public CxxTest::TestSuite
         full_ds_name = CxxTest::TangoPrinter::get_param("fulldsname");
         dserver_name = "dserver/" + CxxTest::TangoPrinter::get_param("fulldsname");
         server_host = CxxTest::TangoPrinter::get_param("serverhost");
-        server_version = atoi(CxxTest::TangoPrinter::get_param("serverversion").c_str());
+        TS_ASSERT_THROWS_NOTHING(server_version = parse_as<int>(CxxTest::TangoPrinter::get_param("serverversion")));
         doc_url = CxxTest::TangoPrinter::get_param("docurl");
 
         CxxTest::TangoPrinter::validate_args();
@@ -444,4 +443,5 @@ class DServerMiscTestSuite : public CxxTest::TestSuite
         device1->command_inout("PushPipeEvent", data);
     }
 };
-#endif // DServerMiscTestSuite_h
+
+// NOLINTEND(*)
