@@ -1,5 +1,4 @@
-#ifndef EncodedTestSuite_h
-#define EncodedTestSuite_h
+// NOLINTBEGIN(*)
 
 #include <ctime>
 
@@ -219,4 +218,5 @@ class EncodedTestSuite : public CxxTest::TestSuite
         device1->write_attribute(da_in);
     }
 };
-#endif // EncodedTestSuite_h
+
+// NOLINTEND(*)
