@@ -1,5 +1,4 @@
-#ifndef PollTestSuite_h
-#define PollTestSuite_h
+// NOLINTBEGIN(*)
 
 #include <thread>
 #include <chrono>
@@ -1428,4 +1427,4 @@ void del_device_no_error(Database &db, string &d_name)
     }
 }
 
-#endif // PollTestSuite_h
+// NOLINTEND(*)
