@@ -1,5 +1,4 @@
-#ifndef PollAdminTestSuite_h
-#define PollAdminTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -1148,4 +1147,4 @@ class PollAdminTestSuite__loop : public CxxTest::TestSuite
     }
 };
 
-#endif // PollAdminTestSuite_h
+// NOLINTEND(*)
