@@ -1,5 +1,4 @@
-#ifndef SignalTestSuite_h
-#define SignalTestSuite_h
+// NOLINTBEGIN(*)
 
 #include <signal.h>
 #include "compare_test.h"
@@ -31,8 +30,8 @@ class SignalTestSuite : public CxxTest::TestSuite
         dserver_name = "dserver/" + CxxTest::TangoPrinter::get_param("fulldsname");
         outpath = CxxTest::TangoPrinter::get_param("outpath");
         refpath = CxxTest::TangoPrinter::get_param("refpath");
-        loglevel = atoi(CxxTest::TangoPrinter::get_param("loglevel").c_str());
-        dsloglevel = atoi(CxxTest::TangoPrinter::get_param("dsloglevel").c_str());
+        TS_ASSERT_THROWS_NOTHING(loglevel = parse_as<int>(CxxTest::TangoPrinter::get_param("loglevel")));
+        TS_ASSERT_THROWS_NOTHING(dsloglevel = parse_as<int>(CxxTest::TangoPrinter::get_param("dsloglevel")));
         dbserver_name = CxxTest::TangoPrinter::get_param("dbserver");
 
         CxxTest::TangoPrinter::validate_args();
@@ -63,7 +62,7 @@ class SignalTestSuite : public CxxTest::TestSuite
         //
 
         ref_file = refpath + file_name;
-        out_file = outpath + file_name;
+        out_file = CmpTst::CompareTest::make_filename_unique(outpath + file_name);
         CmpTst::CompareTest::clean_on_startup(ref_file, out_file);
     }
 
@@ -240,13 +239,13 @@ class SignalTestSuite : public CxxTest::TestSuite
         CxxTest::TangoPrinter::restore_set("logging_target_restored");
 
         // get device server PID and send signal
-        TangoSys_Pid pid;
+        TangoSys_Pid pid = 0;
         const DevVarLongStringArray *result;
         string query = "select pid from device where name='" + dserver_name + "'";
         din << query;
         TS_ASSERT_THROWS_NOTHING(dout = dbserver->command_inout("DbMySqlSelect", din));
         dout >> result;
-        pid = atoi((*result).svalue[0].in());
+        TS_ASSERT_THROWS_NOTHING(pid = parse_as<int>((*result).svalue[0].in()));
         if(pid > 0)
         {
             kill(pid, sig_num_int);
@@ -335,4 +334,4 @@ class SignalTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // SignalTestSuite_h
+// NOLINTEND(*)
