@@ -1,5 +1,4 @@
-#ifndef SyntaxTestSuite_h
-#define SyntaxTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 #include <tango/internal/utils.h>
@@ -281,4 +280,5 @@ class SyntaxTestSuite : public CxxTest::TestSuite
         TS_ASSERT(!IDLVersionIsTooOld(0, 0));
     }
 };
-#endif // SyntaxTestSuite_h
+
+// NOLINTEND(*)
