@@ -1,5 +1,4 @@
-#ifndef DynCmdSuite_h
-#define DynCmdSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -191,4 +190,4 @@ class DynCmdTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // DynCmdTestSuite_h
+// NOLINTEND(*)
