@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 // Testprogram to demonstrate a tango exit crash problem:
 // memory double free or corruption.
@@ -266,3 +268,5 @@ georg@taco10:/home/projekte/tango/Tests/ExitCrashProblem>
 georg@taco10:/home/projekte/tango/Tests/ExitCrashProblem>
 
 */
+
+// NOLINTEND(*)
