@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 #include <tango/client/helpers/DeviceProxyHelper.h>
 
@@ -13,7 +15,7 @@ int main(int argc, char **argv)
     }
 
     string device_name = argv[1];
-    long loop = atol(argv[2]);
+    long loop = parse_as<long>(argv[2]);
 
     try
     {
@@ -420,3 +422,5 @@ int main(int argc, char **argv)
         exit(1);
     }
 }
+
+// NOLINTEND(*)
