@@ -1,3 +1,5 @@
+// NOLINTBEGIN(*)
+
 #ifdef WIN32
   #include <process.h>
   #define WEXITSTATUS(w) w
@@ -6,7 +8,7 @@
 #endif
 
 #include <tango/internal/net.h>
-#include "common.h"
+#include "old_common.h"
 
 #include "locked_device_cmd.h"
 
@@ -473,3 +475,5 @@ int main(int argc, char **argv)
     delete device;
     return 0;
 }
+
+// NOLINTEND(*)
