@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 /*
  * Small utility program to help testing locking features.
@@ -179,3 +181,5 @@ int main(int argc, char **argv)
     delete device;
     return 0;
 }
+
+// NOLINTEND(*)
