@@ -1,16 +1,18 @@
+// NOLINTBEGIN(*)
+
 #ifdef WIN32
   #include <process.h>
 #endif
 
-#include "common.h"
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
     DeviceProxy *device;
 
-    if(argc != 3)
+    if(argc != 4)
     {
-        TEST_LOG << "usage: " << argv[0] << " <device> <full ds name>" << endl;
+        TEST_LOG << "usage: " << argv[0] << " <device> <full ds name> <idlver>" << endl;
         exit(-1);
     }
 
@@ -18,6 +20,7 @@ int main(int argc, char **argv)
     string ds_name = argv[2];
     string admin_device("dserver/");
     admin_device = admin_device + ds_name;
+    int idlver = parse_as<int>(argv[3]);
 
     try
     {
@@ -82,7 +85,7 @@ int main(int argc, char **argv)
         tg_version = device->get_tango_lib_version();
 
         assert(tg_version >= 810);
-        TEST_LOG << "   Tango lib version --> OK" << endl;
+        TEST_LOG << "   Tango lib version --> " << tg_version << endl;
 
         // Test adm_name
 
@@ -153,6 +156,14 @@ int main(int argc, char **argv)
 
         TEST_LOG << "   Info --> OK" << endl;
 
+        const int vi_size = static_cast<int>(inf.version_info.size());
+        TEST_LOG << "version_info.size --> " << vi_size << endl;
+
+        for(const auto &[key, value] : inf.version_info)
+        {
+            TEST_LOG << "\t" << key << " : " << value << endl;
+        }
+
         // Test command_query
 
         DevCommandInfo cmd_info;
@@ -311,7 +322,7 @@ int main(int argc, char **argv)
 
 #ifndef COMPAT
         int vers = device->get_idl_version();
-        assert(vers == 5);
+        assert(vers == idlver);
 
         TEST_LOG << "   Get IDL version --> OK" << endl;
 #endif
@@ -359,3 +370,5 @@ int main(int argc, char **argv)
 
     return 0;
 }
+
+// NOLINTEND(*)
