@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
@@ -40,3 +42,5 @@ int main(int argc, char **argv)
 
     //    sleep(1000);
 }
+
+// NOLINTEND(*)
