@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
@@ -53,3 +55,5 @@ int main(int argc, char **argv)
 
     delete device;
 }
+
+// NOLINTEND(*)
