@@ -1,8 +1,10 @@
+// NOLINTBEGIN(*)
+
 #ifdef WIN32
   #include <process.h>
 #endif
 
-#include "common.h"
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
@@ -197,3 +199,5 @@ int main(int argc, char **argv)
 
     return 0;
 }
+
+// NOLINTEND(*)
