@@ -1,8 +1,10 @@
+// NOLINTBEGIN(*)
+
 #ifdef WIN32
   #include <process.h>
 #endif
 
-#include "common.h"
+#include "old_common.h"
 
 #define STATE_LOG_MESSAGE "State: Number of attribute(s) to read: "
 
@@ -739,3 +741,5 @@ int message_in_file(string &f_name, string &mess, vector<string> &mess_occur)
     inFile.close();
     return ret;
 }
+
+// NOLINTEND(*)
