@@ -27,12 +27,12 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // Tango is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
@@ -78,19 +78,19 @@ AnyOption::init(int maxopt, int maxcharopt )
 	max_usage_lines	= DEFAULT_MAXUSAGE;
 	usage_lines	= 0 ;
 	argc 		= 0;
-	argv 		= NULL;
+	argv 		= nullptr;
 	posix_style	= true;
 	verbose 	= false;
-	filename 	= NULL;
-	appname 	= NULL;	
+	filename 	= nullptr;
+	appname 	= nullptr;
 	option_counter 	= 0;
 	optchar_counter	= 0;
-	new_argv 	= NULL;
+	new_argv 	= nullptr;
 	new_argc 	= 0 ;
 	max_legal_args 	= 0 ;
 	command_set 	= false;
 	file_set 	= false;
-	values 		= NULL;	
+	values 		= nullptr;
 	g_value_counter = 0;
 	mem_allocated 	= false;
 	command_set 	= false;
@@ -129,24 +129,24 @@ AnyOption::alloc()
 		return true;
 
 	size = (max_options+1) * sizeof(const char*);
-	options = (const char**)malloc( size );	
-	optiontype = (int*) malloc( (max_options+1)*sizeof(int) );	
-	optionindex = (int*) malloc( (max_options+1)*sizeof(int) );	
-	if( options == NULL || optiontype == NULL || optionindex == NULL )
+	options = (const char**)malloc( size );
+	optiontype = (int*) malloc( (max_options+1)*sizeof(int) );
+	optionindex = (int*) malloc( (max_options+1)*sizeof(int) );
+	if( options == nullptr || optiontype == nullptr || optionindex == nullptr )
 		return false;
 	else
 		mem_allocated  = true;
 	for( i = 0 ; i < max_options ; i++ ){
-		options[i] = NULL;
+		options[i] = nullptr;
 		optiontype[i] = 0 ;
 		optionindex[i] = -1 ;
 	}
 	optionchars = (char*) malloc( (max_char_options+1)*sizeof(char) );
-	optchartype = (int*) malloc( (max_char_options+1)*sizeof(int) );	
-	optcharindex = (int*) malloc( (max_char_options+1)*sizeof(int) );	
-	if( optionchars == NULL || 
-            optchartype == NULL || 
-            optcharindex == NULL )
+	optchartype = (int*) malloc( (max_char_options+1)*sizeof(int) );
+	optcharindex = (int*) malloc( (max_char_options+1)*sizeof(int) );
+	if( optionchars == nullptr ||
+            optchartype == nullptr ||
+            optcharindex == nullptr )
         {
 		mem_allocated = false;
 		return false;
@@ -160,12 +160,12 @@ AnyOption::alloc()
 	size = (max_usage_lines+1) * sizeof(const char*) ;
 	usage = (const char**) malloc( size );
 
-	if( usage == NULL  ){
+	if( usage == nullptr  ){
 		mem_allocated = false;
 		return false;
 	}
 	for( i = 0 ; i < max_usage_lines ; i++ )
-		usage[i] = NULL;
+		usage[i] = nullptr;
 
 	return true;
 }
@@ -176,32 +176,32 @@ AnyOption::doubleOptStorage()
 	const char **tmp_ptr;
 	int *tmp_ptr_int;
 	tmp_ptr = options;
-	options = (const char**)realloc( tmp_ptr,  
+	options = (const char**)realloc( tmp_ptr,
 			((2*max_options)+1) * sizeof( const char*) );
-	if( options == NULL)
+	if( options == nullptr)
 	{
 		free(tmp_ptr);
 		return false;
 	}
 	tmp_ptr_int = optiontype;
-	optiontype = (int*) realloc(  tmp_ptr_int ,  
+	optiontype = (int*) realloc(  tmp_ptr_int ,
 			((2 * max_options)+1)* sizeof(int) );
-	if( optiontype == NULL)
+	if( optiontype == nullptr)
 	{
 		free(tmp_ptr_int);
 		return false;
 	}
 	tmp_ptr_int = optionindex;
-	optionindex = (int*) realloc(  tmp_ptr_int,  
+	optionindex = (int*) realloc(  tmp_ptr_int,
 			((2 * max_options)+1) * sizeof(int) );
-	if (optionindex == NULL)
+	if (optionindex == nullptr)
 	{
 		free(tmp_ptr_int);
 		return false;
 	}
 	/* init new storage */
 	for( int i = max_options ; i < 2*max_options ; i++ ){
-		options[i] = NULL;
+		options[i] = nullptr;
 		optiontype[i] = 0 ;
 		optionindex[i] = -1 ;
 	}
@@ -215,25 +215,25 @@ AnyOption::doubleCharStorage()
 	char *tmp_ptr;
 	int *tmp_ptr_int;
 	tmp_ptr = optionchars;
-	optionchars = (char*) realloc( tmp_ptr,  
+	optionchars = (char*) realloc( tmp_ptr,
 			((2*max_char_options)+1)*sizeof(char) );
-	if( optionchars == NULL)
+	if( optionchars == nullptr)
 	{
 		free(tmp_ptr);
 		return false;
 	}
 	tmp_ptr_int = optchartype;
-	optchartype = (int*) realloc( tmp_ptr_int,  
+	optchartype = (int*) realloc( tmp_ptr_int,
 			((2*max_char_options)+1)*sizeof(int) );
-	if (optchartype == NULL)
+	if (optchartype == nullptr)
 	{
 		free(tmp_ptr_int);
 		return false;
 	}
 	tmp_ptr_int = optcharindex;
-	optcharindex = (int*) realloc( tmp_ptr_int,  
+	optcharindex = (int*) realloc( tmp_ptr_int,
 			((2*max_char_options)+1)*sizeof(int) );
-	if (optcharindex == NULL)
+	if (optcharindex == nullptr)
 	{
 		free(tmp_ptr_int);
 		return false;
@@ -244,7 +244,7 @@ AnyOption::doubleCharStorage()
 		optchartype[i] = 0 ;
 		optcharindex[i] = -1 ;
 	}
-	max_char_options = 2 * max_char_options;	
+	max_char_options = 2 * max_char_options;
 	return true;
 }
 
@@ -252,13 +252,13 @@ bool
 AnyOption::doubleUsageStorage()
 {
 	const char **new_usage = (const char**)realloc( usage, ((2*max_usage_lines)+1) * sizeof( const char*) );
-	if ( new_usage == NULL ) {
+	if ( new_usage == nullptr ) {
 		free(usage);
 		return false;
 	}
 	usage = new_usage;
 	for( int i = max_usage_lines ; i < 2*max_usage_lines ; i++ )
-		usage[i] = NULL;
+		usage[i] = nullptr;
 	max_usage_lines = 2 * max_usage_lines ;
 	return true;
 
@@ -268,23 +268,23 @@ AnyOption::doubleUsageStorage()
 void
 AnyOption::cleanup()
 {
-	if (options != NULL)
+	if (options != nullptr)
 		free (options);
-	if (optiontype != NULL)
+	if (optiontype != nullptr)
 		free (optiontype);
-	if (optionindex != NULL)
+	if (optionindex != nullptr)
 		free (optionindex);
-	if (optionchars != NULL)
+	if (optionchars != nullptr)
 		free (optionchars);
-	if (optchartype != NULL)
+	if (optchartype != nullptr)
 		free (optchartype);
-	if (optcharindex != NULL)
+	if (optcharindex != nullptr)
 		free (optcharindex);
-	if (usage != NULL)
+	if (usage != nullptr)
 		free (usage);
-	if( values != NULL )
+	if( values != nullptr )
 		free (values);
-	if( new_argv != NULL )
+	if( new_argv != nullptr )
 		free (new_argv);
 }
 
@@ -298,7 +298,7 @@ void
 AnyOption::setCommandLongPrefix( char *_prefix )
 {
 	if( strlen( _prefix ) > MAX_LONG_PREFIX_LENGTH ){
-		*( _prefix + MAX_LONG_PREFIX_LENGTH ) = '\0'; 
+		*( _prefix + MAX_LONG_PREFIX_LENGTH ) = '\0';
 	}
 
 	strcpy (long_opt_prefix,  _prefix);
@@ -405,7 +405,7 @@ AnyOption::useFiileName( const char *_filename )
 }
 
 /*
- * set methods for options 
+ * set methods for options
  */
 
 void
@@ -551,7 +551,7 @@ AnyOption::addOption( const char *opt, int type )
 	}
 	options[ option_counter ] = opt ;
 	optiontype[ option_counter ] =  type ;
-	optionindex[ option_counter ] = g_value_counter; 
+	optionindex[ option_counter ] = g_value_counter;
 	option_counter++;
 }
 
@@ -575,7 +575,7 @@ AnyOption::addOption( char opt, int type )
 	}
 	optionchars[ optchar_counter ] =  opt ;
 	optchartype[ optchar_counter ] =  type ;
-	optcharindex[ optchar_counter ] = g_value_counter; 
+	optcharindex[ optchar_counter ] = g_value_counter;
 	optchar_counter++;
 }
 
@@ -608,13 +608,13 @@ AnyOption::processOptions()
 		return;
 }
 
-void 
+void
 AnyOption::processCommandArgs(int max_args)
 {
 	max_legal_args = max_args;
 	processCommandArgs();
 }
- 
+
 void
 AnyOption::processCommandArgs( int _argc, char **_argv, int max_args )
 {
@@ -634,25 +634,33 @@ AnyOption::processCommandArgs()
 {
    	if( ! ( valueStoreOK() && CommandSet() )  )
 	   return;
-	   
+
 	if( max_legal_args == 0 )
 		max_legal_args = argc;
 	new_argv = (int*) malloc( (max_legal_args+1) * sizeof(int) );
 	for( int i = 1 ; i < argc ; i++ ){/* ignore first argv */
-		if(  argv[i][0] == long_opt_prefix[0] && 
+		if(  argv[i][0] == long_opt_prefix[0] &&
                      argv[i][1] == long_opt_prefix[1] ) { /* long GNU option */
 			int match_at = parseGNU( argv[i]+2 ); /* skip -- */
 			if( match_at >= 0 && i < argc-1 ) /* found match */
 				setValue( options[match_at] , argv[++i] );
 		}else if(  argv[i][0] ==  opt_prefix_char ) { /* POSIX char */
-			if( POSIX() ){ 
-				char ch =  parsePOSIX( argv[i]+1 );/* skip - */ 
+			if( POSIX() ){
+				char ch =  parsePOSIX( argv[i]+1 );/* skip - */
 				if( ch != '0' && i < argc-1 ) /* matching char */
 					setValue( ch ,  argv[++i] );
+				else if( new_argc < max_legal_args ){ // negative numbers
+					new_argv[ new_argc ] = i ;
+					new_argc++;
+				}
 			} else { /* treat it as GNU option with a - */
 				int match_at = parseGNU( argv[i]+1 ); /* skip - */
 				if( match_at >= 0 && i < argc-1 ) /* found match */
 					setValue( options[match_at] , argv[++i] );
+				else if( new_argc < max_legal_args ){ // negative numbers
+					new_argv[ new_argc ] = i ;
+					new_argc++;
+				}
 			}
 		}else { /* not option but an argument keep index */
 			if( new_argc < max_legal_args ){
@@ -672,21 +680,21 @@ AnyOption::processCommandArgs()
 	}
 }
 
-char 
+char
 AnyOption::parsePOSIX( char* arg )
 {
 
-	for( unsigned int i = 0 ; i < strlen(arg) ; i++ ){ 
+	for( unsigned int i = 0 ; i < strlen(arg) ; i++ ){
 		char ch = arg[i] ;
 		if( matchChar(ch) ) { /* keep matching flags till an option */
 			/*if last char argv[++i] is the value */
-			if( i == strlen(arg)-1 ){ 
+			if( i == strlen(arg)-1 ){
 				return ch;
 			}else{/* else the rest of arg is the value */
 				i++; /* skip any '=' and ' ' */
-				while( arg[i] == whitespace 
+				while( arg[i] == whitespace
 			    		|| arg[i] == equalsign )
-					i++;	
+					i++;
 				setValue( ch , arg+i );
 				return '0';
 			}
@@ -734,18 +742,18 @@ AnyOption::parseGNU( char *arg )
 }
 
 
-int 
+int
 AnyOption::matchOpt( char *opt )
 {
 	for( int i = 0 ; i < option_counter ; i++ ){
 		if( strcmp( options[i], opt ) == 0 ){
 			if( optiontype[i] ==  COMMON_OPT ||
-			    optiontype[i] ==  COMMAND_OPT )	
+			    optiontype[i] ==  COMMAND_OPT )
 			{ /* found option return index */
 				return i;
 			}else if( optiontype[i] == COMMON_FLAG ||
 			       optiontype[i] == COMMAND_FLAG )
-			{ /* found flag, set it */ 
+			{ /* found flag, set it */
 				setFlagOn( opt );
 				return -1;
 			}
@@ -755,7 +763,7 @@ AnyOption::matchOpt( char *opt )
 	printVerbose( opt  ) ;
 	printVerbose( );
 	printAutoUsage();
-	return  -1;	
+	return  -1;
 }
 bool
 AnyOption::matchChar( char c )
@@ -765,8 +773,8 @@ AnyOption::matchChar( char c )
 			if(optchartype[i] == COMMON_OPT ||
 			     optchartype[i] == COMMAND_OPT )
 			{ /* an option store and stop scanning */
-				return true;	
-			}else if( optchartype[i] == COMMON_FLAG || 
+				return true;
+			}else if( optchartype[i] == COMMON_FLAG ||
 				  optchartype[i] == COMMAND_FLAG ) { /* a flag store and keep scanning */
 				setFlagOn( c );
 				return false;
@@ -787,9 +795,9 @@ AnyOption::valueStoreOK( )
 		if( g_value_counter > 0 ){
 			int size = 0;
 			size = g_value_counter * sizeof(char*);
-			values = (char**)malloc( size );	
+			values = (char**)malloc( size );
 			for( int i = 0 ; i < g_value_counter ; i++)
-				values[i] = NULL;
+				values[i] = nullptr;
 			set = true;
 		}
 	}
@@ -797,19 +805,19 @@ AnyOption::valueStoreOK( )
 }
 
 /*
- * public get methods 
+ * public get methods
  */
 char*
 AnyOption::getValue( const char *option )
 {
 	if( !valueStoreOK() )
-		return NULL;
+		return nullptr;
 
 	for( int i = 0 ; i < option_counter ; i++ ){
 		if( strcmp( options[i], option ) == 0 )
 			return values[ optionindex[i] ];
 	}
-	return NULL;
+	return nullptr;
 }
 
 bool
@@ -828,12 +836,12 @@ char*
 AnyOption::getValue( char option )
 {
 	if( !valueStoreOK() )
-		return NULL;
+		return nullptr;
 	for( int i = 0 ; i < optchar_counter ; i++ ){
 		if( optionchars[i] == option )
 			return values[ optcharindex[i] ];
 	}
-	return NULL;
+	return nullptr;
 }
 
 bool
@@ -851,7 +859,7 @@ AnyOption::getFlag( char option )
 bool
 AnyOption::findFlag( char* val )
 {
-	if( val == NULL )
+	if( val == nullptr )
 		return false;
 
 	if( strcmp( TRUE_FLAG , val ) == 0 )
@@ -861,7 +869,7 @@ AnyOption::findFlag( char* val )
 }
 
 /*
- * private set methods 
+ * private set methods
  */
 bool
 AnyOption::setValue( const char *option , char *value )
@@ -930,13 +938,13 @@ AnyOption::getArgc( )
 	return new_argc;
 }
 
-char* 
+char*
 AnyOption::getArgv( int index )
 {
 	if( index < new_argc ){
 		return ( argv[ new_argv[ index ] ] );
 	}
-	return NULL;
+	return nullptr;
 }
 
 /* dotfile sub routines */
@@ -963,7 +971,7 @@ AnyOption::readFile()
 }
 
 /*
- * read the file contents to a character buffer 
+ * read the file contents to a character buffer
  */
 
 char*
@@ -975,7 +983,7 @@ AnyOption::readFile( const char* fname )
         is.open ( fname , ifstream::in );
         if( ! is.good() ){
                 is.close();
-                return NULL;
+                return nullptr;
         }
         is.seekg (0, ios::end);
         length = is.tellg();
@@ -987,26 +995,26 @@ AnyOption::readFile( const char* fname )
 }
 
 /*
- * scans a char* buffer for lines that does not 
+ * scans a char* buffer for lines that does not
  * start with the specified comment character.
  */
 bool
 AnyOption::consumeFile( char *buffer )
 {
 
-        if( buffer == NULL ) 
+        if( buffer == nullptr )
 		return false;
 
        	char *cursor = buffer;/* preserve the ptr */
-       	char *pline = NULL ;
+       	char *pline = nullptr ;
        	int linelength = 0;
        	bool newline = true;
        	for( unsigned int i = 0 ; i < strlen( buffer ) ; i++ ){
        	if( *cursor == endofline ) { /* end of line */
-          	if( pline != NULL ) /* valid line */
+          	if( pline != nullptr ) /* valid line */
             {
                		processLine( pline, linelength );
-                 	pline = NULL;
+                 	pline = nullptr;
                  	newline = true;
             }
            	}else if( newline ){ /* start of line */
@@ -1025,7 +1033,7 @@ AnyOption::consumeFile( char *buffer )
 
 
 /*
- *  find a valid type value pair separated by a delimiter 
+ *  find a valid type value pair separated by a delimiter
  *  character and pass it to valuePairs()
  *  any line which is not valid will be considered a value
  *  and will get passed on to justValue()
@@ -1035,13 +1043,13 @@ AnyOption::consumeFile( char *buffer )
  *  width:10    - valid pair valuePairs( width, 10 );
  *  width : 10  - valid pair valuepairs( width, 10 );
  *
- *  ::::        - not valid 
+ *  ::::        - not valid
  *  width       - not valid
- *  :10         - not valid 
- *  width:      - not valid  
- *  ::          - not valid 
- *  :           - not valid 
- *  
+ *  :10         - not valid
+ *  width:      - not valid
+ *  ::          - not valid
+ *  :           - not valid
+ *
  */
 
 void
@@ -1100,7 +1108,7 @@ AnyOption::valuePairs( char *type, char *value )
 				}
 			}
 		}
-	}	
+	}
 	/* if no char options matched */
 	for( int i = 0 ; i < option_counter ; i++ ){
 		if( strcmp( options[i], type ) == 0 ){ /* match */
@@ -1132,7 +1140,7 @@ AnyOption::justValue( char *type )
 				}
 			}
 		}
-	}	
+	}
 	/* if no char options matched */
 	for( int i = 0 ; i < option_counter ; i++ ){
 		if( strcmp( options[i], type ) == 0 ){ /* match */
@@ -1150,7 +1158,7 @@ AnyOption::justValue( char *type )
 }
 
 /*
- * usage and help 
+ * usage and help
  */
 
 
@@ -1163,17 +1171,17 @@ AnyOption::printAutoUsage()
 void
 AnyOption::printUsage()
 {
-	
+
 	if( once ) {
 		once = false ;
 		cout << endl ;
 		for( int i = 0 ; i < usage_lines ; i++ )
-			cout << usage[i] << endl ;	
+			cout << usage[i] << endl ;
 		cout << endl ;
 	}
 }
-	
-	
+
+
 void
 AnyOption::addUsage( const char *line )
 {
@@ -1183,7 +1191,7 @@ AnyOption::addUsage( const char *line )
 			exit(1);
 		}
 	}
-	usage[ usage_lines ] = line ;	
+	usage[ usage_lines ] = line ;
 	usage_lines++;
 }
 
@@ -1198,4 +1206,3 @@ AnyOption::addUsageError( const char *line )
 	exit(0);
 
 }
-
