@@ -44,18 +44,20 @@
 #include <iostream>
 #include <string>
 #include <cmath>
-#include <anyoption.h>
+#include <ctime>
+#include <cstdlib>
+
+ #include <sys/types.h>
+ #include <sys/socket.h>
+ #include <netdb.h>
+
 #include <tango/tango.h>
+#include "anyoption.h"
 
-#include <time.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netdb.h>
 
-#include <stdlib.h>
-
-int ping_database(int);
+int ping_database();
 int check_device(const char *);
+int check_device_exported(const char *);
 int add_server(char *,char *,char *);
 void list2vect(std::string &,std::vector<std::string> &);
 int check_server(char *);
@@ -64,11 +66,10 @@ int server_instance_list(char *);
 int delete_server(char *,bool);
 int add_property(char *,char *,char *);
 int delete_property(char *,char *);
-int ping_network(int,bool);
-int check_net(bool);
+int ping_network(bool);
 int tac_enabled(void);
-int ping_device(const std::string &, double);
-int check_dev(const char *);
+int ping_device(const std::string&);
+int unexport_device(const char *);
 
 // The min and max allowed timeouts. Used by the function
 // compute_loops_and_sleep_time.
@@ -184,6 +185,69 @@ static int convert_string_to_double(const std::string& value_as_string,
     return ret;
 }
 
+// method: call_func
+//
+// description: Generic wrapper for a callable. The wrapper runs for a specified
+//               duration with computed pauses that are based on the duration.
+// input parameters:
+//  - callable: Function to be called.
+//  - timeout_in_s: A timeout or duration which limits how long this function
+//                  runs.
+// return: -ERANGE if the timeout_in_s parameter does not fall within the
+//         expected range.
+//         -ETIMEDOUT if the called function never returned 0 over the entire
+//                     duration.
+//         0 if the callable returned 0 itself which means success.
+static int call_func(std::function<int()> callable, double timeout_in_s)
+{
+    struct timespec sleep_time{};
+    unsigned int loops;
+    bool run_forever{false};
+    if(timeout_in_s >= 0)
+    {
+        auto err{compute_loops_and_sleep_time(timeout_in_s, loops, sleep_time)};
+        if(err != 0)
+        {
+            return err;
+        }
+    }
+    else
+    {
+        // In case the Tango DB check runs forever, set the time to wait between
+        // retires to 0.5s.
+        sleep_time.tv_sec = 0;
+        sleep_time.tv_nsec = 1000000000UL * 0.5;
+        loops = 1U;
+        timeout_in_s = 1.0;
+        run_forever = true;
+        std::cerr << "Will try forever until successful.\n";
+    }
+
+    const double sleep_time_in_s{(sleep_time.tv_sec * 1e9 + sleep_time.tv_nsec) / 1e9};
+    while((loops > 0U) && (timeout_in_s > 0.0))
+    {
+        if(callable() == 0)
+        {
+            return 0;
+        }
+
+        nanosleep(&sleep_time, nullptr);
+        if(!run_forever)
+        {
+            timeout_in_s -= sleep_time_in_s;
+            --loops;
+        }
+    };
+
+    return -ETIMEDOUT;
+}
+
+static void print_error(const char *msg, const Tango::DevError &e)
+{
+    std::cerr << msg << ": " << e.desc << " (" << e.reason << ")\n";
+}
+
+
 int main(int argc,char *argv[])
 {
 	auto opt{std::make_unique< AnyOption >()};
@@ -196,6 +260,7 @@ int main(int argc,char *argv[])
  	opt->addUsage(" --help  		Prints this help " );
 	opt->addUsage(" --ping-database	[max_time (s)] Ping database " );
 	opt->addUsage(" --check-device <dev>    Check if the device is defined in DB");
+	opt->addUsage(" --check-device-exported <dev>    Check if the device is exported in DB");
  	opt->addUsage(" --add-server <exec/inst> <class> <dev list (comma separated)>   Add a server in DB" );
  	opt->addUsage(" --delete-server <exec/inst> [--with-properties]   Delete a server from DB" );
 	opt->addUsage(" --check-server <exec/inst>   Check if a device server is defined in DB");
@@ -206,25 +271,58 @@ int main(int argc,char *argv[])
 	opt->addUsage(" --tac-enabled Check if the TAC (Tango Access Control) is enabled");
 	opt->addUsage(" --ping-device <dev> [max_time (s)] Check if the device is running");
 	opt->addUsage(" --ping-network [max_time (s)] [-v] Ping network ");
+	opt->addUsage(" --unexport-device <dev> Unexport a device from DB.  USE WITH CARE.");
 
 //
 // Define the command line options
 //
 
-	opt->setFlag("help",'h');
- 	opt->setFlag("ping-database");
-	opt->setOption("add-server");
-	opt->setOption("delete-server");
-	opt->setFlag("with-properties");
-	opt->setOption("add-property");
-	opt->setOption("delete-property");
-	opt->setOption("check-device");
-	opt->setOption("check-server");
-	opt->setFlag("server-list");
-	opt->setOption("server-instance-list");
-	opt->setOption("ping-device");
-	opt->setFlag("ping-network");
-	opt->setFlag("tac-enabled");
+        struct Flag {
+            const char* long_name;
+            char short_name;
+        };
+
+        struct Option {
+            const char* name;
+        };
+
+        std::vector<Flag> flags = {
+            Flag{"help", 'h'},
+            Flag{"ping-database", '\0'},
+            Flag{"with-properties", '\0'},
+            Flag{"server-list", '\0'},
+            Flag{"ping-network", '\0'},
+            Flag{"tac-enabled", '\0'},
+        };
+
+        std::vector<Option> options = {
+            Option{"add-server"},
+            Option{"delete-server"},
+            Option{"add-property"},
+            Option{"delete-property"},
+            Option{"check-property"},
+            Option{"check-device"},
+            Option{"check-device-exported"},
+            Option{"check-server"},
+            Option{"server-instance-list"},
+            Option{"ping-device"},
+            Option{"unexport-device"},
+        };
+
+        for (auto &f: flags) {
+            if (f.short_name != '\0')
+            {
+                opt->setFlag(f.long_name, f.short_name);
+            }
+            else
+            {
+                opt->setFlag(f.long_name);
+            }
+        }
+
+        for (auto &o: options) {
+            opt->setOption(o.name);
+        }
 
 //
 // Process cmd line
@@ -232,8 +330,31 @@ int main(int argc,char *argv[])
 
 	opt->processCommandArgs( argc, argv );
 
-	if (!opt->hasOptions())
+        int opt_count = 0;
+        for (auto &f: flags)
+        {
+            if (opt->getFlag(f.long_name) ||
+                (f.short_name != '\0' && opt->getFlag(f.short_name)))
+            {
+                opt_count += 1;
+            }
+
+        }
+
+        for (auto &o: options)
+        {
+            if (opt->getValue(o.name) != nullptr)
+            {
+                opt_count += 1;
+            }
+        }
+
+	if (opt_count != 1)
 	{
+            if (opt_count > 1)
+            {
+                std::cerr << "Can't mix options\n";
+            }
 		printUsageAndExit(opt);
 	}
 
@@ -245,69 +366,72 @@ int main(int argc,char *argv[])
 	{
 		printUsageAndExit(opt);
 	}
-
 //
 // --ping-database option
 //
-
 	if (opt->getFlag("ping-database") == true)
 	{
-		if (opt->getValue("add-server") != NULL ||
-			opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --ping-database with other option(s)" << std::endl;
 
-		if (argc > 3)
-		{
-			std::cerr << "Bad argument number for option --ping-database" << std::endl;
-      printUsageAndExit(opt);
-		}
+        if(argc != 2 && argc != 3)
+        {
+            std::cerr << "Bad argument number for option --ping-database\n";
+            printUsageAndExit(opt);
+        }
 
-		if (argc == 2)
-			return ping_database(0);
-		else
-		{
-			int sec = atoi(argv[2]);
-			return ping_database(sec);
-		}
-	}
+        setenv("SUPER_TANGO", "true", 1);
+        // First sleep for 1 sec before trying to access the db
+        // This was needed when ported to Natty (Ubuntu 11.04) in the
+        // tango-db startup script. Db process did not start if tango
+        // admin starts pinging db device too early !!
+        struct timespec sleep_time{1, 0};
+        nanosleep(&sleep_time, nullptr);
 
+        if(argc == 2)
+        {
+            auto func{std::bind(ping_database)};
+            return call_func(func, MAX_TIMEOUT);
+        }
+        else
+        {
+            double timeout{};
+            const int ret{convert_string_to_double(argv[2], timeout)};
+            if(ret != 0)
+            {
+                std::cerr << "Illegal parameter provided. Please try "
+                "again!\n";
+                return -ret;
+            }
+
+            auto func{std::bind(ping_database)};
+            return call_func(func, timeout);
+        }
+    }
 //
 // --check-device option
 //
-
-
-	else if (opt->getValue("check-device") != NULL)
+	else if (opt->getValue("check-device") != nullptr)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --add-server with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 3)
-			{
-				std::cerr << "Bad argument number for option --check_device" << std::endl;
-        printUsageAndExit(opt);
-			}
+                if (argc != 3)
+                {
+                    std::cerr << "Bad argument number for option --check_device" << std::endl;
+                    printUsageAndExit(opt);
+                }
 
-			return check_device(opt->getValue("check-device"));
-		}
+                return check_device(opt->getValue("check-device"));
+	}
+
+//
+// --check-device-exported option
+//
+	else if (opt->getValue("check-device-exported") != nullptr)
+	{
+                if (argc != 3)
+                {
+                    std::cerr << "Bad argument number for option --check_device" << std::endl;
+                    printUsageAndExit(opt);
+                }
+
+                return check_device_exported(opt->getValue("check-device-exported"));
 	}
 
 //
@@ -315,29 +439,15 @@ int main(int argc,char *argv[])
 //
 
 
-	else if (opt->getValue("add-server") != NULL)
+	else if (opt->getValue("add-server") != nullptr)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --add-server with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 5)
-			{
-				std::cerr << "Bad argument number for option --add-server" << std::endl;
-				printUsageAndExit(opt);
-			}
+                if (argc != 5)
+                {
+                        std::cerr << "Bad argument number for option --add-server" << std::endl;
+                        printUsageAndExit(opt);
+                }
 
-			return add_server(opt->getValue("add-server"),opt->getArgv(0),opt->getArgv(1));
-		}
+                return add_server(opt->getValue("add-server"),opt->getArgv(0),opt->getArgv(1));
 	}
 
 //
@@ -345,29 +455,15 @@ int main(int argc,char *argv[])
 //
 
 
-	else if (opt->getValue("check-server") != NULL)
+	else if (opt->getValue("check-server") != nullptr)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --check-server with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 3)
-			{
-				std::cerr << "Bad argument number for option --check_server" << std::endl;
-        printUsageAndExit(opt);
-			}
+                    if (argc != 3)
+                    {
+                        std::cerr << "Bad argument number for option --check_server" << std::endl;
+                        printUsageAndExit(opt);
+                    }
 
-			return check_server(opt->getValue("check-server"));
-		}
+                    return check_server(opt->getValue("check-server"));
 	}
 
 //
@@ -377,26 +473,13 @@ int main(int argc,char *argv[])
 
 	else if (opt->getFlag("server-list") == true)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --server-list with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 2)
-			{
-				std::cerr << "Bad argument number for option --server-list" << std::endl;
-        printUsageAndExit(opt);
-			}
+            if (argc != 2)
+            {
+                std::cerr << "Bad argument number for option --server-list" << std::endl;
+                printUsageAndExit(opt);
+            }
 
-			return server_list();
-		}
+            return server_list();
 	}
 
 //
@@ -404,181 +487,119 @@ int main(int argc,char *argv[])
 //
 
 
-	else if (opt->getValue("server-instance-list") != NULL)
+	else if (opt->getValue("server-instance-list") != nullptr)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --server-instance-list with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 3)
-			{
-				std::cerr << "Bad argument number for option --server-instance-list" << std::endl;
-        printUsageAndExit(opt);
-			}
+            if (argc != 3)
+            {
+                std::cerr << "Bad argument number for option --server-instance-list" << std::endl;
+                printUsageAndExit(opt);
+            }
 
-			return server_instance_list(opt->getValue("server-instance-list"));
-		}
+            return server_instance_list(opt->getValue("server-instance-list"));
 	}
 
 //
 // --delete-server option
 //
 
-	else if (opt->getValue("delete-server") != NULL)
+	else if (opt->getValue("delete-server") != nullptr)
 	{
-		if (opt->getValue("add-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getValue("delete-property") != NULL)
-			std::cerr << "Can't mix option --delete-server with other option(s)" << std::endl;
-		else
-		{
-			if ((argc < 3 || argc > 4) ||
-				(argc == 3 && strcmp(argv[2],"--with-properties") == 0) ||
-				(strcmp(opt->getValue("delete-server"),"--with-properties") == 0))
-			{
-				std::cerr << "Bad option delete-server usage" << std::endl;
-        printUsageAndExit(opt);
-			}
+            if ((argc < 3 || argc > 4) ||
+                (argc == 3 && strcmp(argv[2],"--with-properties") == 0) ||
+                (strcmp(opt->getValue("delete-server"),"--with-properties") == 0))
+            {
+                std::cerr << "Bad option delete-server usage" << std::endl;
+                printUsageAndExit(opt);
+            }
 
-			if (opt->getFlag("with-properties") == true)
-				return delete_server(opt->getValue("delete-server"),true);
-			else
-				return  delete_server(opt->getValue("delete-server"),false);
-		}
+            if (opt->getFlag("with-properties") == true)
+                return delete_server(opt->getValue("delete-server"),true);
+            else
+                return  delete_server(opt->getValue("delete-server"),false);
 	}
 
 //
 // --add-property option
 //
 
-	else if (opt->getValue("add-property") != NULL)
+	else if (opt->getValue("add-property") != nullptr)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-		        opt->getFlag("with-properties") == true ||
-			opt->getFlag("tac-enabled") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("ping-database") == true)
-			std::cerr << "Can't mix option --add-property with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 5)
-			{
-				std::cerr << "Bad argument number for option --add-property" << std::endl;
-        printUsageAndExit(opt);
-			}
+                if (argc != 5)
+                {
+                    std::cerr << "Bad argument number for option --add-property" << std::endl;
+                    printUsageAndExit(opt);
+                }
 
-			return add_property(opt->getValue("add-property"),opt->getArgv(0),opt->getArgv(1));
-		}
+                return add_property(opt->getValue("add-property"),opt->getArgv(0),opt->getArgv(1));
 	}
 
 //
 // --delete-property option
 //
 
-	else if (opt->getValue("delete-property") != NULL)
+	else if (opt->getValue("delete-property") != nullptr)
 	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-		    opt->getFlag("with-properties") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-			opt->getFlag("ping-database") == true)
-			std::cerr << "Can't mix option --delete-property with other option(s)" << std::endl;
-		else
-		{
-			if (argc != 4)
-			{
-				std::cerr << "Bad argument number for option --add-property" << std::endl;
-        printUsageAndExit(opt);
-			}
+            if (argc != 4)
+            {
+                std::cerr << "Bad argument number for option --add-property" << std::endl;
+                printUsageAndExit(opt);
+            }
 
-			return delete_property(opt->getValue("delete-property"),opt->getArgv(0));
-		}
+            return delete_property(opt->getValue("delete-property"),opt->getArgv(0));
 	}
 
 //
 // --ping-network option
 //
+    if (opt->getFlag("ping-network") == true)
+    {
+        bool verbose = false;
+        if (argc > 4)
+        {
+            std::cerr << "Bad argument number for option --ping-network\n";
+            printUsageAndExit(opt);
+        }
+        else if (argc == 4)
+        {
+            if (strncmp(argv[3], "-v", 2) != 0)
+            {
+                std::cerr << "Bad argument for option --ping-network\n";
+                printUsageAndExit(opt);
+            }
+            else
+                verbose = true;
+        }
+        else if (argc == 3)
+        {
+            if (strncmp(argv[2], "-v", 2) == 0)
+            {
+                verbose = true;
+            }
 
-	if (opt->getFlag("ping-network") == true)
-	{
-		bool verbose = false;
+        }
 
-		if (opt->getValue("add-server") != NULL ||
-			opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-database") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --ping-network with other option(s)" << std::endl;
-
-		if (argc > 4)
-		{
-			std::cerr << "Bad argument number for option --ping-network" << std::endl;
-      printUsageAndExit(opt);
-		}
-		else if (argc == 4)
-		{
-			if (strcmp(argv[3],"-v") != 0)
-			{
-				std::cerr << "Bad argument for option --ping-network" << std::endl;
-        printUsageAndExit(opt);
-			}
-			else
-				verbose = true;
-		}
-		else if (argc == 3)
-		{
-			if (strcmp(argv[2],"-v") == 0)
-			{
-				verbose = true;
-			}
-		}
-
-		if (argc == 2)
-			return ping_network(0,verbose);
-		else
-		{
-			int sec = 0;
-			sec = atoi(argv[2]);
-			if ((verbose == false) && (sec == 0))
-			{
-				std::cerr << "Bad argument for option --ping-network" << std::endl;
-        printUsageAndExit(opt);
-			}
-			return ping_network(sec,verbose);
-		}
-	}
+        if (argc == 2)
+        {
+            auto func{std::bind(ping_network, verbose)};
+            return call_func(func, 0.0);
+        }
+        else
+        {
+            double timeout{};
+            const int ret{convert_string_to_double(argv[2], timeout)};
+            if(ret == 0)
+            {
+                auto func{std::bind(ping_network, verbose)};
+                return call_func(func, timeout);
+            }
+            else
+            {
+                std::cerr << "Illegal parameter provided. Please try "
+                "again!\n";
+                return -ret;
+            }
+        }
+    }
 
 //
 // --tac-enabled option
@@ -586,54 +607,35 @@ int main(int argc,char *argv[])
 
 	if (opt->getFlag("tac-enabled") == true)
 	{
-		if (opt->getValue("add-server") != NULL ||
-			opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("check-device") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --tac-enabled with other option(s)" << std::endl;
+            if (argc > 2)
+            {
+                std::cerr << "Bad argument number for option --tac-enabled" << std::endl;
+                printUsageAndExit(opt);
+            }
 
-		if (argc > 2)
-		{
-			std::cerr << "Bad argument number for option --tac-enabled" << std::endl;
-      printUsageAndExit(opt);
-		}
-
-		return tac_enabled();
-    }
+            return tac_enabled();
+        }
 
 //
 // --ping-device option
 //
 
 
-	if (opt->getValue("ping-device") != NULL)
-	{
-		if (opt->getValue("delete-server") != NULL ||
-		    opt->getValue("add-property") != NULL ||
-		    opt->getValue("delete-property") != NULL ||
-			opt->getValue("add-server") != NULL ||
-			opt->getValue("check-server") != NULL ||
-			opt->getValue("server-instance-list") != NULL ||
-			opt->getFlag("server-list") == true ||
-			opt->getFlag("ping-network") == true ||
-			opt->getFlag("tac-enabled") == true ||
-		    opt->getFlag("with-properties") == true)
-			std::cerr << "Can't mix option --ping-device with other option(s)" << std::endl;
-		else
-		{
-			if (argc == 3)
-			{
+    if (opt->getValue("ping-device") != nullptr)
+    {
+            if (argc == 3)
+            {
+                auto func{std::bind(ping_device, opt->getValue("ping-device"))};
+                return call_func(func, MAX_TIMEOUT);
+            }
+            else if (argc == 4)
+            {
                 double timeout{};
-                const int ret{convert_string_to_double(argv[2], timeout)};
+                const int ret{convert_string_to_double(argv[3], timeout)};
                 if(ret == 0)
                 {
-                    return ping_device(opt->getValue("ping-device"), timeout);
+                    auto func{std::bind(ping_device, opt->getValue("ping-device"))};
+                    return call_func(func, timeout);
                 }
                 else
                 {
@@ -647,18 +649,23 @@ int main(int argc,char *argv[])
                 std::cerr << "Bad argument number for option --ping_device" << std::endl;
                 printUsageAndExit(opt);
             }
+    }
+
+//
+// --unexport-device option
+//
+
+
+    if (opt->getValue("unexport-device") != nullptr)
+    {
+        if (argc != 3)
+        {
+            std::cerr << "Bad argument number for option --unexport-device" << std::endl;
+            printUsageAndExit(opt);
         }
-	}
 
-//
-// Unknown choice
-//
-
-	else
-	{
-		std::cerr << "Wrong usage" << std::endl;
-		printUsageAndExit(opt);
-	}
+        return unexport_device(opt->getValue("unexport-device"));
+    }
 
     return -ENOTSUP;
 }
@@ -671,78 +678,24 @@ int main(int argc,char *argv[])
 //					one of its command in order to check the database
 //					connectivity.
 //
-// argument : in : 	- nb_sec : Max time (in sec) to do re-try in case of failure
-//
-// The function returns 0 is everything is fine. Otherwise, it returns -1
+// The function returns 0 is everything is fine. Otherwise, it returns
+// -ETIMEDOUT
 //
 //--------------------------------------------------------------------------
-
-int ping_database(int nb_sec)
+int ping_database()
 {
-	setenv("SUPER_TANGO","true",1);
+    try
+    {
+        Tango::Database db;
+        const std::string db_info{db.get_info()};
+        return 0;
+    }
+    catch(const Tango::DevFailed& e)
+    {
+        // This is OK. Just try again until we reach the timeout.
+    }
 
-	int nb_loop;
-	bool infinite = false;
-
-	if (nb_sec == 0)
-		nb_loop = 1;
-	else if (nb_sec < 0)
-	{
-		infinite = true;
-		nb_loop = 2;
-	}
-	else
-		nb_loop = nb_sec << 1;
-
-
-	struct timespec ts;
-	ts.tv_sec = 0;
-	ts.tv_nsec = 500000000;
-
-//
-// First sleep for 1 sec before trying to access the db
-// This was needed when ported to Natty (Ubuntu 11.04) in the
-// tango-db startup script. Db process did not start if tango
-// admin starts pinging db device too early !!
-//
-
-	if (nb_loop != 1)
-	{
-		ts.tv_sec = 1;
-		ts.tv_nsec = 0;
-
-		nanosleep(&ts,NULL);
-	}
-
-//
-// re-try the call every 500 mS
-//
-
-	ts.tv_sec = 0;
-	ts.tv_nsec = 500000000;
-
-	while(nb_loop > 0)
-	{
-		try
-		{
-			Tango::Database db;
-
-			std::string db_info;
-			db_info = db.get_info();
-
-      return 0;
-		}
-		catch (Tango::DevFailed &e)
-		{
-			if (infinite == false)
-				--nb_loop;
-		}
-
-		if (nb_loop != 0)
-			nanosleep(&ts,NULL);
-	}
-
-	return -1;
+    return -1;
 }
 
 //+-------------------------------------------------------------------------
@@ -753,7 +706,8 @@ int ping_database(int nb_sec)
 //
 // argument : in : 	- name : The device name
 //
-// The function returns 0 is the device is defined. Otherwise, it returns -1
+// The function returns 0 is the device is defined. If we can connect to the
+// database, but it is not defined, it return 1. Otherwise, it returns -1
 //
 //--------------------------------------------------------------------------
 
@@ -768,12 +722,56 @@ int check_device(const char *name)
 	}
 	catch (Tango::DevFailed &e)
 	{
+    if (strcmp(e.errors[0].reason, "DB_DeviceNotDefined") != 0)
+    {
+      print_error("Database query failed", e.errors[0]);
+      return 1;
+    }
+
     return -1;
 	}
 
   return 0;
 }
 
+//+-------------------------------------------------------------------------
+//
+// method : 		check_device_exported
+//
+// description : 	This function checks if a device is exported in the DB
+//
+// argument : in : 	- name : The device name
+//
+// The function returns 0 is the device is defined and exported. Otherwise, it returns 1.
+// If it fails to query the database, it returns -1.
+//
+//--------------------------------------------------------------------------
+
+int check_device_exported(const char *name)
+{
+    Tango::Database db;
+    std::string d_name(name);
+
+    try
+    {
+        Tango::DbDevImportInfo dii = db.import_device(d_name);
+
+        if (dii.exported == 1)
+        {
+            return 0;
+        }
+        else
+        {
+            return 1;
+        }
+    }
+    catch (Tango::DevFailed &e)
+    {
+        print_error("Database query failed", e.errors[0]);
+        return -1;
+    }
+}
+
 //+-------------------------------------------------------------------------
 //
 // method : 		add_server
@@ -1255,132 +1253,70 @@ void list2vect(std::string &dev_list,std::vector<std::string> &dev_names)
 //
 // method : 		ping_network
 //
-// description : 	This function periodically chechs the network avaibility
+// description : 	This function checks the network avaibility.
 //
-// argument : in : 	- nb_sec : Max time (in sec) to do re-try in case of failure
-//					- verbose : Boolean flag set to true if some printing is required
-//
-// The function returns 0 is everything is fine. Otherwise, it returns -1
+// Parameter
+//      verbose: Boolean flag set to true if some printing is required
 //
+// The function returns 0 on success, -1 otherwise.
 //--------------------------------------------------------------------------
-
-int ping_network(int nb_sec,bool verbose)
+int ping_network(bool verbose)
 {
-	int nb_loop;
-	bool infinite = false;
+    char buffer[80]{};
+    std::string hostname;
 
-	if (nb_sec == 0)
-		nb_loop = 1;
-	else if (nb_sec < 0)
-	{
-		infinite = true;
-		nb_loop = 2;
-	}
-	else
-		nb_loop = nb_sec << 1;
+    if (gethostname(buffer,80) == 0)
+    {
+        hostname = buffer;
+        if (verbose == true)
+            std::cout << "Host name returned by gethostname function: " << hostname << std::endl;
 
-//
-// re-try the call every 500 mS
-//
+        struct addrinfo hints{};
+        hints.ai_flags     = AI_ADDRCONFIG;
+        hints.ai_family    = AF_INET;
+        hints.ai_socktype  = SOCK_STREAM;
 
-	struct timespec ts;
-	ts.tv_sec = 0;
-	ts.tv_nsec = 500000000;
+        struct addrinfo	*info{};
+        struct addrinfo *ptr{};
+        char tmp_host[512]{};
+        int result;
 
-	while(nb_loop > 0)
-	{
+        result = getaddrinfo(buffer, nullptr, &hints, &info);
 
-		int res = check_net(verbose);
-		if (res == 0)
-		{
-      return 0;
-		}
+        if (result == 0)
+        {
+            ptr = info;
+            if (verbose == true)
+                std::cout << "getaddrinfo() is a success" << std::endl;
+            while (ptr != nullptr)
+            {
+                if (getnameinfo(ptr->ai_addr,ptr->ai_addrlen,tmp_host,512,0,0,0) != 0)
+                {
+                    if (verbose == true)
+                        std::cout << "getnameinfo() call failed" << std::endl;
+                    return -1;
+                }
+                if (verbose == true)
+                    std::cout << "Host name as returned by getnameinfo call: " << tmp_host << std::endl;
+                ptr = ptr->ai_next;
+            };
 
-    if (infinite == false)
-				--nb_loop;
+            freeaddrinfo(info);
+        }
+        else
+        {
+            if (verbose == true)
+                std::cout << "getaddrinfo() call failed with returned value = " << result << std::endl;
+            return -1;
+        }
+    }
+    else
+    {
+        std::cerr << "Cant retrieve server host name" << std::endl;
+        return -1;
+    }
 
-		if (nb_loop != 0)
-			nanosleep(&ts,NULL);
-	}
-
-	return -1;
-}
-
-//+-------------------------------------------------------------------------
-//
-// method : 		check_net
-//
-// description : 	This function connect to the network and check if it is
-//					fully ready.
-//
-// argument : in : 	- verbose : Flag set to true if some printing is required
-//
-// The function returns 0 is everything is fine. Otherwise, it returns -1
-//
-//--------------------------------------------------------------------------
-
-int check_net(bool verbose)
-{
-	char buffer[80];
-	std::string hostname;
-
-	if (gethostname(buffer,80) == 0)
-	{
-		hostname = buffer;
-		if (verbose == true)
-			std::cout << "Host name returned by gethostname function: " << hostname << std::endl;
-
-  		struct addrinfo hints;
-
-		memset(&hints,0,sizeof(struct addrinfo));
-
-  		hints.ai_flags     = AI_ADDRCONFIG;
-
-  		hints.ai_family    = AF_INET;
-  		hints.ai_socktype  = SOCK_STREAM;
-
-  		struct addrinfo	*info;
-		struct addrinfo *ptr;
-		char tmp_host[512];
-		int result;
-
-  		result = getaddrinfo(buffer, NULL, &hints, &info);
-
-		if (result == 0)
-		{
-			ptr = info;
-			if (verbose == true)
-				std::cout << "getaddrinfo() is a success" << std::endl;
-			while (ptr != NULL)
-			{
-    			if (getnameinfo(ptr->ai_addr,ptr->ai_addrlen,tmp_host,512,0,0,0) != 0)
-				{
-					if (verbose == true)
-						std::cout << "getnameinfo() call failed" << std::endl;
-          return -1;
-				}
-				if (verbose == true)
-					std::cout << "Host name as returned by getnameinfo call: " << tmp_host << std::endl;
-				ptr = ptr->ai_next;
-			}
-
-			freeaddrinfo(info);
-		}
-		else
-		{
-			if (verbose == true)
-				std::cout << "getaddrinfo() call failed with returned value = " << result << std::endl;
-
-      return -1;
-		}
-	}
-	else
-	{
-		std::cerr << "Cant retrieve server host name" << std::endl;
-    return -1;
-	}
-
-	return 0;
+    return 0;
 }
 
 //+-------------------------------------------------------------------------
@@ -1421,68 +1357,62 @@ int tac_enabled(void)
 //
 // method : 		ping_device
 //
-// description : 	This function periodically checks a device's avaibility
+// description : 	This function checks a device's avaibility
 //
-// argument : in : 	- timeout_in_s : Max time (in fractional seconds) to do re-try in case of failure
-//					- dev_name : The device name
+// Parameter dev_name: The device name
 //
-// return:  0 on sucess
-//          -ETIMEDOUT if device did not respond within time out
-//          negative errno returned bycompute_loops_and_sleep_time
+// return:  0 on sucess, -1 otherwise.
 //
 //--------------------------------------------------------------------------
-int ping_device(const std::string &dev_name, double timeout_in_s)
+int ping_device(const std::string &dev_name)
 {
-    unsigned int loops;
-    struct timespec sleep_time{};
-    auto err{compute_loops_and_sleep_time(timeout_in_s, loops, sleep_time)};
-    if(err != 0)
+    try
     {
-        return err;
+        Tango::DeviceProxy dev(dev_name.c_str());
+        dev.ping();
+    }
+    catch (Tango::DevFailed &e)
+    {
+        return -1;
     }
 
-    const double sleep_time_in_s{(sleep_time.tv_sec * 1e9 + sleep_time.tv_nsec) / 1e9};
-
-    while((loops > 0U) && (timeout_in_s > 0.0))
-    {
-        if(check_dev(dev_name.c_str()) == 0)
-        {
-            return 0;
-        }
-
-        nanosleep(&sleep_time, nullptr);
-        timeout_in_s -= sleep_time_in_s;
-        --loops;
-    };
-
-    return -ETIMEDOUT;
+    return 0;
 }
 
 //+-------------------------------------------------------------------------
 //
-// method : 		check_dev
+// method : 		unexport_device
 //
-// description : 	This function connect to a device and try to ping it
+// description : 	Unexport a device from the database
 //
-// argument : in : 	- dev_name : The device name
+// Parameter dev_name: The device name
 //
-// The function returns 0 is everything is fine. Otherwise, it returns -1
+// return:  0 on success, -1 otherwise.
 //
 //--------------------------------------------------------------------------
-
-int check_dev(const char *dev_name)
+int unexport_device(const char *dev_name)
 {
-	try
-	{
-		Tango::DeviceProxy dev(dev_name);
+    int ret = check_device(dev_name);
+    if (ret != 0)
+    {
+        if (ret == 1)
+        {
+            std::cerr << "Device \"" << dev_name << "\" not defined in the database. Cannot unexport.\n";
+        }
+        return -1;
+    }
 
-		dev.ping();
-	}
-	catch (Tango::DevFailed &e)
-	{
-		return -1;
-	}
+    Tango::Database db;
 
-	return 0;
+    try
+    {
+        db.unexport_device(dev_name);
+    }
+    catch (Tango::DevFailed &e)
+    {
+        print_error("Unexport device failed", e.errors[0]);
+        return -1;
+    }
 
+    return 0;
 }
